@@ -384,7 +384,7 @@ define([
 						tree.dndController.removeTreeNode(node);
 
 						// Deregister mapping from item id --> this node and its descendants
-						function remove(node){
+						var remove = function remove(node){
 							var id = model.getIdentity(node.item),
 								ary = tree._itemNodesMap[id];
 							if(ary.length == 1){
@@ -396,7 +396,7 @@ define([
 								}
 							}
 							array.forEach(node.getChildren(), remove);
-						}
+						};
 
 						remove(node);
 
@@ -1572,7 +1572,7 @@ define([
 			// tags:
 			//		protected
                         var tmp = [];
-                        for(var domNode = this.domNode; 
+                        for(var domNode = this.domNode;
                             domNode && domNode.tagName && domNode.tagName.toUpperCase() !== 'IFRAME';
                             domNode = domNode.parentNode) {
                             tmp.push({
