@@ -12,17 +12,23 @@ define(
 	"field-tue-narrow-relative+0": "الثلاثاء الحالي",
 	"field-tue-narrow-relative+1": "الثلاثاء القادم",
 	"field-thu-short-relative+0": "الخميس الحالي",
+	"field-day-short-relative+-1": "أمس",
+	"dateTimeFormat-short": "{1} في {0}",
 	"field-thu-short-relative+1": "الخميس القادم",
 	"field-day-relative+0": "اليوم",
+	"field-day-short-relative+-2": "أول أمس",
 	"field-day-relative+1": "غدًا",
 	"field-day-relative+2": "بعد الغد",
 	"field-wed-narrow-relative+-1": "الأربعاء الماضي",
 	"field-year-narrow": "السنة",
+	"field-era-short": "العصر",
 	"field-tue-relative+0": "الثلاثاء الحالي",
 	"field-tue-relative+1": "الثلاثاء القادم",
+	"field-weekdayOfMonth": "يوم عمل من الشهر",
 	"field-second-short": "الثواني",
 	"dayPeriods-format-narrow-am": "ص",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "يوم عمل/شهر",
 	"dayPeriods-format-abbr-am": "ص",
 	"field-week-relative+0": "هذا الأسبوع",
 	"field-month-relative+0": "هذا الشهر",
@@ -30,7 +36,7 @@ define(
 	"field-month-relative+1": "الشهر القادم",
 	"field-sun-narrow-relative+0": "الأحد الحالي",
 	"timeFormat-medium": "h:mm:ss a",
-	"field-mon-short-relative+0": "الاثنين الحالي",
+	"field-mon-short-relative+0": "الإثنين الحالي",
 	"field-sun-narrow-relative+1": "الأحد القادم",
 	"field-mon-short-relative+1": "الإثنين القادم",
 	"field-second-relative+0": "الآن",
@@ -38,17 +44,20 @@ define(
 	"eraNames": [
 		"ص"
 	],
+	"field-weekOfMonth": "الأسبوع من الشهر",
 	"dayPeriods-standAlone-abbr-pm": "م",
 	"field-month-short": "الشهر",
-	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
+	"dateFormatItem-GyMMMEd": "E، d MMM y G",
 	"dateFormatItem-yyyyMd": "d/M/y G",
 	"field-day": "يوم",
+	"field-dayOfYear-short": "يوم من سنة",
 	"field-year-relative+-1": "السنة الماضية",
 	"dayPeriods-format-wide-am": "ص",
 	"field-sat-short-relative+-1": "السبت الماضي",
 	"field-hour-relative+0": "الساعة الحالية",
 	"dateFormatItem-yyyyMEd": "E، d/M/y G",
 	"field-wed-relative+-1": "الأربعاء الماضي",
+	"dateTimeFormat-medium": "{1} في {0}",
 	"field-sat-narrow-relative+-1": "السبت الماضي",
 	"field-second": "الثواني",
 	"days-standAlone-narrow": [
@@ -61,10 +70,13 @@ define(
 		"س"
 	],
 	"dayPeriods-standAlone-wide-pm": "مساءً",
-	"dateFormat-long": "d MMMM، y G",
-	"dateFormatItem-GyMMMd": "d MMM، y G",
+	"dateFormat-long": "d MMMM y G",
+	"dateFormatItem-GyMMMd": "d MMM y G",
 	"field-quarter": "ربع السنة",
 	"field-week-short": "الأسبوع",
+	"field-day-narrow-relative+0": "اليوم",
+	"field-day-narrow-relative+1": "غدًا",
+	"field-day-narrow-relative+2": "بعد الغد",
 	"quarters-standAlone-wide": [
 		"الربع الأول",
 		"الربع الثاني",
@@ -82,7 +94,7 @@ define(
 	],
 	"field-tue-short-relative+0": "الثلاثاء الحالي",
 	"field-tue-short-relative+1": "الثلاثاء القادم",
-	"field-mon-relative+-1": "الاثنين الماضي",
+	"field-mon-relative+-1": "الإثنين الماضي",
 	"dateFormatItem-GyMMM": "MMM y G",
 	"field-month": "الشهر",
 	"field-day-narrow": "يوم",
@@ -92,7 +104,7 @@ define(
 	"field-sat-short-relative+1": "السبت القادم",
 	"dayPeriods-format-narrow-pm": "م",
 	"dateFormat-medium": "dd‏/MM‏/y G",
-	"dateFormatItem-yyyyMMMM": "MMMM، y G",
+	"dateFormatItem-yyyyMMMM": "MMMM y G",
 	"eraAbbr": [
 		"ص"
 	],
@@ -105,20 +117,23 @@ define(
 	"dayPeriods-format-abbr-pm": "م",
 	"dateFormatItem-yyyyM": "M/y G",
 	"field-second-narrow": "الثواني",
-	"field-mon-relative+0": "الاثنين الحالي",
-	"field-mon-relative+1": "الاثنين القادم",
+	"field-mon-relative+0": "الإثنين الحالي",
+	"field-mon-relative+1": "الإثنين القادم",
+	"field-day-narrow-relative+-1": "أمس",
 	"field-year-short": "السنة",
+	"field-day-narrow-relative+-2": "أول أمس",
 	"field-quarter-relative+-1": "الربع الأخير",
-	"dateFormatItem-yyyyMMMd": "d MMM، y G",
+	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "ص/م",
 	"dayPeriods-standAlone-narrow-am": "ص",
 	"days-format-short": [
-		"الأحد",
-		"الاثنين",
-		"الثلاثاء",
-		"الأربعاء",
-		"الخميس",
-		"الجمعة",
-		"السبت"
+		"أحد",
+		"إثنين",
+		"ثلاثاء",
+		"أربعاء",
+		"خميس",
+		"جمعة",
+		"سبت"
 	],
 	"quarters-format-narrow": [
 		"١",
@@ -127,7 +142,9 @@ define(
 		"٤"
 	],
 	"dayPeriods-format-wide-pm": "م",
+	"field-dayOfYear": "يوم من السنة",
 	"field-sat-relative+-1": "السبت الماضي",
+	"dateTimeFormat-long": "{1} في {0}",
 	"dateFormatItem-Md": "d/M",
 	"field-hour": "الساعات",
 	"months-format-wide": [
@@ -145,7 +162,7 @@ define(
 		"آب",
 		"أيلول"
 	],
-	"dateFormat-full": "EEEE، d MMMM، y G",
+	"dateFormat-full": "EEEE، d MMMM y G",
 	"field-month-relative+-1": "الشهر الماضي",
 	"field-quarter-short": "ربع السنة",
 	"field-sat-narrow-relative+0": "السبت الحالي",
@@ -187,11 +204,12 @@ define(
 		"الجمعة",
 		"السبت"
 	],
-	"dateFormatItem-yyyyMMMEd": "E، d MMM، y G",
+	"dateFormatItem-yyyyMMMEd": "E، d MMM y G",
 	"field-mon-narrow-relative+-1": "الإثنين الماضي",
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "الخميس الماضي",
 	"field-tue-narrow-relative+-1": "الثلاثاء الماضي",
+	"field-weekOfMonth-short": "أسبوع من شهر",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "م",
 	"field-wed-short-relative+0": "الأربعاء الحالي",
@@ -221,12 +239,16 @@ define(
 		"الجمعة",
 		"السبت"
 	],
+	"dateTimeFormat-full": "{1} في {0}",
 	"months-format-abbr-leap": "آذار الثاني",
 	"field-weekday": "اليوم",
+	"field-day-short-relative+0": "اليوم",
 	"field-quarter-narrow-relative+0": "هذا الربع",
 	"field-sat-relative+0": "السبت الحالي",
+	"field-day-short-relative+1": "غدًا",
 	"field-quarter-narrow-relative+1": "الربع القادم",
 	"field-sat-relative+1": "السبت القادم",
+	"field-day-short-relative+2": "بعد الغد",
 	"months-standAlone-abbr": [
 		"تشري",
 		"مرحشوان",
@@ -243,13 +265,16 @@ define(
 		"أيلول"
 	],
 	"months-format-wide-leap": "آذار الثاني",
+	"field-dayOfYear-narrow": "يوم/سنة",
+	"field-weekdayOfMonth-short": "يوم عمل من شهر",
 	"timeFormat-full": "h:mm:ss a zzzz",
 	"dateFormatItem-MEd": "E، d/M",
+	"field-zone-narrow": "توقيت",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "الخميس الحالي",
 	"field-thu-narrow-relative+1": "الخميس القادم",
 	"field-sun-narrow-relative+-1": "الأحد الماضي",
-	"field-mon-short-relative+-1": "الاثنين الماضي",
+	"field-mon-short-relative+-1": "الإثنين الماضي",
 	"field-thu-relative+0": "الخميس الحالي",
 	"field-thu-relative+1": "الخميس القادم",
 	"field-fri-short-relative+-1": "الجمعة الماضي",
@@ -271,21 +296,23 @@ define(
 	"field-wed-narrow-relative+0": "الأربعاء الحالي",
 	"field-wed-narrow-relative+1": "الأربعاء القادم",
 	"field-quarter-narrow-relative+-1": "الربع الأخير",
-	"dateFormatItem-yyyyMMM": "MMM، y G",
+	"field-dayperiod-short": "ص/م",
+	"dateFormatItem-yyyyMMM": "MMM y G",
 	"field-fri-short-relative+0": "الجمعة الحالي",
 	"field-fri-short-relative+1": "الجمعة القادم",
 	"days-standAlone-short": [
-		"الأحد",
-		"الاثنين",
-		"الثلاثاء",
-		"الأربعاء",
-		"الخميس",
-		"الجمعة",
-		"السبت"
+		"أحد",
+		"إثنين",
+		"ثلاثاء",
+		"أربعاء",
+		"خميس",
+		"جمعة",
+		"سبت"
 	],
 	"months-standAlone-abbr-leap": "آذار الثاني",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "الساعات",
+	"field-zone-short": "توقيت",
 	"quarters-format-abbr": [
 		"الربع الأول",
 		"الربع الثاني",
@@ -297,6 +324,7 @@ define(
 	"field-fri-narrow-relative+-1": "الجمعة الماضي",
 	"field-year-relative+0": "السنة الحالية",
 	"field-year-relative+1": "السنة القادمة",
+	"field-era-narrow": "العصر",
 	"field-fri-relative+-1": "الجمعة الماضي",
 	"eraNarrow": [
 		"ص"
@@ -316,12 +344,15 @@ define(
 	"field-mon-narrow-relative+1": "الإثنين القادم",
 	"field-zone": "التوقيت",
 	"dateFormatItem-MMMEd": "E، d MMM",
+	"field-weekOfMonth-narrow": "أسبوع/شهر",
+	"field-weekday-narrow": "اليوم",
 	"months-standAlone-wide-leap": "آذار الثاني",
 	"field-quarter-narrow": "ربع السنة",
 	"field-sun-short-relative+-1": "الأحد الماضي",
 	"field-day-relative+-1": "أمس",
 	"dayPeriods-standAlone-abbr-am": "ص",
 	"field-day-relative+-2": "أول أمس",
+	"field-weekday-short": "اليوم",
 	"days-format-abbr": [
 		"الأحد",
 		"الاثنين",
