@@ -5,6 +5,7 @@ define(
 	"field-quarter-short-relative+1": "الربع القادم",
 	"field-tue-relative+-1": "الثلاثاء الماضي",
 	"field-year": "السنة",
+	"dateFormatItem-Hm": "HH:mm",
 	"field-wed-relative+0": "الأربعاء الحالي",
 	"field-wed-relative+1": "الأربعاء القادم",
 	"timeFormat-short": "h:mm a",
@@ -12,17 +13,24 @@ define(
 	"field-tue-narrow-relative+0": "الثلاثاء الحالي",
 	"field-tue-narrow-relative+1": "الثلاثاء القادم",
 	"field-thu-short-relative+0": "الخميس الحالي",
+	"field-day-short-relative+-1": "أمس",
+	"dateTimeFormat-short": "{1} في {0}",
 	"field-thu-short-relative+1": "الخميس القادم",
 	"field-day-relative+0": "اليوم",
+	"field-day-short-relative+-2": "أول أمس",
 	"field-day-relative+1": "غدًا",
 	"field-day-relative+2": "بعد الغد",
 	"field-wed-narrow-relative+-1": "الأربعاء الماضي",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
 	"field-year-narrow": "السنة",
+	"field-era-short": "العصر",
 	"field-tue-relative+0": "الثلاثاء الحالي",
 	"field-tue-relative+1": "الثلاثاء القادم",
+	"field-weekdayOfMonth": "يوم عمل من الشهر",
 	"field-second-short": "الثواني",
 	"dayPeriods-format-narrow-am": "ص",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "يوم عمل/شهر",
 	"dayPeriods-format-abbr-am": "ص",
 	"field-week-relative+0": "هذا الأسبوع",
 	"field-month-relative+0": "هذا الشهر",
@@ -30,7 +38,7 @@ define(
 	"field-month-relative+1": "الشهر القادم",
 	"field-sun-narrow-relative+0": "الأحد الحالي",
 	"timeFormat-medium": "h:mm:ss a",
-	"field-mon-short-relative+0": "الاثنين الحالي",
+	"field-mon-short-relative+0": "الإثنين الحالي",
 	"field-sun-narrow-relative+1": "الأحد القادم",
 	"field-mon-short-relative+1": "الإثنين القادم",
 	"field-second-relative+0": "الآن",
@@ -52,17 +60,20 @@ define(
 	"eraNames": [
 		"هـ"
 	],
+	"field-weekOfMonth": "الأسبوع من الشهر",
 	"dayPeriods-standAlone-abbr-pm": "م",
 	"field-month-short": "الشهر",
-	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
+	"dateFormatItem-GyMMMEd": "E، d MMM y G",
 	"dateFormatItem-yyyyMd": "d‏/M‏/y G",
 	"field-day": "يوم",
+	"field-dayOfYear-short": "يوم من سنة",
 	"field-year-relative+-1": "السنة الماضية",
 	"dayPeriods-format-wide-am": "ص",
 	"field-sat-short-relative+-1": "السبت الماضي",
 	"field-hour-relative+0": "الساعة الحالية",
 	"dateFormatItem-yyyyMEd": "E، d/‏M/‏y G",
 	"field-wed-relative+-1": "الأربعاء الماضي",
+	"dateTimeFormat-medium": "{1} في {0}",
 	"field-sat-narrow-relative+-1": "السبت الماضي",
 	"field-second": "الثواني",
 	"days-standAlone-narrow": [
@@ -75,10 +86,14 @@ define(
 		"س"
 	],
 	"dayPeriods-standAlone-wide-pm": "مساءً",
-	"dateFormat-long": "d MMMM، y G",
-	"dateFormatItem-GyMMMd": "d MMM، y G",
+	"dateFormatItem-Ehms": "E h:mm:ss a",
+	"dateFormat-long": "d MMMM y G",
+	"dateFormatItem-GyMMMd": "d MMM y G",
 	"field-quarter": "ربع السنة",
 	"field-week-short": "الأسبوع",
+	"field-day-narrow-relative+0": "اليوم",
+	"field-day-narrow-relative+1": "غدًا",
+	"field-day-narrow-relative+2": "بعد الغد",
 	"quarters-standAlone-wide": [
 		"الربع الأول",
 		"الربع الثاني",
@@ -96,7 +111,7 @@ define(
 	],
 	"field-tue-short-relative+0": "الثلاثاء الحالي",
 	"field-tue-short-relative+1": "الثلاثاء القادم",
-	"field-mon-relative+-1": "الاثنين الماضي",
+	"field-mon-relative+-1": "الإثنين الماضي",
 	"dateFormatItem-GyMMM": "MMM y G",
 	"field-month": "الشهر",
 	"field-day-narrow": "يوم",
@@ -106,8 +121,8 @@ define(
 	"field-sat-short-relative+0": "السبت الحالي",
 	"field-sat-short-relative+1": "السبت القادم",
 	"dayPeriods-format-narrow-pm": "م",
-	"dateFormat-medium": "d MMM، y G",
-	"dateFormatItem-yyyyMMMM": "MMMM، y G",
+	"dateFormat-medium": "d MMM y G",
+	"dateFormatItem-yyyyMMMM": "MMMM y G",
 	"eraAbbr": [
 		"هـ"
 	],
@@ -120,9 +135,11 @@ define(
 	"dayPeriods-format-abbr-pm": "م",
 	"dateFormatItem-yyyyM": "M‏/y G",
 	"field-second-narrow": "الثواني",
-	"field-mon-relative+0": "الاثنين الحالي",
-	"field-mon-relative+1": "الاثنين القادم",
+	"field-mon-relative+0": "الإثنين الحالي",
+	"field-mon-relative+1": "الإثنين القادم",
+	"field-day-narrow-relative+-1": "أمس",
 	"field-year-short": "السنة",
+	"field-day-narrow-relative+-2": "أول أمس",
 	"months-format-narrow": [
 		"١",
 		"٢",
@@ -138,16 +155,17 @@ define(
 		"١٢"
 	],
 	"field-quarter-relative+-1": "الربع الأخير",
-	"dateFormatItem-yyyyMMMd": "d MMM، y G",
+	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "ص/م",
 	"dayPeriods-standAlone-narrow-am": "ص",
 	"days-format-short": [
-		"الأحد",
-		"الاثنين",
-		"الثلاثاء",
-		"الأربعاء",
-		"الخميس",
-		"الجمعة",
-		"السبت"
+		"أحد",
+		"إثنين",
+		"ثلاثاء",
+		"أربعاء",
+		"خميس",
+		"جمعة",
+		"سبت"
 	],
 	"quarters-format-narrow": [
 		"١",
@@ -156,7 +174,9 @@ define(
 		"٤"
 	],
 	"dayPeriods-format-wide-pm": "م",
+	"field-dayOfYear": "يوم من السنة",
 	"field-sat-relative+-1": "السبت الماضي",
+	"dateTimeFormat-long": "{1} في {0}",
 	"dateFormatItem-Md": "d/‏M",
 	"field-hour": "الساعات",
 	"months-format-wide": [
@@ -173,17 +193,20 @@ define(
 		"ذو القعدة",
 		"ذو الحجة"
 	],
-	"dateFormat-full": "EEEE، d MMMM، y G",
+	"dateFormat-full": "EEEE، d MMMM y G",
 	"field-month-relative+-1": "الشهر الماضي",
+	"dateFormatItem-Hms": "HH:mm:ss",
 	"field-quarter-short": "ربع السنة",
 	"field-sat-narrow-relative+0": "السبت الحالي",
 	"field-fri-relative+0": "الجمعة الحالي",
 	"field-sat-narrow-relative+1": "السبت القادم",
 	"field-fri-relative+1": "الجمعة القادم",
+	"dateFormatItem-EBhm": "E h:mm B",
 	"field-sun-short-relative+0": "الأحد الحالي",
 	"field-sun-short-relative+1": "الأحد القادم",
 	"field-week-relative+-1": "الأسبوع الماضي",
 	"field-quarter-short-relative+-1": "الربع الأخير",
+	"dateFormatItem-Ehm": "E h:mm a",
 	"months-format-abbr": [
 		"محرم",
 		"صفر",
@@ -204,6 +227,7 @@ define(
 	"field-quarter-relative+1": "الربع القادم",
 	"field-wed-short-relative+-1": "الأربعاء الماضي",
 	"dateFormat-short": "d‏/M‏/y GGGGG",
+	"dateFormatItem-Bh": "h B",
 	"field-thu-short-relative+-1": "الخميس الماضي",
 	"days-standAlone-wide": [
 		"الأحد",
@@ -214,15 +238,16 @@ define(
 		"الجمعة",
 		"السبت"
 	],
-	"dateFormatItem-yyyyMMMEd": "E، d MMM، y G",
+	"dateFormatItem-yyyyMMMEd": "E، d MMM y G",
 	"field-mon-narrow-relative+-1": "الإثنين الماضي",
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "الخميس الماضي",
 	"dateFormatItem-E": "ccc",
 	"field-tue-narrow-relative+-1": "الثلاثاء الماضي",
+	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "أسبوع من شهر",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "م",
-	"field-wed-short-relative+0": "الأربعاء الحالي",
 	"dateFormatItem-M": "L",
 	"months-standAlone-wide": [
 		"محرم",
@@ -238,6 +263,7 @@ define(
 		"ذو القعدة",
 		"ذو الحجة"
 	],
+	"field-wed-short-relative+0": "الأربعاء الحالي",
 	"field-wed-short-relative+1": "الأربعاء القادم",
 	"field-sun-relative+-1": "الأحد الماضي",
 	"days-standAlone-abbr": [
@@ -249,11 +275,17 @@ define(
 		"الجمعة",
 		"السبت"
 	],
+	"dateTimeFormat-full": "{1} في {0}",
+	"dateFormatItem-hm": "h:mm a",
 	"dateFormatItem-d": "d",
 	"field-weekday": "اليوم",
+	"field-day-short-relative+0": "اليوم",
 	"field-quarter-narrow-relative+0": "هذا الربع",
+	"field-day-short-relative+1": "غدًا",
 	"field-sat-relative+0": "السبت الحالي",
 	"field-quarter-narrow-relative+1": "الربع القادم",
+	"dateFormatItem-h": "h a",
+	"field-day-short-relative+2": "بعد الغد",
 	"field-sat-relative+1": "السبت القادم",
 	"months-standAlone-abbr": [
 		"محرم",
@@ -269,15 +301,19 @@ define(
 		"ذو القعدة",
 		"ذو الحجة"
 	],
+	"field-dayOfYear-narrow": "يوم/سنة",
+	"field-weekdayOfMonth-short": "يوم عمل من شهر",
 	"timeFormat-full": "h:mm:ss a zzzz",
-	"dateFormatItem-MEd": "E، d/M",
+	"dateFormatItem-MEd": "E، d/‏M",
+	"field-zone-narrow": "توقيت",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "الخميس الحالي",
-	"field-thu-narrow-relative+1": "الخميس القادم",
 	"field-sun-narrow-relative+-1": "الأحد الماضي",
-	"field-mon-short-relative+-1": "الاثنين الماضي",
+	"field-mon-short-relative+-1": "الإثنين الماضي",
+	"field-thu-narrow-relative+1": "الخميس القادم",
 	"field-thu-relative+0": "الخميس الحالي",
 	"field-thu-relative+1": "الخميس القادم",
+	"dateFormatItem-hms": "h:mm:ss a",
 	"field-fri-short-relative+-1": "الجمعة الماضي",
 	"field-thu-relative+-1": "الخميس الماضي",
 	"field-week": "الأسبوع",
@@ -297,20 +333,22 @@ define(
 	"field-wed-narrow-relative+0": "الأربعاء الحالي",
 	"field-wed-narrow-relative+1": "الأربعاء القادم",
 	"field-quarter-narrow-relative+-1": "الربع الأخير",
-	"dateFormatItem-yyyyMMM": "MMM، y G",
+	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "ص/م",
 	"field-fri-short-relative+0": "الجمعة الحالي",
 	"field-fri-short-relative+1": "الجمعة القادم",
 	"days-standAlone-short": [
-		"الأحد",
-		"الاثنين",
-		"الثلاثاء",
-		"الأربعاء",
-		"الخميس",
-		"الجمعة",
-		"السبت"
+		"أحد",
+		"إثنين",
+		"ثلاثاء",
+		"أربعاء",
+		"خميس",
+		"جمعة",
+		"سبت"
 	],
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "الساعات",
+	"field-zone-short": "توقيت",
 	"quarters-format-abbr": [
 		"الربع الأول",
 		"الربع الثاني",
@@ -322,10 +360,12 @@ define(
 	"field-fri-narrow-relative+-1": "الجمعة الماضي",
 	"field-year-relative+0": "السنة الحالية",
 	"field-year-relative+1": "السنة القادمة",
+	"field-era-narrow": "العصر",
 	"field-fri-relative+-1": "الجمعة الماضي",
 	"eraNarrow": [
 		"هـ"
 	],
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"field-tue-short-relative+-1": "الثلاثاء الماضي",
 	"field-minute-narrow": "الدقائق",
 	"days-format-wide": [
@@ -338,14 +378,20 @@ define(
 		"السبت"
 	],
 	"field-mon-narrow-relative+0": "الإثنين الحالي",
+	"dateFormatItem-EHm": "E HH:mm",
 	"field-mon-narrow-relative+1": "الإثنين القادم",
 	"field-zone": "التوقيت",
 	"dateFormatItem-MMMEd": "E، d MMM",
+	"field-weekOfMonth-narrow": "أسبوع/شهر",
+	"dateFormatItem-EHms": "E HH:mm:ss",
+	"field-weekday-narrow": "اليوم",
 	"field-quarter-narrow": "ربع السنة",
 	"field-sun-short-relative+-1": "الأحد الماضي",
 	"field-day-relative+-1": "أمس",
 	"dayPeriods-standAlone-abbr-am": "ص",
 	"field-day-relative+-2": "أول أمس",
+	"field-weekday-short": "اليوم",
+	"dateFormatItem-Bhm": "h:mm B",
 	"days-format-abbr": [
 		"الأحد",
 		"الاثنين",
