@@ -17,11 +17,15 @@ define(
 	"field-day-relative+1": "sutra",
 	"field-day-relative+2": "prekosutra",
 	"field-wed-narrow-relative+-1": "prošla sri.",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
 	"field-year-narrow": "g.",
+	"field-era-short": "era",
 	"field-tue-relative+0": "ovaj utorak",
 	"field-tue-relative+1": "sljedeći utorak",
+	"field-weekdayOfMonth": "dan u mjesecu",
 	"field-second-short": "sek.",
 	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "d. u mj.",
 	"field-week-relative+0": "ove sedmice",
 	"field-month-relative+0": "ovaj mjesec",
 	"field-week-relative+1": "sljedeće sedmice",
@@ -32,10 +36,12 @@ define(
 	"field-mon-short-relative+1": "sljedeći pon",
 	"field-second-relative+0": "sada",
 	"dateFormatItem-yyyyQQQ": "G y QQQ",
+	"field-weekOfMonth": "sedmica u mjesecu",
 	"field-month-short": "mj.",
 	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
 	"dateFormatItem-yyyyMd": "d.M.y. G",
 	"field-day": "dan",
+	"field-dayOfYear-short": "dan u god.",
 	"field-year-relative+-1": "prošle godine",
 	"field-sat-short-relative+-1": "prošla sub.",
 	"field-hour-relative+0": "ovaj sat",
@@ -44,6 +50,7 @@ define(
 	"dateTimeFormat-medium": "{1}, {0}",
 	"field-sat-narrow-relative+-1": "prošla sub.",
 	"field-second": "sekunda",
+	"dateFormatItem-Ehms": "E h:mm:ss a",
 	"dateFormat-long": "dd. MMMM y. G",
 	"dateFormatItem-GyMMMd": "d. MMM y. G",
 	"field-quarter": "kvartal",
@@ -68,6 +75,8 @@ define(
 	"field-year-short": "god.",
 	"field-quarter-relative+-1": "posljednji kvartal",
 	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
+	"field-dayperiod-narrow": "prijepodne/poslijepodne",
+	"field-dayOfYear": "dan u godini",
 	"field-sat-relative+-1": "prošla subota",
 	"dateTimeFormat-long": "{1} 'u' {0}",
 	"dateFormatItem-Md": "d.M.",
@@ -80,14 +89,17 @@ define(
 	"field-fri-relative+0": "ovaj petak",
 	"field-sat-narrow-relative+1": "sljedeća sub.",
 	"field-fri-relative+1": "sljedeći petak",
+	"dateFormatItem-EBhm": "E h:mm B",
 	"field-sun-short-relative+0": "ova ned.",
 	"field-sun-short-relative+1": "sljedeća ned.",
 	"field-week-relative+-1": "prošle sedmice",
+	"dateFormatItem-Ehm": "E h:mm a",
 	"field-quarter-relative+0": "ovaj kvartal",
 	"field-minute-relative+0": "ova minuta",
 	"field-quarter-relative+1": "sljedeći kvartal",
 	"field-wed-short-relative+-1": "prošla sri.",
 	"dateFormat-short": "dd.MM.y. GGGGG",
+	"dateFormatItem-Bh": "h B",
 	"field-thu-short-relative+-1": "prošli čet.",
 	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
 	"field-mon-narrow-relative+-1": "prošli pon.",
@@ -95,6 +107,8 @@ define(
 	"field-thu-narrow-relative+-1": "prošli čet.",
 	"dateFormatItem-E": "ccc",
 	"field-tue-narrow-relative+-1": "prošli uto.",
+	"dateFormatItem-H": "H",
+	"field-weekOfMonth-short": "sed. u mj.",
 	"dateFormatItem-yyyy": "y. G",
 	"field-wed-short-relative+0": "ova sri.",
 	"dateFormatItem-M": "L",
@@ -106,8 +120,12 @@ define(
 	"dateFormatItem-d": "d",
 	"field-weekday": "dan u sedmici",
 	"field-sat-relative+0": "ova subota",
+	"dateFormatItem-h": "h a",
 	"field-sat-relative+1": "sljedeća subota",
+	"field-dayOfYear-narrow": "dan u g.",
+	"field-weekdayOfMonth-short": "dan u mj.",
 	"dateFormatItem-MEd": "E, d.M.",
+	"field-zone-narrow": "zona",
 	"dateFormatItem-y": "y. G",
 	"field-thu-narrow-relative+0": "ovaj čet.",
 	"field-thu-narrow-relative+1": "sljedeći čet.",
@@ -123,26 +141,36 @@ define(
 	"field-wed-narrow-relative+0": "ova sri.",
 	"field-wed-narrow-relative+1": "sljedeća sri.",
 	"dateFormatItem-yyyyMMM": "MMM y. G",
+	"field-dayperiod-short": "prijepodne/poslijepodne",
 	"field-fri-short-relative+0": "ovaj pet.",
 	"field-fri-short-relative+1": "sljedeći pet.",
 	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
 	"field-hour-short": "h",
+	"field-zone-short": "zona",
 	"field-month-narrow": "mj.",
 	"field-hour-narrow": "h",
 	"field-fri-narrow-relative+-1": "prošli pet.",
 	"field-year-relative+0": "ove godine",
 	"field-year-relative+1": "sljedeće godine",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "prošli petak",
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"field-tue-short-relative+-1": "prošli uto.",
 	"field-minute-narrow": "min.",
 	"field-mon-narrow-relative+0": "ovaj pon.",
-	"field-mon-narrow-relative+1": "sljedeći pon",
+	"dateFormatItem-EHm": "E HH:mm",
+	"field-mon-narrow-relative+1": "sljedeći pon.",
 	"field-zone": "vremenska zona",
 	"dateFormatItem-MMMEd": "E, d. MMM",
+	"field-weekOfMonth-narrow": "s. u mj.",
+	"dateFormatItem-EHms": "E HH:mm:ss",
+	"field-weekday-narrow": "dan u sed.",
 	"field-quarter-narrow": "kv.",
 	"field-sun-short-relative+-1": "prošla ned.",
 	"field-day-relative+-1": "jučer",
 	"field-day-relative+-2": "prekjučer",
+	"field-weekday-short": "dan u sed.",
+	"dateFormatItem-Bhm": "h:mm B",
 	"field-sun-relative+0": "ova nedjelja",
 	"field-sun-relative+1": "sljedeća nedjelja",
 	"dateFormatItem-Gy": "y. G",
