@@ -25,14 +25,18 @@ define({ root:
 	"field-week-narrow-relative+0": "this week",
 	"field-week-narrow-relative+1": "next week",
 	"field-wed-narrow-relative+-1": "last Wednesday",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
 	"field-year-narrow": "Year",
+	"field-era-short": "Era",
 	"field-year-narrow-relative+0": "this year",
 	"field-tue-relative+0": "this Tuesday",
 	"field-year-narrow-relative+1": "next year",
 	"field-tue-relative+1": "next Tuesday",
+	"field-weekdayOfMonth": "Weekday Of Month",
 	"field-second-short": "Second",
 	"dayPeriods-format-narrow-am": "AM",
 	"dateFormatItem-MMMd": "MMM d",
+	"field-weekdayOfMonth-narrow": "Weekday Of Month",
 	"dayPeriods-format-abbr-am": "AM",
 	"field-week-relative+0": "this week",
 	"field-month-relative+0": "this month",
@@ -63,11 +67,13 @@ define({ root:
 	"eraNames": [
 		"BE"
 	],
+	"field-weekOfMonth": "Week Of Month",
 	"dayPeriods-standAlone-abbr-pm": "PM",
 	"field-month-short": "Month",
 	"dateFormatItem-GyMMMEd": "G y MMM d, E",
 	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
 	"field-day": "Day",
+	"field-dayOfYear-short": "Day Of Year",
 	"field-year-relative+-1": "last year",
 	"dayPeriods-format-wide-am": "AM",
 	"field-sat-short-relative+-1": "last Saturday",
@@ -159,6 +165,7 @@ define({ root:
 	],
 	"field-quarter-relative+-1": "last quarter",
 	"dateFormatItem-yyyyMMMd": "G y MMM d",
+	"field-dayperiod-narrow": "Dayperiod",
 	"dayPeriods-standAlone-narrow-am": "AM",
 	"field-week-narrow-relative+-1": "last week",
 	"days-format-short": [
@@ -177,6 +184,7 @@ define({ root:
 		"4"
 	],
 	"dayPeriods-format-wide-pm": "PM",
+	"field-dayOfYear": "Day Of Year",
 	"field-sat-relative+-1": "last Saturday",
 	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
 	"dateTimeFormat-long": "{1} {0}",
@@ -205,6 +213,7 @@ define({ root:
 	"field-fri-relative+0": "this Friday",
 	"field-sat-narrow-relative+1": "next Saturday",
 	"field-fri-relative+1": "next Friday",
+	"dateFormatItem-EBhm": "E h:mm B",
 	"field-month-narrow-relative+0": "this month",
 	"field-month-narrow-relative+1": "next month",
 	"field-sun-short-relative+0": "this Sunday",
@@ -234,6 +243,7 @@ define({ root:
 	"field-quarter-relative+1": "next quarter",
 	"field-wed-short-relative+-1": "last Wednesday",
 	"dateFormat-short": "GGGGG y-MM-dd",
+	"dateFormatItem-Bh": "h B",
 	"field-thu-short-relative+-1": "last Thursday",
 	"field-year-narrow-relative+-1": "last year",
 	"days-standAlone-wide": [
@@ -253,6 +263,7 @@ define({ root:
 	"dateFormatItem-E": "ccc",
 	"field-tue-narrow-relative+-1": "last Tuesday",
 	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "Week Of Month",
 	"dayPeriods-standAlone-narrow-pm": "PM",
 	"dateFormatItem-yyyy": "G y",
 	"field-wed-short-relative+0": "this Wednesday",
@@ -282,8 +293,8 @@ define({ root:
 		"Fri",
 		"Sat"
 	],
-	"field-second-narrow-relative+0": "now",
 	"dateTimeFormat-full": "{1} {0}",
+	"field-second-narrow-relative+0": "now",
 	"dateFormatItem-hm": "h:mm a",
 	"dateFormatItem-d": "d",
 	"field-weekday": "Day of the Week",
@@ -310,10 +321,13 @@ define({ root:
 		"M11",
 		"M12"
 	],
+	"field-dayOfYear-narrow": "Day Of Year",
 	"field-month-short-relative+0": "this month",
 	"field-month-short-relative+1": "next month",
+	"field-weekdayOfMonth-short": "Weekday Of Month",
 	"timeFormat-full": "HH:mm:ss zzzz",
 	"dateFormatItem-MEd": "MM-dd, E",
+	"field-zone-narrow": "Zone",
 	"dateFormatItem-y": "G y",
 	"field-thu-narrow-relative+0": "this Thursday",
 	"field-thu-narrow-relative+1": "next Thursday",
@@ -345,6 +359,7 @@ define({ root:
 	"field-quarter-narrow-relative+-1": "last quarter",
 	"field-year-short-relative+0": "this year",
 	"dateFormatItem-yyyyMMM": "G y MMM",
+	"field-dayperiod-short": "Dayperiod",
 	"field-year-short-relative+1": "next year",
 	"field-fri-short-relative+0": "this Friday",
 	"field-fri-short-relative+1": "next Friday",
@@ -361,6 +376,7 @@ define({ root:
 	"field-week-short-relative+-1": "last week",
 	"field-hour-narrow-relative+0": "this hour",
 	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
+	"field-zone-short": "Zone",
 	"field-hour-short": "Hour",
 	"quarters-format-abbr": [
 		"Q1",
@@ -373,10 +389,12 @@ define({ root:
 	"field-fri-narrow-relative+-1": "last Friday",
 	"field-year-relative+0": "this year",
 	"field-year-relative+1": "next year",
+	"field-era-narrow": "Era",
 	"field-fri-relative+-1": "last Friday",
 	"eraNarrow": [
 		"BE"
 	],
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"field-tue-short-relative+-1": "last Tuesday",
 	"field-minute-narrow": "Minute",
 	"days-format-wide": [
@@ -395,11 +413,15 @@ define({ root:
 	"field-year-short-relative+-1": "last year",
 	"field-zone": "Zone",
 	"dateFormatItem-MMMEd": "MMM d, E",
+	"field-weekOfMonth-narrow": "Week Of Month",
 	"dateFormatItem-EHms": "E HH:mm:ss",
+	"field-weekday-narrow": "Day of the Week",
 	"field-quarter-narrow": "Quarter",
 	"field-sun-short-relative+-1": "last Sunday",
 	"field-day-relative+-1": "yesterday",
 	"dayPeriods-standAlone-abbr-am": "AM",
+	"field-weekday-short": "Day of the Week",
+	"dateFormatItem-Bhm": "h:mm B",
 	"days-format-abbr": [
 		"Sun",
 		"Mon",
@@ -433,12 +455,14 @@ define({ root:
 	"es": true,
 	"fi": true,
 	"fr": true,
+	"he": true,
 	"hr": true,
 	"hu": true,
 	"id": true,
 	"it": true,
 	"ja": true,
 	"ko": true,
+	"mk": true,
 	"nb": true,
 	"nl": true,
 	"pl": true,
@@ -446,6 +470,8 @@ define({ root:
 	"pt-pt": true,
 	"ro": true,
 	"ru": true,
+	"sk": true,
+	"sl": true,
 	"sr": true,
 	"sv": true,
 	"th": true,
