@@ -10,7 +10,7 @@ define(
 	"field-wed-relative+1": "dimecres que ve",
 	"timeFormat-short": "H:mm",
 	"field-minute": "minut",
-	"field-month-narrow-relative+-1": "mes passat",
+	"field-month-narrow-relative+-1": "el mes passat",
 	"field-tue-narrow-relative+0": "aquest dt.",
 	"field-tue-narrow-relative+1": "dt. que ve",
 	"field-thu-short-relative+0": "aquest dj.",
@@ -22,17 +22,20 @@ define(
 	"field-day-relative+1": "demà",
 	"field-week-narrow-relative+0": "aquesta setm.",
 	"field-day-relative+2": "demà passat",
-	"field-week-narrow-relative+1": "setm. vinent",
+	"field-week-narrow-relative+1": "la setm. que ve",
 	"field-wed-narrow-relative+-1": "dc. passat",
 	"field-year-narrow": "any",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "enguany",
 	"field-tue-relative+0": "aquest dimarts",
 	"field-year-narrow-relative+1": "l’any que ve",
 	"field-tue-relative+1": "dimarts que ve",
+	"field-weekdayOfMonth": "dia de la setmana del mes",
 	"field-second-short": "s",
-	"dayPeriods-format-narrow-am": "a. m.",
+	"dayPeriods-format-narrow-am": "a. m.",
 	"dateFormatItem-MMMd": "d MMM",
-	"dayPeriods-format-abbr-am": "a. m.",
+	"field-weekdayOfMonth-narrow": "dia de la setm. del mes",
+	"dayPeriods-format-abbr-am": "a. m.",
 	"field-week-relative+0": "aquesta setmana",
 	"field-month-relative+0": "aquest mes",
 	"field-week-relative+1": "la setmana que ve",
@@ -61,16 +64,19 @@ define(
 	"eraNames": [
 		"eB"
 	],
-	"dayPeriods-standAlone-abbr-pm": "p. m.",
+	"field-weekOfMonth": "setmana del mes",
+	"dayPeriods-standAlone-abbr-pm": "p. m.",
 	"field-month-short": "mes",
 	"dateFormatItem-GyMMMEd": "E, d MMM y G",
 	"dateFormatItem-yyyyMd": "d/M/y G",
 	"field-day": "dia",
+	"field-dayOfYear-short": "dia de l’any",
 	"field-year-relative+-1": "l’any passat",
-	"dayPeriods-format-wide-am": "a. m.",
+	"dayPeriods-format-wide-am": "a. m.",
 	"field-sat-short-relative+-1": "ds. passat",
 	"field-hour-relative+0": "aquesta hora",
-	"dateFormatItem-yyyyMEd": "E, d.M.y G",
+	"dateFormatItem-yyyyMEd": "E, d/M/y GGGGG",
+	"field-second-short-relative+0": "ara",
 	"field-wed-relative+-1": "dimecres passat",
 	"dateTimeFormat-medium": "{1}, {0}",
 	"field-sat-narrow-relative+-1": "ds. passat",
@@ -84,7 +90,7 @@ define(
 		"dv",
 		"ds"
 	],
-	"dayPeriods-standAlone-wide-pm": "p. m.",
+	"dayPeriods-standAlone-wide-pm": "p. m.",
 	"dateFormat-long": "d MMMM y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
 	"field-hour-short-relative+0": "aquesta hora",
@@ -115,12 +121,11 @@ define(
 	"dateFormatItem-GyMMM": "LLL y G",
 	"field-month": "mes",
 	"field-day-narrow": "dia",
-	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
-	"field-dayperiod": "a. m./p. m.",
+	"field-dayperiod": "a. m./p. m.",
 	"field-sat-short-relative+0": "aquest ds.",
 	"field-sat-short-relative+1": "ds. que ve",
-	"dayPeriods-format-narrow-pm": "p. m.",
+	"dayPeriods-format-narrow-pm": "p. m.",
 	"dateFormat-medium": "d MMM y G",
 	"dateFormatItem-yyyyMMMM": "LLLL 'de' y G",
 	"eraAbbr": [
@@ -132,7 +137,7 @@ define(
 		"3T",
 		"4T"
 	],
-	"dayPeriods-format-abbr-pm": "p. m.",
+	"dayPeriods-format-abbr-pm": "p. m.",
 	"dateFormatItem-yyyyM": "M/y G",
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "aquest dilluns",
@@ -156,8 +161,9 @@ define(
 	],
 	"field-quarter-relative+-1": "el trimestre passat",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
-	"dayPeriods-standAlone-narrow-am": "a. m.",
-	"field-week-narrow-relative+-1": "setm. passada",
+	"field-dayperiod-narrow": "a. m./p. m.",
+	"dayPeriods-standAlone-narrow-am": "a. m.",
+	"field-week-narrow-relative+-1": "la setm. passada",
 	"days-format-short": [
 		"dg.",
 		"dl.",
@@ -167,7 +173,8 @@ define(
 		"dv.",
 		"ds."
 	],
-	"dayPeriods-format-wide-pm": "p. m.",
+	"dayPeriods-format-wide-pm": "p. m.",
+	"field-dayOfYear": "dia de l’any",
 	"field-sat-relative+-1": "dissabte passat",
 	"dateTimeFormat-long": "{1}, {0}",
 	"dateFormatItem-Md": "d/M",
@@ -196,7 +203,7 @@ define(
 	"field-sat-narrow-relative+1": "ds. que ve",
 	"field-fri-relative+1": "divendres que ve",
 	"field-month-narrow-relative+0": "aquest mes",
-	"field-month-narrow-relative+1": "mes vinent",
+	"field-month-narrow-relative+1": "el mes que ve",
 	"field-sun-short-relative+0": "aquest dg.",
 	"field-sun-short-relative+1": "dg. que ve",
 	"field-week-relative+-1": "la setmana passada",
@@ -238,11 +245,11 @@ define(
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "dj. passat",
 	"field-tue-narrow-relative+-1": "dt. passat",
+	"field-weekOfMonth-short": "setm. del mes",
 	"dateFormatItem-H": "H",
+	"dayPeriods-standAlone-narrow-pm": "p. m.",
 	"dateFormatItem-yyyy": "y G",
-	"dayPeriods-standAlone-narrow-pm": "p. m.",
 	"field-wed-short-relative+0": "aquest dc.",
-	"dateFormatItem-M": "L",
 	"months-standAlone-wide": [
 		"gener",
 		"febrer",
@@ -269,15 +276,15 @@ define(
 		"ds."
 	],
 	"dateTimeFormat-full": "{1}, {0}",
-	"dateFormatItem-d": "d",
+	"field-second-narrow-relative+0": "ara",
 	"field-weekday": "dia de la setmana",
 	"field-day-short-relative+0": "avui",
 	"field-quarter-narrow-relative+0": "aquest trim.",
-	"field-sat-relative+0": "aquest dissabte",
 	"field-day-short-relative+1": "demà",
+	"field-sat-relative+0": "aquest dissabte",
 	"field-quarter-narrow-relative+1": "trim. vinent",
-	"field-sat-relative+1": "dissabte que ve",
 	"field-day-short-relative+2": "demà passat",
+	"field-sat-relative+1": "dissabte que ve",
 	"field-week-short-relative+0": "aquesta setm.",
 	"field-week-short-relative+1": "la setm. que ve",
 	"months-standAlone-abbr": [
@@ -294,10 +301,13 @@ define(
 		"nov.",
 		"des."
 	],
+	"field-dayOfYear-narrow": "dia de l’any",
 	"field-month-short-relative+0": "aquest mes",
 	"field-month-short-relative+1": "el mes que ve",
-	"timeFormat-full": "H:mm:ss zzzz",
+	"field-weekdayOfMonth-short": "dia de la setm. del mes",
+	"timeFormat-full": "H:mm:ss (zzzz)",
 	"dateFormatItem-MEd": "E, d/M",
+	"field-zone-narrow": "fus horari",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "aquest dj.",
 	"field-thu-narrow-relative+1": "dj. que ve",
@@ -319,6 +329,7 @@ define(
 	"field-wed-narrow-relative+1": "dc. que ve",
 	"field-quarter-narrow-relative+-1": "trim. passat",
 	"field-year-short-relative+0": "enguany",
+	"field-dayperiod-short": "a. m./p. m.",
 	"dateFormatItem-yyyyMMM": "LLL y G",
 	"field-year-short-relative+1": "l’any que ve",
 	"field-fri-short-relative+0": "aquest dv.",
@@ -336,6 +347,7 @@ define(
 	"field-hour-narrow-relative+0": "aquesta hora",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "h",
+	"field-zone-short": "fus horari",
 	"quarters-format-abbr": [
 		"1T",
 		"2T",
@@ -347,10 +359,9 @@ define(
 	"field-fri-narrow-relative+-1": "dv. passat",
 	"field-year-relative+0": "enguany",
 	"field-year-relative+1": "l’any que ve",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "divendres passat",
-	"eraNarrow": [
-		"eB"
-	],
+	"eraNarrow": "eB",
 	"field-tue-short-relative+-1": "dt. passat",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -367,11 +378,14 @@ define(
 	"field-year-short-relative+-1": "l’any passat",
 	"field-zone": "fus horari",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "setm. del mes",
+	"field-weekday-narrow": "dia de la setm.",
 	"field-quarter-narrow": "trim.",
 	"field-sun-short-relative+-1": "dg. passat",
 	"field-day-relative+-1": "ahir",
-	"dayPeriods-standAlone-abbr-am": "a. m.",
+	"dayPeriods-standAlone-abbr-am": "a. m.",
 	"field-day-relative+-2": "abans-d’ahir",
+	"field-weekday-short": "dia de la setm.",
 	"days-format-abbr": [
 		"dg.",
 		"dl.",
@@ -389,7 +403,7 @@ define(
 	"field-era": "era",
 	"field-fri-narrow-relative+0": "aquest dv.",
 	"field-fri-narrow-relative+1": "dv. que ve",
-	"dayPeriods-standAlone-wide-am": "a. m."
+	"dayPeriods-standAlone-wide-am": "a. m."
 }
 //end v1.x content
 );
\ No newline at end of file
