@@ -4,12 +4,12 @@ define(
 	"HKD_displayName": "dòlar de Hong Kong",
 	"CNY_displayName": "iuan xinès",
 	"JPY_displayName": "ien japonès",
-	"JPY_symbol": "JP¥",
+	"JPY_symbol": "¥",
 	"USD_displayName": "dòlar dels Estats Units",
 	"CAD_symbol": "CAD",
 	"GBP_displayName": "lliura esterlina britànica",
 	"CHF_displayName": "franc suís",
-	"CNY_symbol": "¥",
+	"CNY_symbol": "CNY",
 	"EUR_displayName": "euro",
 	"GBP_symbol": "£",
 	"CAD_displayName": "dòlar canadenc",
