@@ -1,6 +1,8 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "toto čtvrtletí",
+	"field-quarter-short-relative+1": "příští čtvrtletí",
 	"field-tue-relative+-1": "minulé úterý",
 	"field-year": "rok",
 	"dateFormatItem-Hm": "H:mm",
@@ -8,10 +10,12 @@ define(
 	"field-wed-relative+1": "příští středu",
 	"timeFormat-short": "H:mm",
 	"field-minute": "minuta",
+	"field-month-narrow-relative+-1": "minulý měs.",
 	"field-tue-narrow-relative+0": "toto úterý",
 	"field-tue-narrow-relative+1": "příští úterý",
 	"field-thu-short-relative+0": "tento čtvrtek",
 	"field-day-short-relative+-1": "včera",
+	"dateTimeFormat-short": "{1} {0}",
 	"field-thu-short-relative+1": "příští čtvrtek",
 	"field-day-relative+0": "dnes",
 	"field-day-short-relative+-2": "předevčírem",
@@ -21,13 +25,16 @@ define(
 	"field-week-narrow-relative+1": "příští týd.",
 	"field-wed-narrow-relative+-1": "minulou středu",
 	"field-year-narrow": "r.",
+	"field-era-short": "letop.",
 	"field-year-narrow-relative+0": "tento rok",
 	"field-tue-relative+0": "toto úterý",
 	"field-year-narrow-relative+1": "příští rok",
 	"field-tue-relative+1": "příští úterý",
+	"field-weekdayOfMonth": "den týdne v měsíci",
 	"field-second-short": "s",
 	"dayPeriods-format-narrow-am": "dop.",
 	"dateFormatItem-MMMd": "d. M.",
+	"field-weekdayOfMonth-narrow": "d. týd. v měs.",
 	"dayPeriods-format-abbr-am": "dop.",
 	"field-week-relative+0": "tento týden",
 	"field-month-relative+0": "tento měsíc",
@@ -55,18 +62,25 @@ define(
 		"12",
 		"13"
 	],
+	"eraNames": [
+		"AM"
+	],
+	"field-weekOfMonth": "týden v měsíci",
 	"dayPeriods-standAlone-abbr-pm": "odp.",
 	"field-month-short": "měs.",
 	"dateFormatItem-GyMMMEd": "E d. M. y G",
 	"dateFormatItem-yyyyMd": "d. M. y GGGGG",
 	"field-day": "den",
+	"field-dayOfYear-short": "den v r.",
 	"field-year-relative+-1": "minulý rok",
 	"dayPeriods-format-wide-am": "dop.",
 	"field-sat-short-relative+-1": "minulou sobotu",
+	"dateFormatItem-yyyyMMMMd": "d. MMMM y G",
 	"field-hour-relative+0": "tuto hodinu",
 	"dateFormatItem-yyyyMEd": "E d. M. y GGGGG",
 	"field-second-short-relative+0": "nyní",
 	"field-wed-relative+-1": "minulou středu",
+	"dateTimeFormat-medium": "{1} {0}",
 	"field-sat-narrow-relative+-1": "minulou sobotu",
 	"field-second": "sekunda",
 	"days-standAlone-narrow": [
@@ -81,6 +95,7 @@ define(
 	"dayPeriods-standAlone-wide-pm": "odp.",
 	"dateFormat-long": "d. MMMM y G",
 	"dateFormatItem-GyMMMd": "d. M. y G",
+	"field-hour-short-relative+0": "tuto hodinu",
 	"field-quarter": "čtvrtletí",
 	"field-week-short": "týd.",
 	"field-day-narrow-relative+0": "dnes",
@@ -101,12 +116,15 @@ define(
 		"P",
 		"S"
 	],
+	"dateFormatItem-yyyyMMMMEd": "E d. MMMM y G",
 	"field-tue-short-relative+0": "toto úterý",
 	"field-tue-short-relative+1": "příští úterý",
+	"field-month-short-relative+-1": "minulý měs.",
 	"field-mon-relative+-1": "minulé pondělí",
 	"dateFormatItem-GyMMM": "LLLL y G",
 	"field-month": "měsíc",
 	"field-day-narrow": "den",
+	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
 	"field-dayperiod": "část dne",
 	"field-sat-short-relative+0": "tuto sobotu",
@@ -142,6 +160,7 @@ define(
 	],
 	"field-quarter-relative+-1": "minulé čtvrtletí",
 	"dateFormatItem-yyyyMMMd": "d. M. y G",
+	"field-dayperiod-narrow": "část d.",
 	"dayPeriods-standAlone-narrow-am": "dop.",
 	"field-week-narrow-relative+-1": "minulý týd.",
 	"days-format-short": [
@@ -154,9 +173,27 @@ define(
 		"so"
 	],
 	"dayPeriods-format-wide-pm": "odp.",
+	"field-dayOfYear": "den v roce",
 	"field-sat-relative+-1": "minulou sobotu",
+	"dateTimeFormat-long": "{1} {0}",
 	"dateFormatItem-Md": "d. M.",
+	"field-minute-narrow-relative+0": "tuto minutu",
 	"field-hour": "hodina",
+	"months-format-wide": [
+		"tišri",
+		"chešvan",
+		"kislev",
+		"tevet",
+		"ševat",
+		"adar I",
+		"adar",
+		"nisan",
+		"ijar",
+		"sivan",
+		"tamuz",
+		"av",
+		"elul"
+	],
 	"dateFormat-full": "EEEE d. MMMM y G",
 	"field-month-relative+-1": "minulý měsíc",
 	"dateFormatItem-Hms": "H:mm:ss",
@@ -165,9 +202,28 @@ define(
 	"field-fri-relative+0": "tento pátek",
 	"field-sat-narrow-relative+1": "příští sobotu",
 	"field-fri-relative+1": "příští pátek",
+	"field-month-narrow-relative+0": "tento měs.",
+	"field-month-narrow-relative+1": "příští měs.",
 	"field-sun-short-relative+0": "tuto neděli",
 	"field-sun-short-relative+1": "příští neděli",
 	"field-week-relative+-1": "minulý týden",
+	"field-quarter-short-relative+-1": "minulé čtvrtletí",
+	"field-minute-short-relative+0": "tuto minutu",
+	"months-format-abbr": [
+		"tišri",
+		"chešvan",
+		"kislev",
+		"tevet",
+		"ševat",
+		"adar I",
+		"adar",
+		"nisan",
+		"ijar",
+		"sivan",
+		"tamuz",
+		"av",
+		"elul"
+	],
 	"field-quarter-relative+0": "toto čtvrtletí",
 	"field-minute-relative+0": "tuto minutu",
 	"timeFormat-long": "H:mm:ss z",
@@ -176,6 +232,7 @@ define(
 	"dateFormat-short": "dd.MM.yy GGGGG",
 	"field-thu-short-relative+-1": "minulý čtvrtek",
 	"field-year-narrow-relative+-1": "minulý rok",
+	"dateFormatItem-yyyyMMMEd": "E d. M. y G",
 	"days-standAlone-wide": [
 		"neděle",
 		"pondělí",
@@ -185,17 +242,35 @@ define(
 		"pátek",
 		"sobota"
 	],
-	"dateFormatItem-yyyyMMMEd": "E d. M. y G",
 	"field-mon-narrow-relative+-1": "minulé pondělí",
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "minulý čtvrtek",
+	"dateFormatItem-E": "ccc",
+	"field-weekOfMonth-short": "týd. v m.",
 	"field-tue-narrow-relative+-1": "minulé úterý",
 	"dateFormatItem-H": "H",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "odp.",
+	"dateFormatItem-M": "L",
+	"months-standAlone-wide": [
+		"tišri",
+		"chešvan",
+		"kislev",
+		"tevet",
+		"ševat",
+		"adar I",
+		"adar",
+		"nisan",
+		"ijar",
+		"sivan",
+		"tamuz",
+		"av",
+		"elul"
+	],
 	"field-wed-short-relative+0": "tuto středu",
 	"field-wed-short-relative+1": "příští středu",
 	"field-sun-relative+-1": "minulou neděli",
+	"dateFormatItem-MMMMEd": "E d. MMMM",
 	"days-standAlone-abbr": [
 		"ne",
 		"po",
@@ -205,25 +280,51 @@ define(
 		"pá",
 		"so"
 	],
+	"dateTimeFormat-full": "{1} {0}",
 	"field-second-narrow-relative+0": "nyní",
+	"months-format-abbr-leap": "adar II",
 	"dateFormatItem-d": "d.",
 	"field-weekday": "den v týdnu",
-	"field-day-short-relative+0": "dnes",
 	"months-standAlone-narrow-leap": "7",
-	"field-sat-relative+0": "tuto sobotu",
+	"field-day-short-relative+0": "dnes",
+	"field-quarter-narrow-relative+0": "toto čtvrtletí",
 	"field-day-short-relative+1": "zítra",
-	"field-sat-relative+1": "příští sobotu",
+	"field-sat-relative+0": "tuto sobotu",
+	"field-quarter-narrow-relative+1": "příští čtvrtletí",
 	"field-day-short-relative+2": "pozítří",
+	"field-sat-relative+1": "příští sobotu",
 	"field-week-short-relative+0": "tento týd.",
 	"field-week-short-relative+1": "příští týd.",
+	"months-standAlone-abbr": [
+		"tišri",
+		"chešvan",
+		"kislev",
+		"tevet",
+		"ševat",
+		"adar I",
+		"adar",
+		"nisan",
+		"ijar",
+		"sivan",
+		"tamuz",
+		"av",
+		"elul"
+	],
+	"months-format-wide-leap": "adar II",
 	"months-format-narrow-leap": "7",
+	"dateFormatItem-GyMMMMEd": "E d. MMMM y G",
+	"field-dayOfYear-narrow": "d. v r.",
+	"field-month-short-relative+0": "tento měs.",
+	"field-month-short-relative+1": "příští měs.",
+	"field-weekdayOfMonth-short": "den týd. v měs.",
 	"timeFormat-full": "H:mm:ss zzzz",
 	"dateFormatItem-MEd": "E d. M.",
+	"field-zone-narrow": "pásmo",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "tento čtvrtek",
-	"field-thu-narrow-relative+1": "příští čtvrtek",
 	"field-sun-narrow-relative+-1": "minulou neděli",
 	"field-mon-short-relative+-1": "minulé pondělí",
+	"field-thu-narrow-relative+1": "příští čtvrtek",
 	"field-thu-relative+0": "tento čtvrtek",
 	"field-thu-relative+1": "příští čtvrtek",
 	"field-fri-short-relative+-1": "minulý pátek",
@@ -238,8 +339,10 @@ define(
 	"dateFormatItem-Ed": "E d.",
 	"field-wed-narrow-relative+0": "tuto středu",
 	"field-wed-narrow-relative+1": "příští středu",
+	"field-quarter-narrow-relative+-1": "minulé čtvrtletí",
 	"field-year-short-relative+0": "tento rok",
 	"dateFormatItem-yyyyMMM": "LLLL y G",
+	"field-dayperiod-short": "část dne",
 	"field-year-short-relative+1": "příští rok",
 	"field-fri-short-relative+0": "tento pátek",
 	"field-fri-short-relative+1": "příští pátek",
@@ -253,14 +356,20 @@ define(
 		"so"
 	],
 	"field-week-short-relative+-1": "minulý týd.",
+	"months-standAlone-abbr-leap": "adar II",
+	"dateFormatItem-GyMMMMd": "d. MMMM y G",
+	"field-hour-narrow-relative+0": "tuto hodinu",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "h",
+	"field-zone-short": "čas. pásmo",
 	"field-month-narrow": "měs.",
 	"field-hour-narrow": "h",
 	"field-fri-narrow-relative+-1": "minulý pátek",
 	"field-year-relative+0": "tento rok",
 	"field-year-relative+1": "příští rok",
+	"field-era-narrow": "let.",
 	"field-fri-relative+-1": "minulý pátek",
+	"eraNarrow": "AM",
 	"field-tue-short-relative+-1": "minulé úterý",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -274,14 +383,20 @@ define(
 	],
 	"field-mon-narrow-relative+0": "toto pondělí",
 	"field-mon-narrow-relative+1": "příští pondělí",
+	"dateFormatItem-EHm": "E H:mm",
 	"field-year-short-relative+-1": "minulý rok",
 	"field-zone": "časové pásmo",
 	"dateFormatItem-MMMEd": "E d. M.",
+	"field-weekOfMonth-narrow": "týd. v m.",
+	"dateFormatItem-EHms": "E H:mm:ss",
+	"field-weekday-narrow": "d. v týd.",
+	"months-standAlone-wide-leap": "adar II",
 	"field-quarter-narrow": "Q",
 	"field-sun-short-relative+-1": "minulou neděli",
 	"field-day-relative+-1": "včera",
 	"dayPeriods-standAlone-abbr-am": "dop.",
 	"field-day-relative+-2": "předevčírem",
+	"field-weekday-short": "den v týd.",
 	"days-format-abbr": [
 		"ne",
 		"po",
