@@ -23,11 +23,9 @@ define({ root:
 	"en": true,
 	"en-au": true,
 	"en-ca": true,
-	"en-gb": true,
 	"es": true,
 	"fi": true,
 	"fr": true,
-	"fr-ch": true,
 	"he": true,
 	"hr": true,
 	"hu": true,
