@@ -7,16 +7,16 @@ define(
 	"field-year": "år",
 	"dateFormatItem-Hm": "HH.mm",
 	"field-wed-relative+0": "på onsdag",
-	"field-wed-relative+1": "næste onsdag",
+	"field-wed-relative+1": "på onsdag",
 	"dateFormatItem-ms": "mm.ss",
 	"timeFormat-short": "HH.mm",
 	"field-minute": "minut",
 	"field-month-narrow-relative+-1": "sidste md.",
 	"field-tue-narrow-relative+0": "på ti.",
-	"field-tue-narrow-relative+1": "næste ti.",
+	"field-tue-narrow-relative+1": "på ti.",
 	"field-thu-short-relative+0": "på tor.",
 	"field-day-short-relative+-1": "i går",
-	"field-thu-short-relative+1": "næste tor.",
+	"field-thu-short-relative+1": "på tor.",
 	"field-day-relative+0": "i dag",
 	"field-day-short-relative+-2": "i forgårs",
 	"field-day-relative+1": "i morgen",
@@ -24,14 +24,18 @@ define(
 	"field-day-relative+2": "i overmorgen",
 	"field-week-narrow-relative+1": "næste uge",
 	"field-wed-narrow-relative+-1": "sidste on.",
+	"dateFormatItem-EBhms": "E h.mm.ss B",
 	"field-year-narrow": "år",
+	"field-era-short": "æra",
 	"field-year-narrow-relative+0": "i år",
 	"field-tue-relative+0": "på tirsdag",
 	"field-year-narrow-relative+1": "næste år",
-	"field-tue-relative+1": "næste tirsdag",
+	"field-tue-relative+1": "på tirsdag",
+	"field-weekdayOfMonth": "ugedag i måneden",
 	"field-second-short": "sek.",
 	"dayPeriods-format-narrow-am": "a",
 	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "ugedag i md.",
 	"field-week-relative+0": "denne uge",
 	"field-month-relative+0": "denne måned",
 	"field-week-relative+1": "næste uge",
@@ -39,17 +43,22 @@ define(
 	"field-sun-narrow-relative+0": "på sø.",
 	"timeFormat-medium": "HH.mm.ss",
 	"field-mon-short-relative+0": "på man.",
-	"field-sun-narrow-relative+1": "næste sø.",
-	"field-mon-short-relative+1": "næste man.",
+	"field-sun-narrow-relative+1": "på sø.",
+	"field-mon-short-relative+1": "på man.",
 	"field-second-relative+0": "nu",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"eraNames": [
+		"AH"
+	],
+	"field-weekOfMonth": "uge i måneden",
 	"field-month-short": "md.",
 	"dateFormatItem-GyMMMEd": "E d. MMM y G",
 	"dateFormatItem-yyyyMd": "d/M/y G",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag i året",
 	"field-year-relative+-1": "sidste år",
 	"field-sat-short-relative+-1": "sidste lør.",
-	"field-hour-relative+0": "i den kommende time",
+	"field-hour-relative+0": "denne time",
 	"dateFormatItem-yyyyMEd": "E d/M/y G",
 	"field-wed-relative+-1": "sidste onsdag",
 	"field-sat-narrow-relative+-1": "sidste lø.",
@@ -63,6 +72,7 @@ define(
 		"F",
 		"L"
 	],
+	"dateFormatItem-Ehms": "E h.mm.ss a",
 	"dateFormat-long": "d. MMMM y G",
 	"dateFormatItem-GyMMMd": "d. MMM y G",
 	"field-hour-short-relative+0": "denne time",
@@ -87,7 +97,7 @@ define(
 		"L"
 	],
 	"field-tue-short-relative+0": "på tir.",
-	"field-tue-short-relative+1": "næste tir.",
+	"field-tue-short-relative+1": "på tir.",
 	"field-month-short-relative+-1": "sidste md.",
 	"field-mon-relative+-1": "sidste mandag",
 	"dateFormatItem-GyMMM": "MMM y G",
@@ -97,7 +107,7 @@ define(
 	"field-minute-short": "min.",
 	"field-dayperiod": "AM/PM",
 	"field-sat-short-relative+0": "på lør.",
-	"field-sat-short-relative+1": "næste lør.",
+	"field-sat-short-relative+1": "på lør.",
 	"dayPeriods-format-narrow-pm": "p",
 	"dateFormat-medium": "d. MMM y G",
 	"dateFormatItem-yyyyMMMM": "MMMM y G",
@@ -113,12 +123,13 @@ define(
 	"dateFormatItem-yyyyM": "M/y G",
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "på mandag",
-	"field-mon-relative+1": "næste mandag",
+	"field-mon-relative+1": "på mandag",
 	"field-day-narrow-relative+-1": "i går",
 	"field-year-short": "år",
 	"field-day-narrow-relative+-2": "i forgårs",
 	"field-quarter-relative+-1": "sidste kvartal",
 	"dateFormatItem-yyyyMMMd": "d. MMM y G",
+	"field-dayperiod-narrow": "AM/PM",
 	"field-week-narrow-relative+-1": "sidste uge",
 	"days-format-short": [
 		"sø",
@@ -129,27 +140,58 @@ define(
 		"fr",
 		"lø"
 	],
+	"field-dayOfYear": "dag i året",
 	"field-sat-relative+-1": "sidste lørdag",
 	"dateFormatItem-Md": "d/M",
-	"field-minute-narrow-relative+0": "denne minut",
+	"field-minute-narrow-relative+0": "dette min.",
 	"field-hour": "time",
+	"months-format-wide": [
+		"muharram",
+		"safar",
+		"rabiʻ I",
+		"rabiʻ II",
+		"jumada I",
+		"jumada II",
+		"rajab",
+		"shaʻban",
+		"ramadan",
+		"shawwal",
+		"dhuʻl-Qiʻdah",
+		"dhuʻl-Hijjah"
+	],
 	"dateFormat-full": "EEEE d. MMMM y G",
 	"field-month-relative+-1": "sidste måned",
 	"dateFormatItem-Hms": "HH.mm.ss",
 	"field-quarter-short": "kvt.",
 	"field-sat-narrow-relative+0": "på lø.",
 	"field-fri-relative+0": "på fredag",
-	"field-sat-narrow-relative+1": "næste lø.",
-	"field-fri-relative+1": "næste fredag",
+	"field-sat-narrow-relative+1": "på lø.",
+	"field-fri-relative+1": "på fredag",
+	"dateFormatItem-EBhm": "E h.mm B",
 	"field-month-narrow-relative+0": "denne md.",
 	"field-month-narrow-relative+1": "næste md.",
 	"field-sun-short-relative+0": "på søn.",
-	"field-sun-short-relative+1": "næste søn.",
+	"field-sun-short-relative+1": "på søn.",
 	"field-week-relative+-1": "sidste uge",
 	"field-quarter-short-relative+-1": "sidste kvt.",
-	"field-minute-short-relative+0": "denne minut",
+	"field-minute-short-relative+0": "dette min.",
+	"dateFormatItem-Ehm": "E h.mm a",
+	"months-format-abbr": [
+		"muharram",
+		"safar",
+		"rabiʻ I",
+		"rabiʻ II",
+		"jumada I",
+		"jumada II",
+		"rajab",
+		"shaʻban",
+		"ramadan",
+		"shawwal",
+		"dhuʻl-Qiʻdah",
+		"dhuʻl-Hijjah"
+	],
 	"field-quarter-relative+0": "dette kvartal",
-	"field-minute-relative+0": "i det kommende minut",
+	"field-minute-relative+0": "dette minut",
 	"timeFormat-long": "HH.mm.ss z",
 	"field-quarter-relative+1": "næste kvartal",
 	"field-wed-short-relative+-1": "sidste ons.",
@@ -170,10 +212,25 @@ define(
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "sidste to.",
 	"field-tue-narrow-relative+-1": "sidste ti.",
+	"field-weekOfMonth-short": "uge i md.",
 	"dateFormatItem-yyyy": "y G",
 	"field-wed-short-relative+0": "på ons.",
+	"months-standAlone-wide": [
+		"muharram",
+		"safar",
+		"rabiʻ I",
+		"rabiʻ II",
+		"jumada I",
+		"jumada II",
+		"rajab",
+		"shaʻban",
+		"ramadan",
+		"shawwal",
+		"dhuʻl-Qiʻdah",
+		"dhuʻl-Hijjah"
+	],
 	"dateFormatItem-M": "M",
-	"field-wed-short-relative+1": "næste ons.",
+	"field-wed-short-relative+1": "på ons.",
 	"field-sun-relative+-1": "sidste søndag",
 	"days-standAlone-abbr": [
 		"søn",
@@ -185,28 +242,45 @@ define(
 		"lør"
 	],
 	"dateFormatItem-hm": "h.mm a",
-	"dateFormatItem-d": "d.",
 	"field-weekday": "ugedag",
+	"dateFormatItem-d": "d.",
 	"field-day-short-relative+0": "i dag",
 	"field-quarter-narrow-relative+0": "dette kvt.",
 	"field-sat-relative+0": "på lørdag",
 	"field-day-short-relative+1": "i morgen",
 	"field-quarter-narrow-relative+1": "næste kvt.",
-	"field-sat-relative+1": "næste lørdag",
+	"field-sat-relative+1": "på lørdag",
 	"field-day-short-relative+2": "i overmorgen",
 	"field-week-short-relative+0": "denne uge",
 	"field-week-short-relative+1": "næste uge",
+	"months-standAlone-abbr": [
+		"muharram",
+		"safar",
+		"rabiʻ I",
+		"rabiʻ II",
+		"jumada I",
+		"jumada II",
+		"rajab",
+		"shaʻban",
+		"ramadan",
+		"shawwal",
+		"dhuʻl-Qiʻdah",
+		"dhuʻl-Hijjah"
+	],
+	"field-dayOfYear-narrow": "dag i året",
 	"field-month-short-relative+0": "denne md.",
 	"field-month-short-relative+1": "næste md.",
+	"field-weekdayOfMonth-short": "ugedag i md.",
 	"timeFormat-full": "HH.mm.ss zzzz",
 	"dateFormatItem-MEd": "E d/M",
+	"field-zone-narrow": "zone",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "på to.",
-	"field-thu-narrow-relative+1": "næste to.",
+	"field-thu-narrow-relative+1": "på to.",
 	"field-sun-narrow-relative+-1": "sidste sø.",
 	"field-mon-short-relative+-1": "sidste man.",
 	"field-thu-relative+0": "på torsdag",
-	"field-thu-relative+1": "næste torsdag",
+	"field-thu-relative+1": "på torsdag",
 	"field-fri-short-relative+-1": "sidste fre.",
 	"dateFormatItem-hms": "h.mm.ss a",
 	"field-thu-relative+-1": "sidste torsdag",
@@ -219,13 +293,14 @@ define(
 	],
 	"dateFormatItem-Ed": "E 'd'. d.",
 	"field-wed-narrow-relative+0": "på on.",
-	"field-wed-narrow-relative+1": "næste on.",
+	"field-wed-narrow-relative+1": "på on.",
 	"field-quarter-narrow-relative+-1": "sidste kvt.",
 	"field-year-short-relative+0": "i år",
+	"field-dayperiod-short": "AM/PM",
 	"dateFormatItem-yyyyMMM": "MMM y G",
 	"field-year-short-relative+1": "næste år",
 	"field-fri-short-relative+0": "på fre.",
-	"field-fri-short-relative+1": "næste fre.",
+	"field-fri-short-relative+1": "på fre.",
 	"days-standAlone-short": [
 		"sø",
 		"ma",
@@ -239,6 +314,7 @@ define(
 	"field-hour-narrow-relative+0": "denne time",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "t.",
+	"field-zone-short": "zone",
 	"quarters-format-abbr": [
 		"1. kvt.",
 		"2. kvt.",
@@ -246,13 +322,16 @@ define(
 		"4. kvt."
 	],
 	"field-month-narrow": "md.",
-	"field-hour-narrow": "t",
+	"field-hour-narrow": "t.",
 	"field-fri-narrow-relative+-1": "sidste fr.",
 	"field-year-relative+0": "i år",
 	"field-year-relative+1": "næste år",
+	"field-era-narrow": "æra",
 	"field-fri-relative+-1": "sidste fredag",
+	"eraNarrow": "AH",
+	"dateFormatItem-Bhms": "h.mm.ss B",
 	"field-tue-short-relative+-1": "sidste tir.",
-	"field-minute-narrow": "min",
+	"field-minute-narrow": "min.",
 	"days-format-wide": [
 		"søndag",
 		"mandag",
@@ -263,14 +342,19 @@ define(
 		"lørdag"
 	],
 	"field-mon-narrow-relative+0": "på ma.",
-	"field-mon-narrow-relative+1": "næste ma.",
+	"field-mon-narrow-relative+1": "på ma.",
+	"dateFormatItem-EHm": "E HH.mm",
 	"field-year-short-relative+-1": "sidste år",
 	"field-zone": "tidszone",
 	"dateFormatItem-MMMEd": "E d. MMM",
+	"field-weekOfMonth-narrow": "uge i md.",
+	"dateFormatItem-EHms": "E HH.mm.ss",
+	"field-weekday-narrow": "ugedag",
 	"field-quarter-narrow": "kvt.",
 	"field-sun-short-relative+-1": "sidste søn.",
 	"field-day-relative+-1": "i går",
 	"field-day-relative+-2": "i forgårs",
+	"field-weekday-short": "ugedag",
 	"days-format-abbr": [
 		"søn.",
 		"man.",
@@ -280,14 +364,15 @@ define(
 		"fre.",
 		"lør."
 	],
+	"dateFormatItem-Bhm": "h.mm B",
 	"field-sun-relative+0": "på søndag",
-	"field-sun-relative+1": "næste søndag",
+	"field-sun-relative+1": "på søndag",
 	"dateFormatItem-Gy": "y G",
 	"field-day-short": "dag",
 	"field-week-narrow": "uge",
 	"field-era": "æra",
 	"field-fri-narrow-relative+0": "på fr.",
-	"field-fri-narrow-relative+1": "næste fr."
+	"field-fri-narrow-relative+1": "på fr."
 }
 //end v1.x content
 );
\ No newline at end of file
