@@ -20,11 +20,14 @@ define(
 	"field-week-narrow-relative+1": "nächste Woche",
 	"field-wed-narrow-relative+-1": "letzten Mi.",
 	"field-year-narrow": "J",
+	"field-era-short": "Epoche",
 	"field-year-narrow-relative+0": "dieses Jahr",
 	"field-tue-relative+0": "diesen Dienstag",
 	"field-year-narrow-relative+1": "nächstes Jahr",
 	"field-tue-relative+1": "nächsten Dienstag",
+	"field-weekdayOfMonth": "Wochentag",
 	"field-second-short": "Sek.",
+	"field-weekdayOfMonth-narrow": "WT",
 	"field-week-relative+0": "diese Woche",
 	"field-month-relative+0": "diesen Monat",
 	"field-week-relative+1": "nächste Woche",
@@ -34,8 +37,10 @@ define(
 	"field-sun-narrow-relative+1": "nächsten So.",
 	"field-mon-short-relative+1": "nächsten Mo.",
 	"field-second-relative+0": "jetzt",
+	"field-weekOfMonth": "Woche des Monats",
 	"field-month-short": "Monat",
 	"field-day": "Tag",
+	"field-dayOfYear-short": "Tag des Jahres",
 	"field-year-relative+-1": "letztes Jahr",
 	"field-sat-short-relative+-1": "letzten Sa.",
 	"field-hour-relative+0": "in dieser Stunde",
@@ -70,7 +75,9 @@ define(
 	"field-year-short": "Jahr",
 	"field-day-narrow-relative+-2": "vorgestern",
 	"field-quarter-relative+-1": "letztes Quartal",
+	"field-dayperiod-narrow": "Tagesh.",
 	"field-week-narrow-relative+-1": "letzte Woche",
+	"field-dayOfYear": "Tag des Jahres",
 	"field-sat-relative+-1": "letzten Samstag",
 	"field-hour": "Stunde",
 	"field-minute-narrow-relative+0": "in dieser Minute",
@@ -97,6 +104,7 @@ define(
 	"field-mon-narrow-relative+-1": "letzten Mo.",
 	"field-thu-narrow-relative+-1": "letzten Do.",
 	"field-tue-narrow-relative+-1": "letzten Di.",
+	"field-weekOfMonth-short": "W/M",
 	"field-wed-short-relative+0": "diesen Mi.",
 	"field-wed-short-relative+1": "nächsten Mi.",
 	"field-sun-relative+-1": "letzten Sonntag",
@@ -110,8 +118,11 @@ define(
 	"field-day-short-relative+2": "übermorgen",
 	"field-week-short-relative+0": "diese Woche",
 	"field-week-short-relative+1": "nächste Woche",
+	"field-dayOfYear-narrow": "T/J",
 	"field-month-short-relative+0": "diesen Monat",
 	"field-month-short-relative+1": "nächsten Monat",
+	"field-weekdayOfMonth-short": "Wochentag",
+	"field-zone-narrow": "Zeitz.",
 	"field-thu-narrow-relative+0": "diesen Do.",
 	"field-thu-narrow-relative+1": "nächsten Do.",
 	"field-sun-narrow-relative+-1": "letzten So.",
@@ -125,17 +136,20 @@ define(
 	"field-wed-narrow-relative+1": "nächsten Mi.",
 	"field-quarter-narrow-relative+-1": "letztes Quartal",
 	"field-year-short-relative+0": "dieses Jahr",
+	"field-dayperiod-short": "Tageshälfte",
 	"field-year-short-relative+1": "nächstes Jahr",
 	"field-fri-short-relative+0": "diesen Fr.",
 	"field-fri-short-relative+1": "nächsten Fr.",
 	"field-week-short-relative+-1": "letzte Woche",
 	"field-hour-narrow-relative+0": "in dieser Stunde",
 	"field-hour-short": "Std.",
+	"field-zone-short": "Zeitzone",
 	"field-month-narrow": "M",
 	"field-hour-narrow": "Std.",
 	"field-fri-narrow-relative+-1": "letzten Fr.",
 	"field-year-relative+0": "dieses Jahr",
 	"field-year-relative+1": "nächstes Jahr",
+	"field-era-narrow": "E",
 	"field-fri-relative+-1": "letzten Freitag",
 	"field-tue-short-relative+-1": "letzten Di.",
 	"field-minute-narrow": "Min.",
@@ -143,10 +157,13 @@ define(
 	"field-mon-narrow-relative+1": "nächsten Mo.",
 	"field-year-short-relative+-1": "letztes Jahr",
 	"field-zone": "Zeitzone",
+	"field-weekOfMonth-narrow": "Wo. des Monats",
+	"field-weekday-narrow": "Wochent.",
 	"field-quarter-narrow": "Q",
 	"field-sun-short-relative+-1": "letzten So.",
 	"field-day-relative+-1": "gestern",
 	"field-day-relative+-2": "vorgestern",
+	"field-weekday-short": "Wochentag",
 	"field-sun-relative+0": "diesen Sonntag",
 	"field-sun-relative+1": "nächsten Sonntag",
 	"field-day-short": "Tag",
