@@ -2,22 +2,23 @@ define(
 //begin v1.x content
 {
 	"HKD_displayName": "Δολάριο Χονγκ Κονγκ",
-	"CHF_displayName": "Φράγκο Ελβετίας",
-	"JPY_symbol": "JP¥",
-	"CAD_displayName": "Δολάριο Καναδά",
-	"HKD_symbol": "HK$",
 	"CNY_displayName": "Γουάν Κίνας",
-	"USD_symbol": "$",
-	"AUD_displayName": "Δολάριο Αυστραλίας",
 	"JPY_displayName": "Γιεν Ιαπωνίας",
-	"CAD_symbol": "CA$",
+	"JPY_symbol": "JP¥",
 	"USD_displayName": "Δολάριο ΗΠΑ",
-	"EUR_symbol": "€",
+	"CAD_symbol": "CA$",
+	"GBP_displayName": "Λίρα Στερλίνα Βρετανίας",
+	"CHF_displayName": "Φράγκο Ελβετίας",
 	"CNY_symbol": "CN¥",
-	"GBP_displayName": "Λίρα Βρετανίας",
+	"EUR_displayName": "Ευρώ",
 	"GBP_symbol": "£",
-	"AUD_symbol": "A$",
-	"EUR_displayName": "Ευρώ"
+	"CAD_displayName": "Δολάριο Καναδά",
+	"USD_symbol": "$",
+	"EUR_symbol": "€",
+	"AUD_displayName": "Δολάριο Αυστραλίας",
+	"CHF_symbol": "CHF",
+	"HKD_symbol": "HK$",
+	"AUD_symbol": "A$"
 }
 //end v1.x content
 );
\ No newline at end of file
