@@ -1,133 +1,173 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "τώρα",
-	"field-quarter-relative+-1": "προηγούμενο τρίμηνο",
-	"field-weekday": "καθημερινή",
-	"field-mon-narrow-relative+0": "αυτήν τη Δε",
-	"field-mon-narrow-relative+1": "επόμ. Δε",
+	"field-quarter-short-relative+0": "τρέχον τρίμ.",
+	"field-quarter-short-relative+1": "επόμ. τρίμ.",
+	"field-tue-relative+-1": "προηγούμενη Τρίτη",
+	"field-year": "έτος",
 	"field-wed-relative+0": "αυτήν την Τετάρτη",
 	"field-wed-relative+1": "επόμενη Τετάρτη",
-	"field-week-short": "εβδ.",
-	"field-tue-relative+-1": "προηγούμενη Τρίτη",
-	"field-year-short": "έτ.",
-	"field-thu-narrow-relative+-1": "προηγ. Πέ",
-	"field-hour-relative+0": "αυτήν την ώρα",
-	"field-quarter-narrow": "τρίμ.",
-	"field-fri-relative+-1": "προηγούμενη Παρασκευή",
-	"field-hour-short": "ώρ.",
-	"field-wed-relative+-1": "προηγούμενη Τετάρτη",
-	"field-mon-short-relative+-1": "προηγ. Δευτ.",
-	"field-thu-relative+-1": "προηγούμενη Πέμπτη",
-	"field-era": "περίοδος",
-	"field-sat-narrow-relative+0": "αυτό το Σά",
-	"field-sat-narrow-relative+1": "επόμ. Σά",
-	"field-year": "έτος",
-	"field-hour": "ώρα",
-	"field-sat-relative+0": "αυτό το Σάββατο",
-	"field-sat-relative+1": "επόμενο Σάββατο",
-	"field-sat-short-relative+-1": "προηγ. Σάβ.",
-	"field-minute-narrow": "λ",
+	"field-minute": "λεπτό",
+	"field-month-narrow-relative+-1": "προηγ. μήνας",
+	"field-tue-narrow-relative+0": "αυτήν την Τρ",
+	"field-tue-narrow-relative+1": "επόμ. Τρ",
+	"field-thu-short-relative+0": "αυτήν την Πέμ.",
+	"field-day-short-relative+-1": "χθες",
+	"field-thu-short-relative+1": "επόμ. Πέμ.",
 	"field-day-relative+0": "σήμερα",
 	"field-day-relative+1": "αύριο",
-	"field-thu-relative+0": "αυτήν την Πέμπτη",
-	"field-mon-narrow-relative+-1": "προηγ. Δε",
+	"field-week-narrow-relative+0": "τρέχ. εβδ.",
 	"field-day-relative+2": "μεθαύριο",
-	"field-wed-narrow-relative+0": "αυτήν την Τε",
-	"field-thu-relative+1": "επόμενη Πέμπτη",
-	"field-wed-narrow-relative+1": "επόμ. Τε",
-	"field-mon-short-relative+0": "αυτήν τη Δευτ.",
-	"field-mon-short-relative+1": "επόμ. Δευτ.",
-	"field-wed-short-relative+-1": "προηγ. Τετ.",
-	"field-fri-narrow-relative+-1": "προηγ. Πα",
-	"field-hour-narrow": "ώ",
-	"field-tue-short-relative+0": "αυτήν την Τρ.",
+	"field-week-narrow-relative+1": "επόμ. εβδ.",
+	"field-wed-narrow-relative+-1": "προηγ. Τε",
 	"field-year-narrow": "έτ.",
-	"field-tue-short-relative+1": "επόμ. Τρ.",
-	"field-minute-short": "λεπ.",
-	"field-day-narrow": "ημέρα",
-	"field-year-narrow-relative+-1": "πέρσι",
-	"field-wed-short-relative+0": "αυτήν την Τετ.",
-	"field-wed-short-relative+1": "επόμ. Τετ.",
-	"field-sun-relative+0": "αυτήν την Κυριακή",
-	"field-sun-relative+1": "επόμενη Κυριακή",
-	"field-year-short-relative+0": "φέτος",
-	"eraAbbr": [
-		"Πριν R.O.C.",
+	"field-era-short": "περ.",
+	"field-year-narrow-relative+0": "φέτος",
+	"field-tue-relative+0": "αυτήν την Τρίτη",
+	"field-year-narrow-relative+1": "επόμενο έτος",
+	"field-tue-relative+1": "επόμενη Τρίτη",
+	"field-weekdayOfMonth": "καθημερινή μήνα",
+	"field-second-short": "δευτ.",
+	"field-weekdayOfMonth-narrow": "καθημερ. μήνα",
+	"field-week-relative+0": "τρέχουσα εβδομάδα",
+	"field-month-relative+0": "τρέχων μήνας",
+	"field-week-relative+1": "επόμενη εβδομάδα",
+	"field-month-relative+1": "επόμενος μήνας",
+	"field-sun-narrow-relative+0": "αυτήν την Κυ",
+	"field-mon-short-relative+0": "αυτήν τη Δευτ.",
+	"field-sun-narrow-relative+1": "επόμ. Κυ",
+	"field-mon-short-relative+1": "επόμ. Δευτ.",
+	"field-second-relative+0": "τώρα",
+	"eraNames": [
+		"προ R.O.C.",
 		"R.O.C."
 	],
-	"field-minute": "λεπτό",
+	"field-weekOfMonth": "εβδομάδα μήνα",
 	"field-month-short": "μήν.",
-	"field-year-short-relative+1": "επόμενο έτος",
-	"field-dayperiod": "π.μ./μ.μ.",
-	"field-day-relative+-1": "χθες",
-	"field-day-relative+-2": "προχθές",
-	"field-minute-relative+0": "αυτό το λεπτό",
-	"field-week-narrow": "εβδ.",
-	"field-wed-narrow-relative+-1": "προηγ. Τε",
-	"field-day-short": "ημέρα",
-	"field-quarter-relative+0": "τρέχον τρίμηνο",
-	"field-quarter-relative+1": "επόμενο τρίμηνο",
-	"field-fri-relative+0": "αυτήν την Παρασκευή",
-	"field-fri-relative+1": "επόμενη Παρασκευή",
 	"field-day": "ημέρα",
-	"field-second-narrow": "δ",
-	"field-zone": "ζώνη ώρας",
+	"field-dayOfYear-short": "ημ. έτους",
 	"field-year-relative+-1": "πέρσι",
-	"field-month-relative+-1": "προηγούμενος μήνας",
-	"field-thu-short-relative+0": "αυτήν την Πέμ.",
-	"field-thu-short-relative+1": "επόμ. Πέμ.",
-	"field-quarter-narrow-relative+0": "τρέχον τρίμ.",
-	"field-quarter-narrow-relative+1": "επόμ. τρίμ.",
-	"field-quarter": "τρίμηνο",
-	"field-month": "μήνας",
-	"field-tue-relative+0": "αυτήν την Τρίτη",
-	"field-quarter-short-relative+0": "τρέχον τρίμ.",
-	"field-tue-relative+1": "επόμενη Τρίτη",
-	"field-quarter-short-relative+1": "επόμ. τρίμ.",
-	"field-fri-narrow-relative+0": "αυτήν την Πα",
-	"field-fri-narrow-relative+1": "επόμ. Πα",
-	"field-fri-short-relative+-1": "προηγ. Παρ.",
-	"field-year-narrow-relative+0": "φέτος",
-	"field-sun-narrow-relative+-1": "προηγ. Κυ",
-	"field-year-narrow-relative+1": "επόμενο έτος",
-	"field-quarter-short-relative+-1": "προηγ. τρίμ.",
-	"field-sun-narrow-relative+0": "αυτήν την Κυ",
-	"field-thu-narrow-relative+0": "αυτήν την Πέ",
-	"field-sun-narrow-relative+1": "επόμ. Κυ",
-	"field-thu-narrow-relative+1": "επόμ. Πέ",
-	"field-tue-narrow-relative+0": "αυτήν την Τρ",
-	"field-mon-relative+0": "αυτήν τη Δευτέρα",
-	"field-tue-narrow-relative+1": "επόμ. Τρ",
-	"field-mon-relative+1": "επόμενη Δευτέρα",
-	"field-tue-narrow-relative+-1": "προηγ. Τρ",
-	"field-second-short": "δευτ.",
+	"field-sat-short-relative+-1": "προηγ. Σάβ.",
+	"field-hour-relative+0": "τρέχουσα ώρα",
+	"field-wed-relative+-1": "προηγούμενη Τετάρτη",
+	"field-sat-narrow-relative+-1": "προηγ. Σά",
 	"field-second": "δευτερόλεπτο",
-	"field-fri-short-relative+0": "αυτήν την Παρ.",
-	"field-sat-relative+-1": "προηγούμενο Σάββατο",
-	"field-fri-short-relative+1": "επόμ. Παρ.",
-	"field-sun-relative+-1": "προηγούμενη Κυριακή",
-	"field-month-relative+0": "τρέχων μήνας",
-	"field-quarter-narrow-relative+-1": "προηγ. τρίμ.",
-	"field-month-relative+1": "επόμενος μήνας",
-	"field-week": "εβδομάδα",
+	"field-quarter": "τρίμηνο",
+	"field-week-short": "εβδ.",
+	"field-day-narrow-relative+0": "σήμερα",
+	"field-day-narrow-relative+1": "αύριο",
+	"field-tue-short-relative+0": "αυτήν την Τρ.",
+	"field-tue-short-relative+1": "επόμ. Τρ.",
+	"field-mon-relative+-1": "προηγούμενη Δευτέρα",
+	"field-month": "μήνας",
+	"field-day-narrow": "ημ.",
+	"field-minute-short": "λεπ.",
+	"field-dayperiod": "π.μ./μ.μ.",
 	"field-sat-short-relative+0": "αυτό το Σάβ.",
 	"field-sat-short-relative+1": "επόμ. Σάβ.",
-	"field-year-relative+0": "φέτος",
-	"field-week-relative+-1": "προηγούμενη εβδομάδα",
-	"field-year-relative+1": "επόμενο έτος",
-	"field-year-short-relative+-1": "πέρσι",
+	"eraAbbr": [
+		"προ R.O.C.",
+		"R.O.C."
+	],
+	"field-second-narrow": "δ.",
+	"field-mon-relative+0": "αυτήν τη Δευτέρα",
+	"field-mon-relative+1": "επόμενη Δευτέρα",
+	"field-day-narrow-relative+-1": "χθες",
+	"field-year-short": "έτ.",
+	"field-quarter-relative+-1": "προηγούμενο τρίμηνο",
+	"field-dayperiod-narrow": "πμ/μμ",
+	"field-week-narrow-relative+-1": "προηγ. εβδ.",
+	"field-dayOfYear": "ημέρα έτους",
+	"field-sat-relative+-1": "προηγούμενο Σάββατο",
+	"field-hour": "ώρα",
+	"field-month-relative+-1": "προηγούμενος μήνας",
 	"field-quarter-short": "τρίμ.",
-	"field-sun-short-relative+-1": "προηγ. Κυρ.",
-	"field-thu-short-relative+-1": "προηγ. Πέμ.",
-	"field-tue-short-relative+-1": "προηγ. Τρ.",
-	"field-mon-relative+-1": "προηγούμενη Δευτέρα",
-	"field-sat-narrow-relative+-1": "προηγ. Σά",
-	"field-month-narrow": "μήν.",
-	"field-week-relative+0": "αυτήν την εβδομάδα",
+	"field-sat-narrow-relative+0": "αυτό το Σά",
+	"field-fri-relative+0": "αυτήν την Παρασκευή",
+	"field-sat-narrow-relative+1": "επόμ. Σά",
+	"field-fri-relative+1": "επόμενη Παρασκευή",
+	"field-month-narrow-relative+0": "τρέχ. μήνας",
+	"field-month-narrow-relative+1": "επόμ. μήνας",
 	"field-sun-short-relative+0": "αυτήν την Κυρ.",
-	"field-week-relative+1": "επόμενη εβδομάδα",
-	"field-sun-short-relative+1": "επόμ. Κυρ."
+	"field-sun-short-relative+1": "επόμ. Κυρ.",
+	"field-week-relative+-1": "προηγούμενη εβδομάδα",
+	"field-quarter-short-relative+-1": "προηγ. τρίμ.",
+	"field-quarter-relative+0": "τρέχον τρίμηνο",
+	"field-minute-relative+0": "τρέχον λεπτό",
+	"field-quarter-relative+1": "επόμενο τρίμηνο",
+	"field-wed-short-relative+-1": "προηγ. Τετ.",
+	"field-thu-short-relative+-1": "προηγ. Πέμ.",
+	"field-year-narrow-relative+-1": "πέρσι",
+	"field-mon-narrow-relative+-1": "προηγ. Δε",
+	"field-thu-narrow-relative+-1": "προηγ. Πέ",
+	"field-tue-narrow-relative+-1": "προηγ. Τρ",
+	"field-weekOfMonth-short": "εβδ. μήνα",
+	"field-wed-short-relative+0": "αυτήν την Τετ.",
+	"field-wed-short-relative+1": "επόμ. Τετ.",
+	"field-sun-relative+-1": "προηγούμενη Κυριακή",
+	"field-weekday": "καθημερινή",
+	"field-day-short-relative+0": "σήμερα",
+	"field-quarter-narrow-relative+0": "τρέχον τρίμ.",
+	"field-sat-relative+0": "αυτό το Σάββατο",
+	"field-day-short-relative+1": "αύριο",
+	"field-quarter-narrow-relative+1": "επόμ. τρίμ.",
+	"field-sat-relative+1": "επόμενο Σάββατο",
+	"field-week-short-relative+0": "τρέχ. εβδομάδα",
+	"field-week-short-relative+1": "επόμ. εβδομάδα",
+	"field-dayOfYear-narrow": "ημ. έτους",
+	"field-weekdayOfMonth-short": "καθημερ. μήνα",
+	"field-zone-narrow": "ζώνη",
+	"field-thu-narrow-relative+0": "αυτήν την Πέ",
+	"field-thu-narrow-relative+1": "επόμ. Πέ",
+	"field-sun-narrow-relative+-1": "προηγ. Κυ",
+	"field-mon-short-relative+-1": "προηγ. Δευτ.",
+	"field-thu-relative+0": "αυτήν την Πέμπτη",
+	"field-thu-relative+1": "επόμενη Πέμπτη",
+	"field-fri-short-relative+-1": "προηγ. Παρ.",
+	"field-thu-relative+-1": "προηγούμενη Πέμπτη",
+	"field-week": "εβδομάδα",
+	"field-wed-narrow-relative+0": "αυτήν την Τε",
+	"field-wed-narrow-relative+1": "επόμ. Τε",
+	"field-quarter-narrow-relative+-1": "προηγ. τρίμ.",
+	"field-year-short-relative+0": "φέτος",
+	"field-dayperiod-short": "πμ/μμ",
+	"field-year-short-relative+1": "επόμενο έτος",
+	"field-fri-short-relative+0": "αυτήν την Παρ.",
+	"field-fri-short-relative+1": "επόμ. Παρ.",
+	"field-week-short-relative+-1": "προηγ. εβδομάδα",
+	"field-hour-short": "ώ.",
+	"field-zone-short": "ζώνη",
+	"field-month-narrow": "μήν.",
+	"field-hour-narrow": "ώ.",
+	"field-fri-narrow-relative+-1": "προηγ. Πα",
+	"field-year-relative+0": "φέτος",
+	"field-year-relative+1": "επόμενο έτος",
+	"field-era-narrow": "περ.",
+	"field-fri-relative+-1": "προηγούμενη Παρασκευή",
+	"eraNarrow": [
+		"προ R.O.C.",
+		"R.O.C."
+	],
+	"field-tue-short-relative+-1": "προηγ. Τρ.",
+	"field-minute-narrow": "λ.",
+	"field-mon-narrow-relative+0": "αυτήν τη Δε",
+	"field-mon-narrow-relative+1": "επόμ. Δε",
+	"field-year-short-relative+-1": "πέρσι",
+	"field-zone": "ζώνη ώρας",
+	"field-weekOfMonth-narrow": "εβδ. μήνα",
+	"field-weekday-narrow": "καθημερ.",
+	"field-quarter-narrow": "τρίμ.",
+	"field-sun-short-relative+-1": "προηγ. Κυρ.",
+	"field-day-relative+-1": "χθες",
+	"field-day-relative+-2": "προχθές",
+	"field-weekday-short": "καθημερ.",
+	"field-sun-relative+0": "αυτήν την Κυριακή",
+	"field-sun-relative+1": "επόμενη Κυριακή",
+	"field-day-short": "ημ.",
+	"field-week-narrow": "εβδ.",
+	"field-era": "περίοδος",
+	"field-fri-narrow-relative+0": "αυτήν την Πα",
+	"field-fri-narrow-relative+1": "επόμ. Πα"
 }
 //end v1.x content
 );
\ No newline at end of file
