@@ -7,7 +7,7 @@ define(
 	"dayPeriods-standAlone-abbr-noon": "noon",
 	"field-tue-relative+-1": "last Tuesday",
 	"field-year": "year",
-	"dateFormatItem-yw": "'week' w 'of' y",
+	"dateFormatItem-yw": "'week' w 'of' Y",
 	"dayPeriods-format-abbr-afternoon1": "in the afternoon",
 	"dateFormatItem-Hm": "HH:mm",
 	"field-wed-relative+0": "this Wednesday",
@@ -23,8 +23,11 @@ define(
 	"field-day-relative+0": "today",
 	"field-day-relative+1": "tomorrow",
 	"field-wed-narrow-relative+-1": "last W",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
+	"field-era-short": "era",
 	"field-tue-relative+0": "this Tuesday",
 	"field-tue-relative+1": "next Tuesday",
+	"field-weekdayOfMonth": "weekday of the month",
 	"field-second-short": "sec.",
 	"dayPeriods-format-narrow-am": "a",
 	"dayPeriods-standAlone-abbr-morning1": "morning",
@@ -61,11 +64,13 @@ define(
 		"Before Christ",
 		"Anno Domini"
 	],
+	"field-weekOfMonth": "week of month",
 	"dayPeriods-standAlone-abbr-pm": "PM",
 	"field-month-short": "mo.",
 	"dateFormatItem-GyMMMEd": "E, MMM d, y G",
 	"field-day": "day",
 	"dayPeriods-standAlone-wide-night1": "night",
+	"field-dayOfYear-short": "day of yr.",
 	"field-year-relative+-1": "last year",
 	"dayPeriods-format-wide-am": "AM",
 	"field-sat-short-relative+-1": "last Sat.",
@@ -151,6 +156,7 @@ define(
 		"Sa"
 	],
 	"dayPeriods-format-wide-pm": "PM",
+	"field-dayOfYear": "day of year",
 	"field-sat-relative+-1": "last Saturday",
 	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
 	"dateTimeFormat-long": "{1} 'at' {0}",
@@ -181,6 +187,7 @@ define(
 	"field-fri-relative+0": "this Friday",
 	"field-sat-narrow-relative+1": "next Sa",
 	"field-fri-relative+1": "next Friday",
+	"dateFormatItem-EBhm": "E h:mm B",
 	"dayPeriods-format-narrow-noon": "n",
 	"field-sun-short-relative+0": "this Sun.",
 	"field-sun-short-relative+1": "next Sun.",
@@ -210,9 +217,10 @@ define(
 	"field-wed-short-relative+-1": "last Wed.",
 	"dateFormatItem-yMMM": "MMM y",
 	"dateFormat-short": "M/d/yy",
+	"dateFormatItem-Bh": "h B",
 	"field-thu-short-relative+-1": "last Thu.",
 	"dayPeriods-format-abbr-night1": "at night",
-	"dateFormatItem-MMMMW": "'week' W 'of' MMM",
+	"dateFormatItem-MMMMW": "'week' W 'of' MMMM",
 	"days-standAlone-wide": [
 		"Sunday",
 		"Monday",
@@ -227,8 +235,9 @@ define(
 	"dateFormatItem-MMMMd": "MMMM d",
 	"field-thu-narrow-relative+-1": "last Th",
 	"dateFormatItem-E": "ccc",
-	"field-tue-narrow-relative+-1": "last Tu",
 	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "wk. of mo.",
+	"field-tue-narrow-relative+-1": "last Tu",
 	"dayPeriods-format-abbr-evening1": "in the evening",
 	"dateFormatItem-M": "L",
 	"field-wed-short-relative+0": "this Wed.",
@@ -276,8 +285,9 @@ define(
 	],
 	"dayPeriods-format-abbr-morning1": "in the morning",
 	"field-month-short-relative+0": "this mo.",
-	"field-month-short-relative+1": "next mo.",
 	"timeFormat-full": "h:mm:ss a zzzz",
+	"field-month-short-relative+1": "next mo.",
+	"field-weekdayOfMonth-short": "wkday. of mo.",
 	"dateFormatItem-MEd": "E, M/d",
 	"dateFormatItem-y": "y",
 	"field-thu-narrow-relative+0": "this Th",
@@ -295,13 +305,13 @@ define(
 	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
 	"field-thu-relative+-1": "last Thursday",
 	"dateFormatItem-yMd": "M/d/y",
-	"field-week": "week",
 	"quarters-standAlone-narrow": [
 		"1",
 		"2",
 		"3",
 		"4"
 	],
+	"field-week": "week",
 	"quarters-format-wide": [
 		"1st quarter",
 		"2nd quarter",
@@ -313,6 +323,7 @@ define(
 	"field-wed-narrow-relative+1": "next W",
 	"dayPeriods-standAlone-wide-morning1": "morning",
 	"field-year-short-relative+0": "this yr.",
+	"field-dayperiod-short": "am/pm",
 	"field-year-short-relative+1": "next yr.",
 	"field-fri-short-relative+0": "this Fri.",
 	"field-fri-short-relative+1": "next Fri.",
@@ -329,6 +340,7 @@ define(
 	"field-week-short-relative+-1": "last wk.",
 	"dayPeriods-format-abbr-midnight": "midnight",
 	"field-hour-short": "hr.",
+	"field-zone-short": "zone",
 	"quarters-format-abbr": [
 		"Q1",
 		"Q2",
@@ -343,6 +355,7 @@ define(
 		"B",
 		"A"
 	],
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"dayPeriods-format-wide-noon": "noon",
 	"field-tue-short-relative+-1": "last Tue.",
 	"dayPeriods-standAlone-wide-afternoon1": "afternoon",
@@ -372,6 +385,8 @@ define(
 	"field-day-relative+-1": "yesterday",
 	"field-sun-short-relative+-1": "last Sun.",
 	"dayPeriods-format-narrow-night1": "at night",
+	"field-weekday-short": "day of wk.",
+	"dateFormatItem-Bhm": "h:mm B",
 	"days-format-abbr": [
 		"Sun",
 		"Mon",
