@@ -6,8 +6,11 @@ define(
 	"field-weekday": "day of the week",
 	"field-mon-narrow-relative+0": "this M",
 	"field-mon-narrow-relative+1": "next M",
+	"field-weekOfMonth-short": "wk. of mo.",
+	"field-weekday-short": "day of wk.",
 	"field-wed-relative+0": "this Wednesday",
 	"field-wed-relative+1": "next Wednesday",
+	"field-dayperiod-short": "am/pm",
 	"field-week-short": "wk.",
 	"field-tue-relative+-1": "last Tuesday",
 	"field-year-short": "yr.",
@@ -16,6 +19,7 @@ define(
 	"field-fri-relative+-1": "last Friday",
 	"field-hour-short": "hr.",
 	"field-wed-relative+-1": "last Wednesday",
+	"field-dayOfYear": "day of year",
 	"field-mon-short-relative+-1": "last Mon.",
 	"field-thu-relative+-1": "last Thursday",
 	"field-era": "era",
@@ -35,6 +39,7 @@ define(
 	"field-wed-narrow-relative+1": "next W",
 	"field-mon-short-relative+0": "this Mon.",
 	"field-mon-short-relative+1": "next Mon.",
+	"field-weekdayOfMonth-short": "wkday. of mo.",
 	"field-wed-short-relative+-1": "last Wed.",
 	"field-fri-narrow-relative+-1": "last F",
 	"field-tue-short-relative+0": "this Tue.",
@@ -59,6 +64,7 @@ define(
 	"field-day-short": "day",
 	"field-quarter-relative+0": "this quarter",
 	"field-quarter-relative+1": "next quarter",
+	"field-zone-short": "zone",
 	"field-fri-relative+0": "this Friday",
 	"field-fri-relative+1": "next Friday",
 	"field-day": "day",
@@ -69,6 +75,7 @@ define(
 	"field-thu-short-relative+1": "next Thu.",
 	"field-quarter": "quarter",
 	"field-month": "month",
+	"field-weekOfMonth": "week of month",
 	"field-tue-relative+0": "this Tuesday",
 	"field-quarter-short-relative+0": "this qtr.",
 	"field-tue-relative+1": "next Tuesday",
@@ -78,6 +85,7 @@ define(
 	"field-fri-short-relative+-1": "last Fri.",
 	"field-sun-narrow-relative+-1": "last Su",
 	"field-quarter-short-relative+-1": "last qtr.",
+	"field-dayOfYear-short": "day of yr.",
 	"field-sun-narrow-relative+0": "this Su",
 	"field-thu-narrow-relative+0": "this Th",
 	"field-sun-narrow-relative+1": "next Su",
@@ -97,6 +105,7 @@ define(
 	"field-month-short-relative+0": "this mo.",
 	"field-month-relative+0": "this month",
 	"field-month-short-relative+1": "next mo.",
+	"field-weekdayOfMonth": "weekday of the month",
 	"field-month-relative+1": "next month",
 	"field-week-short-relative+0": "this wk.",
 	"field-week-short-relative+1": "next wk.",
@@ -107,6 +116,7 @@ define(
 	"field-week-relative+-1": "last week",
 	"field-year-relative+1": "next year",
 	"field-year-short-relative+-1": "last yr.",
+	"field-era-short": "era",
 	"field-quarter-short": "qtr.",
 	"field-sun-short-relative+-1": "last Sun.",
 	"field-thu-short-relative+-1": "last Thu.",
