@@ -11,21 +11,26 @@ define(
 	"field-month-narrow-relative+-1": "el mes pasado",
 	"field-tue-narrow-relative+0": "este MA",
 	"field-tue-narrow-relative+1": "el próximo MA",
-	"field-thu-short-relative+0": "este jue.",
 	"field-day-short-relative+-1": "ayer",
-	"field-thu-short-relative+1": "el próximo jue.",
+	"field-thu-short-relative+0": "este jue.",
 	"field-day-relative+0": "hoy",
 	"field-day-short-relative+-2": "anteayer",
+	"field-thu-short-relative+1": "el próximo jue.",
 	"field-day-relative+1": "mañana",
+	"field-week-narrow-relative+0": "esta sem.",
 	"field-day-relative+2": "pasado mañana",
+	"field-week-narrow-relative+1": "próx. sem.",
 	"field-wed-narrow-relative+-1": "el MI pasado",
 	"field-year-narrow": "a",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "este año",
 	"field-tue-relative+0": "este martes",
 	"field-year-narrow-relative+1": "el próximo año",
 	"field-tue-relative+1": "el próximo martes",
+	"field-weekdayOfMonth": "día de la semana del mes",
 	"field-second-short": "s",
 	"dateFormatItem-MMMd": "d-M",
+	"field-weekdayOfMonth-narrow": "día de sem. de mes",
 	"field-week-relative+0": "esta semana",
 	"field-month-relative+0": "este mes",
 	"field-week-relative+1": "la próxima semana",
@@ -36,10 +41,12 @@ define(
 	"field-mon-short-relative+1": "el próximo lun.",
 	"field-second-relative+0": "ahora",
 	"dateFormatItem-yyyyQQQ": "QQQ y",
+	"field-weekOfMonth": "semana del mes",
 	"field-month-short": "m",
 	"dateFormatItem-GyMMMEd": "E, d-M-y",
 	"dateFormatItem-yyyyMd": "d-M-y",
 	"field-day": "día",
+	"field-dayOfYear-short": "día del a",
 	"field-year-relative+-1": "el año pasado",
 	"field-sat-short-relative+-1": "el sáb. pasado",
 	"field-hour-relative+0": "esta hora",
@@ -63,7 +70,7 @@ define(
 	"field-day-narrow": "d",
 	"dateFormatItem-MMM": "L",
 	"field-minute-short": "min",
-	"field-dayperiod": "a. m./p. m.",
+	"field-dayperiod": "a. m./p. m.",
 	"field-sat-short-relative+0": "este sáb.",
 	"field-sat-short-relative+1": "el próximo sáb.",
 	"dateFormat-medium": "d-M-y",
@@ -77,6 +84,9 @@ define(
 	"field-day-narrow-relative+-2": "anteayer",
 	"field-quarter-relative+-1": "el trimestre pasado",
 	"dateFormatItem-yyyyMMMd": "d-M-y",
+	"field-dayperiod-narrow": "a. m./p. m.",
+	"field-week-narrow-relative+-1": "sem. ant.",
+	"field-dayOfYear": "día del año",
 	"field-sat-relative+-1": "el sábado pasado",
 	"dateFormatItem-Md": "d-M",
 	"field-hour": "hora",
@@ -98,13 +108,14 @@ define(
 	"field-quarter-relative+1": "el próximo trimestre",
 	"field-wed-short-relative+-1": "el mié. pasado",
 	"dateFormat-short": "d-M-y",
-	"field-thu-short-relative+-1": "el jue. pasado",
 	"field-year-narrow-relative+-1": "el año pasado",
+	"field-thu-short-relative+-1": "el jue. pasado",
 	"dateFormatItem-yyyyMMMEd": "E, d-M-y",
 	"field-mon-narrow-relative+-1": "el LU pasado",
 	"field-thu-narrow-relative+-1": "el JU pasado",
 	"field-tue-narrow-relative+-1": "el MA pasado",
 	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "sem. de mes",
 	"dateFormatItem-yyyy": "y",
 	"field-wed-short-relative+0": "este mié.",
 	"dateFormatItem-M": "L",
@@ -119,14 +130,19 @@ define(
 	"dateFormatItem-h": "hh a",
 	"field-day-short-relative+2": "pasado mañana",
 	"field-sat-relative+1": "el próximo sábado",
+	"field-week-short-relative+0": "esta sem.",
+	"field-week-short-relative+1": "próx. sem.",
+	"field-dayOfYear-narrow": "día del a",
 	"field-month-short-relative+0": "este mes",
 	"field-month-short-relative+1": "el próximo mes",
+	"field-weekdayOfMonth-short": "día de sem. de mes",
 	"dateFormatItem-MEd": "E, d-M",
+	"field-zone-narrow": "zona",
 	"dateFormatItem-y": "y",
 	"field-thu-narrow-relative+0": "este JU",
-	"field-thu-narrow-relative+1": "el próximo JU",
 	"field-sun-narrow-relative+-1": "el DO pasado",
 	"field-mon-short-relative+-1": "el lun. pasado",
+	"field-thu-narrow-relative+1": "el próximo JU",
 	"field-thu-relative+0": "este jueves",
 	"field-thu-relative+1": "el próximo jueves",
 	"dateFormatItem-hms": "hh:mm:ss a",
@@ -138,16 +154,20 @@ define(
 	"field-wed-narrow-relative+1": "el próximo MI",
 	"field-year-short-relative+0": "este año",
 	"dateFormatItem-yyyyMMM": "M-y",
+	"field-dayperiod-short": "a. m./p. m.",
 	"field-year-short-relative+1": "el próximo año",
 	"field-fri-short-relative+0": "este vie.",
 	"field-fri-short-relative+1": "el próximo vie.",
+	"field-week-short-relative+-1": "sem. ant.",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y",
 	"field-hour-short": "h",
+	"field-zone-short": "zona",
 	"field-month-narrow": "m",
 	"field-hour-narrow": "h",
 	"field-fri-narrow-relative+-1": "el VI pasado",
 	"field-year-relative+0": "este año",
 	"field-year-relative+1": "el próximo año",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "el viernes pasado",
 	"field-tue-short-relative+-1": "el mar. pasado",
 	"field-minute-narrow": "min",
@@ -156,10 +176,13 @@ define(
 	"field-year-short-relative+-1": "el año pasado",
 	"field-zone": "zona horaria",
 	"dateFormatItem-MMMEd": "E d-M",
+	"field-weekOfMonth-narrow": "sem. de mes",
+	"field-weekday-narrow": "día de sem.",
 	"field-quarter-narrow": "trim.",
 	"field-sun-short-relative+-1": "el dom. pasado",
 	"field-day-relative+-1": "ayer",
 	"field-day-relative+-2": "anteayer",
+	"field-weekday-short": "día de sem.",
 	"field-sun-relative+0": "este domingo",
 	"field-sun-relative+1": "el próximo domingo",
 	"dateFormatItem-Gy": "y",
