@@ -6,14 +6,14 @@ define(
 	"JPY_displayName": "yen",
 	"JPY_symbol": "JPY",
 	"USD_displayName": "dólar estadounidense",
-	"CAD_symbol": "CA$",
-	"GBP_displayName": "libra británica",
+	"CAD_symbol": "CAD",
+	"GBP_displayName": "libra esterlina",
 	"CHF_displayName": "franco suizo",
 	"CNY_symbol": "CNY",
 	"EUR_displayName": "euro",
 	"GBP_symbol": "GBP",
 	"CAD_displayName": "dólar canadiense",
-	"USD_symbol": "$",
+	"USD_symbol": "US$",
 	"EUR_symbol": "€",
 	"AUD_displayName": "dólar australiano",
 	"CHF_symbol": "CHF",
