@@ -16,6 +16,7 @@ define(
 	"field-tue-narrow-relative+1": "ensi ti",
 	"field-thu-short-relative+0": "tänä to",
 	"field-day-short-relative+-1": "eilen",
+	"dateTimeFormat-short": "{1} {0}",
 	"field-thu-short-relative+1": "ensi to",
 	"field-day-relative+0": "tänään",
 	"field-day-short-relative+-2": "toissap.",
@@ -24,14 +25,19 @@ define(
 	"field-day-relative+2": "ylihuomenna",
 	"field-week-narrow-relative+1": "ensi vk",
 	"field-wed-narrow-relative+-1": "viime ke",
+	"dateFormatItem-EBhms": "E h.mm.ss B",
 	"field-year-narrow": "v",
+	"field-era-short": "aikakausi",
 	"field-year-narrow-relative+0": "tänä v",
 	"field-tue-relative+0": "tänä tiistaina",
 	"field-year-narrow-relative+1": "ensi v",
 	"field-tue-relative+1": "ensi tiistaina",
+	"field-weekdayOfMonth": "kuukauden viikonpäivä",
 	"field-second-short": "s",
 	"dayPeriods-format-narrow-am": "ap.",
+	"dateFormatItem-yyyyMM": "M.y G",
 	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "kuukauden vk päivä",
 	"dayPeriods-format-abbr-am": "ap.",
 	"field-week-relative+0": "tällä viikolla",
 	"field-month-relative+0": "tässä kuussa",
@@ -58,11 +64,16 @@ define(
 		"M",
 		"J"
 	],
+	"eraNames": [
+		"buddhalainen aika"
+	],
+	"field-weekOfMonth": "kuukauden viikko",
 	"dayPeriods-standAlone-abbr-pm": "ip.",
 	"field-month-short": "kk",
 	"dateFormatItem-GyMMMEd": "E d. MMM y G",
 	"dateFormatItem-yyyyMd": "d.M.y G",
 	"field-day": "päivä",
+	"field-dayOfYear-short": "vuodenpv",
 	"field-year-relative+-1": "viime vuonna",
 	"dayPeriods-format-wide-am": "ap.",
 	"field-sat-short-relative+-1": "viime la",
@@ -82,7 +93,9 @@ define(
 		"P",
 		"L"
 	],
+	"dateFormatItem-yyyyMMMMccccd": "cccc d. MMMM y G",
 	"dayPeriods-standAlone-wide-pm": "ip.",
+	"dateFormatItem-Ehms": "E h.mm.ss a",
 	"dateFormat-long": "d. MMMM y G",
 	"dateFormatItem-GyMMMd": "d. MMM y G",
 	"field-hour-short-relative+0": "tunnin sisällä",
@@ -113,7 +126,6 @@ define(
 	"dateFormatItem-GyMMM": "LLL y G",
 	"field-month": "kuukausi",
 	"field-day-narrow": "pv",
-	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
 	"field-dayperiod": "vuorokaudenaika",
 	"field-sat-short-relative+0": "tänä la",
@@ -121,9 +133,6 @@ define(
 	"dayPeriods-format-narrow-pm": "ip.",
 	"dateFormat-medium": "d.M.y G",
 	"dateFormatItem-yyyyMMMM": "LLLL y G",
-	"eraAbbr": [
-		"BE"
-	],
 	"quarters-standAlone-abbr": [
 		"1. nelj.",
 		"2. nelj.",
@@ -154,6 +163,7 @@ define(
 	],
 	"field-quarter-relative+-1": "viime neljännesvuonna",
 	"dateFormatItem-yyyyMMMd": "d. MMM y G",
+	"field-dayperiod-narrow": "vuorokaudenaika",
 	"dayPeriods-standAlone-narrow-am": "ap.",
 	"field-week-narrow-relative+-1": "viime vk",
 	"days-format-short": [
@@ -166,6 +176,7 @@ define(
 		"la"
 	],
 	"dayPeriods-format-wide-pm": "ip.",
+	"field-dayOfYear": "vuodenpäivä",
 	"field-sat-relative+-1": "viime lauantaina",
 	"dateTimeFormat-long": "{1} 'klo' {0}",
 	"dateFormatItem-Md": "d.M.",
@@ -193,6 +204,7 @@ define(
 	"field-fri-relative+0": "tänä perjantaina",
 	"field-sat-narrow-relative+1": "ensi la",
 	"field-fri-relative+1": "ensi perjantaina",
+	"dateFormatItem-EBhm": "E h.mm B",
 	"field-month-narrow-relative+0": "tässä kk",
 	"field-month-narrow-relative+1": "ensi kk",
 	"field-sun-short-relative+0": "tänä su",
@@ -200,6 +212,7 @@ define(
 	"field-week-relative+-1": "viime viikolla",
 	"field-quarter-short-relative+-1": "viime neljänneksenä",
 	"field-minute-short-relative+0": "minuutin sisällä",
+	"dateFormatItem-Ehm": "E h.mm a",
 	"months-format-abbr": [
 		"tammik.",
 		"helmik.",
@@ -220,8 +233,9 @@ define(
 	"field-quarter-relative+1": "ensi neljännesvuonna",
 	"field-wed-short-relative+-1": "viime ke",
 	"dateFormat-short": "d.M.y GGGGG",
-	"field-thu-short-relative+-1": "viime to",
 	"field-year-narrow-relative+-1": "viime v",
+	"field-thu-short-relative+-1": "viime to",
+	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
 	"days-standAlone-wide": [
 		"sunnuntai",
 		"maanantai",
@@ -231,16 +245,15 @@ define(
 		"perjantai",
 		"lauantai"
 	],
-	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
 	"field-mon-narrow-relative+-1": "viime ma",
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "viime to",
 	"field-tue-narrow-relative+-1": "viime ti",
+	"field-weekOfMonth-short": "kuukauden vk",
 	"dateFormatItem-H": "H",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "ip.",
 	"field-wed-short-relative+0": "tänä ke",
-	"dateFormatItem-M": "L",
 	"months-standAlone-wide": [
 		"tammikuu",
 		"helmikuu",
@@ -266,10 +279,9 @@ define(
 		"pe",
 		"la"
 	],
-	"field-second-narrow-relative+0": "nyt",
 	"dateTimeFormat-full": "{1} 'klo' {0}",
+	"field-second-narrow-relative+0": "nyt",
 	"dateFormatItem-hm": "h.mm a",
-	"dateFormatItem-d": "d",
 	"field-weekday": "viikonpäivä",
 	"field-day-short-relative+0": "tänään",
 	"field-quarter-narrow-relative+0": "tänä nelj.",
@@ -294,15 +306,18 @@ define(
 		"marras",
 		"joulu"
 	],
+	"field-dayOfYear-narrow": "vuodenpv",
 	"field-month-short-relative+0": "tässä kk",
 	"field-month-short-relative+1": "ensi kk",
+	"field-weekdayOfMonth-short": "kuukauden vk päivä",
 	"timeFormat-full": "H.mm.ss zzzz",
 	"dateFormatItem-MEd": "E d.M.",
+	"field-zone-narrow": "aikavyöhyke",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "tänä to",
-	"field-thu-narrow-relative+1": "ensi to",
 	"field-sun-narrow-relative+-1": "viime su",
 	"field-mon-short-relative+-1": "viime ma",
+	"field-thu-narrow-relative+1": "ensi to",
 	"field-thu-relative+0": "tänä torstaina",
 	"field-thu-relative+1": "ensi torstaina",
 	"field-fri-short-relative+-1": "viime pe",
@@ -321,6 +336,7 @@ define(
 	"field-quarter-narrow-relative+-1": "viime nelj.",
 	"field-year-short-relative+0": "tänä v",
 	"dateFormatItem-yyyyMMM": "LLL y G",
+	"field-dayperiod-short": "vuorokaudenaika",
 	"field-year-short-relative+1": "ensi v",
 	"field-fri-short-relative+0": "tänä pe",
 	"field-fri-short-relative+1": "ensi pe",
@@ -337,6 +353,7 @@ define(
 	"field-hour-narrow-relative+0": "tunnin sisällä",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "t",
+	"field-zone-short": "aikavyöhyke",
 	"quarters-format-abbr": [
 		"1. nelj.",
 		"2. nelj.",
@@ -348,7 +365,9 @@ define(
 	"field-fri-narrow-relative+-1": "viime pe",
 	"field-year-relative+0": "tänä vuonna",
 	"field-year-relative+1": "ensi vuonna",
+	"field-era-narrow": "aikakausi",
 	"field-fri-relative+-1": "viime perjantaina",
+	"dateFormatItem-Bhms": "h.mm.ss B",
 	"field-tue-short-relative+-1": "viime ti",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -362,14 +381,19 @@ define(
 	],
 	"field-mon-narrow-relative+0": "tänä ma",
 	"field-mon-narrow-relative+1": "ensi ma",
+	"dateFormatItem-EHm": "E HH.mm",
 	"field-year-short-relative+-1": "viime v",
 	"field-zone": "aikavyöhyke",
 	"dateFormatItem-MMMEd": "ccc d. MMM",
+	"field-weekOfMonth-narrow": "kuukauden vk",
+	"dateFormatItem-EHms": "E HH.mm.ss",
+	"field-weekday-narrow": "viikonpäivä",
 	"field-quarter-narrow": "nelj.",
 	"field-sun-short-relative+-1": "viime su",
 	"field-day-relative+-1": "eilen",
 	"dayPeriods-standAlone-abbr-am": "ap.",
 	"field-day-relative+-2": "toissa päivänä",
+	"field-weekday-short": "viikonpäivä",
 	"days-format-abbr": [
 		"su",
 		"ma",
@@ -379,6 +403,7 @@ define(
 		"pe",
 		"la"
 	],
+	"dateFormatItem-Bhm": "h.mm B",
 	"field-sun-relative+0": "tänä sunnuntaina",
 	"field-sun-relative+1": "ensi sunnuntaina",
 	"dateFormatItem-Gy": "y G",
