@@ -23,15 +23,19 @@ define(
 	"field-week-narrow-relative+0": "tällä vk",
 	"field-day-relative+2": "ylihuomenna",
 	"field-week-narrow-relative+1": "ensi vk",
+	"dateFormatItem-EBhms": "E h.mm.ss B",
 	"field-wed-narrow-relative+-1": "viime ke",
 	"field-year-narrow": "v",
+	"field-era-short": "aikakausi",
 	"field-year-narrow-relative+0": "tänä v",
 	"field-tue-relative+0": "tänä tiistaina",
 	"field-year-narrow-relative+1": "ensi v",
 	"field-tue-relative+1": "ensi tiistaina",
+	"field-weekdayOfMonth": "kuukauden viikonpäivä",
 	"field-second-short": "s",
 	"dateFormatItem-yyyyMM": "M.y G",
 	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "kuukauden vk päivä",
 	"field-week-relative+0": "tällä viikolla",
 	"field-month-relative+0": "tässä kuussa",
 	"field-week-relative+1": "ensi viikolla",
@@ -42,10 +46,12 @@ define(
 	"field-mon-short-relative+1": "ensi ma",
 	"field-second-relative+0": "nyt",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"field-weekOfMonth": "kuukauden viikko",
 	"field-month-short": "kk",
 	"dateFormatItem-GyMMMEd": "E d. MMM y G",
 	"dateFormatItem-yyyyMd": "d.M.y G",
 	"field-day": "päivä",
+	"field-dayOfYear-short": "vuodenpv",
 	"field-year-relative+-1": "viime vuonna",
 	"field-sat-short-relative+-1": "viime la",
 	"field-hour-relative+0": "tämän tunnin aikana",
@@ -56,6 +62,7 @@ define(
 	"field-sat-narrow-relative+-1": "viime la",
 	"field-second": "sekunti",
 	"dateFormatItem-yyyyMMMMccccd": "cccc d. MMMM y G",
+	"dateFormatItem-Ehms": "E h.mm.ss a",
 	"dateFormat-long": "d. MMMM y G",
 	"dateFormatItem-GyMMMd": "d. MMM y G",
 	"field-hour-short-relative+0": "tunnin sisällä",
@@ -81,13 +88,15 @@ define(
 	"dateFormatItem-yyyyM": "L.y G",
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "tänä maanantaina",
-	"field-mon-relative+1": "ensi maanantaina",
 	"field-day-narrow-relative+-1": "eilen",
 	"field-year-short": "v",
+	"field-mon-relative+1": "ensi maanantaina",
 	"field-day-narrow-relative+-2": "toissap.",
 	"field-quarter-relative+-1": "viime neljännesvuonna",
 	"dateFormatItem-yyyyMMMd": "d. MMM y G",
+	"field-dayperiod-narrow": "vuorokaudenaika",
 	"field-week-narrow-relative+-1": "viime vk",
+	"field-dayOfYear": "vuodenpäivä",
 	"field-sat-relative+-1": "viime lauantaina",
 	"dateTimeFormat-long": "{1} 'klo' {0}",
 	"dateFormatItem-Md": "d.M.",
@@ -101,18 +110,21 @@ define(
 	"field-fri-relative+0": "tänä perjantaina",
 	"field-sat-narrow-relative+1": "ensi la",
 	"field-fri-relative+1": "ensi perjantaina",
+	"dateFormatItem-EBhm": "E h.mm B",
 	"field-month-narrow-relative+0": "tässä kk",
 	"field-month-narrow-relative+1": "ensi kk",
 	"field-sun-short-relative+0": "tänä su",
 	"field-sun-short-relative+1": "ensi su",
 	"field-week-relative+-1": "viime viikolla",
 	"field-quarter-short-relative+-1": "viime neljänneksenä",
+	"dateFormatItem-Ehm": "E h.mm a",
 	"field-minute-short-relative+0": "minuutin sisällä",
 	"field-quarter-relative+0": "tänä neljännesvuonna",
 	"field-minute-relative+0": "tämän minuutin aikana",
 	"field-quarter-relative+1": "ensi neljännesvuonna",
 	"field-wed-short-relative+-1": "viime ke",
 	"dateFormat-short": "d.M.y GGGGG",
+	"dateFormatItem-Bh": "h B",
 	"field-year-narrow-relative+-1": "viime v",
 	"field-thu-short-relative+-1": "viime to",
 	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
@@ -120,11 +132,12 @@ define(
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "viime to",
 	"dateFormatItem-E": "ccc",
-	"field-tue-narrow-relative+-1": "viime ti",
 	"dateFormatItem-H": "H",
+	"field-weekOfMonth-short": "kuukauden vk",
+	"field-tue-narrow-relative+-1": "viime ti",
 	"dateFormatItem-yyyy": "y G",
-	"field-wed-short-relative+0": "tänä ke",
 	"dateFormatItem-M": "L",
+	"field-wed-short-relative+0": "tänä ke",
 	"field-wed-short-relative+1": "ensi ke",
 	"field-sun-relative+-1": "viime sunnuntaina",
 	"dateTimeFormat-full": "{1} 'klo' {0}",
@@ -142,9 +155,12 @@ define(
 	"field-sat-relative+1": "ensi lauantaina",
 	"field-week-short-relative+0": "tällä vk",
 	"field-week-short-relative+1": "ensi vk",
+	"field-dayOfYear-narrow": "vuodenpv",
 	"field-month-short-relative+0": "tässä kk",
 	"field-month-short-relative+1": "ensi kk",
+	"field-weekdayOfMonth-short": "kuukauden vk päivä",
 	"dateFormatItem-MEd": "E d.M.",
+	"field-zone-narrow": "aikavyöhyke",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "tänä to",
 	"field-sun-narrow-relative+-1": "viime su",
@@ -162,6 +178,7 @@ define(
 	"field-quarter-narrow-relative+-1": "viime nelj.",
 	"field-year-short-relative+0": "tänä v",
 	"dateFormatItem-yyyyMMM": "LLL y G",
+	"field-dayperiod-short": "vuorokaudenaika",
 	"field-year-short-relative+1": "ensi v",
 	"field-fri-short-relative+0": "tänä pe",
 	"field-fri-short-relative+1": "ensi pe",
@@ -169,23 +186,32 @@ define(
 	"field-hour-narrow-relative+0": "tunnin sisällä",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "t",
+	"field-zone-short": "aikavyöhyke",
 	"field-month-narrow": "kk",
 	"field-hour-narrow": "t",
 	"field-fri-narrow-relative+-1": "viime pe",
 	"field-year-relative+0": "tänä vuonna",
 	"field-year-relative+1": "ensi vuonna",
+	"field-era-narrow": "aikakausi",
 	"field-fri-relative+-1": "viime perjantaina",
+	"dateFormatItem-Bhms": "h.mm.ss B",
 	"field-tue-short-relative+-1": "viime ti",
 	"field-minute-narrow": "min",
 	"field-mon-narrow-relative+0": "tänä ma",
+	"dateFormatItem-EHm": "E HH.mm",
 	"field-mon-narrow-relative+1": "ensi ma",
 	"field-year-short-relative+-1": "viime v",
 	"field-zone": "aikavyöhyke",
 	"dateFormatItem-MMMEd": "ccc d. MMM",
+	"field-weekOfMonth-narrow": "kuukauden vk",
+	"dateFormatItem-EHms": "E HH.mm.ss",
+	"field-weekday-narrow": "viikonpäivä",
 	"field-quarter-narrow": "nelj.",
 	"field-sun-short-relative+-1": "viime su",
 	"field-day-relative+-1": "eilen",
 	"field-day-relative+-2": "toissa päivänä",
+	"field-weekday-short": "viikonpäivä",
+	"dateFormatItem-Bhm": "h.mm B",
 	"field-sun-relative+0": "tänä sunnuntaina",
 	"field-sun-relative+1": "ensi sunnuntaina",
 	"dateFormatItem-Gy": "y G",
