@@ -22,11 +22,14 @@ define(
 	"field-week-narrow-relative+1": "ensi vk",
 	"field-wed-narrow-relative+-1": "viime ke",
 	"field-year-narrow": "v",
+	"field-era-short": "aikakausi",
 	"field-year-narrow-relative+0": "tänä v",
 	"field-tue-relative+0": "tänä tiistaina",
 	"field-year-narrow-relative+1": "ensi v",
 	"field-tue-relative+1": "ensi tiistaina",
+	"field-weekdayOfMonth": "kuukauden viikonpäivä",
 	"field-second-short": "s",
+	"field-weekdayOfMonth-narrow": "kuukauden vk päivä",
 	"field-week-relative+0": "tällä viikolla",
 	"field-month-relative+0": "tässä kuussa",
 	"field-week-relative+1": "ensi viikolla",
@@ -36,8 +39,10 @@ define(
 	"field-sun-narrow-relative+1": "ensi su",
 	"field-mon-short-relative+1": "ensi ma",
 	"field-second-relative+0": "nyt",
+	"field-weekOfMonth": "kuukauden viikko",
 	"field-month-short": "kk",
 	"field-day": "päivä",
+	"field-dayOfYear-short": "vuodenpv",
 	"field-year-relative+-1": "viime vuonna",
 	"field-sat-short-relative+-1": "viime la",
 	"field-hour-relative+0": "tämän tunnin aikana",
@@ -70,7 +75,9 @@ define(
 	"field-year-short": "v",
 	"field-day-narrow-relative+-2": "toissap.",
 	"field-quarter-relative+-1": "viime neljännesvuonna",
+	"field-dayperiod-narrow": "vuorokaudenaika",
 	"field-week-narrow-relative+-1": "viime vk",
+	"field-dayOfYear": "vuodenpäivä",
 	"field-sat-relative+-1": "viime lauantaina",
 	"field-hour": "tunti",
 	"field-minute-narrow-relative+0": "minuutin sisällä",
@@ -98,6 +105,7 @@ define(
 	"field-mon-narrow-relative+-1": "viime ma",
 	"field-thu-narrow-relative+-1": "viime to",
 	"field-tue-narrow-relative+-1": "viime ti",
+	"field-weekOfMonth-short": "kuukauden vk",
 	"field-wed-short-relative+0": "tänä ke",
 	"field-wed-short-relative+1": "ensi ke",
 	"field-sun-relative+-1": "viime sunnuntaina",
@@ -112,8 +120,11 @@ define(
 	"field-day-short-relative+2": "ylihuom.",
 	"field-week-short-relative+0": "tällä vk",
 	"field-week-short-relative+1": "ensi vk",
+	"field-dayOfYear-narrow": "vuodenpv",
 	"field-month-short-relative+0": "tässä kk",
 	"field-month-short-relative+1": "ensi kk",
+	"field-weekdayOfMonth-short": "kuukauden vk päivä",
+	"field-zone-narrow": "aikavyöhyke",
 	"field-thu-narrow-relative+0": "tänä to",
 	"field-thu-narrow-relative+1": "ensi to",
 	"field-sun-narrow-relative+-1": "viime su",
@@ -127,17 +138,20 @@ define(
 	"field-wed-narrow-relative+1": "ensi ke",
 	"field-quarter-narrow-relative+-1": "viime nelj.",
 	"field-year-short-relative+0": "tänä v",
+	"field-dayperiod-short": "vuorokaudenaika",
 	"field-year-short-relative+1": "ensi v",
 	"field-fri-short-relative+0": "tänä pe",
 	"field-fri-short-relative+1": "ensi pe",
 	"field-week-short-relative+-1": "viime vk",
 	"field-hour-narrow-relative+0": "tunnin sisällä",
 	"field-hour-short": "t",
+	"field-zone-short": "aikavyöhyke",
 	"field-month-narrow": "kk",
 	"field-hour-narrow": "t",
 	"field-fri-narrow-relative+-1": "viime pe",
 	"field-year-relative+0": "tänä vuonna",
 	"field-year-relative+1": "ensi vuonna",
+	"field-era-narrow": "aikakausi",
 	"field-fri-relative+-1": "viime perjantaina",
 	"field-tue-short-relative+-1": "viime ti",
 	"field-minute-narrow": "min",
@@ -145,10 +159,13 @@ define(
 	"field-mon-narrow-relative+1": "ensi ma",
 	"field-year-short-relative+-1": "viime v",
 	"field-zone": "aikavyöhyke",
+	"field-weekOfMonth-narrow": "kuukauden vk",
+	"field-weekday-narrow": "viikonpäivä",
 	"field-quarter-narrow": "nelj.",
 	"field-sun-short-relative+-1": "viime su",
 	"field-day-relative+-1": "eilen",
 	"field-day-relative+-2": "toissa päivänä",
+	"field-weekday-short": "viikonpäivä",
 	"field-sun-relative+0": "tänä sunnuntaina",
 	"field-sun-relative+1": "ensi sunnuntaina",
 	"field-day-short": "pv",
