@@ -3,12 +3,9 @@ define(
 {
 	"dayPeriods-format-narrow-noon": "midi",
 	"dateFormatItem-yMd": "dd.MM.y",
-	"dayPeriods-format-wide-afternoon1": "de l’après-midi",
 	"dateFormatItem-MEd": "E, dd.MM.",
 	"dateFormatItem-MMdd": "dd.MM",
 	"dateFormatItem-yMEd": "E, dd.MM.y",
-	"dayPeriods-format-wide-noon": "midi",
-	"dayPeriods-format-wide-night1": "du matin",
 	"dayPeriods-format-narrow-night1": "du mat.",
 	"timeFormat-full": "HH.mm:ss 'h' zzzz",
 	"dateFormatItem-Md": "dd.MM.",
@@ -20,16 +17,13 @@ define(
 	"dayPeriods-format-abbr-evening1": "du soir",
 	"dayPeriods-format-narrow-midnight": "min.",
 	"dayPeriods-format-narrow-afternoon1": "de l’ap.m.",
-	"dayPeriods-format-wide-midnight": "minuit",
 	"dateFormat-short": "dd.MM.yy",
 	"dayPeriods-standAlone-narrow-midnight": "min.",
 	"dateFormatItem-yM": "MM.y",
 	"dayPeriods-format-narrow-morning1": "du mat.",
-	"dayPeriods-format-wide-morning1": "du matin",
 	"dayPeriods-format-narrow-evening1": "du soir",
 	"dayPeriods-format-abbr-noon": "midi",
-	"dateFormat-full": "EEEE, d MMMM y",
-	"dayPeriods-format-wide-evening1": "du soir"
+	"dateFormat-full": "EEEE, d MMMM y"
 }
 //end v1.x content
 );
\ No newline at end of file
