@@ -8,26 +8,36 @@ define(
 	"field-wed-relative+0": "ce mercredi",
 	"field-wed-relative+1": "mercredi prochain",
 	"field-minute": "minute",
-	"field-tue-narrow-relative+0": "ce mar",
-	"field-tue-narrow-relative+1": "mar proch",
+	"field-month-narrow-relative+-1": "le mois dernier",
+	"field-tue-narrow-relative+0": "ce mar.",
+	"field-tue-narrow-relative+1": "mar. prochain",
 	"field-thu-short-relative+0": "ce jeu.",
+	"field-day-short-relative+-1": "hier",
 	"field-thu-short-relative+1": "jeu. prochain",
 	"field-day-relative+0": "aujourd’hui",
+	"field-day-short-relative+-2": "avant-hier",
 	"field-day-relative+1": "demain",
+	"field-week-narrow-relative+0": "cette semaine",
 	"field-day-relative+2": "après-demain",
-	"field-wed-narrow-relative+-1": "mer dern",
+	"field-week-narrow-relative+1": "la semaine prochaine",
+	"field-wed-narrow-relative+-1": "mer. dernier",
 	"field-year-narrow": "a",
+	"field-era-short": "ère",
+	"field-year-narrow-relative+0": "cette année",
 	"field-tue-relative+0": "ce mardi",
+	"field-year-narrow-relative+1": "l’année prochaine",
 	"field-tue-relative+1": "mardi prochain",
+	"field-weekdayOfMonth": "jour (mois)",
 	"field-second-short": "s",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "jour (mois)",
 	"field-week-relative+0": "cette semaine",
 	"field-month-relative+0": "ce mois-ci",
 	"field-week-relative+1": "la semaine prochaine",
 	"field-month-relative+1": "le mois prochain",
-	"field-sun-narrow-relative+0": "ce dim",
+	"field-sun-narrow-relative+0": "ce dim.",
 	"field-mon-short-relative+0": "ce lun.",
-	"field-sun-narrow-relative+1": "dim proch",
+	"field-sun-narrow-relative+1": "dim. prochain",
 	"field-mon-short-relative+1": "lun. prochain",
 	"field-second-relative+0": "maintenant",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
@@ -45,16 +55,21 @@ define(
 		"11",
 		"12"
 	],
+	"eraNames": [
+		"ère de l’Hégire"
+	],
+	"field-weekOfMonth": "semaine (mois)",
 	"field-month-short": "m.",
 	"dateFormatItem-GyMMMEd": "E d MMM y G",
 	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
 	"field-day": "jour",
+	"field-dayOfYear-short": "j (an)",
 	"field-year-relative+-1": "l’année dernière",
 	"field-sat-short-relative+-1": "sam. dernier",
 	"field-hour-relative+0": "cette heure-ci",
 	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
 	"field-wed-relative+-1": "mercredi dernier",
-	"field-sat-narrow-relative+-1": "sam dern",
+	"field-sat-narrow-relative+-1": "sam. dernier",
 	"field-second": "seconde",
 	"days-standAlone-narrow": [
 		"D",
@@ -70,6 +85,9 @@ define(
 	"field-hour-short-relative+0": "cette h",
 	"field-quarter": "trimestre",
 	"field-week-short": "sem.",
+	"field-day-narrow-relative+0": "aujourd’hui",
+	"field-day-narrow-relative+1": "demain",
+	"field-day-narrow-relative+2": "après-demain",
 	"quarters-standAlone-wide": [
 		"1er trimestre",
 		"2e trimestre",
@@ -87,6 +105,7 @@ define(
 	],
 	"field-tue-short-relative+0": "ce mar.",
 	"field-tue-short-relative+1": "mar. prochain",
+	"field-month-short-relative+-1": "le mois dernier",
 	"field-mon-relative+-1": "lundi dernier",
 	"dateFormatItem-GyMMM": "MMM y G",
 	"field-month": "mois",
@@ -111,7 +130,9 @@ define(
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "ce lundi",
 	"field-mon-relative+1": "lundi prochain",
+	"field-day-narrow-relative+-1": "hier",
 	"field-year-short": "an",
+	"field-day-narrow-relative+-2": "avant-hier",
 	"months-format-narrow": [
 		"1",
 		"2",
@@ -128,6 +149,8 @@ define(
 	],
 	"field-quarter-relative+-1": "le trimestre dernier",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "cadran",
+	"field-week-narrow-relative+-1": "la semaine dernière",
 	"days-format-short": [
 		"di",
 		"lu",
@@ -137,6 +160,7 @@ define(
 		"ve",
 		"sa"
 	],
+	"field-dayOfYear": "jour (année)",
 	"field-sat-relative+-1": "samedi dernier",
 	"dateTimeFormat-long": "{1} 'à' {0}",
 	"dateFormatItem-Md": "dd/MM",
@@ -159,10 +183,12 @@ define(
 	"dateFormat-full": "EEEE d MMMM y G",
 	"field-month-relative+-1": "le mois dernier",
 	"field-quarter-short": "trim.",
-	"field-sat-narrow-relative+0": "ce sam",
+	"field-sat-narrow-relative+0": "ce sam.",
 	"field-fri-relative+0": "ce vendredi",
-	"field-sat-narrow-relative+1": "sam proch",
+	"field-sat-narrow-relative+1": "sam. prochain",
 	"field-fri-relative+1": "vendredi prochain",
+	"field-month-narrow-relative+0": "ce mois-ci",
+	"field-month-narrow-relative+1": "le mois prochain",
 	"field-sun-short-relative+0": "ce dim.",
 	"field-sun-short-relative+1": "dim. prochain",
 	"field-week-relative+-1": "la semaine dernière",
@@ -188,6 +214,7 @@ define(
 	"field-wed-short-relative+-1": "mer. dernier",
 	"dateFormat-short": "dd/MM/y GGGGG",
 	"field-thu-short-relative+-1": "jeu. dernier",
+	"field-year-narrow-relative+-1": "l’année dernière",
 	"days-standAlone-wide": [
 		"dimanche",
 		"lundi",
@@ -198,11 +225,12 @@ define(
 		"samedi"
 	],
 	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
-	"field-mon-narrow-relative+-1": "lun dern",
+	"field-mon-narrow-relative+-1": "lun. dernier",
 	"dateFormatItem-MMMMd": "d MMMM",
-	"field-thu-narrow-relative+-1": "jeu dern",
+	"field-thu-narrow-relative+-1": "jeu. dernier",
 	"dateFormatItem-E": "ccc",
-	"field-tue-narrow-relative+-1": "mar dern",
+	"field-tue-narrow-relative+-1": "mar. dernier",
+	"field-weekOfMonth-short": "sem. (m.)",
 	"dateFormatItem-yyyy": "y G",
 	"field-wed-short-relative+0": "ce mer.",
 	"dateFormatItem-M": "L",
@@ -234,10 +262,15 @@ define(
 	"dateTimeFormat-full": "{1} 'à' {0}",
 	"dateFormatItem-d": "d",
 	"field-weekday": "jour de la semaine",
-	"field-quarter-narrow-relative+0": "ce trim",
+	"field-day-short-relative+0": "aujourd’hui",
+	"field-quarter-narrow-relative+0": "ce trim.",
+	"field-day-short-relative+1": "demain",
 	"field-sat-relative+0": "ce samedi",
-	"field-quarter-narrow-relative+1": "trim proch",
+	"field-quarter-narrow-relative+1": "trim. proch.",
+	"field-day-short-relative+2": "après-demain",
 	"field-sat-relative+1": "samedi prochain",
+	"field-week-short-relative+0": "cette semaine",
+	"field-week-short-relative+1": "la semaine prochaine",
 	"months-standAlone-abbr": [
 		"mouh.",
 		"saf.",
@@ -252,12 +285,17 @@ define(
 		"dhou. qi.",
 		"dhou. hi."
 	],
+	"field-dayOfYear-narrow": "j (an)",
+	"field-month-short-relative+0": "ce mois-ci",
+	"field-month-short-relative+1": "le mois prochain",
+	"field-weekdayOfMonth-short": "jour (mois)",
 	"dateFormatItem-MEd": "E dd/MM",
+	"field-zone-narrow": "fuseau horaire",
 	"dateFormatItem-y": "y G",
-	"field-thu-narrow-relative+0": "ce jeu",
-	"field-thu-narrow-relative+1": "jeu proch",
-	"field-sun-narrow-relative+-1": "dim dern",
+	"field-thu-narrow-relative+0": "ce jeu.",
+	"field-sun-narrow-relative+-1": "dim. dernier",
 	"field-mon-short-relative+-1": "lun. dernier",
+	"field-thu-narrow-relative+1": "jeu. prochain",
 	"field-thu-relative+0": "ce jeudi",
 	"field-thu-relative+1": "jeudi prochain",
 	"field-fri-short-relative+-1": "ven. dernier",
@@ -270,10 +308,13 @@ define(
 		"4e trimestre"
 	],
 	"dateFormatItem-Ed": "E d",
-	"field-wed-narrow-relative+0": "ce mer",
-	"field-wed-narrow-relative+1": "mer proch",
-	"field-quarter-narrow-relative+-1": "trim dern",
+	"field-wed-narrow-relative+0": "ce mer.",
+	"field-wed-narrow-relative+1": "mer. prochain",
+	"field-quarter-narrow-relative+-1": "trim. dern.",
+	"field-year-short-relative+0": "cette année",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "cadran",
+	"field-year-short-relative+1": "l’année prochaine",
 	"field-fri-short-relative+0": "ce ven.",
 	"field-fri-short-relative+1": "ven. prochain",
 	"days-standAlone-short": [
@@ -285,9 +326,11 @@ define(
 		"ve",
 		"sa"
 	],
+	"field-week-short-relative+-1": "la semaine dernière",
 	"field-hour-narrow-relative+0": "cette h",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "h",
+	"field-zone-short": "fuseau horaire",
 	"quarters-format-abbr": [
 		"T1",
 		"T2",
@@ -296,10 +339,12 @@ define(
 	],
 	"field-month-narrow": "m.",
 	"field-hour-narrow": "h",
-	"field-fri-narrow-relative+-1": "ven dern",
+	"field-fri-narrow-relative+-1": "ven. dernier",
 	"field-year-relative+0": "cette année",
 	"field-year-relative+1": "l’année prochaine",
+	"field-era-narrow": "ère",
 	"field-fri-relative+-1": "vendredi dernier",
+	"eraNarrow": "H",
 	"field-tue-short-relative+-1": "mar. dernier",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -311,14 +356,18 @@ define(
 		"vendredi",
 		"samedi"
 	],
-	"field-mon-narrow-relative+0": "ce lun",
-	"field-mon-narrow-relative+1": "lun proch",
+	"field-mon-narrow-relative+0": "ce lun.",
+	"field-mon-narrow-relative+1": "lun. prochain",
+	"field-year-short-relative+-1": "l’année dernière",
 	"field-zone": "fuseau horaire",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "sem. (m.)",
+	"field-weekday-narrow": "j (sem.)",
 	"field-quarter-narrow": "trim.",
 	"field-sun-short-relative+-1": "dim. dernier",
 	"field-day-relative+-1": "hier",
 	"field-day-relative+-2": "avant-hier",
+	"field-weekday-short": "j (sem.)",
 	"days-format-abbr": [
 		"dim.",
 		"lun.",
@@ -334,8 +383,8 @@ define(
 	"field-day-short": "j",
 	"field-week-narrow": "sem.",
 	"field-era": "ère",
-	"field-fri-narrow-relative+0": "ce ven",
-	"field-fri-narrow-relative+1": "ven proch"
+	"field-fri-narrow-relative+0": "ce ven.",
+	"field-fri-narrow-relative+1": "ven. prochain"
 }
 //end v1.x content
 );
\ No newline at end of file
