@@ -22,12 +22,15 @@ define(
 	"field-week-narrow-relative+1": "sljedeći tj.",
 	"field-wed-narrow-relative+-1": "prošla sri.",
 	"field-year-narrow": "g.",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "ove g.",
 	"field-tue-relative+0": "ovaj utorak",
 	"field-year-narrow-relative+1": "sljedeće g.",
 	"field-tue-relative+1": "sljedeći utorak",
+	"field-weekdayOfMonth": "radni dan u mjesecu",
 	"field-second-short": "s",
 	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "r. dan u mj.",
 	"field-week-relative+0": "ovaj tjedan",
 	"field-month-relative+0": "ovaj mjesec",
 	"field-week-relative+1": "sljedeći tjedan",
@@ -52,10 +55,12 @@ define(
 		"11.",
 		"12."
 	],
+	"field-weekOfMonth": "tjedan u mjesecu",
 	"field-month-short": "mj.",
 	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
 	"dateFormatItem-yyyyMd": "dd. MM. y. GGGGG",
 	"field-day": "dan",
+	"field-dayOfYear-short": "dan u god.",
 	"field-year-relative+-1": "prošle godine",
 	"field-sat-short-relative+-1": "prošla sub.",
 	"field-hour-relative+0": "ovaj sat",
@@ -125,21 +130,22 @@ define(
 	"field-year-short": "g.",
 	"field-day-narrow-relative+-2": "prekjučer",
 	"months-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
+		"1.",
+		"2.",
+		"3.",
+		"4.",
+		"5.",
+		"6.",
+		"7.",
+		"8.",
+		"9.",
+		"10.",
+		"11.",
+		"12."
 	],
 	"field-quarter-relative+-1": "prošli kvartal",
 	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
+	"field-dayperiod-narrow": "AM/PM",
 	"field-week-narrow-relative+-1": "prošli tj.",
 	"days-format-short": [
 		"ned",
@@ -156,6 +162,7 @@ define(
 		"3.",
 		"4."
 	],
+	"field-dayOfYear": "dan u godini",
 	"field-sat-relative+-1": "prošla subota",
 	"dateTimeFormat-long": "{1} 'u' {0}",
 	"dateFormatItem-Md": "d. M.",
@@ -222,6 +229,7 @@ define(
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "prošli čet.",
 	"field-tue-narrow-relative+-1": "prošli uto.",
+	"field-weekOfMonth-short": "tj. u mj.",
 	"dateFormatItem-yyyy": "y. G",
 	"field-wed-short-relative+0": "ova sri.",
 	"dateFormatItem-M": "L.",
@@ -259,9 +267,9 @@ define(
 	"field-sat-relative+0": "ova subota",
 	"field-day-short-relative+1": "sutra",
 	"field-quarter-narrow-relative+1": "sljedeći kv.",
-	"dateFormatItem-h": "hh a",
-	"field-sat-relative+1": "sljedeća subota",
 	"field-day-short-relative+2": "prekosutra",
+	"field-sat-relative+1": "sljedeća subota",
+	"dateFormatItem-h": "hh a",
 	"field-week-short-relative+0": "ovaj tj.",
 	"field-week-short-relative+1": "sljedeći tj.",
 	"months-standAlone-abbr": [
@@ -278,15 +286,18 @@ define(
 		"Dhuʻl-Q.",
 		"Dhuʻl-H."
 	],
+	"field-dayOfYear-narrow": "dan u g.",
 	"field-month-short-relative+0": "ovaj mj.",
 	"field-month-short-relative+1": "sljedeći mj.",
+	"field-weekdayOfMonth-short": "radni dan u mj.",
 	"timeFormat-full": "HH:mm:ss (zzzz)",
 	"dateFormatItem-MEd": "E, d. M.",
+	"field-zone-narrow": "zona",
 	"dateFormatItem-y": "y. G",
 	"field-thu-narrow-relative+0": "ovaj čet.",
-	"field-thu-narrow-relative+1": "sljedeći čet.",
 	"field-sun-narrow-relative+-1": "prošla ned.",
 	"field-mon-short-relative+-1": "prošli pon.",
+	"field-thu-narrow-relative+1": "sljedeći čet.",
 	"field-thu-relative+0": "ovaj četvrtak",
 	"field-thu-relative+1": "sljedeći četvrtak",
 	"field-fri-short-relative+-1": "prošli pet.",
@@ -310,6 +321,7 @@ define(
 	"field-wed-narrow-relative+1": "sljedeća sri.",
 	"field-quarter-narrow-relative+-1": "prošli kv.",
 	"field-year-short-relative+0": "ove god.",
+	"field-dayperiod-short": "AM/PM",
 	"dateFormatItem-yyyyMMM": "LLL y. G",
 	"field-year-short-relative+1": "sljedeće god.",
 	"field-fri-short-relative+0": "ovaj pet.",
@@ -326,6 +338,7 @@ define(
 	"field-week-short-relative+-1": "prošli tj.",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
 	"field-hour-short": "h",
+	"field-zone-short": "zona",
 	"quarters-format-abbr": [
 		"1kv",
 		"2kv",
@@ -337,6 +350,7 @@ define(
 	"field-fri-narrow-relative+-1": "prošli pet.",
 	"field-year-relative+0": "ove godine",
 	"field-year-relative+1": "sljedeće godine",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "prošli petak",
 	"field-tue-short-relative+-1": "prošli uto.",
 	"field-minute-narrow": "min",
@@ -354,10 +368,13 @@ define(
 	"field-year-short-relative+-1": "prošle god.",
 	"field-zone": "vremenska zona",
 	"dateFormatItem-MMMEd": "E, d. MMM",
+	"field-weekOfMonth-narrow": "tj. u mjesecu",
+	"field-weekday-narrow": "dan u tj.",
 	"field-quarter-narrow": "kv.",
 	"field-sun-short-relative+-1": "prošla ned.",
 	"field-day-relative+-1": "jučer",
 	"field-day-relative+-2": "prekjučer",
+	"field-weekday-short": "dan u tjed.",
 	"days-format-abbr": [
 		"ned",
 		"pon",
