@@ -6,14 +6,15 @@ define(
 	"superscriptingExponent": "×",
 	"list": ";",
 	"percentSign": "%",
-	"minusSign": "-",
+	"minusSign": "−",
 	"decimalFormat-short": "000 bil'.'",
 	"nan": "NaN",
 	"plusSign": "+",
 	"currencyFormat": "#,##0.00 ¤",
 	"perMille": "‰",
+	"approximatelySign": "~",
 	"group": ".",
-	"percentFormat": "#,##0%",
+	"percentFormat": "#,##0 %",
 	"decimalFormat-long": "000 bilijuna",
 	"decimalFormat": "#,##0.###",
 	"currencyFormat-short": "000 bil'.' ¤",
