@@ -2,30 +2,40 @@ define(
 //begin v1.x content
 {
 	"field-tue-relative+-1": "Selasa lalu",
-	"field-year": "Tahun",
+	"field-year": "tahun",
 	"dateFormatItem-Hm": "HH.mm",
 	"field-wed-relative+0": "Rabu ini",
 	"field-wed-relative+1": "Rabu berikutnya",
 	"dateFormatItem-ms": "mm.ss",
 	"timeFormat-short": "HH.mm",
-	"field-minute": "Menit",
+	"field-minute": "menit",
+	"field-month-narrow-relative+-1": "bln lalu",
 	"field-tue-narrow-relative+0": "Sel. ini",
 	"field-tue-narrow-relative+1": "Sel. berikutnya",
 	"field-thu-short-relative+0": "Kam. ini",
+	"dateTimeFormat-short": "{1}, {0}",
 	"field-thu-short-relative+1": "Kam. berikutnya",
 	"field-day-relative+0": "hari ini",
 	"field-day-relative+1": "besok",
+	"field-week-narrow-relative+0": "mgg ini",
 	"field-day-relative+2": "lusa",
+	"field-week-narrow-relative+1": "mgg depan",
 	"field-wed-narrow-relative+-1": "Rab. lalu",
+	"dateFormatItem-EBhms": "E h.mm.ss B",
 	"field-year-narrow": "thn.",
+	"field-era-short": "era",
+	"field-year-narrow-relative+0": "thn ini",
 	"field-tue-relative+0": "Selasa ini",
+	"field-year-narrow-relative+1": "thn depan",
 	"field-tue-relative+1": "Selasa berikutnya",
+	"field-weekdayOfMonth": "hari kerja",
 	"field-second-short": "dtk.",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "hr kerja",
 	"field-week-relative+0": "minggu ini",
 	"field-month-relative+0": "bulan ini",
 	"field-week-relative+1": "minggu depan",
-	"field-month-relative+1": "Bulan berikutnya",
+	"field-month-relative+1": "bulan berikutnya",
 	"field-sun-narrow-relative+0": "Min. ini",
 	"timeFormat-medium": "HH.mm.ss",
 	"field-mon-short-relative+0": "Sen. ini",
@@ -33,31 +43,23 @@ define(
 	"field-mon-short-relative+1": "Sen. berikutnya",
 	"field-second-relative+0": "sekarang",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
-	"months-standAlone-narrow": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
+	"eraNames": [
+		"H"
 	],
+	"field-weekOfMonth": "minggu",
 	"field-month-short": "bln.",
 	"dateFormatItem-GyMMMEd": "E, d MMM y G",
 	"dateFormatItem-yyyyMd": "d/M/y G",
-	"field-day": "Hari",
+	"field-day": "hari",
+	"field-dayOfYear-short": "hari dlm setahun",
 	"field-year-relative+-1": "tahun lalu",
 	"field-sat-short-relative+-1": "Sab. lalu",
 	"field-hour-relative+0": "jam ini",
 	"dateFormatItem-yyyyMEd": "E, d/M/y G",
 	"field-wed-relative+-1": "Rabu lalu",
+	"dateTimeFormat-medium": "{1}, {0}",
 	"field-sat-narrow-relative+-1": "Sab. lalu",
-	"field-second": "Detik",
+	"field-second": "detik",
 	"days-standAlone-narrow": [
 		"M",
 		"S",
@@ -67,10 +69,12 @@ define(
 		"J",
 		"S"
 	],
+	"dateFormatItem-Ehms": "E h.mm.ss a",
 	"dateFormat-long": "d MMMM y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
-	"field-quarter": "Kuartal",
+	"field-quarter": "kuartal",
 	"field-week-short": "mgg.",
+	"field-day-narrow-relative+2": "lusa",
 	"quarters-standAlone-wide": [
 		"Kuartal ke-1",
 		"Kuartal ke-2",
@@ -88,11 +92,11 @@ define(
 	],
 	"field-tue-short-relative+0": "Sel. ini",
 	"field-tue-short-relative+1": "Sel. berikutnya",
+	"field-month-short-relative+-1": "bln lalu",
 	"field-mon-relative+-1": "Senin lalu",
 	"dateFormatItem-GyMMM": "MMM y G",
-	"field-month": "Bulan",
+	"field-month": "bulan",
 	"field-day-narrow": "h",
-	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "mnt.",
 	"field-dayperiod": "AM/PM",
 	"field-sat-short-relative+0": "Sab. ini",
@@ -100,7 +104,7 @@ define(
 	"dateFormat-medium": "d MMM y G",
 	"dateFormatItem-yyyyMMMM": "MMMM y G",
 	"eraAbbr": [
-		"AH"
+		"H"
 	],
 	"quarters-standAlone-abbr": [
 		"K1",
@@ -113,22 +117,10 @@ define(
 	"field-mon-relative+0": "Senin ini",
 	"field-mon-relative+1": "Senin berikutnya",
 	"field-year-short": "thn.",
-	"months-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
-	],
 	"field-quarter-relative+-1": "Kuartal lalu",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "mgg lalu",
 	"days-format-short": [
 		"Min",
 		"Sen",
@@ -138,22 +130,24 @@ define(
 		"Jum",
 		"Sab"
 	],
+	"field-dayOfYear": "hari dalam setahun",
 	"field-sat-relative+-1": "Sabtu lalu",
+	"dateTimeFormat-long": "{1} 'pukul' {0}",
 	"dateFormatItem-Md": "d/M",
 	"field-hour": "Jam",
 	"months-format-wide": [
-		"Muharram",
+		"Muharam",
 		"Safar",
-		"Rabiʻ I",
-		"Rabiʻ II",
-		"Jumada I",
-		"Jumada II",
+		"Rabiulawal",
+		"Rabiulakhir",
+		"Jumadilawal",
+		"Jumadilakhir",
 		"Rajab",
-		"Sya’ban",
-		"Ramadhan",
+		"Syakban",
+		"Ramadan",
 		"Syawal",
-		"Dhuʻl-Qiʻdah",
-		"Dhuʻl-Hijjah"
+		"Zulkaidah",
+		"Zulhijah"
 	],
 	"dateFormat-full": "EEEE, dd MMMM y G",
 	"field-month-relative+-1": "bulan lalu",
@@ -163,30 +157,35 @@ define(
 	"field-fri-relative+0": "Jumat ini",
 	"field-sat-narrow-relative+1": "Sab. berikutnya",
 	"field-fri-relative+1": "Jumat berikutnya",
+	"dateFormatItem-EBhm": "E h.mm B",
+	"field-month-narrow-relative+0": "bln ini",
+	"field-month-narrow-relative+1": "bln berikutnya",
 	"field-sun-short-relative+0": "Min. ini",
 	"field-sun-short-relative+1": "Min. berikutnya",
 	"field-week-relative+-1": "minggu lalu",
+	"dateFormatItem-Ehm": "E h.mm a",
 	"months-format-abbr": [
 		"Muh.",
 		"Saf.",
-		"Rab. I",
-		"Rab. II",
-		"Jum. I",
-		"Jum. II",
+		"Rab. Awal",
+		"Rab. Akhir",
+		"Jum. Awal",
+		"Jum. Akhir",
 		"Raj.",
-		"Sha.",
+		"Sya.",
 		"Ram.",
 		"Syaw.",
-		"Dhuʻl-Q.",
-		"Dhuʻl-H."
+		"Zulka.",
+		"Zulhi."
 	],
-	"field-quarter-relative+0": "Kuartal ini",
+	"field-quarter-relative+0": "kuartal ini",
 	"field-minute-relative+0": "menit ini",
 	"timeFormat-long": "HH.mm.ss z",
-	"field-quarter-relative+1": "Kuartal berikutnya",
+	"field-quarter-relative+1": "kuartal berikutnya",
 	"field-wed-short-relative+-1": "Rab. lalu",
 	"dateFormat-short": "d/M/y GGGGG",
 	"field-thu-short-relative+-1": "Kam. lalu",
+	"field-year-narrow-relative+-1": "thn lalu",
 	"days-standAlone-wide": [
 		"Minggu",
 		"Senin",
@@ -201,22 +200,22 @@ define(
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "Kam. lalu",
 	"field-tue-narrow-relative+-1": "Sel. lalu",
+	"field-weekOfMonth-short": "mgg.",
 	"dateFormatItem-yyyy": "y G",
 	"field-wed-short-relative+0": "Rab. ini",
-	"dateFormatItem-M": "L",
 	"months-standAlone-wide": [
-		"Muharram",
+		"Muharam",
 		"Safar",
-		"Rabiʻ I",
-		"Rabiʻ II",
-		"Jumada I",
-		"Jumada II",
+		"Rabiulawal",
+		"Rabiulakhir",
+		"Jumadilawal",
+		"Jumadilakhir",
 		"Rajab",
-		"Sya’ban",
-		"Ramadhan",
+		"Syakban",
+		"Ramadan",
 		"Syawal",
-		"Dhuʻl-Qiʻdah",
-		"Dhuʻl-Hijjah"
+		"Zulkaidah",
+		"Zulhijah"
 	],
 	"field-wed-short-relative+1": "Rab. berikutnya",
 	"field-sun-relative+-1": "hari Minggu lalu",
@@ -230,38 +229,46 @@ define(
 		"Jum",
 		"Sab"
 	],
+	"dateTimeFormat-full": "{1} 'pukul' {0}",
 	"dateFormatItem-hm": "h.mm a",
-	"dateFormatItem-d": "d",
-	"field-weekday": "Hari dalam Seminggu",
+	"field-weekday": "hari dalam seminggu",
 	"field-sat-relative+0": "Sabtu ini",
 	"field-sat-relative+1": "Sabtu berikutnya",
+	"field-day-short-relative+2": "lusa",
+	"field-week-short-relative+0": "mgg ini",
+	"field-week-short-relative+1": "mgg depan",
 	"months-standAlone-abbr": [
 		"Muh.",
 		"Saf.",
-		"Rab. I",
-		"Rab. II",
-		"Jum. I",
-		"Jum. II",
+		"Rab. Awal",
+		"Rab. Akhir",
+		"Jum. Awal",
+		"Jum. Akhir",
 		"Raj.",
-		"Sha.",
+		"Sya.",
 		"Ram.",
 		"Syaw.",
-		"Dhuʻl-Q.",
-		"Dhuʻl-H."
+		"Zulka.",
+		"Zulhi."
 	],
+	"field-dayOfYear-narrow": "hari dlm 1 thn",
+	"field-month-short-relative+0": "bln ini",
+	"field-month-short-relative+1": "bln berikutnya",
+	"field-weekdayOfMonth-short": "hr kerja",
 	"timeFormat-full": "HH.mm.ss zzzz",
 	"dateFormatItem-MEd": "E, d/M",
+	"field-zone-narrow": "zona wkt",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "Kam. ini",
-	"field-thu-narrow-relative+1": "Kam. berikutnya",
 	"field-sun-narrow-relative+-1": "Min. lalu",
 	"field-mon-short-relative+-1": "Sen. lalu",
+	"field-thu-narrow-relative+1": "Kam. berikutnya",
 	"field-thu-relative+0": "Kamis ini",
 	"field-thu-relative+1": "Kamis berikutnya",
-	"dateFormatItem-hms": "h.mm.ss a",
 	"field-fri-short-relative+-1": "Jum. lalu",
+	"dateFormatItem-hms": "h.mm.ss a",
 	"field-thu-relative+-1": "Kamis lalu",
-	"field-week": "Minggu",
+	"field-week": "minggu",
 	"quarters-format-wide": [
 		"Kuartal ke-1",
 		"Kuartal ke-2",
@@ -271,7 +278,10 @@ define(
 	"dateFormatItem-Ed": "E, d",
 	"field-wed-narrow-relative+0": "Rab. ini",
 	"field-wed-narrow-relative+1": "Rab. berikutnya",
+	"field-year-short-relative+0": "thn ini",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "AM/PM",
+	"field-year-short-relative+1": "thn depan",
 	"field-fri-short-relative+0": "Jum. ini",
 	"field-fri-short-relative+1": "Jum. berikutnya",
 	"days-standAlone-short": [
@@ -283,8 +293,10 @@ define(
 		"Jum",
 		"Sab"
 	],
+	"field-week-short-relative+-1": "mgg lalu",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "jam",
+	"field-zone-short": "zona wkt",
 	"quarters-format-abbr": [
 		"K1",
 		"K2",
@@ -296,7 +308,10 @@ define(
 	"field-fri-narrow-relative+-1": "Jum. lalu",
 	"field-year-relative+0": "tahun ini",
 	"field-year-relative+1": "tahun depan",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "Jumat lalu",
+	"eraNarrow": "H",
+	"dateFormatItem-Bhms": "h.mm.ss B",
 	"field-tue-short-relative+-1": "Sel. lalu",
 	"field-minute-narrow": "m",
 	"days-format-wide": [
@@ -310,12 +325,18 @@ define(
 	],
 	"field-mon-narrow-relative+0": "Sen. ini",
 	"field-mon-narrow-relative+1": "Sen. berikutnya",
-	"field-zone": "Zona Waktu",
+	"dateFormatItem-EHm": "E HH.mm",
+	"field-year-short-relative+-1": "thn lalu",
+	"field-zone": "zona waktu",
 	"dateFormatItem-MMMEd": "E, d MMM",
+	"field-weekOfMonth-narrow": "mgg.",
+	"dateFormatItem-EHms": "E HH.mm.ss",
+	"field-weekday-narrow": "hari dlm seminggu",
 	"field-quarter-narrow": "krtl.",
 	"field-sun-short-relative+-1": "Min. lalu",
 	"field-day-relative+-1": "kemarin",
 	"field-day-relative+-2": "kemarin dulu",
+	"field-weekday-short": "hari dlm seminggu",
 	"days-format-abbr": [
 		"Min",
 		"Sen",
@@ -325,12 +346,13 @@ define(
 		"Jum",
 		"Sab"
 	],
+	"dateFormatItem-Bhm": "h.mm B",
 	"field-sun-relative+0": "hari Minggu ini",
 	"field-sun-relative+1": "hari Minggu berikutnya",
 	"dateFormatItem-Gy": "y G",
 	"field-day-short": "h",
 	"field-week-narrow": "mgg.",
-	"field-era": "Era",
+	"field-era": "era",
 	"field-fri-narrow-relative+0": "Jum. ini",
 	"field-fri-narrow-relative+1": "Jum. berikutnya"
 }
