@@ -1,127 +1,172 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "ora",
-	"field-quarter-relative+-1": "trimestre scorso",
-	"field-weekday": "giorno della settimana",
-	"field-mon-narrow-relative+0": "questo lu",
-	"field-mon-narrow-relative+1": "lu prossimo",
+	"field-quarter-short-relative+0": "questo trim.",
+	"field-quarter-short-relative+1": "trim. prossimo",
+	"field-tue-relative+-1": "martedì scorso",
+	"field-year": "anno",
 	"field-wed-relative+0": "questo mercoledì",
 	"field-wed-relative+1": "mercoledì prossimo",
-	"field-week-short": "sett.",
-	"field-tue-relative+-1": "martedì scorso",
-	"field-year-short": "anno",
-	"field-thu-narrow-relative+-1": "gi scorso",
-	"field-hour-relative+0": "quest’ora",
-	"dateFormat-long": "dd MMMM U",
-	"field-quarter-narrow": "trim.",
-	"field-fri-relative+-1": "venerdì scorso",
-	"field-hour-short": "h.",
-	"field-wed-relative+-1": "mercoledì scorso",
-	"dateFormat-full": "EEEE d MMMM U",
-	"field-mon-short-relative+-1": "lun. scorso",
-	"field-thu-relative+-1": "giovedì scorso",
-	"field-era": "era",
-	"field-sat-narrow-relative+0": "questo sa",
-	"field-sat-narrow-relative+1": "sa prossimo",
-	"field-year": "anno",
-	"field-hour": "ora",
-	"field-sat-relative+0": "questo sabato",
-	"field-sat-relative+1": "sabato prossimo",
-	"field-sat-short-relative+-1": "sab. scorso",
-	"field-minute-narrow": "m",
+	"field-minute": "minuto",
+	"field-month-narrow-relative+-1": "mese scorso",
+	"field-tue-narrow-relative+0": "questo mar.",
+	"field-tue-narrow-relative+1": "mar. prossimo",
+	"field-thu-short-relative+0": "questo gio.",
+	"field-day-short-relative+-1": "ieri",
+	"field-thu-short-relative+1": "gio. prossimo",
 	"field-day-relative+0": "oggi",
+	"field-day-short-relative+-2": "l’altro ieri",
 	"field-day-relative+1": "domani",
-	"field-thu-relative+0": "questo giovedì",
-	"field-mon-narrow-relative+-1": "lu scorso",
+	"field-week-narrow-relative+0": "questa sett.",
 	"field-day-relative+2": "dopodomani",
-	"field-wed-narrow-relative+0": "questo me",
-	"field-thu-relative+1": "giovedì prossimo",
-	"field-wed-narrow-relative+1": "me prossimo",
-	"field-mon-short-relative+0": "questo lun.",
-	"field-mon-short-relative+1": "lun. prossimo",
-	"field-wed-short-relative+-1": "mer. scorso",
-	"field-fri-narrow-relative+-1": "ve scorso",
-	"field-hour-narrow": "h",
-	"field-tue-short-relative+0": "questo mar.",
+	"field-week-narrow-relative+1": "sett. prossima",
+	"field-wed-narrow-relative+-1": "mer. scorso",
 	"field-year-narrow": "anno",
+	"field-era-short": "era",
+	"field-year-narrow-relative+0": "quest’anno",
+	"field-tue-relative+0": "questo martedì",
+	"field-year-narrow-relative+1": "anno prossimo",
+	"field-tue-relative+1": "martedì prossimo",
+	"field-weekdayOfMonth": "giorno del mese",
+	"field-second-short": "s",
+	"field-weekdayOfMonth-narrow": "giorno mese",
+	"field-week-relative+0": "questa settimana",
+	"field-month-relative+0": "questo mese",
+	"field-week-relative+1": "settimana prossima",
+	"field-month-relative+1": "mese prossimo",
+	"field-sun-narrow-relative+0": "questa dom.",
+	"field-mon-short-relative+0": "questo lun.",
+	"field-sun-narrow-relative+1": "dom. prossima",
+	"field-mon-short-relative+1": "lun. prossimo",
+	"field-second-relative+0": "ora",
+	"field-weekOfMonth": "settimana del mese",
+	"field-month-short": "mese",
+	"field-day": "giorno",
+	"field-dayOfYear-short": "giorno anno",
+	"field-year-relative+-1": "anno scorso",
+	"field-sat-short-relative+-1": "sab. scorso",
+	"field-hour-relative+0": "quest’ora",
+	"field-wed-relative+-1": "mercoledì scorso",
+	"field-sat-narrow-relative+-1": "sab. scorso",
+	"field-second": "secondo",
+	"dateFormat-long": "dd MMMM U",
+	"field-quarter": "trimestre",
+	"field-week-short": "sett.",
+	"field-day-narrow-relative+0": "oggi",
+	"field-day-narrow-relative+1": "domani",
+	"field-day-narrow-relative+2": "dopodomani",
+	"field-tue-short-relative+0": "questo mar.",
 	"field-tue-short-relative+1": "mar. prossimo",
-	"field-minute-short": "min.",
-	"field-day-narrow": "g",
+	"field-month-short-relative+-1": "mese scorso",
+	"field-mon-relative+-1": "lunedì scorso",
+	"field-month": "mese",
+	"field-day-narrow": "g.",
+	"field-minute-short": "min",
+	"field-dayperiod": "AM/PM",
+	"field-sat-short-relative+0": "questo sab.",
+	"field-sat-short-relative+1": "sab. prossimo",
+	"dateFormat-medium": "dd MMM U",
+	"field-second-narrow": "s",
+	"field-mon-relative+0": "questo lunedì",
+	"field-mon-relative+1": "lunedì prossimo",
+	"field-day-narrow-relative+-1": "ieri",
+	"field-year-short": "anno",
+	"field-day-narrow-relative+-2": "l’altro ieri",
+	"field-quarter-relative+-1": "trimestre scorso",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "sett. scorsa",
+	"field-dayOfYear": "giorno dell’anno",
+	"field-sat-relative+-1": "sabato scorso",
+	"field-hour": "ora",
+	"dateFormat-full": "EEEE d MMMM U",
+	"field-month-relative+-1": "mese scorso",
+	"field-quarter-short": "trim.",
+	"field-sat-narrow-relative+0": "questo sab.",
+	"field-fri-relative+0": "questo venerdì",
+	"field-sat-narrow-relative+1": "sab. prossimo",
+	"field-fri-relative+1": "venerdì prossimo",
+	"field-month-narrow-relative+0": "questo mese",
+	"field-month-narrow-relative+1": "mese prossimo",
+	"field-sun-short-relative+0": "questa dom.",
+	"field-sun-short-relative+1": "dom. prossima",
+	"field-week-relative+-1": "settimana scorsa",
+	"field-quarter-short-relative+-1": "trim. scorso",
+	"field-quarter-relative+0": "questo trimestre",
+	"field-minute-relative+0": "questo minuto",
+	"field-quarter-relative+1": "trimestre prossimo",
+	"field-wed-short-relative+-1": "mer. scorso",
+	"dateFormat-short": "dd/MM/yy",
+	"field-thu-short-relative+-1": "gio. scorso",
+	"field-year-narrow-relative+-1": "anno scorso",
+	"field-mon-narrow-relative+-1": "lun. scorso",
+	"field-thu-narrow-relative+-1": "gio. scorso",
+	"field-tue-narrow-relative+-1": "mar. scorso",
+	"field-weekOfMonth-short": "sett. mese",
 	"field-wed-short-relative+0": "questo mer.",
 	"field-wed-short-relative+1": "mer. prossimo",
-	"field-sun-relative+0": "questa domenica",
-	"field-sun-relative+1": "domenica prossima",
-	"field-minute": "minuto",
-	"field-month-short": "mese",
-	"field-dayperiod": "AM/PM",
+	"field-sun-relative+-1": "domenica scorsa",
+	"field-weekday": "giorno della settimana",
+	"field-day-short-relative+0": "oggi",
+	"field-quarter-narrow-relative+0": "questo trim.",
+	"field-sat-relative+0": "questo sabato",
+	"field-day-short-relative+1": "domani",
+	"field-quarter-narrow-relative+1": "trim. prossimo",
+	"field-sat-relative+1": "sabato prossimo",
+	"field-day-short-relative+2": "dopodomani",
+	"field-week-short-relative+0": "questa sett.",
+	"field-week-short-relative+1": "sett. prossima",
+	"field-dayOfYear-narrow": "giorno anno",
+	"field-month-short-relative+0": "questo mese",
+	"field-month-short-relative+1": "mese prossimo",
+	"field-weekdayOfMonth-short": "giorno mese",
+	"field-zone-narrow": "fuso",
+	"field-thu-narrow-relative+0": "questo gio.",
+	"field-thu-narrow-relative+1": "gio. prossimo",
+	"field-sun-narrow-relative+-1": "dom. scorsa",
+	"field-mon-short-relative+-1": "lun. scorso",
+	"field-thu-relative+0": "questo giovedì",
+	"field-thu-relative+1": "giovedì prossimo",
+	"field-fri-short-relative+-1": "ven. scorso",
+	"field-thu-relative+-1": "giovedì scorso",
+	"field-week": "settimana",
+	"field-wed-narrow-relative+0": "questo mer.",
+	"field-wed-narrow-relative+1": "mer. prossimo",
+	"field-quarter-narrow-relative+-1": "trim. scorso",
+	"field-year-short-relative+0": "quest’anno",
+	"field-dayperiod-short": "AM/PM",
+	"field-year-short-relative+1": "anno prossimo",
+	"field-fri-short-relative+0": "questo ven.",
+	"field-fri-short-relative+1": "ven. prossimo",
+	"field-week-short-relative+-1": "sett. scorsa",
+	"field-hour-short": "h",
+	"field-zone-short": "fuso",
+	"field-month-narrow": "mese",
+	"field-hour-narrow": "h",
+	"field-fri-narrow-relative+-1": "ven. scorso",
+	"field-year-relative+0": "quest’anno",
+	"field-year-relative+1": "anno prossimo",
+	"field-era-narrow": "era",
+	"field-fri-relative+-1": "venerdì scorso",
+	"field-tue-short-relative+-1": "mar. scorso",
+	"field-minute-narrow": "min",
+	"field-mon-narrow-relative+0": "questo lun.",
+	"field-mon-narrow-relative+1": "lun. prossimo",
+	"field-year-short-relative+-1": "anno scorso",
+	"field-zone": "fuso orario",
+	"field-weekOfMonth-narrow": "sett. mese",
+	"field-weekday-narrow": "giorno sett.",
+	"field-quarter-narrow": "trim.",
+	"field-sun-short-relative+-1": "dom. scorsa",
 	"field-day-relative+-1": "ieri",
 	"field-day-relative+-2": "l’altro ieri",
-	"field-minute-relative+0": "questo minuto",
+	"field-weekday-short": "giorno settimana",
+	"field-sun-relative+0": "questa domenica",
+	"field-sun-relative+1": "domenica prossima",
+	"field-day-short": "g.",
 	"field-week-narrow": "sett.",
-	"field-wed-narrow-relative+-1": "me scorso",
-	"field-day-short": "g",
-	"field-quarter-relative+0": "questo trimestre",
-	"field-quarter-relative+1": "trimestre prossimo",
-	"field-fri-relative+0": "questo venerdì",
-	"field-fri-relative+1": "venerdì prossimo",
-	"field-day": "giorno",
-	"field-second-narrow": "s",
-	"field-zone": "fuso orario",
-	"field-year-relative+-1": "anno scorso",
-	"field-month-relative+-1": "mese scorso",
-	"field-thu-short-relative+0": "questo gio.",
-	"field-thu-short-relative+1": "gio. prossimo",
-	"field-quarter-narrow-relative+0": "questo trim.",
-	"field-quarter-narrow-relative+1": "trim. prossimo",
-	"field-quarter": "trimestre",
-	"field-month": "mese",
-	"field-tue-relative+0": "questo martedì",
-	"field-quarter-short-relative+0": "questo trim.",
-	"field-tue-relative+1": "martedì prossimo",
-	"field-quarter-short-relative+1": "trim. prossimo",
-	"field-fri-narrow-relative+0": "questo ve",
-	"field-fri-narrow-relative+1": "ve prossimo",
-	"field-fri-short-relative+-1": "ven. scorso",
-	"field-sun-narrow-relative+-1": "do scorsa",
-	"field-quarter-short-relative+-1": "trim. scorso",
-	"field-sun-narrow-relative+0": "questa do",
-	"field-thu-narrow-relative+0": "questo gi",
-	"field-sun-narrow-relative+1": "do prossima",
-	"field-thu-narrow-relative+1": "gi prossimo",
-	"field-tue-narrow-relative+0": "questo ma",
-	"field-mon-relative+0": "questo lunedì",
-	"field-tue-narrow-relative+1": "ma prossimo",
-	"field-mon-relative+1": "lunedì prossimo",
-	"dateFormat-short": "dd/MM/yy",
-	"field-tue-narrow-relative+-1": "ma scorso",
-	"field-second-short": "sec.",
-	"field-second": "secondo",
-	"field-fri-short-relative+0": "questo ven.",
-	"field-sat-relative+-1": "sabato scorso",
-	"field-fri-short-relative+1": "ven. prossimo",
-	"field-sun-relative+-1": "domenica scorsa",
-	"field-month-relative+0": "questo mese",
-	"field-quarter-narrow-relative+-1": "trim. scorso",
-	"field-month-relative+1": "mese prossimo",
-	"field-week": "settimana",
-	"field-sat-short-relative+0": "questo sab.",
-	"dateFormat-medium": "dd MMM U",
-	"field-sat-short-relative+1": "sab. prossimo",
-	"field-year-relative+0": "quest’anno",
-	"field-week-relative+-1": "settimana scorsa",
-	"field-year-relative+1": "anno prossimo",
-	"field-quarter-short": "trim.",
-	"field-sun-short-relative+-1": "dom. scorsa",
-	"field-thu-short-relative+-1": "gio. scorso",
-	"field-tue-short-relative+-1": "mar. scorso",
-	"field-mon-relative+-1": "lunedì scorso",
-	"field-sat-narrow-relative+-1": "sa scorso",
-	"field-month-narrow": "mese",
-	"field-week-relative+0": "questa settimana",
-	"field-sun-short-relative+0": "questa dom.",
-	"field-week-relative+1": "settimana prossima",
-	"field-sun-short-relative+1": "dom. prossima"
+	"field-era": "era",
+	"field-fri-narrow-relative+0": "questo ven.",
+	"field-fri-narrow-relative+1": "ven. prossimo"
 }
 //end v1.x content
 );
\ No newline at end of file
