@@ -1,186 +1,11 @@
 define(
 //begin v1.x content
 {
-	"field-quarter-short-relative+0": "questo trim.",
-	"field-quarter-short-relative+1": "trim. prossimo",
-	"dayPeriods-standAlone-abbr-noon": "mezzogiorno",
-	"field-tue-relative+-1": "martedì scorso",
-	"field-year": "anno",
-	"dateFormatItem-yw": "'settimana' w 'del' y",
-	"dayPeriods-format-abbr-afternoon1": "del pomeriggio",
-	"dateFormatItem-Hm": "HH:mm",
-	"field-wed-relative+0": "questo mercoledì",
-	"field-wed-relative+1": "mercoledì prossimo",
-	"dateFormatItem-ms": "mm:ss",
-	"timeFormat-short": "HH:mm",
-	"field-minute": "minuto",
-	"field-tue-narrow-relative+0": "questo ma",
-	"field-tue-narrow-relative+1": "ma prossimo",
-	"field-thu-short-relative+0": "questo gio.",
-	"dateTimeFormat-short": "{1}, {0}",
-	"field-day-relative+0": "oggi",
-	"field-thu-short-relative+1": "gio. prossimo",
-	"field-day-relative+1": "domani",
-	"field-day-relative+2": "dopodomani",
-	"field-wed-narrow-relative+-1": "me scorso",
-	"field-year-narrow": "anno",
-	"field-tue-relative+0": "questo martedì",
-	"field-tue-relative+1": "martedì prossimo",
-	"dayPeriods-format-narrow-am": "m.",
-	"field-second-short": "sec.",
-	"dayPeriods-standAlone-abbr-morning1": "mattina",
-	"dateFormatItem-MMMd": "d MMM",
-	"dayPeriods-format-narrow-morning1": "mattina",
-	"dayPeriods-format-abbr-am": "AM",
-	"field-month-relative+0": "questo mese",
-	"field-week-relative+0": "questa settimana",
-	"timeFormat-medium": "HH:mm:ss",
-	"field-month-relative+1": "mese prossimo",
-	"field-week-relative+1": "settimana prossima",
-	"field-sun-narrow-relative+0": "questa do",
-	"field-mon-short-relative+0": "questo lun.",
-	"field-sun-narrow-relative+1": "do prossima",
-	"field-mon-short-relative+1": "lun. prossimo",
-	"field-second-relative+0": "ora",
-	"months-standAlone-narrow": [
-		"G",
-		"F",
-		"M",
-		"A",
-		"M",
-		"G",
-		"L",
-		"A",
-		"S",
-		"O",
-		"N",
-		"D"
-	],
-	"dayPeriods-standAlone-wide-noon": "mezzogiorno",
-	"eraNames": [
-		"avanti Cristo",
-		"dopo Cristo"
-	],
-	"dayPeriods-standAlone-abbr-pm": "PM",
-	"dateFormatItem-GyMMMEd": "E d MMM y G",
-	"field-month-short": "mese",
-	"field-day": "giorno",
-	"dayPeriods-standAlone-wide-night1": "notte",
-	"field-year-relative+-1": "anno scorso",
-	"dayPeriods-format-wide-am": "AM",
-	"field-sat-short-relative+-1": "sab. scorso",
-	"dayPeriods-format-narrow-afternoon1": "pomeriggio",
-	"dayPeriods-format-wide-afternoon1": "del pomeriggio",
-	"field-hour-relative+0": "quest’ora",
-	"field-wed-relative+-1": "mercoledì scorso",
-	"dateTimeFormat-medium": "{1}, {0}",
-	"days-standAlone-narrow": [
-		"D",
-		"L",
-		"M",
-		"M",
-		"G",
-		"V",
-		"S"
-	],
-	"dayPeriods-standAlone-narrow-noon": "mezzogiorno",
-	"field-sat-narrow-relative+-1": "sa scorso",
-	"field-second": "secondo",
-	"dayPeriods-standAlone-wide-pm": "PM",
-	"dateFormatItem-Ehms": "E h:mm:ss a",
-	"dateFormat-long": "d MMMM y",
-	"dateFormatItem-GyMMMd": "d MMM y G",
-	"dayPeriods-standAlone-abbr-midnight": "mezzanotte",
-	"field-quarter": "trimestre",
-	"field-week-short": "sett.",
-	"dayPeriods-format-narrow-midnight": "mezzanotte",
-	"dateFormatItem-yMMMEd": "E d MMM y",
-	"quarters-standAlone-wide": [
-		"1º trimestre",
-		"2º trimestre",
-		"3º trimestre",
-		"4º trimestre"
-	],
-	"days-format-narrow": [
-		"D",
-		"L",
-		"M",
-		"M",
-		"G",
-		"V",
-		"S"
-	],
-	"dayPeriods-format-wide-evening1": "di sera",
-	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
-	"field-tue-short-relative+0": "questo mar.",
-	"field-tue-short-relative+1": "mar. prossimo",
-	"field-mon-relative+-1": "lunedì scorso",
-	"dateFormatItem-GyMMM": "MMM y G",
-	"field-month": "mese",
-	"dayPeriods-standAlone-abbr-night1": "notte",
-	"field-day-narrow": "g",
-	"dayPeriods-standAlone-narrow-afternoon1": "pomeriggio",
-	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "min.",
-	"field-dayperiod": "AM/PM",
-	"field-sat-short-relative+0": "questo sab.",
-	"field-sat-short-relative+1": "sab. prossimo",
-	"dayPeriods-format-narrow-pm": "p.",
-	"dateFormat-medium": "dd MMM y",
-	"eraAbbr": [
-		"a.C.",
-		"d.C."
-	],
-	"quarters-standAlone-abbr": [
-		"T1",
-		"T2",
-		"T3",
-		"T4"
-	],
-	"dayPeriods-format-abbr-pm": "PM",
-	"field-second-narrow": "s",
-	"dayPeriods-standAlone-narrow-night1": "notte",
-	"field-mon-relative+0": "questo lunedì",
-	"field-year-short": "anno",
-	"field-mon-relative+1": "lunedì prossimo",
-	"months-format-narrow": [
-		"G",
-		"F",
-		"M",
-		"A",
-		"M",
-		"G",
-		"L",
-		"A",
-		"S",
-		"O",
-		"N",
-		"D"
-	],
-	"dayPeriods-format-wide-morning1": "di mattina",
-	"field-quarter-relative+-1": "trimestre scorso",
-	"dayPeriods-standAlone-narrow-am": "m.",
-	"days-format-short": [
-		"dom",
-		"lun",
-		"mar",
-		"mer",
-		"gio",
-		"ven",
-		"sab"
-	],
-	"quarters-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"dayPeriods-format-wide-pm": "PM",
-	"field-sat-relative+-1": "sabato scorso",
-	"dateTimeFormat-long": "{1} {0}",
-	"dateFormatItem-Md": "d/M",
-	"field-hour": "ora",
-	"dateFormatItem-yQQQQ": "QQQQ y",
+	"dateFormatItem-yMMMM": "MMMM y",
+	"field-thu-narrow-relative+0": "questo gio.",
+	"field-thu-narrow-relative+1": "gio. prossimo",
+	"field-sun-narrow-relative+0": "questa dom.",
+	"field-sun-narrow-relative+1": "dom. prossima",
 	"months-format-wide": [
 		"gennaio",
 		"febbraio",
@@ -195,47 +20,28 @@ define(
 		"novembre",
 		"dicembre"
 	],
-	"dayPeriods-format-wide-night1": "di notte",
-	"dateFormat-full": "EEEE d MMMM y",
-	"field-month-relative+-1": "mese scorso",
+	"dayPeriods-standAlone-abbr-pm": "PM",
 	"dateFormatItem-Hms": "HH:mm:ss",
-	"field-quarter-short": "trim.",
-	"field-sat-narrow-relative+0": "questo sa",
-	"dateFormatItem-Hmv": "HH:mm v",
-	"field-fri-relative+0": "questo venerdì",
-	"field-sat-narrow-relative+1": "sa prossimo",
-	"field-fri-relative+1": "venerdì prossimo",
-	"dayPeriods-format-narrow-noon": "mezzogiorno",
-	"field-sun-short-relative+0": "questa dom.",
-	"field-sun-short-relative+1": "dom. prossima",
-	"field-week-relative+-1": "settimana scorsa",
-	"field-quarter-short-relative+-1": "trim. scorso",
-	"dateFormatItem-Ehm": "E h:mm a",
-	"months-format-abbr": [
-		"gen",
-		"feb",
-		"mar",
-		"apr",
-		"mag",
-		"giu",
-		"lug",
-		"ago",
-		"set",
-		"ott",
-		"nov",
-		"dic"
+	"field-fri-narrow-relative+0": "questo ven.",
+	"field-fri-narrow-relative+1": "ven. prossimo",
+	"eraNarrow": [
+		"aC",
+		"dC"
 	],
-	"dayPeriods-format-wide-midnight": "mezzanotte",
-	"field-quarter-relative+0": "questo trimestre",
-	"timeFormat-long": "HH:mm:ss z",
-	"field-minute-relative+0": "questo minuto",
-	"field-quarter-relative+1": "trimestre prossimo",
-	"field-wed-short-relative+-1": "mer. scorso",
-	"dateFormatItem-yMMM": "MMM y",
-	"dateFormat-short": "dd/MM/yy",
+	"dateFormatItem-Hmv": "HH:mm v",
+	"dateFormatItem-hmsv": "h:mm:ss a v",
+	"dateFormatItem-yMMMd": "d MMM y",
 	"dayPeriods-format-abbr-night1": "di notte",
-	"dateFormatItem-MMMMW": "'settimana' W 'di' MMM",
-	"field-thu-short-relative+-1": "gio. scorso",
+	"dayPeriods-format-narrow-evening1": "di sera",
+	"days-standAlone-narrow": [
+		"D",
+		"L",
+		"M",
+		"M",
+		"G",
+		"V",
+		"S"
+	],
 	"days-standAlone-wide": [
 		"domenica",
 		"lunedì",
@@ -245,15 +51,66 @@ define(
 		"venerdì",
 		"sabato"
 	],
-	"field-mon-narrow-relative+-1": "lu scorso",
-	"dateFormatItem-MMMMd": "d MMMM",
-	"field-thu-narrow-relative+-1": "gi scorso",
-	"dateFormatItem-E": "ccc",
-	"dateFormatItem-H": "HH",
-	"field-tue-narrow-relative+-1": "ma scorso",
-	"dayPeriods-format-abbr-evening1": "di sera",
-	"dayPeriods-standAlone-narrow-pm": "p.",
-	"dateFormatItem-M": "L",
+	"dayPeriods-format-abbr-afternoon1": "di pomeriggio",
+	"dayPeriods-format-wide-evening1": "di sera",
+	"dateFormatItem-Ehm": "E h:mm a",
+	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
+	"field-wed-narrow-relative+-1": "mer. scorso",
+	"dayPeriods-standAlone-wide-evening1": "sera",
+	"days-format-wide": [
+		"domenica",
+		"lunedì",
+		"martedì",
+		"mercoledì",
+		"giovedì",
+		"venerdì",
+		"sabato"
+	],
+	"field-month-short-relative+0": "questo mese",
+	"field-month-short-relative+1": "mese prossimo",
+	"dateFormatItem-Ehms": "E h:mm:ss a",
+	"dayPeriods-standAlone-narrow-evening1": "sera",
+	"dayPeriods-standAlone-abbr-afternoon1": "pomeriggio",
+	"field-thu-relative+0": "questo giovedì",
+	"dayPeriods-standAlone-abbr-night1": "notte",
+	"field-thu-relative+1": "giovedì prossimo",
+	"dayPeriods-format-wide-am": "AM",
+	"field-fri-relative+0": "questo venerdì",
+	"field-fri-relative+1": "venerdì prossimo",
+	"dateFormatItem-yMd": "d/M/y",
+	"field-thu-narrow-relative+-1": "gio. scorso",
+	"field-quarter-relative+0": "questo trimestre",
+	"field-quarter-relative+1": "trimestre prossimo",
+	"field-sun-short-relative+0": "questa dom.",
+	"timeFormat-short": "HH:mm",
+	"field-sun-short-relative+1": "dom. prossima",
+	"dateFormatItem-hms": "h:mm:ss a",
+	"dayPeriods-format-narrow-afternoon1": "di pomeriggio",
+	"dateFormatItem-Md": "d/M",
+	"dateFormatItem-Hmsv": "HH:mm:ss v",
+	"dateFormatItem-hmv": "h:mm a v",
+	"field-week-narrow": "sett.",
+	"field-hour-relative+0": "quest’ora",
+	"field-day-relative+-1": "ieri",
+	"field-day-relative+-2": "l’altro ieri",
+	"field-mon-narrow-relative+-1": "lun. scorso",
+	"field-minute-narrow": "min",
+	"field-thu-short-relative+0": "questo gio.",
+	"field-mon-relative+0": "questo lunedì",
+	"field-thu-short-relative+1": "gio. prossimo",
+	"field-mon-relative+1": "lunedì prossimo",
+	"field-day-narrow-relative+0": "oggi",
+	"field-era-short": "era",
+	"field-day-narrow-relative+1": "domani",
+	"field-sat-narrow-relative+0": "questo sab.",
+	"field-day-narrow-relative+2": "dopodomani",
+	"timeFormat-long": "HH:mm:ss z",
+	"field-sat-narrow-relative+1": "sab. prossimo",
+	"field-week-narrow-relative+0": "questa sett.",
+	"field-week-narrow-relative+1": "sett. prossima",
+	"field-wed-narrow-relative+0": "questo mer.",
+	"field-wed-narrow-relative+1": "mer. prossimo",
+	"field-month": "mese",
 	"months-standAlone-wide": [
 		"gennaio",
 		"febbraio",
@@ -268,10 +125,197 @@ define(
 		"novembre",
 		"dicembre"
 	],
+	"field-weekday-narrow": "giorno sett.",
+	"dayPeriods-standAlone-narrow-afternoon1": "pomeriggio",
+	"field-year-relative+0": "quest’anno",
+	"field-year-relative+1": "anno prossimo",
+	"dayPeriods-format-abbr-evening1": "di sera",
+	"dayPeriods-format-abbr-noon": "mezzogiorno",
+	"dayPeriods-format-narrow-midnight": "mezzanotte",
+	"dayPeriods-format-wide-midnight": "mezzanotte",
+	"field-tue-relative+0": "questo martedì",
+	"field-tue-relative+1": "martedì prossimo",
+	"dayPeriods-standAlone-abbr-evening1": "sera",
+	"dateFormatItem-hm": "h:mm a",
+	"dayPeriods-standAlone-wide-midnight": "mezzanotte",
+	"field-year-narrow": "anno",
+	"dayPeriods-standAlone-abbr-noon": "mezzogiorno",
+	"field-tue-short-relative+0": "questo mar.",
+	"dayPeriods-standAlone-narrow-midnight": "mezzanotte",
+	"field-tue-short-relative+1": "mar. prossimo",
+	"field-tue-narrow-relative+0": "questo mar.",
+	"field-tue-narrow-relative+1": "mar. prossimo",
+	"dateTimeFormat-full": "{1} {0}",
+	"dateFormatItem-E": "ccc",
+	"dateFormatItem-EBhm": "E h:mm B",
+	"dateFormatItem-H": "HH",
+	"field-wed-relative+0": "questo mercoledì",
+	"field-wed-relative+1": "mercoledì prossimo",
+	"dateFormatItem-M": "L",
 	"field-wed-short-relative+0": "questo mer.",
+	"field-fri-short-relative+0": "questo ven.",
 	"field-wed-short-relative+1": "mer. prossimo",
-	"dateFormatItem-Hmsv": "HH:mm:ss v",
-	"field-sun-relative+-1": "domenica scorsa",
+	"field-fri-short-relative+1": "ven. prossimo",
+	"field-weekOfMonth-short": "sett. mese",
+	"field-quarter-short-relative+-1": "trim. scorso",
+	"field-year-short-relative+-1": "anno scorso",
+	"dateFormatItem-Bhm": "h:mm B",
+	"dayPeriods-format-wide-night1": "di notte",
+	"dateTimeFormat-medium": "{1}, {0}",
+	"field-quarter-narrow-relative+-1": "trim. scorso",
+	"dateFormatItem-d": "d",
+	"dayPeriods-format-abbr-pm": "PM",
+	"dateFormatItem-h": "h a",
+	"quarters-standAlone-wide": [
+		"1º trimestre",
+		"2º trimestre",
+		"3º trimestre",
+		"4º trimestre"
+	],
+	"field-weekOfMonth-narrow": "sett. mese",
+	"dateFormatItem-y": "y",
+	"field-minute-relative+0": "questo minuto",
+	"field-year-short-relative+0": "quest’anno",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
+	"field-year-short-relative+1": "anno prossimo",
+	"field-weekday": "giorno della settimana",
+	"dayPeriods-format-narrow-pm": "p.",
+	"field-tue-narrow-relative+-1": "mar. scorso",
+	"dateFormatItem-yMEd": "E d/M/y",
+	"dayPeriods-standAlone-wide-night1": "notte",
+	"field-year-narrow-relative+-1": "anno scorso",
+	"field-sat-relative+-1": "sabato scorso",
+	"dayPeriods-format-abbr-midnight": "mezzanotte",
+	"dayPeriods-format-narrow-morning1": "di mattina",
+	"dayPeriods-format-wide-morning1": "di mattina",
+	"dayPeriods-standAlone-abbr-midnight": "mezzanotte",
+	"dayPeriods-standAlone-narrow-pm": "p.",
+	"dayPeriods-standAlone-wide-morning1": "mattina",
+	"field-mon-narrow-relative+0": "questo lun.",
+	"field-mon-narrow-relative+1": "lun. prossimo",
+	"field-second": "secondo",
+	"dateFormatItem-yMMMEd": "E d MMM y",
+	"field-year-relative+-1": "anno scorso",
+	"field-weekdayOfMonth-short": "giorno mese",
+	"dateFormat-short": "dd/MM/yy",
+	"eraNames": [
+		"avanti Cristo",
+		"dopo Cristo"
+	],
+	"field-second-short": "s",
+	"field-thu-short-relative+-1": "gio. scorso",
+	"field-zone": "fuso orario",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-sun-short-relative+-1": "dom. scorsa",
+	"dayPeriods-standAlone-narrow-morning1": "mattina",
+	"eraAbbr": [
+		"a.C.",
+		"d.C."
+	],
+	"field-week-short": "sett.",
+	"dayPeriods-standAlone-abbr-am": "AM",
+	"dayPeriods-standAlone-wide-pm": "PM",
+	"dateFormatItem-ms": "mm:ss",
+	"field-day-relative+0": "oggi",
+	"field-day-relative+1": "domani",
+	"field-day-relative+2": "dopodomani",
+	"field-day-short-relative+0": "oggi",
+	"field-dayOfYear-short": "giorno anno",
+	"field-day-short-relative+1": "domani",
+	"dateFormat-long": "d MMMM y",
+	"field-day-short-relative+2": "dopodomani",
+	"field-sun-narrow-relative+-1": "dom. scorsa",
+	"dayPeriods-format-wide-noon": "mezzogiorno",
+	"field-second-relative+0": "ora",
+	"field-quarter-relative+-1": "trimestre scorso",
+	"dayPeriods-format-narrow-night1": "di notte",
+	"quarters-format-abbr": [
+		"T1",
+		"T2",
+		"T3",
+		"T4"
+	],
+	"dayPeriods-standAlone-wide-noon": "mezzogiorno",
+	"dayPeriods-standAlone-narrow-night1": "notte",
+	"field-week-relative+-1": "settimana scorsa",
+	"dayPeriods-format-abbr-morning1": "di mattina",
+	"field-month-relative+-1": "mese scorso",
+	"months-format-narrow": [
+		"G",
+		"F",
+		"M",
+		"A",
+		"M",
+		"G",
+		"L",
+		"A",
+		"S",
+		"O",
+		"N",
+		"D"
+	],
+	"field-year": "anno",
+	"field-era": "era",
+	"dayPeriods-standAlone-abbr-morning1": "mattina",
+	"days-standAlone-short": [
+		"dom",
+		"lun",
+		"mar",
+		"mer",
+		"gio",
+		"ven",
+		"sab"
+	],
+	"quarters-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"dateFormatItem-yQQQQ": "QQQQ y",
+	"field-day-short-relative+-1": "ieri",
+	"field-day-short-relative+-2": "l’altro ieri",
+	"dateFormatItem-GyMMM": "MMM y G",
+	"timeFormat-full": "HH:mm:ss zzzz",
+	"dateFormatItem-Bhms": "h:mm:ss B",
+	"field-hour": "ora",
+	"field-dayOfYear-narrow": "giorno anno",
+	"field-quarter": "trimestre",
+	"field-month-narrow-relative+0": "questo mese",
+	"field-month-narrow-relative+1": "mese prossimo",
+	"field-day": "giorno",
+	"field-mon-relative+-1": "lunedì scorso",
+	"field-dayOfYear": "giorno dell’anno",
+	"dateFormat-medium": "d MMM y",
+	"dateTimeFormat-short": "{1}, {0}",
+	"dateFormatItem-yMMM": "MMM y",
+	"dateFormatItem-GyMMMd": "d MMM y G",
+	"dateFormatItem-MEd": "E d/M",
+	"field-tue-short-relative+-1": "mar. scorso",
+	"field-year-short": "anno",
+	"field-month-short": "mese",
+	"dateFormatItem-MMMEd": "E d MMM",
+	"dayPeriods-format-wide-afternoon1": "del pomeriggio",
+	"dateFormatItem-MMMd": "d MMM",
+	"dateFormatItem-Bh": "h B",
+	"months-format-abbr": [
+		"gen",
+		"feb",
+		"mar",
+		"apr",
+		"mag",
+		"giu",
+		"lug",
+		"ago",
+		"set",
+		"ott",
+		"nov",
+		"dic"
+	],
+	"dayPeriods-format-abbr-am": "AM",
+	"field-sat-relative+0": "questo sabato",
+	"field-sat-relative+1": "sabato prossimo",
+	"dayPeriods-format-wide-pm": "PM",
 	"days-standAlone-abbr": [
 		"dom",
 		"lun",
@@ -281,16 +325,95 @@ define(
 		"ven",
 		"sab"
 	],
-	"dateTimeFormat-full": "{1} {0}",
-	"dateFormatItem-hm": "h:mm a",
-	"dateFormatItem-d": "d",
-	"field-weekday": "giorno della settimana",
-	"dayPeriods-standAlone-wide-evening1": "sera",
-	"field-quarter-narrow-relative+0": "questo trim.",
-	"field-sat-relative+0": "questo sabato",
-	"dateFormatItem-h": "h a",
-	"field-quarter-narrow-relative+1": "trim. prossimo",
-	"field-sat-relative+1": "sabato prossimo",
+	"field-zone-short": "fuso",
+	"field-week-short-relative+0": "questa sett.",
+	"field-week-short-relative+1": "sett. prossima",
+	"dayPeriods-standAlone-wide-afternoon1": "pomeriggio",
+	"field-fri-short-relative+-1": "ven. scorso",
+	"field-month-narrow": "mese",
+	"dayPeriods-format-narrow-am": "m.",
+	"field-month-narrow-relative+-1": "mese scorso",
+	"days-format-abbr": [
+		"dom",
+		"lun",
+		"mar",
+		"mer",
+		"gio",
+		"ven",
+		"sab"
+	],
+	"field-weekday-short": "giorno settimana",
+	"field-day-narrow-relative+-1": "ieri",
+	"field-day-narrow-relative+-2": "l’altro ieri",
+	"field-quarter-short": "trim.",
+	"days-format-short": [
+		"dom",
+		"lun",
+		"mar",
+		"mer",
+		"gio",
+		"ven",
+		"sab"
+	],
+	"months-standAlone-narrow": [
+		"G",
+		"F",
+		"M",
+		"A",
+		"M",
+		"G",
+		"L",
+		"A",
+		"S",
+		"O",
+		"N",
+		"D"
+	],
+	"days-format-narrow": [
+		"D",
+		"L",
+		"M",
+		"M",
+		"G",
+		"V",
+		"S"
+	],
+	"dateFormatItem-EHm": "E HH:mm",
+	"field-quarter-narrow": "trim.",
+	"field-mon-short-relative+0": "questo lun.",
+	"field-mon-short-relative+1": "lun. prossimo",
+	"field-dayperiod-short": "AM/PM",
+	"dayPeriods-standAlone-narrow-am": "m.",
+	"field-week-narrow-relative+-1": "sett. scorsa",
+	"field-thu-relative+-1": "giovedì scorso",
+	"field-fri-narrow-relative+-1": "ven. scorso",
+	"field-mon-short-relative+-1": "lun. scorso",
+	"timeFormat-medium": "HH:mm:ss",
+	"field-quarter-short-relative+0": "questo trim.",
+	"field-quarter-short-relative+1": "trim. prossimo",
+	"dateFormatItem-Ed": "E d",
+	"field-wed-relative+-1": "mercoledì scorso",
+	"field-weekOfMonth": "settimana del mese",
+	"field-weekdayOfMonth-narrow": "giorno mese",
+	"dayPeriods-standAlone-wide-am": "AM",
+	"dateFormatItem-yQQQ": "QQQ y",
+	"field-fri-relative+-1": "venerdì scorso",
+	"field-minute": "minuto",
+	"quarters-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"quarters-format-wide": [
+		"1º trimestre",
+		"2º trimestre",
+		"3º trimestre",
+		"4º trimestre"
+	],
+	"field-day-short": "g.",
+	"field-dayperiod": "AM/PM",
+	"field-hour-short": "h",
 	"months-standAlone-abbr": [
 		"gen",
 		"feb",
@@ -305,127 +428,52 @@ define(
 		"nov",
 		"dic"
 	],
-	"dateFormatItem-hmsv": "h:mm:ss a v",
-	"dayPeriods-format-abbr-morning1": "di mattina",
-	"dayPeriods-standAlone-narrow-evening1": "sera",
-	"timeFormat-full": "HH:mm:ss zzzz",
-	"dateFormatItem-MEd": "E d/M",
-	"dateFormatItem-y": "y",
-	"field-thu-narrow-relative+0": "questo gi",
-	"field-sun-narrow-relative+-1": "do scorsa",
-	"field-mon-short-relative+-1": "lun. scorso",
-	"field-thu-narrow-relative+1": "gi prossimo",
-	"field-thu-relative+0": "questo giovedì",
-	"dayPeriods-standAlone-abbr-afternoon1": "pomeriggio",
-	"field-thu-relative+1": "giovedì prossimo",
-	"dateFormatItem-hms": "h:mm:ss a",
-	"field-fri-short-relative+-1": "ven. scorso",
-	"dateFormatItem-hmv": "h:mm a v",
-	"dayPeriods-format-abbr-noon": "mezzogiorno",
-	"field-thu-relative+-1": "giovedì scorso",
-	"dateFormatItem-yMd": "d/M/y",
-	"quarters-standAlone-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"field-week": "settimana",
-	"quarters-format-wide": [
-		"1º trimestre",
-		"2º trimestre",
-		"3º trimestre",
-		"4º trimestre"
-	],
-	"dateFormatItem-Ed": "E d",
-	"field-wed-narrow-relative+0": "questo me",
-	"field-wed-narrow-relative+1": "me prossimo",
-	"dayPeriods-standAlone-wide-morning1": "mattina",
-	"field-quarter-narrow-relative+-1": "trim. scorso",
-	"field-fri-short-relative+0": "questo ven.",
-	"field-fri-short-relative+1": "ven. prossimo",
-	"days-standAlone-short": [
-		"dom",
-		"lun",
-		"mar",
-		"mer",
-		"gio",
-		"ven",
-		"sab"
-	],
-	"dayPeriods-standAlone-narrow-morning1": "mattina",
-	"dayPeriods-format-abbr-midnight": "mezzanotte",
-	"field-hour-short": "h.",
-	"quarters-format-abbr": [
+	"field-month-relative+0": "questo mese",
+	"field-second-narrow": "s",
+	"field-month-relative+1": "mese prossimo",
+	"dateFormat-full": "EEEE d MMMM y",
+	"field-era-narrow": "era",
+	"field-sat-short-relative+-1": "sab. scorso",
+	"dayPeriods-format-narrow-noon": "mezzogiorno",
+	"field-week-short-relative+-1": "sett. scorsa",
+	"dateTimeFormat-long": "{1} {0}",
+	"dateFormatItem-yM": "M/y",
+	"field-sun-relative+-1": "domenica scorsa",
+	"field-wed-short-relative+-1": "mer. scorso",
+	"field-weekdayOfMonth": "giorno del mese",
+	"field-quarter-narrow-relative+0": "questo trim.",
+	"dateFormatItem-GyMMMEd": "E d MMM y G",
+	"field-quarter-narrow-relative+1": "trim. prossimo",
+	"field-sat-short-relative+0": "questo sab.",
+	"field-hour-narrow": "h",
+	"field-sat-short-relative+1": "sab. prossimo",
+	"field-year-narrow-relative+0": "quest’anno",
+	"field-year-narrow-relative+1": "anno prossimo",
+	"dateFormatItem-Gy": "y G",
+	"field-zone-narrow": "fuso",
+	"dayPeriods-standAlone-narrow-noon": "mezzogiorno",
+	"field-tue-relative+-1": "martedì scorso",
+	"field-minute-short": "min",
+	"dateFormatItem-yw": "'settimana' w 'del' Y",
+	"dateFormatItem-Hm": "HH:mm",
+	"field-week-relative+0": "questa settimana",
+	"field-week-relative+1": "settimana prossima",
+	"dateFormatItem-MMM": "LLL",
+	"field-sun-relative+0": "questa domenica",
+	"field-sun-relative+1": "domenica prossima",
+	"field-sat-narrow-relative+-1": "sab. scorso",
+	"quarters-standAlone-abbr": [
 		"T1",
 		"T2",
 		"T3",
 		"T4"
 	],
-	"field-month-narrow": "mese",
-	"field-hour-narrow": "h",
-	"field-fri-narrow-relative+-1": "ve scorso",
-	"field-year-relative+0": "quest’anno",
-	"field-year-relative+1": "anno prossimo",
-	"field-fri-relative+-1": "venerdì scorso",
-	"eraNarrow": [
-		"aC",
-		"BCE",
-		"dC",
-		"CE"
-	],
-	"dayPeriods-format-wide-noon": "mezzogiorno",
-	"field-tue-short-relative+-1": "mar. scorso",
-	"field-minute-narrow": "m",
-	"dayPeriods-standAlone-wide-afternoon1": "pomeriggio",
-	"dateFormatItem-yQQQ": "QQQ y",
-	"days-format-wide": [
-		"domenica",
-		"lunedì",
-		"martedì",
-		"mercoledì",
-		"giovedì",
-		"venerdì",
-		"sabato"
-	],
-	"field-mon-narrow-relative+0": "questo lu",
-	"dateFormatItem-EHm": "E HH:mm",
-	"field-mon-narrow-relative+1": "lu prossimo",
-	"dayPeriods-standAlone-wide-midnight": "mezzanotte",
-	"dateFormatItem-yM": "M/y",
-	"field-zone": "fuso orario",
-	"dateFormatItem-yMMMM": "MMMM y",
-	"dateFormatItem-MMMEd": "E d MMM",
+	"dateFormatItem-MMMMW": "'settimana' W 'di' MMMM",
+	"field-month-short-relative+-1": "mese scorso",
 	"dateFormatItem-EHms": "E HH:mm:ss",
-	"dateFormatItem-yMEd": "E d/M/y",
-	"dayPeriods-standAlone-narrow-midnight": "mezzanotte",
-	"field-quarter-narrow": "trim.",
-	"dayPeriods-standAlone-abbr-am": "AM",
-	"field-day-relative+-1": "ieri",
-	"field-sun-short-relative+-1": "dom. scorsa",
-	"field-day-relative+-2": "l’altro ieri",
-	"dayPeriods-format-narrow-night1": "notte",
-	"days-format-abbr": [
-		"dom",
-		"lun",
-		"mar",
-		"mer",
-		"gio",
-		"ven",
-		"sab"
-	],
-	"field-sun-relative+0": "questa domenica",
-	"field-sun-relative+1": "domenica prossima",
-	"dateFormatItem-yMMMd": "d MMM y",
-	"dateFormatItem-Gy": "y G",
-	"field-era": "era",
-	"field-week-narrow": "sett.",
-	"field-day-short": "g",
-	"dayPeriods-standAlone-abbr-evening1": "sera",
-	"field-fri-narrow-relative+0": "questo ve",
-	"dayPeriods-format-narrow-evening1": "sera",
-	"field-fri-narrow-relative+1": "ve prossimo",
-	"dayPeriods-standAlone-wide-am": "AM"
+	"dateFormatItem-MMMMd": "d MMMM",
+	"field-week": "settimana",
+	"field-day-narrow": "g."
 }
 //end v1.x content
 );
\ No newline at end of file
