@@ -15,11 +15,15 @@ define(
 	"field-day-relative+1": "내일",
 	"field-day-relative+2": "모레",
 	"field-wed-narrow-relative+-1": "지난 수요일",
+	"dateFormatItem-EBhms": "E B h:mm:ss",
 	"field-year-narrow": "년",
+	"field-era-short": "연호",
 	"field-tue-relative+0": "이번 화요일",
 	"field-tue-relative+1": "다음 화요일",
+	"field-weekdayOfMonth": "월의 평일",
 	"field-second-short": "초",
-	"dateFormatItem-MMMd": "MMM월 d일",
+	"dateFormatItem-MMMd": "MMM d일",
+	"field-weekdayOfMonth-narrow": "월의 평일",
 	"field-week-relative+0": "이번 주",
 	"field-month-relative+0": "이번 달",
 	"field-week-relative+1": "다음 주",
@@ -48,10 +52,12 @@ define(
 	"eraNames": [
 		"불기"
 	],
+	"field-weekOfMonth": "월의 주",
 	"field-month-short": "월",
-	"dateFormatItem-GyMMMEd": "G y년 MMM월 d일 (E)",
+	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
 	"dateFormatItem-yyyyMd": "G y. M. d.",
 	"field-day": "일",
+	"field-dayOfYear-short": "년의 일",
 	"field-year-relative+-1": "작년",
 	"dayPeriods-format-wide-am": "오전",
 	"field-sat-short-relative+-1": "지난 토요일",
@@ -70,10 +76,12 @@ define(
 		"토"
 	],
 	"dayPeriods-standAlone-wide-pm": "오후",
+	"dateFormatItem-Ehms": "E a h:mm:ss",
 	"dateFormat-long": "G y년 M월 d일",
-	"dateFormatItem-GyMMMd": "G y년 MMM월 d일",
+	"dateFormatItem-GyMMMd": "G y년 MMM d일",
 	"field-quarter": "분기",
 	"field-week-short": "주",
+	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
 	"quarters-standAlone-wide": [
 		"제 1/4분기",
 		"제 2/4분기",
@@ -92,7 +100,7 @@ define(
 	"field-tue-short-relative+0": "이번 화요일",
 	"field-tue-short-relative+1": "다음 화요일",
 	"field-mon-relative+-1": "지난 월요일",
-	"dateFormatItem-GyMMM": "G y년 MMM월",
+	"dateFormatItem-GyMMM": "G y년 MMM",
 	"field-month": "월",
 	"field-day-narrow": "일",
 	"field-minute-short": "분",
@@ -100,7 +108,7 @@ define(
 	"field-sat-short-relative+0": "이번 토요일",
 	"field-sat-short-relative+1": "다음 토요일",
 	"dateFormat-medium": "G y. M. d.",
-	"dateFormatItem-yyyyMMMM": "G y년 MMMM월",
+	"dateFormatItem-yyyyMMMM": "G y년 MMMM",
 	"eraAbbr": [
 		"불기"
 	],
@@ -130,7 +138,8 @@ define(
 		"12월"
 	],
 	"field-quarter-relative+-1": "지난 분기",
-	"dateFormatItem-yyyyMMMd": "G y년 MMM월 d일",
+	"dateFormatItem-yyyyMMMd": "G y년 MMM d일",
+	"field-dayperiod-narrow": "오전/오후",
 	"days-format-short": [
 		"일",
 		"월",
@@ -141,6 +150,7 @@ define(
 		"토"
 	],
 	"dayPeriods-format-wide-pm": "오후",
+	"field-dayOfYear": "년의 일",
 	"field-sat-relative+-1": "지난 토요일",
 	"dateFormatItem-Md": "M. d.",
 	"field-hour": "시",
@@ -160,15 +170,16 @@ define(
 	],
 	"dateFormat-full": "G y년 M월 d일 EEEE",
 	"field-month-relative+-1": "지난달",
-	"dateFormatItem-Hms": "H시 m분 s초",
 	"field-quarter-short": "분기",
 	"field-sat-narrow-relative+0": "이번 토요일",
 	"field-fri-relative+0": "이번 금요일",
 	"field-sat-narrow-relative+1": "다음 토요일",
 	"field-fri-relative+1": "다음 금요일",
+	"dateFormatItem-EBhm": "E B h:mm",
 	"field-sun-short-relative+0": "이번 일요일",
 	"field-sun-short-relative+1": "다음 일요일",
 	"field-week-relative+-1": "지난주",
+	"dateFormatItem-Ehm": "E a h:mm",
 	"months-format-abbr": [
 		"1월",
 		"2월",
@@ -189,6 +200,7 @@ define(
 	"field-quarter-relative+1": "다음 분기",
 	"field-wed-short-relative+-1": "지난 수요일",
 	"dateFormat-short": "G y. M. d.",
+	"dateFormatItem-Bh": "B h시",
 	"field-thu-short-relative+-1": "지난 목요일",
 	"days-standAlone-wide": [
 		"일요일",
@@ -199,12 +211,13 @@ define(
 		"금요일",
 		"토요일"
 	],
-	"dateFormatItem-yyyyMMMEd": "G y년 MMM월 d일 (E)",
+	"dateFormatItem-yyyyMMMEd": "G y년 MMM d일 (E)",
 	"field-mon-narrow-relative+-1": "지난 월요일",
-	"dateFormatItem-MMMMd": "MMMM월 d일",
+	"dateFormatItem-MMMMd": "MMMM d일",
 	"field-thu-narrow-relative+-1": "지난 목요일",
 	"field-tue-narrow-relative+-1": "지난 화요일",
 	"dateFormatItem-H": "H시",
+	"field-weekOfMonth-short": "월의 주",
 	"dateFormatItem-yyyy": "G y년",
 	"field-wed-short-relative+0": "이번 수요일",
 	"dateFormatItem-M": "M월",
@@ -253,8 +266,11 @@ define(
 		"11월",
 		"12월"
 	],
+	"field-dayOfYear-narrow": "년의 일",
+	"field-weekdayOfMonth-short": "월의 평일",
 	"timeFormat-full": "a h시 m분 s초 zzzz",
 	"dateFormatItem-MEd": "M. d. (E)",
+	"field-zone-narrow": "시간대",
 	"dateFormatItem-y": "G y년",
 	"field-thu-narrow-relative+0": "이번 목요일",
 	"field-thu-narrow-relative+1": "다음 목요일",
@@ -262,8 +278,8 @@ define(
 	"field-mon-short-relative+-1": "지난 월요일",
 	"field-thu-relative+0": "이번 목요일",
 	"field-thu-relative+1": "다음 목요일",
-	"dateFormatItem-hms": "a h:mm:ss",
 	"field-fri-short-relative+-1": "지난 금요일",
+	"dateFormatItem-hms": "a h:mm:ss",
 	"field-thu-relative+-1": "지난 목요일",
 	"field-week": "주",
 	"quarters-format-wide": [
@@ -275,7 +291,9 @@ define(
 	"dateFormatItem-Ed": "d일 (E)",
 	"field-wed-narrow-relative+0": "이번 수요일",
 	"field-wed-narrow-relative+1": "다음 수요일",
-	"dateFormatItem-yyyyMMM": "G y년 MMM월",
+	"dateFormatItem-yyyyMMMEEEEd": "G y년 MMM d일 EEEE",
+	"dateFormatItem-yyyyMMM": "G y년 MMM",
+	"field-dayperiod-short": "오전/오후",
 	"field-fri-short-relative+0": "이번 금요일",
 	"field-fri-short-relative+1": "다음 금요일",
 	"days-standAlone-short": [
@@ -288,6 +306,7 @@ define(
 		"토"
 	],
 	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
+	"field-zone-short": "시간대",
 	"field-hour-short": "시",
 	"quarters-format-abbr": [
 		"1분기",
@@ -300,10 +319,12 @@ define(
 	"field-fri-narrow-relative+-1": "지난 금요일",
 	"field-year-relative+0": "올해",
 	"field-year-relative+1": "내년",
+	"field-era-narrow": "연호",
 	"field-fri-relative+-1": "지난 금요일",
 	"eraNarrow": [
 		"불기"
 	],
+	"dateFormatItem-Bhms": "B h:mm:ss",
 	"field-tue-short-relative+-1": "지난 화요일",
 	"field-minute-narrow": "분",
 	"days-format-wide": [
@@ -317,12 +338,16 @@ define(
 	],
 	"field-mon-narrow-relative+0": "이번 월요일",
 	"field-mon-narrow-relative+1": "다음 월요일",
+	"dateFormatItem-GyMMMEEEEd": "G y년 MMM d일 EEEE",
 	"field-zone": "시간대",
-	"dateFormatItem-MMMEd": "MMM월 d일 (E)",
+	"dateFormatItem-MMMEd": "MMM d일 (E)",
+	"field-weekOfMonth-narrow": "월의 주",
+	"field-weekday-narrow": "요일",
 	"field-quarter-narrow": "분기",
 	"field-sun-short-relative+-1": "지난 일요일",
 	"field-day-relative+-1": "어제",
 	"field-day-relative+-2": "그저께",
+	"field-weekday-short": "요일",
 	"days-format-abbr": [
 		"일",
 		"월",
@@ -332,6 +357,7 @@ define(
 		"금",
 		"토"
 	],
+	"dateFormatItem-Bhm": "B h:mm",
 	"field-sun-relative+0": "이번 일요일",
 	"field-sun-relative+1": "다음 일요일",
 	"dateFormatItem-Gy": "G y년",
