@@ -15,11 +15,15 @@ define(
 	"field-day-relative+1": "내일",
 	"field-day-relative+2": "모레",
 	"field-wed-narrow-relative+-1": "지난 수요일",
+	"dateFormatItem-EBhms": "E B h:mm:ss",
 	"field-year-narrow": "년",
+	"field-era-short": "연호",
 	"field-tue-relative+0": "이번 화요일",
 	"field-tue-relative+1": "다음 화요일",
+	"field-weekdayOfMonth": "월의 평일",
 	"field-second-short": "초",
-	"dateFormatItem-MMMd": "MMM월 d일",
+	"dateFormatItem-MMMd": "M월 d일",
+	"field-weekdayOfMonth-narrow": "월의 평일",
 	"field-week-relative+0": "이번 주",
 	"field-month-relative+0": "이번 달",
 	"field-week-relative+1": "다음 주",
@@ -31,10 +35,15 @@ define(
 	"field-mon-short-relative+1": "다음 월요일",
 	"field-second-relative+0": "지금",
 	"dateFormatItem-yyyyQQQ": "G y년 QQQ",
+	"eraNames": [
+		"유대력"
+	],
+	"field-weekOfMonth": "월의 주",
 	"field-month-short": "월",
-	"dateFormatItem-GyMMMEd": "G y년 MMM월 d일 (E)",
+	"dateFormatItem-GyMMMEd": "G y년 M월 d일 (E)",
 	"dateFormatItem-yyyyMd": "G y. M. d.",
 	"field-day": "일",
+	"field-dayOfYear-short": "년의 일",
 	"field-year-relative+-1": "작년",
 	"dayPeriods-format-wide-am": "오전",
 	"field-sat-short-relative+-1": "지난 토요일",
@@ -53,8 +62,9 @@ define(
 		"토"
 	],
 	"dayPeriods-standAlone-wide-pm": "오후",
+	"dateFormatItem-Ehms": "E a h:mm:ss",
 	"dateFormat-long": "G y년 M월 d일",
-	"dateFormatItem-GyMMMd": "G y년 MMM월 d일",
+	"dateFormatItem-GyMMMd": "G y년 M월 d일",
 	"field-quarter": "분기",
 	"field-week-short": "주",
 	"quarters-standAlone-wide": [
@@ -75,7 +85,7 @@ define(
 	"field-tue-short-relative+0": "이번 화요일",
 	"field-tue-short-relative+1": "다음 화요일",
 	"field-mon-relative+-1": "지난 월요일",
-	"dateFormatItem-GyMMM": "G y년 MMM월",
+	"dateFormatItem-GyMMM": "G y년 M월",
 	"field-month": "월",
 	"field-day-narrow": "일",
 	"field-minute-short": "분",
@@ -83,7 +93,7 @@ define(
 	"field-sat-short-relative+0": "이번 토요일",
 	"field-sat-short-relative+1": "다음 토요일",
 	"dateFormat-medium": "G y. M. d.",
-	"dateFormatItem-yyyyMMMM": "G y년 MMMM월",
+	"dateFormatItem-yyyyMMMM": "G y년 M월",
 	"eraAbbr": [
 		"AM"
 	],
@@ -99,7 +109,8 @@ define(
 	"field-mon-relative+1": "다음 월요일",
 	"field-year-short": "년",
 	"field-quarter-relative+-1": "지난 분기",
-	"dateFormatItem-yyyyMMMd": "G y년 MMM월 d일",
+	"dateFormatItem-yyyyMMMd": "G y년 M월 d일",
+	"field-dayperiod-narrow": "오전/오후",
 	"days-format-short": [
 		"일",
 		"월",
@@ -110,49 +121,51 @@ define(
 		"토"
 	],
 	"dayPeriods-format-wide-pm": "오후",
+	"field-dayOfYear": "년의 일",
 	"field-sat-relative+-1": "지난 토요일",
 	"dateFormatItem-Md": "M. d.",
 	"field-hour": "시",
 	"months-format-wide": [
-		"디스리월",
-		"말케스월",
-		"기슬르월",
-		"데벳월",
-		"스밧월",
-		"아달월 1",
-		"아달월",
-		"닛산월",
-		"이야르월",
-		"시완월",
-		"담무르월",
-		"압월",
-		"엘룰월"
+		"디스리",
+		"말케스",
+		"기슬르",
+		"데벳",
+		"스밧",
+		"아달 1",
+		"아달",
+		"닛산",
+		"이야르",
+		"시완",
+		"담무르",
+		"압",
+		"엘룰"
 	],
 	"dateFormat-full": "G y년 M월 d일 EEEE",
 	"field-month-relative+-1": "지난달",
-	"dateFormatItem-Hms": "H시 m분 s초",
 	"field-quarter-short": "분기",
 	"field-sat-narrow-relative+0": "이번 토요일",
 	"field-fri-relative+0": "이번 금요일",
 	"field-sat-narrow-relative+1": "다음 토요일",
 	"field-fri-relative+1": "다음 금요일",
+	"dateFormatItem-EBhm": "E B h:mm",
 	"field-sun-short-relative+0": "이번 일요일",
 	"field-sun-short-relative+1": "다음 일요일",
 	"field-week-relative+-1": "지난주",
+	"dateFormatItem-Ehm": "E a h:mm",
 	"months-format-abbr": [
-		"디스리월",
-		"말케스월",
-		"기슬르월",
-		"데벳월",
-		"스밧월",
-		"아달월 1",
-		"아달월",
-		"닛산월",
-		"이야르월",
-		"시완월",
-		"담무르월",
-		"압월",
-		"엘룰월"
+		"디스리",
+		"말케스",
+		"기슬르",
+		"데벳",
+		"스밧",
+		"아달 1",
+		"아달",
+		"닛산",
+		"이야르",
+		"시완",
+		"담무르",
+		"압",
+		"엘룰"
 	],
 	"field-quarter-relative+0": "이번 분기",
 	"field-minute-relative+0": "현재 분",
@@ -160,6 +173,7 @@ define(
 	"field-quarter-relative+1": "다음 분기",
 	"field-wed-short-relative+-1": "지난 수요일",
 	"dateFormat-short": "G y. M. d.",
+	"dateFormatItem-Bh": "B h시",
 	"field-thu-short-relative+-1": "지난 목요일",
 	"days-standAlone-wide": [
 		"일요일",
@@ -170,12 +184,13 @@ define(
 		"금요일",
 		"토요일"
 	],
-	"dateFormatItem-yyyyMMMEd": "G y년 MMM월 d일 (E)",
+	"dateFormatItem-yyyyMMMEd": "G y년 M월 d일 (E)",
 	"field-mon-narrow-relative+-1": "지난 월요일",
-	"dateFormatItem-MMMMd": "MMMM월 d일",
+	"dateFormatItem-MMMMd": "M월 d일",
 	"field-thu-narrow-relative+-1": "지난 목요일",
 	"field-tue-narrow-relative+-1": "지난 화요일",
 	"dateFormatItem-H": "H시",
+	"field-weekOfMonth-short": "월의 주",
 	"dateFormatItem-yyyy": "G y년",
 	"field-wed-short-relative+0": "이번 수요일",
 	"dateFormatItem-M": "M월",
@@ -206,7 +221,7 @@ define(
 		"토"
 	],
 	"dateFormatItem-hm": "a h:mm",
-	"months-format-abbr-leap": "아달월 2",
+	"months-format-abbr-leap": "아달 2",
 	"dateFormatItem-d": "d일",
 	"field-weekday": "요일",
 	"field-sat-relative+0": "이번 토요일",
@@ -227,9 +242,12 @@ define(
 		"압월",
 		"엘룰월"
 	],
-	"months-format-wide-leap": "아달월 2",
+	"months-format-wide-leap": "아달 2",
+	"field-dayOfYear-narrow": "년의 일",
+	"field-weekdayOfMonth-short": "월의 평일",
 	"timeFormat-full": "a h시 m분 s초 zzzz",
 	"dateFormatItem-MEd": "M. d. (E)",
+	"field-zone-narrow": "시간대",
 	"dateFormatItem-y": "G y년",
 	"field-thu-narrow-relative+0": "이번 목요일",
 	"field-thu-narrow-relative+1": "다음 목요일",
@@ -237,8 +255,8 @@ define(
 	"field-mon-short-relative+-1": "지난 월요일",
 	"field-thu-relative+0": "이번 목요일",
 	"field-thu-relative+1": "다음 목요일",
-	"dateFormatItem-hms": "a h:mm:ss",
 	"field-fri-short-relative+-1": "지난 금요일",
+	"dateFormatItem-hms": "a h:mm:ss",
 	"field-thu-relative+-1": "지난 목요일",
 	"field-week": "주",
 	"quarters-format-wide": [
@@ -250,7 +268,8 @@ define(
 	"dateFormatItem-Ed": "d일 (E)",
 	"field-wed-narrow-relative+0": "이번 수요일",
 	"field-wed-narrow-relative+1": "다음 수요일",
-	"dateFormatItem-yyyyMMM": "G y년 MMM월",
+	"field-dayperiod-short": "오전/오후",
+	"dateFormatItem-yyyyMMM": "G y년 M월",
 	"field-fri-short-relative+0": "이번 금요일",
 	"field-fri-short-relative+1": "다음 금요일",
 	"days-standAlone-short": [
@@ -264,6 +283,7 @@ define(
 	],
 	"months-standAlone-abbr-leap": "아달월 2",
 	"dateFormatItem-yyyyQQQQ": "G y년 QQQQ",
+	"field-zone-short": "시간대",
 	"field-hour-short": "시",
 	"quarters-format-abbr": [
 		"1분기",
@@ -276,7 +296,10 @@ define(
 	"field-fri-narrow-relative+-1": "지난 금요일",
 	"field-year-relative+0": "올해",
 	"field-year-relative+1": "내년",
+	"field-era-narrow": "연호",
 	"field-fri-relative+-1": "지난 금요일",
+	"eraNarrow": "AM",
+	"dateFormatItem-Bhms": "B h:mm:ss",
 	"field-tue-short-relative+-1": "지난 화요일",
 	"field-minute-narrow": "분",
 	"days-format-wide": [
@@ -291,12 +314,15 @@ define(
 	"field-mon-narrow-relative+0": "이번 월요일",
 	"field-mon-narrow-relative+1": "다음 월요일",
 	"field-zone": "시간대",
-	"dateFormatItem-MMMEd": "MMM월 d일 (E)",
+	"dateFormatItem-MMMEd": "M월 d일 (E)",
+	"field-weekOfMonth-narrow": "월의 주",
+	"field-weekday-narrow": "요일",
 	"months-standAlone-wide-leap": "아달월 2",
 	"field-quarter-narrow": "분기",
 	"field-sun-short-relative+-1": "지난 일요일",
 	"field-day-relative+-1": "어제",
 	"field-day-relative+-2": "그저께",
+	"field-weekday-short": "요일",
 	"days-format-abbr": [
 		"일",
 		"월",
@@ -306,6 +332,7 @@ define(
 		"금",
 		"토"
 	],
+	"dateFormatItem-Bhm": "B h:mm",
 	"field-sun-relative+0": "이번 일요일",
 	"field-sun-relative+1": "다음 일요일",
 	"dateFormatItem-Gy": "G y년",
