@@ -6,43 +6,58 @@ define(
 	"field-weekday": "요일",
 	"field-mon-narrow-relative+0": "이번 월요일",
 	"field-mon-narrow-relative+1": "다음 월요일",
+	"field-weekOfMonth-short": "월의 주",
+	"field-weekday-short": "요일",
 	"field-wed-relative+0": "이번 수요일",
+	"dateFormatItem-GyMMMEd": "G y년 MMM d일 (E)",
+	"dateFormatItem-MMMEd": "MMM d일 (E)",
 	"field-wed-relative+1": "다음 수요일",
+	"field-dayperiod-short": "오전/오후",
 	"field-week-short": "주",
-	"field-tue-relative+-1": "지난 화요일",
 	"field-year-short": "년",
+	"field-era-narrow": "연호",
+	"field-tue-relative+-1": "지난 화요일",
 	"field-thu-narrow-relative+-1": "지난 목요일",
 	"field-hour-relative+0": "현재 시간",
 	"field-quarter-narrow": "분기",
 	"field-fri-relative+-1": "지난 금요일",
 	"field-hour-short": "시",
 	"field-wed-relative+-1": "지난 수요일",
+	"field-dayOfYear": "년의 일",
 	"field-mon-short-relative+-1": "지난 월요일",
 	"field-thu-relative+-1": "지난 목요일",
 	"field-era": "연호",
 	"field-sat-narrow-relative+0": "이번 토요일",
 	"field-sat-narrow-relative+1": "다음 토요일",
 	"field-year": "년",
+	"dateFormatItem-yyyyMMMM": "G y년 MMMM",
 	"field-hour": "시",
 	"field-sat-relative+0": "이번 토요일",
 	"field-sat-relative+1": "다음 토요일",
 	"field-sat-short-relative+-1": "지난 토요일",
+	"field-weekOfMonth-narrow": "월의 주",
 	"field-minute-narrow": "분",
 	"field-day-relative+0": "오늘",
 	"field-day-relative+1": "내일",
 	"field-thu-relative+0": "이번 목요일",
-	"field-wed-narrow-relative+0": "이번 수요일",
-	"field-mon-narrow-relative+-1": "지난 월요일",
+	"dateFormatItem-GyMMMd": "G y년 MMM d일",
 	"field-day-relative+2": "모레",
+	"field-mon-narrow-relative+-1": "지난 월요일",
+	"field-wed-narrow-relative+0": "이번 수요일",
 	"field-thu-relative+1": "다음 목요일",
 	"field-wed-narrow-relative+1": "다음 수요일",
 	"field-mon-short-relative+0": "이번 월요일",
 	"field-mon-short-relative+1": "다음 월요일",
+	"field-weekdayOfMonth-short": "월의 평일",
+	"dateFormatItem-yyyyMMMEd": "G y년 MMM d일 (E)",
 	"field-wed-short-relative+-1": "지난 수요일",
 	"field-fri-narrow-relative+-1": "지난 금요일",
+	"dateFormatItem-yyyyMMM": "G y년 MMM",
+	"dateFormatItem-yyyyMMMd": "G y년 MMM d일",
+	"dateFormatItem-MMMMd": "MMMM d일",
 	"field-hour-narrow": "시",
-	"field-tue-short-relative+0": "이번 화요일",
 	"field-year-narrow": "년",
+	"field-tue-short-relative+0": "이번 화요일",
 	"field-tue-short-relative+1": "다음 화요일",
 	"field-minute-short": "분",
 	"field-day-narrow": "일",
@@ -57,14 +72,18 @@ define(
 	"field-minute": "분",
 	"field-month-short": "월",
 	"field-dayperiod": "오전/오후",
+	"field-weekdayOfMonth-narrow": "월의 평일",
 	"field-day-relative+-1": "어제",
 	"field-day-relative+-2": "그저께",
 	"field-minute-relative+0": "현재 분",
 	"field-week-narrow": "주",
 	"field-wed-narrow-relative+-1": "지난 수요일",
+	"dateFormatItem-MMMd": "MMM d일",
 	"field-day-short": "일",
 	"field-quarter-relative+0": "이번 분기",
+	"field-dayperiod-narrow": "오전/오후",
 	"field-quarter-relative+1": "다음 분기",
+	"field-zone-short": "시간대",
 	"field-fri-relative+0": "이번 금요일",
 	"field-fri-relative+1": "다음 금요일",
 	"field-day": "일",
@@ -74,14 +93,21 @@ define(
 	"field-month-relative+-1": "지난달",
 	"field-thu-short-relative+0": "이번 목요일",
 	"field-thu-short-relative+1": "다음 목요일",
+	"dateFormatItem-GyMMMEEEEd": "G y년 MMM d일 EEEE",
+	"field-weekday-narrow": "요일",
 	"field-quarter": "분기",
+	"dateFormatItem-yyyyMMMEEEEd": "G y년 MMM d일 EEEE",
+	"dateFormatItem-MMMEEEEd": "MMM d일 EEEE",
+	"field-zone-narrow": "시간대",
 	"field-month": "월",
+	"field-weekOfMonth": "월의 주",
 	"field-tue-relative+0": "이번 화요일",
 	"field-tue-relative+1": "다음 화요일",
 	"field-fri-narrow-relative+0": "이번 금요일",
 	"field-fri-narrow-relative+1": "다음 금요일",
 	"field-fri-short-relative+-1": "지난 금요일",
 	"field-sun-narrow-relative+-1": "지난 일요일",
+	"field-dayOfYear-short": "년의 일",
 	"field-sun-narrow-relative+0": "이번 일요일",
 	"field-thu-narrow-relative+0": "이번 목요일",
 	"field-sun-narrow-relative+1": "다음 일요일",
@@ -98,6 +124,7 @@ define(
 	"field-fri-short-relative+1": "다음 금요일",
 	"field-sun-relative+-1": "지난 일요일",
 	"field-month-relative+0": "이번 달",
+	"field-weekdayOfMonth": "월의 평일",
 	"field-month-relative+1": "다음 달",
 	"field-week": "주",
 	"field-sat-short-relative+0": "이번 토요일",
@@ -105,10 +132,13 @@ define(
 	"field-year-relative+0": "올해",
 	"field-week-relative+-1": "지난주",
 	"field-year-relative+1": "내년",
+	"field-era-short": "연호",
 	"field-quarter-short": "분기",
+	"field-dayOfYear-narrow": "년의 일",
 	"field-sun-short-relative+-1": "지난 일요일",
 	"field-thu-short-relative+-1": "지난 목요일",
 	"field-tue-short-relative+-1": "지난 화요일",
+	"dateFormatItem-GyMMM": "G y년 MMM",
 	"field-mon-relative+-1": "지난 월요일",
 	"field-sat-narrow-relative+-1": "지난 토요일",
 	"field-month-narrow": "월",
