@@ -4,19 +4,19 @@ define(
 	"scientificFormat": "#E0",
 	"infinity": "∞",
 	"superscriptingExponent": "×",
-	"list": ";",
 	"percentSign": "%",
 	"minusSign": "-",
-	"decimalFormat-short": "000 трил'.'",
+	"decimalFormat-short": "000 бил'.'",
 	"nan": "NaN",
 	"plusSign": "+",
 	"currencyFormat": "#,##0.00 ¤",
 	"perMille": "‰",
+	"approximatelySign": "≈",
 	"group": ".",
-	"percentFormat": "#,##0%",
-	"decimalFormat-long": "000 трилиони",
+	"percentFormat": "#,##0 %",
+	"decimalFormat-long": "000 билиони",
 	"decimalFormat": "#,##0.###",
-	"currencyFormat-short": "¤ 000 трил'.'",
+	"currencyFormat-short": "000 бил'.' ¤",
 	"timeSeparator": ":",
 	"decimal": ",",
 	"exponential": "E"
