@@ -1,146 +1,214 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "nå",
-	"field-quarter-relative+-1": "forrige kvartal",
-	"field-weekday": "ukedag",
-	"field-mon-narrow-relative+0": "denne ma.",
-	"field-mon-narrow-relative+1": "neste ma.",
-	"field-day-short-relative+0": "i dag",
-	"field-day-short-relative+1": "i morgen",
-	"field-day-short-relative+2": "i overmorgen",
-	"field-wed-relative+0": "onsdag denne uken",
-	"field-wed-relative+1": "onsdag neste uke",
-	"field-week-short": "uke",
-	"field-year-short": "år",
-	"field-tue-relative+-1": "tirsdag sist uke",
-	"field-thu-narrow-relative+-1": "sist to.",
-	"field-hour-relative+0": "denne timen",
-	"field-quarter-narrow": "kv.",
-	"field-fri-relative+-1": "fredag sist uke",
-	"field-hour-short": "t",
-	"field-wed-relative+-1": "onsdag sist uke",
-	"field-mon-short-relative+-1": "sist man.",
-	"field-day-short-relative+-1": "i går",
-	"field-thu-relative+-1": "torsdag sist uke",
-	"field-day-short-relative+-2": "i forgårs",
-	"field-era": "tidsalder",
-	"field-sat-narrow-relative+0": "denne lø.",
-	"field-sat-narrow-relative+1": "neste lø.",
+	"field-quarter-short-relative+0": "dette kv.",
+	"field-quarter-short-relative+1": "neste kv.",
+	"field-tue-relative+-1": "forrige tirsdag",
 	"field-year": "år",
-	"field-hour": "time",
-	"field-sat-relative+0": "lørdag denne uken",
-	"field-sat-relative+1": "lørdag neste uke",
-	"field-sat-short-relative+-1": "sist lør.",
-	"field-week-narrow-relative+-1": "forrige uke",
-	"field-minute-narrow": "m",
-	"dateFormatItem-E": "ccc",
+	"field-wed-relative+0": "onsdag",
+	"field-wed-relative+1": "neste onsdag",
+	"field-minute": "minutt",
+	"field-month-narrow-relative+-1": "forrige md.",
+	"field-tue-narrow-relative+0": "denne ti.",
+	"field-tue-narrow-relative+1": "neste ti.",
+	"field-day-short-relative+-1": "i går",
+	"field-thu-short-relative+0": "denne tor.",
+	"dateTimeFormat-short": "{1} {0}",
 	"field-day-relative+0": "i dag",
+	"field-day-short-relative+-2": "i forgårs",
+	"field-thu-short-relative+1": "neste tor.",
 	"field-day-relative+1": "i morgen",
-	"field-thu-relative+0": "torsdag denne uken",
+	"field-week-narrow-relative+0": "denne uken",
 	"field-day-relative+2": "i overmorgen",
-	"field-mon-narrow-relative+-1": "sist ma.",
-	"field-wed-narrow-relative+0": "denne on.",
-	"field-thu-relative+1": "torsdag neste uke",
-	"field-wed-narrow-relative+1": "neste on.",
-	"field-mon-short-relative+0": "denne man.",
-	"field-mon-short-relative+1": "neste man.",
-	"field-wed-short-relative+-1": "sist ons.",
-	"field-fri-narrow-relative+-1": "sist fr.",
-	"dateFormatItem-MMMMd": "d. MMMM",
-	"field-hour-narrow": "t",
+	"field-week-narrow-relative+1": "neste uke",
+	"field-wed-narrow-relative+-1": "sist on.",
 	"field-year-narrow": "år",
-	"field-tue-short-relative+0": "denne tir.",
-	"field-tue-short-relative+1": "neste tir.",
-	"field-minute-short": "min",
-	"field-day-narrow": "d.",
-	"field-wed-short-relative+0": "denne ons.",
-	"field-wed-short-relative+1": "neste ons.",
-	"field-sun-relative+0": "søndag denne uken",
-	"field-sun-relative+1": "søndag neste uke",
-	"eraAbbr": [
-		"Before R.O.C.",
+	"field-era-short": "tidsalder",
+	"field-year-narrow-relative+0": "i år",
+	"field-tue-relative+0": "tirsdag",
+	"field-year-narrow-relative+1": "neste år",
+	"field-tue-relative+1": "neste tirsdag",
+	"field-weekdayOfMonth": "ukedag i måneden",
+	"field-second-short": "sek",
+	"dateFormatItem-yyyyMM": "MM.y G",
+	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "uked. i md.",
+	"field-week-relative+0": "denne uken",
+	"field-month-relative+0": "denne måneden",
+	"field-week-relative+1": "neste uke",
+	"field-month-relative+1": "neste måned",
+	"field-sun-narrow-relative+0": "denne sø.",
+	"field-mon-short-relative+0": "denne man.",
+	"field-sun-narrow-relative+1": "neste sø.",
+	"field-mon-short-relative+1": "neste man.",
+	"field-second-relative+0": "nå",
+	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"eraNames": [
+		"Før R.O.C.",
 		"Minguo"
 	],
-	"field-minute": "minutt",
+	"field-weekOfMonth": "uke i måneden",
 	"field-month-short": "mnd.",
-	"field-dayperiod": "a.m./p.m.",
-	"field-day-relative+-1": "i går",
-	"field-day-relative+-2": "i forgårs",
-	"field-minute-relative+0": "dette minuttet",
-	"field-week-narrow": "u.",
-	"field-wed-narrow-relative+-1": "sist on.",
-	"field-day-short": "dag",
-	"field-quarter-relative+0": "dette kvartalet",
-	"field-quarter-relative+1": "neste kvartal",
-	"field-fri-relative+0": "fredag denne uken",
-	"field-fri-relative+1": "fredag neste uke",
+	"dateFormatItem-GyMMMEd": "E d. MMM y G",
+	"dateFormatItem-yyyyMd": "d.M.y G",
 	"field-day": "dag",
-	"field-second-narrow": "s",
-	"field-zone": "tidssone",
+	"field-dayOfYear-short": "dag i året",
 	"field-year-relative+-1": "i fjor",
-	"field-month-relative+-1": "forrige måned",
-	"field-thu-short-relative+0": "denne tor.",
-	"field-thu-short-relative+1": "neste tor.",
-	"field-quarter-narrow-relative+0": "dette kv.",
-	"field-quarter-narrow-relative+1": "neste kv.",
-	"field-quarter": "kvartal",
-	"field-month": "måned",
-	"field-tue-relative+0": "tirsdag denne uken",
-	"field-quarter-short-relative+0": "dette kv.",
-	"field-tue-relative+1": "tirsdag neste uke",
-	"field-quarter-short-relative+1": "neste kv.",
-	"field-fri-narrow-relative+0": "denne fr.",
-	"field-fri-narrow-relative+1": "neste fr.",
-	"field-fri-short-relative+-1": "sist fre.",
-	"field-sun-narrow-relative+-1": "sist sø.",
-	"field-quarter-short-relative+-1": "forrige kv.",
-	"field-week-narrow-relative+0": "denne uken",
-	"field-week-narrow-relative+1": "neste uke",
-	"field-sun-narrow-relative+0": "denne sø.",
-	"field-thu-narrow-relative+0": "denne to.",
-	"field-sun-narrow-relative+1": "neste sø.",
-	"field-thu-narrow-relative+1": "neste to.",
-	"field-tue-narrow-relative+0": "denne ti.",
-	"field-mon-relative+0": "mandag denne uken",
-	"field-tue-narrow-relative+1": "neste ti.",
-	"field-week-short-relative+-1": "forrige uke",
-	"field-mon-relative+1": "mandag neste uke",
-	"field-tue-narrow-relative+-1": "sist ti.",
-	"field-month-narrow-relative+0": "denne md.",
-	"field-second-short": "sek",
-	"field-month-narrow-relative+1": "neste md.",
+	"field-sat-short-relative+-1": "sist lør.",
+	"field-hour-relative+0": "denne timen",
+	"dateFormatItem-yyyyMEd": "E d.M.y G",
+	"field-second-short-relative+0": "nå",
+	"field-wed-relative+-1": "forrige onsdag",
+	"dateTimeFormat-medium": "{1} {0}",
+	"field-sat-narrow-relative+-1": "sist lø.",
 	"field-second": "sekund",
-	"field-fri-short-relative+0": "denne fre.",
-	"field-sat-relative+-1": "lørdag sist uke",
-	"field-fri-short-relative+1": "neste fre.",
-	"field-sun-relative+-1": "søndag sist uke",
-	"field-month-short-relative+0": "denne md.",
-	"field-month-relative+0": "denne måneden",
-	"field-quarter-narrow-relative+-1": "forrige kv.",
-	"field-month-short-relative+1": "neste md.",
-	"field-month-relative+1": "neste måned",
-	"field-week-short-relative+0": "denne uken",
-	"field-week-short-relative+1": "neste uke",
-	"field-week": "uke",
+	"dateFormat-long": "d. MMMM y G",
+	"dateFormatItem-GyMMMd": "d. MMM y G",
+	"field-quarter": "kvartal",
+	"field-week-short": "uke",
+	"field-day-narrow-relative+0": "i dag",
+	"field-day-narrow-relative+1": "i morgen",
+	"field-day-narrow-relative+2": "+2 d.",
+	"field-tue-short-relative+0": "denne tir.",
+	"field-tue-short-relative+1": "neste tir.",
+	"field-month-short-relative+-1": "forrige md.",
+	"field-mon-relative+-1": "forrige mandag",
+	"dateFormatItem-GyMMM": "MMM y G",
+	"field-month": "måned",
+	"field-day-narrow": "d.",
+	"dateFormatItem-MMM": "LLL",
+	"field-minute-short": "min",
+	"field-dayperiod": "a.m./p.m.",
 	"field-sat-short-relative+0": "denne lør.",
 	"field-sat-short-relative+1": "neste lør.",
-	"field-year-relative+0": "i år",
-	"field-week-relative+-1": "forrige uke",
-	"field-year-relative+1": "neste år",
+	"dateFormat-medium": "d. MMM y G",
+	"dateFormatItem-yyyyMMMM": "MMMM y G",
+	"eraAbbr": [
+		"Før ROC",
+		"Minguo"
+	],
+	"dateFormatItem-yyyyM": "M.y G",
+	"field-second-narrow": "s",
+	"field-mon-relative+0": "mandag",
+	"field-mon-relative+1": "neste mandag",
+	"field-day-narrow-relative+-1": "i går",
+	"field-year-short": "år",
+	"field-day-narrow-relative+-2": "-2 d.",
+	"field-quarter-relative+-1": "forrige kvartal",
+	"dateFormatItem-yyyyMMMd": "d. MMM y G",
+	"field-dayperiod-narrow": "am/pm",
+	"field-week-narrow-relative+-1": "forrige uke",
+	"field-dayOfYear": "dag i året",
+	"field-sat-relative+-1": "forrige lørdag",
+	"dateTimeFormat-long": "{1} {0}",
+	"dateFormatItem-Md": "d.M.",
+	"field-hour": "time",
+	"dateFormat-full": "EEEE d. MMMM y G",
+	"field-month-relative+-1": "forrige måned",
 	"field-quarter-short": "kv.",
-	"field-sun-short-relative+-1": "sist søn.",
-	"field-thu-short-relative+-1": "sist tor.",
-	"field-tue-short-relative+-1": "sist tir.",
-	"field-mon-relative+-1": "mandag sist uke",
-	"field-sat-narrow-relative+-1": "sist lø.",
-	"field-month-narrow": "md.",
-	"field-month-narrow-relative+-1": "forrige md.",
-	"field-month-short-relative+-1": "forrige md.",
-	"field-week-relative+0": "denne uken",
+	"field-sat-narrow-relative+0": "denne lø.",
+	"field-fri-relative+0": "fredag",
+	"field-sat-narrow-relative+1": "neste lø.",
+	"field-fri-relative+1": "neste fredag",
+	"field-month-narrow-relative+0": "denne md.",
+	"field-month-narrow-relative+1": "neste md.",
 	"field-sun-short-relative+0": "denne søn.",
-	"field-week-relative+1": "neste uke",
-	"field-sun-short-relative+1": "neste søn."
+	"field-sun-short-relative+1": "neste søn.",
+	"field-week-relative+-1": "forrige uke",
+	"field-quarter-short-relative+-1": "forrige kv.",
+	"field-quarter-relative+0": "dette kvartalet",
+	"field-minute-relative+0": "dette minuttet",
+	"field-quarter-relative+1": "neste kvartal",
+	"field-wed-short-relative+-1": "sist ons.",
+	"dateFormat-short": "d.M.y G",
+	"field-year-narrow-relative+-1": "i fjor",
+	"field-thu-short-relative+-1": "sist tor.",
+	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
+	"field-mon-narrow-relative+-1": "sist ma.",
+	"dateFormatItem-MMMMd": "d. MMMM",
+	"field-thu-narrow-relative+-1": "sist to.",
+	"dateFormatItem-E": "ccc",
+	"field-weekOfMonth-short": "uke i mnd.",
+	"field-tue-narrow-relative+-1": "sist ti.",
+	"dateFormatItem-yyyy": "y G",
+	"dateFormatItem-M": "L.",
+	"field-wed-short-relative+0": "denne ons.",
+	"field-wed-short-relative+1": "neste ons.",
+	"field-sun-relative+-1": "forrige søndag",
+	"dateTimeFormat-full": "{1} {0}",
+	"field-second-narrow-relative+0": "nå",
+	"dateFormatItem-d": "d.",
+	"field-weekday": "ukedag",
+	"field-day-short-relative+0": "i dag",
+	"field-quarter-narrow-relative+0": "dette kv.",
+	"field-day-short-relative+1": "i morgen",
+	"field-sat-relative+0": "lørdag",
+	"field-quarter-narrow-relative+1": "neste kv.",
+	"field-day-short-relative+2": "i overmorgen",
+	"field-sat-relative+1": "neste lørdag",
+	"field-week-short-relative+0": "denne uken",
+	"field-week-short-relative+1": "neste uke",
+	"field-dayOfYear-narrow": "d. i året",
+	"field-month-short-relative+0": "denne md.",
+	"field-month-short-relative+1": "neste md.",
+	"field-weekdayOfMonth-short": "uked. i mnd.",
+	"dateFormatItem-MEd": "E d.M",
+	"field-zone-narrow": "tidssone",
+	"dateFormatItem-y": "y G",
+	"field-thu-narrow-relative+0": "denne to.",
+	"field-sun-narrow-relative+-1": "sist sø.",
+	"field-mon-short-relative+-1": "sist man.",
+	"field-thu-narrow-relative+1": "neste to.",
+	"field-thu-relative+0": "torsdag",
+	"field-thu-relative+1": "neste torsdag",
+	"field-fri-short-relative+-1": "sist fre.",
+	"field-thu-relative+-1": "forrige torsdag",
+	"field-week": "uke",
+	"dateFormatItem-Ed": "E d.",
+	"field-wed-narrow-relative+0": "denne on.",
+	"field-wed-narrow-relative+1": "neste on.",
+	"field-quarter-narrow-relative+-1": "forrige kv.",
+	"field-year-short-relative+0": "i år",
+	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "am/pm",
+	"field-year-short-relative+1": "neste år",
+	"field-fri-short-relative+0": "denne fre.",
+	"field-fri-short-relative+1": "neste fre.",
+	"field-week-short-relative+-1": "forrige uke",
+	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
+	"field-hour-short": "t",
+	"field-zone-short": "tidssone",
+	"field-month-narrow": "md.",
+	"field-hour-narrow": "t",
+	"field-fri-narrow-relative+-1": "sist fr.",
+	"field-year-relative+0": "i år",
+	"field-year-relative+1": "neste år",
+	"field-era-narrow": "tidsalder",
+	"field-fri-relative+-1": "forrige fredag",
+	"eraNarrow": "Minguo",
+	"field-tue-short-relative+-1": "sist tir.",
+	"field-minute-narrow": "m",
+	"field-mon-narrow-relative+0": "denne ma.",
+	"field-mon-narrow-relative+1": "neste ma.",
+	"field-year-short-relative+-1": "i fjor",
+	"field-zone": "tidssone",
+	"dateFormatItem-MMMEd": "E d. MMM",
+	"field-weekOfMonth-narrow": "uke i md.",
+	"field-weekday-narrow": "uked.",
+	"field-quarter-narrow": "kv.",
+	"field-sun-short-relative+-1": "sist søn.",
+	"field-day-relative+-1": "i går",
+	"field-day-relative+-2": "i forgårs",
+	"field-weekday-short": "ukedag",
+	"field-sun-relative+0": "søndag",
+	"dateFormatItem-MMdd": "d.M.",
+	"field-sun-relative+1": "neste søndag",
+	"dateFormatItem-Gy": "y G",
+	"field-day-short": "dag",
+	"field-week-narrow": "u.",
+	"field-era": "tidsalder",
+	"field-fri-narrow-relative+0": "denne fr.",
+	"field-fri-narrow-relative+1": "neste fr."
 }
 //end v1.x content
 );
\ No newline at end of file
