@@ -23,12 +23,15 @@ define(
 	"field-week-narrow-relative+1": "volgende week",
 	"field-wed-narrow-relative+-1": "afgelopen wo",
 	"field-year-narrow": "jr",
+	"field-era-short": "tijdperk",
 	"field-year-narrow-relative+0": "dit jaar",
 	"field-tue-relative+0": "deze dinsdag",
 	"field-year-narrow-relative+1": "volgend jaar",
 	"field-tue-relative+1": "volgende week dinsdag",
+	"field-weekdayOfMonth": "weekdag van de maand",
 	"field-second-short": "sec",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "wkdag v.d. mnd",
 	"field-week-relative+0": "deze week",
 	"field-month-relative+0": "deze maand",
 	"field-week-relative+1": "volgende week",
@@ -54,10 +57,16 @@ define(
 		"12",
 		"13"
 	],
+	"eraNames": [
+		"tijdperk 0",
+		"tijdperk 1"
+	],
+	"field-weekOfMonth": "week van de maand",
 	"field-month-short": "mnd",
 	"dateFormatItem-GyMMMEd": "E d MMM y G",
 	"dateFormatItem-yyyyMd": "d-M-y GGGGG",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag van het jr",
 	"field-year-relative+-1": "vorig jaar",
 	"field-sat-short-relative+-1": "afgelopen zater.",
 	"field-hour-relative+0": "binnen een uur",
@@ -69,6 +78,7 @@ define(
 	"field-second": "seconde",
 	"dateFormat-long": "d MMMM y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
+	"field-hour-short-relative+0": "binnen een uur",
 	"field-quarter": "kwartaal",
 	"field-week-short": "wk",
 	"field-day-narrow-relative+0": "vandaag",
@@ -83,11 +93,15 @@ define(
 	"field-day-narrow": "dag",
 	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
-	"field-dayperiod": "dagdeel",
+	"field-dayperiod": "a.m./p.m.",
 	"field-sat-short-relative+0": "deze zater.",
 	"field-sat-short-relative+1": "volgende week zater.",
 	"dateFormat-medium": "d MMM y G",
 	"dateFormatItem-yyyyMMMM": "MMMM y G",
+	"eraAbbr": [
+		"era 0",
+		"era 1"
+	],
 	"dateFormatItem-yyyyM": "M-y GGGGG",
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "deze maandag",
@@ -112,11 +126,14 @@ define(
 	],
 	"field-quarter-relative+-1": "vorig kwartaal",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "a.m./p.m.",
 	"field-week-narrow-relative+-1": "vorige week",
+	"field-dayOfYear": "dag van het jaar",
 	"field-sat-relative+-1": "afgelopen zaterdag",
-	"dateTimeFormat-long": "{1} {0}",
+	"dateTimeFormat-long": "{1} 'om' {0}",
 	"dateFormatItem-Md": "d-M",
 	"field-hour": "uur",
+	"field-minute-narrow-relative+0": "binnen een minuut",
 	"months-format-wide": [
 		"Mäskäräm",
 		"Teqemt",
@@ -145,6 +162,7 @@ define(
 	"field-sun-short-relative+1": "volgende week zon.",
 	"field-week-relative+-1": "vorige week",
 	"field-quarter-short-relative+-1": "vorig kwartaal",
+	"field-minute-short-relative+0": "binnen een minuut",
 	"months-format-abbr": [
 		"Mäskäräm",
 		"Teqemt",
@@ -171,9 +189,10 @@ define(
 	"field-mon-narrow-relative+-1": "afgelopen ma",
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "afgelopen do",
+	"dateFormatItem-E": "ccc",
+	"field-weekOfMonth-short": "wk van de mnd",
 	"field-tue-narrow-relative+-1": "afgelopen di",
 	"dateFormatItem-yyyy": "y G",
-	"field-wed-short-relative+0": "deze woens.",
 	"dateFormatItem-M": "L",
 	"months-standAlone-wide": [
 		"Mäskäräm",
@@ -190,9 +209,10 @@ define(
 		"Nähase",
 		"Pagumän"
 	],
+	"field-wed-short-relative+0": "deze woens.",
 	"field-wed-short-relative+1": "volgende week woens.",
 	"field-sun-relative+-1": "afgelopen zondag",
-	"dateTimeFormat-full": "{1} {0}",
+	"dateTimeFormat-full": "{1} 'om' {0}",
 	"field-second-narrow-relative+0": "nu",
 	"dateFormatItem-d": "d",
 	"field-weekday": "dag van de week",
@@ -220,9 +240,12 @@ define(
 		"Nähase",
 		"Pagumän"
 	],
+	"field-dayOfYear-narrow": "dag v.h. jr",
 	"field-month-short-relative+0": "deze maand",
 	"field-month-short-relative+1": "volgende maand",
+	"field-weekdayOfMonth-short": "wkdag van de mnd",
 	"dateFormatItem-MEd": "E d-M",
+	"field-zone-narrow": "zone",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "deze do",
 	"field-sun-narrow-relative+-1": "afgelopen zo",
@@ -239,18 +262,26 @@ define(
 	"field-quarter-narrow-relative+-1": "vorig kwartaal",
 	"field-year-short-relative+0": "dit jaar",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "a.m./p.m.",
 	"field-year-short-relative+1": "volgend jaar",
 	"field-fri-short-relative+0": "deze vrij.",
 	"field-fri-short-relative+1": "volgende week vrij.",
 	"field-week-short-relative+-1": "vorige week",
+	"field-hour-narrow-relative+0": "binnen een uur",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "uur",
+	"field-zone-short": "zone",
 	"field-month-narrow": "mnd",
-	"field-hour-narrow": "uur",
+	"field-hour-narrow": "u",
 	"field-fri-narrow-relative+-1": "afgelopen vr",
 	"field-year-relative+0": "dit jaar",
 	"field-year-relative+1": "volgend jaar",
+	"field-era-narrow": "tijdperk",
 	"field-fri-relative+-1": "afgelopen vrijdag",
+	"eraNarrow": [
+		"era 0",
+		"era 1"
+	],
 	"field-tue-short-relative+-1": "afgelopen dins.",
 	"field-minute-narrow": "min",
 	"field-mon-narrow-relative+0": "deze ma",
@@ -258,10 +289,13 @@ define(
 	"field-year-short-relative+-1": "vorig jaar",
 	"field-zone": "tijdzone",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "wk v.d. mnd",
+	"field-weekday-narrow": "dag v.d. wk",
 	"field-quarter-narrow": "kwartaal",
 	"field-sun-short-relative+-1": "afgelopen zon.",
 	"field-day-relative+-1": "gisteren",
 	"field-day-relative+-2": "eergisteren",
+	"field-weekday-short": "dag van de wk",
 	"field-sun-relative+0": "deze zondag",
 	"field-sun-relative+1": "volgende week zondag",
 	"dateFormatItem-Gy": "y G",
