@@ -13,6 +13,7 @@ define(
 	"field-tue-narrow-relative+1": "volgende week di",
 	"field-thu-short-relative+0": "deze donder.",
 	"field-day-short-relative+-1": "gisteren",
+	"dateTimeFormat-short": "{1} {0}",
 	"field-thu-short-relative+1": "volgende week donder.",
 	"field-day-relative+0": "vandaag",
 	"field-day-short-relative+-2": "eergisteren",
@@ -22,13 +23,16 @@ define(
 	"field-week-narrow-relative+1": "volgende week",
 	"field-wed-narrow-relative+-1": "afgelopen wo",
 	"field-year-narrow": "jr",
+	"field-era-short": "tijdperk",
 	"field-year-narrow-relative+0": "dit jaar",
 	"field-tue-relative+0": "deze dinsdag",
 	"field-year-narrow-relative+1": "volgend jaar",
 	"field-tue-relative+1": "volgende week dinsdag",
+	"field-weekdayOfMonth": "weekdag van de maand",
 	"field-second-short": "sec",
 	"dayPeriods-format-narrow-am": "a.m.",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "wkdag v.d. mnd",
 	"dayPeriods-format-abbr-am": "a.m.",
 	"field-week-relative+0": "deze week",
 	"field-month-relative+0": "deze maand",
@@ -55,11 +59,16 @@ define(
 		"12",
 		"13"
 	],
+	"eraNames": [
+		"AM"
+	],
+	"field-weekOfMonth": "week van de maand",
 	"dayPeriods-standAlone-abbr-pm": "p.m.",
 	"field-month-short": "mnd",
 	"dateFormatItem-GyMMMEd": "E d MMM y G",
 	"dateFormatItem-yyyyMd": "d-M-y GGGGG",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag van het jr",
 	"field-year-relative+-1": "vorig jaar",
 	"dayPeriods-format-wide-am": "a.m.",
 	"field-sat-short-relative+-1": "afgelopen zater.",
@@ -67,6 +76,7 @@ define(
 	"dateFormatItem-yyyyMEd": "E d-M-y GGGGG",
 	"field-second-short-relative+0": "nu",
 	"field-wed-relative+-1": "afgelopen woensdag",
+	"dateTimeFormat-medium": "{1} {0}",
 	"field-sat-narrow-relative+-1": "afgelopen za",
 	"field-second": "seconde",
 	"days-standAlone-narrow": [
@@ -81,6 +91,7 @@ define(
 	"dayPeriods-standAlone-wide-pm": "p.m.",
 	"dateFormat-long": "d MMMM y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
+	"field-hour-short-relative+0": "binnen een uur",
 	"field-quarter": "kwartaal",
 	"field-week-short": "wk",
 	"field-day-narrow-relative+0": "vandaag",
@@ -108,8 +119,9 @@ define(
 	"dateFormatItem-GyMMM": "MMM y G",
 	"field-month": "maand",
 	"field-day-narrow": "dag",
+	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "min",
-	"field-dayperiod": "dagdeel",
+	"field-dayperiod": "a.m./p.m.",
 	"field-sat-short-relative+0": "deze zater.",
 	"field-sat-short-relative+1": "volgende week zater.",
 	"dayPeriods-format-narrow-pm": "p.m.",
@@ -149,6 +161,7 @@ define(
 	],
 	"field-quarter-relative+-1": "vorig kwartaal",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "a.m./p.m.",
 	"dayPeriods-standAlone-narrow-am": "a.m.",
 	"field-week-narrow-relative+-1": "vorige week",
 	"days-format-short": [
@@ -161,9 +174,11 @@ define(
 		"za"
 	],
 	"dayPeriods-format-wide-pm": "p.m.",
+	"field-dayOfYear": "dag van het jaar",
 	"field-sat-relative+-1": "afgelopen zaterdag",
 	"dateTimeFormat-long": "{1} 'om' {0}",
-	"dateFormatItem-Md": "d-M",
+	"dateFormatItem-Md": "d MMM",
+	"field-minute-narrow-relative+0": "binnen een minuut",
 	"field-hour": "uur",
 	"months-format-wide": [
 		"Tisjrie",
@@ -193,6 +208,7 @@ define(
 	"field-sun-short-relative+1": "volgende week zon.",
 	"field-week-relative+-1": "vorige week",
 	"field-quarter-short-relative+-1": "vorig kwartaal",
+	"field-minute-short-relative+0": "binnen een minuut",
 	"months-format-abbr": [
 		"Tisjrie",
 		"Chesjwan",
@@ -228,10 +244,12 @@ define(
 	"field-mon-narrow-relative+-1": "afgelopen ma",
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "afgelopen do",
+	"dateFormatItem-E": "ccc",
+	"field-weekOfMonth-short": "wk van de mnd",
 	"field-tue-narrow-relative+-1": "afgelopen di",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "p.m.",
-	"field-wed-short-relative+0": "deze woens.",
+	"dateFormatItem-M": "L",
 	"months-standAlone-wide": [
 		"Tisjrie",
 		"Chesjwan",
@@ -247,6 +265,7 @@ define(
 		"Av",
 		"Elloel"
 	],
+	"field-wed-short-relative+0": "deze woens.",
 	"field-wed-short-relative+1": "volgende week woens.",
 	"field-sun-relative+-1": "afgelopen zondag",
 	"days-standAlone-abbr": [
@@ -258,18 +277,19 @@ define(
 		"vr",
 		"za"
 	],
-	"field-second-narrow-relative+0": "nu",
 	"dateTimeFormat-full": "{1} 'om' {0}",
+	"field-second-narrow-relative+0": "nu",
 	"months-format-abbr-leap": "Adar B",
+	"dateFormatItem-d": "d",
 	"field-weekday": "dag van de week",
 	"months-standAlone-narrow-leap": "7",
 	"field-day-short-relative+0": "vandaag",
 	"field-quarter-narrow-relative+0": "dit kwartaal",
-	"field-sat-relative+0": "deze zaterdag",
 	"field-day-short-relative+1": "morgen",
+	"field-sat-relative+0": "deze zaterdag",
 	"field-quarter-narrow-relative+1": "volgend kwartaal",
-	"field-sat-relative+1": "volgende week zaterdag",
 	"field-day-short-relative+2": "overmorgen",
+	"field-sat-relative+1": "volgende week zaterdag",
 	"field-week-short-relative+0": "deze week",
 	"field-week-short-relative+1": "volgende week",
 	"months-standAlone-abbr": [
@@ -289,14 +309,17 @@ define(
 	],
 	"months-format-wide-leap": "Adar B",
 	"months-format-narrow-leap": "7",
+	"field-dayOfYear-narrow": "dag v.h. jr",
 	"field-month-short-relative+0": "deze maand",
 	"field-month-short-relative+1": "volgende maand",
-	"dateFormatItem-MEd": "E d-M",
-	"dateFormatItem-y": "y G",
+	"field-weekdayOfMonth-short": "wkdag van de mnd",
+	"dateFormatItem-MEd": "E d MMM",
+	"field-zone-narrow": "zone",
+	"dateFormatItem-y": "y",
 	"field-thu-narrow-relative+0": "deze do",
-	"field-thu-narrow-relative+1": "volgende week do",
 	"field-sun-narrow-relative+-1": "afgelopen zo",
 	"field-mon-short-relative+-1": "afgelopen maan.",
+	"field-thu-narrow-relative+1": "volgende week do",
 	"field-thu-relative+0": "deze donderdag",
 	"field-thu-relative+1": "volgende week donderdag",
 	"field-fri-short-relative+-1": "afgelopen vrij.",
@@ -314,6 +337,7 @@ define(
 	"field-quarter-narrow-relative+-1": "vorig kwartaal",
 	"field-year-short-relative+0": "dit jaar",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-dayperiod-short": "a.m./p.m.",
 	"field-year-short-relative+1": "volgend jaar",
 	"field-fri-short-relative+0": "deze vrij.",
 	"field-fri-short-relative+1": "volgende week vrij.",
@@ -328,8 +352,10 @@ define(
 	],
 	"field-week-short-relative+-1": "vorige week",
 	"months-standAlone-abbr-leap": "Adar B",
+	"field-hour-narrow-relative+0": "binnen een uur",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "uur",
+	"field-zone-short": "zone",
 	"quarters-format-abbr": [
 		"K1",
 		"K2",
@@ -337,11 +363,13 @@ define(
 		"K4"
 	],
 	"field-month-narrow": "mnd",
-	"field-hour-narrow": "uur",
+	"field-hour-narrow": "u",
 	"field-fri-narrow-relative+-1": "afgelopen vr",
 	"field-year-relative+0": "dit jaar",
 	"field-year-relative+1": "volgend jaar",
+	"field-era-narrow": "tijdperk",
 	"field-fri-relative+-1": "afgelopen vrijdag",
+	"eraNarrow": "AM",
 	"field-tue-short-relative+-1": "afgelopen dins.",
 	"field-minute-narrow": "min",
 	"days-format-wide": [
@@ -358,12 +386,15 @@ define(
 	"field-year-short-relative+-1": "vorig jaar",
 	"field-zone": "tijdzone",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "wk v.d. mnd",
+	"field-weekday-narrow": "dag v.d. wk",
 	"months-standAlone-wide-leap": "Adar B",
 	"field-quarter-narrow": "kwartaal",
 	"field-sun-short-relative+-1": "afgelopen zon.",
 	"field-day-relative+-1": "gisteren",
 	"dayPeriods-standAlone-abbr-am": "a.m.",
 	"field-day-relative+-2": "eergisteren",
+	"field-weekday-short": "dag van de wk",
 	"days-format-abbr": [
 		"zo",
 		"ma",
