@@ -1,190 +1,11 @@
 define(
 //begin v1.x content
 {
-	"field-quarter-short-relative+0": "w tym kwartale",
-	"field-quarter-short-relative+1": "w przyszłym kwartale",
-	"dayPeriods-standAlone-abbr-noon": "południe",
-	"field-tue-relative+-1": "w zeszły wtorek",
-	"field-year": "rok",
-	"dateFormatItem-yw": "y, 'tydz'. w",
-	"dayPeriods-format-abbr-afternoon1": "po południu",
-	"dateFormatItem-Hm": "HH:mm",
-	"field-wed-relative+0": "w tę środę",
-	"field-wed-relative+1": "w przyszłą środę",
-	"dateFormatItem-ms": "mm:ss",
-	"timeFormat-short": "HH:mm",
-	"field-minute": "minuta",
-	"field-tue-narrow-relative+0": "w ten wtorek",
-	"field-tue-narrow-relative+1": "w przyszły wtorek",
-	"field-thu-short-relative+0": "w ten czwartek",
-	"dateTimeFormat-short": "{1}, {0}",
-	"field-thu-short-relative+1": "w przyszły czwartek",
-	"field-day-relative+0": "dzisiaj",
-	"field-day-relative+1": "jutro",
-	"field-day-relative+2": "pojutrze",
-	"field-wed-narrow-relative+-1": "w zeszłą środę",
-	"field-year-narrow": "r.",
-	"field-tue-relative+0": "w ten wtorek",
-	"field-tue-relative+1": "w przyszły wtorek",
-	"field-second-short": "sek.",
-	"dayPeriods-format-narrow-am": "a",
-	"dayPeriods-standAlone-abbr-morning1": "rano",
-	"dayPeriods-standAlone-abbr-morning2": "przedpołudnie",
-	"dateFormatItem-MMMd": "d MMM",
-	"dayPeriods-format-narrow-morning1": "rano",
-	"dayPeriods-format-narrow-morning2": "przed poł.",
-	"dayPeriods-format-abbr-am": "AM",
-	"field-week-relative+0": "w tym tygodniu",
-	"field-month-relative+0": "w tym miesiącu",
-	"field-week-relative+1": "w przyszłym tygodniu",
-	"field-month-relative+1": "w przyszłym miesiącu",
+	"dateFormatItem-yMMMM": "LLLL y",
+	"field-thu-narrow-relative+0": "w ten czwartek",
+	"field-thu-narrow-relative+1": "w przyszły czwartek",
 	"field-sun-narrow-relative+0": "w tę niedzielę",
-	"timeFormat-medium": "HH:mm:ss",
-	"field-mon-short-relative+0": "w ten poniedziałek",
 	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
-	"field-mon-short-relative+1": "w przyszły poniedziałek",
-	"field-second-relative+0": "teraz",
-	"months-standAlone-narrow": [
-		"S",
-		"L",
-		"M",
-		"K",
-		"M",
-		"C",
-		"L",
-		"S",
-		"W",
-		"P",
-		"L",
-		"G"
-	],
-	"dayPeriods-standAlone-wide-noon": "południe",
-	"eraNames": [
-		"przed naszą erą",
-		"naszej ery"
-	],
-	"dayPeriods-standAlone-abbr-pm": "PM",
-	"field-month-short": "mies.",
-	"dateFormatItem-GyMMMM": "LLLL y G",
-	"dateFormatItem-GyMMMEd": "E, d MMM y G",
-	"field-day": "dzień",
-	"dayPeriods-standAlone-wide-night1": "noc",
-	"field-year-relative+-1": "w zeszłym roku",
-	"dayPeriods-format-wide-am": "AM",
-	"field-sat-short-relative+-1": "w zeszłą sobotę",
-	"dayPeriods-format-narrow-afternoon1": "po poł.",
-	"dayPeriods-format-wide-afternoon1": "po południu",
-	"field-hour-relative+0": "ta godzina",
-	"field-wed-relative+-1": "w zeszłą środę",
-	"dateTimeFormat-medium": "{1}, {0}",
-	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
-	"field-second": "sekunda",
-	"days-standAlone-narrow": [
-		"N",
-		"P",
-		"W",
-		"Ś",
-		"C",
-		"P",
-		"S"
-	],
-	"dayPeriods-standAlone-narrow-noon": "poł.",
-	"dayPeriods-standAlone-wide-pm": "PM",
-	"dateFormatItem-Ehms": "E, h:mm:ss a",
-	"dateFormat-long": "d MMMM y",
-	"dateFormatItem-GyMMMd": "d MMM y G",
-	"dayPeriods-standAlone-abbr-midnight": "północ",
-	"field-quarter": "kwartał",
-	"field-week-short": "tydz.",
-	"dayPeriods-format-narrow-midnight": "o półn.",
-	"dateFormatItem-yMMMEd": "E, d MMM y",
-	"quarters-standAlone-wide": [
-		"I kwartał",
-		"II kwartał",
-		"III kwartał",
-		"IV kwartał"
-	],
-	"days-format-narrow": [
-		"n",
-		"p",
-		"w",
-		"ś",
-		"c",
-		"p",
-		"s"
-	],
-	"dayPeriods-format-wide-evening1": "wieczorem",
-	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
-	"field-tue-short-relative+0": "w ten wtorek",
-	"field-tue-short-relative+1": "w przyszły wtorek",
-	"field-mon-relative+-1": "w zeszły poniedziałek",
-	"dateFormatItem-GyMMM": "MMM y G",
-	"field-month": "miesiąc",
-	"field-day-narrow": "dzień",
-	"dayPeriods-standAlone-abbr-night1": "noc",
-	"dayPeriods-standAlone-narrow-afternoon1": "popoł.",
-	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "min",
-	"field-dayperiod": "rano / po południu / wieczorem",
-	"field-sat-short-relative+0": "w tę sobotę",
-	"field-sat-short-relative+1": "w przyszłą sobotę",
-	"dayPeriods-format-narrow-pm": "p",
-	"dateFormat-medium": "d MMM y",
-	"eraAbbr": [
-		"p.n.e.",
-		"n.e."
-	],
-	"quarters-standAlone-abbr": [
-		"I kw.",
-		"II kw.",
-		"III kw.",
-		"IV kw."
-	],
-	"dayPeriods-format-abbr-pm": "PM",
-	"field-second-narrow": "s",
-	"field-mon-relative+0": "w ten poniedziałek",
-	"dayPeriods-standAlone-narrow-night1": "noc",
-	"field-mon-relative+1": "w przyszły poniedziałek",
-	"field-year-short": "r.",
-	"months-format-narrow": [
-		"s",
-		"l",
-		"m",
-		"k",
-		"m",
-		"c",
-		"l",
-		"s",
-		"w",
-		"p",
-		"l",
-		"g"
-	],
-	"dayPeriods-format-wide-morning1": "rano",
-	"dayPeriods-format-wide-morning2": "przed południem",
-	"field-quarter-relative+-1": "w zeszłym kwartale",
-	"dayPeriods-standAlone-narrow-am": "a",
-	"days-format-short": [
-		"nie",
-		"pon",
-		"wto",
-		"śro",
-		"czw",
-		"pią",
-		"sob"
-	],
-	"quarters-format-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"dayPeriods-format-wide-pm": "PM",
-	"field-sat-relative+-1": "w zeszłą sobotę",
-	"dateTimeFormat-long": "{1} {0}",
-	"dateFormatItem-Md": "d.MM",
-	"field-hour": "godzina",
-	"dateFormatItem-yQQQQ": "QQQQ y",
 	"months-format-wide": [
 		"stycznia",
 		"lutego",
@@ -199,47 +20,28 @@ define(
 		"listopada",
 		"grudnia"
 	],
-	"dayPeriods-format-wide-night1": "w nocy",
-	"dateFormat-full": "EEEE, d MMMM y",
-	"field-month-relative+-1": "w zeszłym miesiącu",
+	"dayPeriods-standAlone-abbr-pm": "PM",
 	"dateFormatItem-Hms": "HH:mm:ss",
-	"field-quarter-short": "kw.",
-	"field-sat-narrow-relative+0": "w tę sobotę",
-	"dateFormatItem-Hmv": "HH:mm v",
-	"field-fri-relative+0": "w ten piątek",
-	"field-sat-narrow-relative+1": "w przyszłą sobotę",
-	"field-fri-relative+1": "w przyszły piątek",
-	"dayPeriods-format-narrow-noon": "w poł.",
-	"field-sun-short-relative+0": "w tę niedzielę",
-	"field-sun-short-relative+1": "w przyszłą niedzielę",
-	"field-week-relative+-1": "w zeszłym tygodniu",
-	"field-quarter-short-relative+-1": "w zeszłym kwartale",
-	"dateFormatItem-Ehm": "E, h:mm a",
-	"months-format-abbr": [
-		"sty",
-		"lut",
-		"mar",
-		"kwi",
-		"maj",
-		"cze",
-		"lip",
-		"sie",
-		"wrz",
-		"paź",
-		"lis",
-		"gru"
+	"field-fri-narrow-relative+0": "w ten piątek",
+	"field-fri-narrow-relative+1": "w przyszły piątek",
+	"eraNarrow": [
+		"p.n.e.",
+		"n.e."
 	],
-	"dayPeriods-format-wide-midnight": "o północy",
-	"field-quarter-relative+0": "w tym kwartale",
-	"field-minute-relative+0": "ta minuta",
-	"timeFormat-long": "HH:mm:ss z",
-	"field-quarter-relative+1": "w przyszłym kwartale",
-	"field-wed-short-relative+-1": "w zeszłą środę",
-	"dateFormatItem-yMMM": "LLL y",
-	"dateFormat-short": "dd.MM.y",
-	"field-thu-short-relative+-1": "w zeszły czwartek",
+	"dateFormatItem-Hmv": "HH:mm v",
+	"dateFormatItem-hmsv": "h:mm:ss a v",
+	"dateFormatItem-yMMMd": "d MMM y",
 	"dayPeriods-format-abbr-night1": "w nocy",
-	"dateFormatItem-MMMMW": "MMM, 'tydz'. W",
+	"dayPeriods-format-narrow-evening1": "wiecz.",
+	"days-standAlone-narrow": [
+		"N",
+		"P",
+		"W",
+		"Ś",
+		"C",
+		"P",
+		"S"
+	],
 	"days-standAlone-wide": [
 		"niedziela",
 		"poniedziałek",
@@ -249,15 +51,68 @@ define(
 		"piątek",
 		"sobota"
 	],
-	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
-	"dateFormatItem-MMMMd": "d MMMM",
+	"dayPeriods-format-abbr-afternoon1": "po południu",
+	"dayPeriods-format-wide-evening1": "wieczorem",
+	"dateFormatItem-Ehm": "E, h:mm a",
+	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
+	"field-wed-narrow-relative+-1": "w zeszłą środę",
+	"dayPeriods-standAlone-wide-evening1": "wieczór",
+	"days-format-wide": [
+		"niedziela",
+		"poniedziałek",
+		"wtorek",
+		"środa",
+		"czwartek",
+		"piątek",
+		"sobota"
+	],
+	"field-month-short-relative+0": "w tym mies.",
+	"field-month-short-relative+1": "w przyszłym mies.",
+	"dateFormatItem-Ehms": "E, h:mm:ss a",
+	"dayPeriods-standAlone-narrow-evening1": "wiecz.",
+	"dayPeriods-standAlone-abbr-afternoon1": "popołudnie",
+	"field-thu-relative+0": "w ten czwartek",
+	"dayPeriods-standAlone-abbr-night1": "noc",
+	"field-thu-relative+1": "w przyszły czwartek",
+	"dayPeriods-format-wide-am": "AM",
+	"field-fri-relative+0": "w ten piątek",
+	"field-fri-relative+1": "w przyszły piątek",
+	"dateFormatItem-yMd": "d.MM.y",
 	"field-thu-narrow-relative+-1": "w zeszły czwartek",
-	"dateFormatItem-E": "ccc",
-	"dateFormatItem-H": "HH",
-	"field-tue-narrow-relative+-1": "w zeszły wtorek",
-	"dayPeriods-format-abbr-evening1": "wieczorem",
-	"dayPeriods-standAlone-narrow-pm": "p",
-	"dateFormatItem-M": "L",
+	"field-quarter-relative+0": "w tym kwartale",
+	"field-quarter-relative+1": "w przyszłym kwartale",
+	"field-sun-short-relative+0": "w tę niedzielę",
+	"timeFormat-short": "HH:mm",
+	"field-sun-short-relative+1": "w przyszłą niedzielę",
+	"dateFormatItem-hms": "h:mm:ss a",
+	"dayPeriods-format-narrow-afternoon1": "po poł.",
+	"dateFormatItem-Md": "d.MM",
+	"dateFormatItem-Hmsv": "HH:mm:ss v",
+	"dateFormatItem-hmv": "h:mm a v",
+	"field-week-narrow": "tydz.",
+	"field-hour-relative+0": "ta godzina",
+	"field-day-relative+-1": "wczoraj",
+	"field-day-relative+-2": "przedwczoraj",
+	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
+	"field-minute-narrow": "min",
+	"dateFormatItem-MMMMEd": "E, d MMMM",
+	"dateFormatItem-GyMMMMEd": "E, d MMMM y G",
+	"field-thu-short-relative+0": "w ten czwartek",
+	"field-mon-relative+0": "w ten poniedziałek",
+	"field-thu-short-relative+1": "w przyszły czwartek",
+	"field-mon-relative+1": "w przyszły poniedziałek",
+	"field-day-narrow-relative+0": "dziś",
+	"field-era-short": "era",
+	"field-day-narrow-relative+1": "jutro",
+	"field-sat-narrow-relative+0": "w tę sobotę",
+	"field-day-narrow-relative+2": "pojutrze",
+	"timeFormat-long": "HH:mm:ss z",
+	"field-sat-narrow-relative+1": "w przyszłą sobotę",
+	"field-week-narrow-relative+0": "w tym tyg.",
+	"field-week-narrow-relative+1": "w przyszłym tyg.",
+	"field-wed-narrow-relative+0": "w tę środę",
+	"field-wed-narrow-relative+1": "w przyszłą środę",
+	"field-month": "miesiąc",
 	"months-standAlone-wide": [
 		"styczeń",
 		"luty",
@@ -272,12 +127,203 @@ define(
 		"listopad",
 		"grudzień"
 	],
+	"field-weekday-narrow": "dz. tyg.",
+	"dayPeriods-standAlone-narrow-afternoon1": "popoł.",
+	"field-year-relative+0": "w tym roku",
+	"field-year-relative+1": "w przyszłym roku",
+	"dayPeriods-format-abbr-evening1": "wieczorem",
+	"dayPeriods-format-abbr-noon": "w południe",
+	"dayPeriods-format-narrow-midnight": "o półn.",
+	"dayPeriods-format-wide-midnight": "o północy",
+	"field-tue-relative+0": "w ten wtorek",
+	"dateFormatItem-GyMMMMd": "d MMMM y G",
+	"field-tue-relative+1": "w przyszły wtorek",
+	"dayPeriods-standAlone-abbr-evening1": "wieczór",
+	"dateFormatItem-hm": "h:mm a",
+	"dayPeriods-standAlone-wide-midnight": "północ",
+	"field-year-narrow": "r.",
+	"dayPeriods-standAlone-abbr-noon": "południe",
+	"field-tue-short-relative+0": "w ten wtorek",
+	"dayPeriods-standAlone-narrow-midnight": "półn.",
+	"field-tue-short-relative+1": "w przyszły wtorek",
+	"field-tue-narrow-relative+0": "w ten wtorek",
+	"field-tue-narrow-relative+1": "w przyszły wtorek",
+	"dateTimeFormat-full": "{1} {0}",
+	"dateFormatItem-E": "ccc",
+	"dateFormatItem-EBhm": "E h:mm B",
+	"dateFormatItem-H": "HH",
+	"field-wed-relative+0": "w tę środę",
+	"field-wed-relative+1": "w przyszłą środę",
+	"dateFormatItem-M": "L",
 	"field-wed-short-relative+0": "w tę środę",
+	"field-fri-short-relative+0": "w ten piątek",
 	"field-wed-short-relative+1": "w przyszłą środę",
-	"dateFormatItem-yMMMMEd": "E, d MMMM y",
-	"dateFormatItem-Hmsv": "HH:mm:ss v",
-	"field-sun-relative+-1": "w zeszłą niedzielę",
-	"dateFormatItem-MMMMEd": "E, d MMMM",
+	"field-fri-short-relative+1": "w przyszły piątek",
+	"field-weekOfMonth-short": "tydz. mies.",
+	"field-quarter-short-relative+-1": "w zeszłym kwartale",
+	"field-year-short-relative+-1": "w zeszłym roku",
+	"dateFormatItem-Bhm": "h:mm B",
+	"dayPeriods-format-wide-night1": "w nocy",
+	"dateTimeFormat-medium": "{1}, {0}",
+	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
+	"dateFormatItem-d": "d",
+	"dayPeriods-format-abbr-pm": "PM",
+	"dateFormatItem-h": "h a",
+	"quarters-standAlone-wide": [
+		"I kwartał",
+		"II kwartał",
+		"III kwartał",
+		"IV kwartał"
+	],
+	"field-weekOfMonth-narrow": "tydz. mies.",
+	"dateFormatItem-y": "y",
+	"field-minute-relative+0": "ta minuta",
+	"field-year-short-relative+0": "w tym roku",
+	"dateFormatItem-EBhms": "E h:mm:ss B",
+	"field-year-short-relative+1": "w przyszłym roku",
+	"field-weekday": "dzień tygodnia",
+	"dayPeriods-format-narrow-pm": "p",
+	"field-tue-narrow-relative+-1": "w zeszły wtorek",
+	"dateFormatItem-yMEd": "E, d.MM.y",
+	"dayPeriods-standAlone-wide-night1": "noc",
+	"field-year-narrow-relative+-1": "w zeszłym roku",
+	"field-sat-relative+-1": "w zeszłą sobotę",
+	"dayPeriods-format-abbr-midnight": "o północy",
+	"dayPeriods-format-narrow-morning1": "rano",
+	"dayPeriods-format-narrow-morning2": "przed poł.",
+	"dayPeriods-format-wide-morning1": "rano",
+	"dayPeriods-format-wide-morning2": "przed południem",
+	"dayPeriods-standAlone-abbr-midnight": "północ",
+	"dayPeriods-standAlone-narrow-pm": "p",
+	"dayPeriods-standAlone-wide-morning1": "rano",
+	"field-mon-narrow-relative+0": "w ten poniedziałek",
+	"dayPeriods-standAlone-wide-morning2": "przedpołudnie",
+	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
+	"field-second": "sekunda",
+	"dateFormatItem-yMMMEd": "E, d MMM y",
+	"field-year-relative+-1": "w zeszłym roku",
+	"field-weekdayOfMonth-short": "dzień mies.",
+	"dateFormat-short": "dd.MM.y",
+	"eraNames": [
+		"przed naszą erą",
+		"naszej ery"
+	],
+	"field-second-short": "sek.",
+	"field-thu-short-relative+-1": "w zeszły czwartek",
+	"field-zone": "strefa czasowa",
+	"field-dayperiod-narrow": "rano / po poł. / wiecz.",
+	"field-sun-short-relative+-1": "w zeszłą niedzielę",
+	"dayPeriods-standAlone-narrow-morning1": "rano",
+	"dayPeriods-standAlone-narrow-morning2": "przedpoł.",
+	"eraAbbr": [
+		"p.n.e.",
+		"n.e."
+	],
+	"field-week-short": "tydz.",
+	"dayPeriods-standAlone-abbr-am": "AM",
+	"dayPeriods-standAlone-wide-pm": "PM",
+	"dateFormatItem-ms": "mm:ss",
+	"field-day-relative+0": "dzisiaj",
+	"field-day-relative+1": "jutro",
+	"field-day-relative+2": "pojutrze",
+	"field-dayOfYear-short": "dz. roku",
+	"dateFormat-long": "d MMMM y",
+	"field-day-short-relative+2": "pojutrze",
+	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
+	"dayPeriods-format-wide-noon": "w południe",
+	"field-second-relative+0": "teraz",
+	"field-quarter-relative+-1": "w zeszłym kwartale",
+	"dayPeriods-format-narrow-night1": "w nocy",
+	"quarters-format-abbr": [
+		"I kw.",
+		"II kw.",
+		"III kw.",
+		"IV kw."
+	],
+	"dayPeriods-standAlone-wide-noon": "południe",
+	"dayPeriods-standAlone-narrow-night1": "noc",
+	"field-week-relative+-1": "w zeszłym tygodniu",
+	"dayPeriods-format-abbr-morning1": "rano",
+	"field-month-relative+-1": "w zeszłym miesiącu",
+	"dayPeriods-format-abbr-morning2": "przed południem",
+	"months-format-narrow": [
+		"s",
+		"l",
+		"m",
+		"k",
+		"m",
+		"c",
+		"l",
+		"s",
+		"w",
+		"p",
+		"l",
+		"g"
+	],
+	"field-year": "rok",
+	"field-era": "era",
+	"dayPeriods-standAlone-abbr-morning1": "rano",
+	"dayPeriods-standAlone-abbr-morning2": "przedpołudnie",
+	"days-standAlone-short": [
+		"nie",
+		"pon",
+		"wto",
+		"śro",
+		"czw",
+		"pią",
+		"sob"
+	],
+	"quarters-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"dateFormatItem-yQQQQ": "QQQQ y",
+	"field-day-short-relative+-2": "przedwczoraj",
+	"dateFormatItem-GyMMM": "MMM y G",
+	"timeFormat-full": "HH:mm:ss zzzz",
+	"dateFormatItem-Bhms": "h:mm:ss B",
+	"field-hour": "godzina",
+	"field-dayOfYear-narrow": "dz. r.",
+	"field-quarter": "kwartał",
+	"field-month-narrow-relative+0": "w tym mies.",
+	"field-month-narrow-relative+1": "w przyszłym mies.",
+	"dateFormatItem-GyMMMM": "LLLL y G",
+	"field-day": "dzień",
+	"field-mon-relative+-1": "w zeszły poniedziałek",
+	"field-dayOfYear": "dzień roku",
+	"dateFormat-medium": "d MMM y",
+	"dateTimeFormat-short": "{1}, {0}",
+	"dateFormatItem-yMMM": "LLL y",
+	"dateFormatItem-GyMMMd": "d MMM y G",
+	"dateFormatItem-MEd": "E, d.MM",
+	"field-tue-short-relative+-1": "w zeszły wtorek",
+	"field-year-short": "r.",
+	"field-month-short": "mies.",
+	"dateFormatItem-MMMEd": "E, d MMM",
+	"dayPeriods-format-wide-afternoon1": "po południu",
+	"dateFormatItem-MMMd": "d MMM",
+	"dateFormatItem-Bh": "h B",
+	"months-format-abbr": [
+		"sty",
+		"lut",
+		"mar",
+		"kwi",
+		"maj",
+		"cze",
+		"lip",
+		"sie",
+		"wrz",
+		"paź",
+		"lis",
+		"gru"
+	],
+	"dayPeriods-format-abbr-am": "AM",
+	"field-sat-relative+0": "w tę sobotę",
+	"field-sat-relative+1": "w przyszłą sobotę",
+	"dayPeriods-format-wide-pm": "PM",
+	"field-zone-short": "str. czasowa",
 	"days-standAlone-abbr": [
 		"niedz.",
 		"pon.",
@@ -287,16 +333,95 @@ define(
 		"pt.",
 		"sob."
 	],
-	"dateTimeFormat-full": "{1} {0}",
-	"dateFormatItem-hm": "h:mm a",
-	"dateFormatItem-d": "d",
-	"field-weekday": "dzień tygodnia",
-	"dayPeriods-standAlone-wide-evening1": "wieczór",
-	"field-quarter-narrow-relative+0": "w tym kwartale",
-	"field-sat-relative+0": "w tę sobotę",
-	"dateFormatItem-h": "h a",
-	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
-	"field-sat-relative+1": "w przyszłą sobotę",
+	"field-week-short-relative+0": "w tym tyg.",
+	"dateFormatItem-yMMMMd": "d MMMM y",
+	"field-week-short-relative+1": "w przyszłym tyg.",
+	"dayPeriods-standAlone-wide-afternoon1": "popołudnie",
+	"field-fri-short-relative+-1": "w zeszły piątek",
+	"field-month-narrow": "mc",
+	"dayPeriods-format-narrow-am": "a",
+	"field-month-narrow-relative+-1": "w zeszłym mies.",
+	"days-format-abbr": [
+		"niedz.",
+		"pon.",
+		"wt.",
+		"śr.",
+		"czw.",
+		"pt.",
+		"sob."
+	],
+	"field-weekday-short": "dzień tyg.",
+	"field-day-narrow-relative+-1": "wcz.",
+	"field-day-narrow-relative+-2": "przedwczoraj",
+	"field-quarter-short": "kw.",
+	"days-format-short": [
+		"nie",
+		"pon",
+		"wto",
+		"śro",
+		"czw",
+		"pią",
+		"sob"
+	],
+	"months-standAlone-narrow": [
+		"S",
+		"L",
+		"M",
+		"K",
+		"M",
+		"C",
+		"L",
+		"S",
+		"W",
+		"P",
+		"L",
+		"G"
+	],
+	"days-format-narrow": [
+		"n",
+		"p",
+		"w",
+		"ś",
+		"c",
+		"p",
+		"s"
+	],
+	"dateFormatItem-EHm": "E, HH:mm",
+	"field-quarter-narrow": "kw.",
+	"field-mon-short-relative+0": "w ten poniedziałek",
+	"field-mon-short-relative+1": "w przyszły poniedziałek",
+	"field-dayperiod-short": "rano / po południu / wieczorem",
+	"dayPeriods-standAlone-narrow-am": "a",
+	"field-week-narrow-relative+-1": "w zeszłym tyg.",
+	"field-thu-relative+-1": "w zeszły czwartek",
+	"field-fri-narrow-relative+-1": "w zeszły piątek",
+	"field-mon-short-relative+-1": "w zeszły poniedziałek",
+	"timeFormat-medium": "HH:mm:ss",
+	"field-quarter-short-relative+0": "w tym kwartale",
+	"field-quarter-short-relative+1": "w przyszłym kwartale",
+	"dateFormatItem-Ed": "E, d",
+	"field-wed-relative+-1": "w zeszłą środę",
+	"field-weekOfMonth": "tydzień miesiąca",
+	"field-weekdayOfMonth-narrow": "dz. mies.",
+	"dayPeriods-standAlone-wide-am": "AM",
+	"dateFormatItem-yQQQ": "QQQ y",
+	"field-fri-relative+-1": "w zeszły piątek",
+	"field-minute": "minuta",
+	"quarters-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4"
+	],
+	"quarters-format-wide": [
+		"I kwartał",
+		"II kwartał",
+		"III kwartał",
+		"IV kwartał"
+	],
+	"field-day-short": "dz.",
+	"field-dayperiod": "rano / po południu / wieczorem",
+	"field-hour-short": "godz.",
 	"months-standAlone-abbr": [
 		"sty",
 		"lut",
@@ -311,131 +436,53 @@ define(
 		"lis",
 		"gru"
 	],
-	"dateFormatItem-hmsv": "h:mm:ss a v",
-	"dayPeriods-format-abbr-morning1": "rano",
-	"dayPeriods-standAlone-narrow-evening1": "wiecz.",
-	"dayPeriods-format-abbr-morning2": "przed południem",
-	"dateFormatItem-GyMMMMEd": "E, d MMMM y G",
-	"timeFormat-full": "HH:mm:ss zzzz",
-	"dateFormatItem-MEd": "E, d.MM",
-	"dateFormatItem-y": "y",
-	"field-thu-narrow-relative+0": "w ten czwartek",
-	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
-	"field-mon-short-relative+-1": "w zeszły poniedziałek",
-	"field-thu-narrow-relative+1": "w przyszły czwartek",
-	"field-thu-relative+0": "w ten czwartek",
-	"dayPeriods-standAlone-abbr-afternoon1": "popołudnie",
-	"field-thu-relative+1": "w przyszły czwartek",
-	"dateFormatItem-hms": "h:mm:ss a",
-	"field-fri-short-relative+-1": "w zeszły piątek",
-	"dateFormatItem-hmv": "h:mm a v",
-	"dayPeriods-format-abbr-noon": "w południe",
-	"field-thu-relative+-1": "w zeszły czwartek",
-	"dateFormatItem-yMd": "d.MM.y",
-	"quarters-standAlone-narrow": [
-		"1",
-		"2",
-		"3",
-		"4"
-	],
-	"field-week": "tydzień",
-	"quarters-format-wide": [
-		"I kwartał",
-		"II kwartał",
-		"III kwartał",
-		"IV kwartał"
-	],
-	"dateFormatItem-Ed": "E, d",
-	"field-wed-narrow-relative+0": "w tę środę",
-	"field-wed-narrow-relative+1": "w przyszłą środę",
-	"dayPeriods-standAlone-wide-morning1": "rano",
-	"dayPeriods-standAlone-wide-morning2": "przedpołudnie",
-	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
-	"field-fri-short-relative+0": "w ten piątek",
-	"field-fri-short-relative+1": "w przyszły piątek",
-	"days-standAlone-short": [
-		"nie",
-		"pon",
-		"wto",
-		"śro",
-		"czw",
-		"pią",
-		"sob"
-	],
-	"dayPeriods-standAlone-narrow-morning1": "rano",
-	"dayPeriods-standAlone-narrow-morning2": "przedpoł.",
-	"dateFormatItem-GyMMMMd": "d MMMM y G",
-	"dayPeriods-format-abbr-midnight": "o północy",
-	"field-hour-short": "godz.",
-	"quarters-format-abbr": [
+	"field-second-narrow": "s",
+	"field-month-relative+0": "w tym miesiącu",
+	"field-month-relative+1": "w przyszłym miesiącu",
+	"dateFormat-full": "EEEE, d MMMM y",
+	"field-era-narrow": "era",
+	"field-sat-short-relative+-1": "w zeszłą sobotę",
+	"dayPeriods-format-narrow-noon": "w poł.",
+	"field-week-short-relative+-1": "w zeszłym tyg.",
+	"dateFormatItem-yMMMMEd": "E, d MMMM y",
+	"dateTimeFormat-long": "{1} {0}",
+	"dateFormatItem-yM": "MM.y",
+	"field-sun-relative+-1": "w zeszłą niedzielę",
+	"field-wed-short-relative+-1": "w zeszłą środę",
+	"field-weekdayOfMonth": "dzień miesiąca",
+	"field-quarter-narrow-relative+0": "w tym kwartale",
+	"dateFormatItem-GyMMMEd": "E, d MMM y G",
+	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
+	"field-sat-short-relative+0": "w tę sobotę",
+	"field-hour-narrow": "g.",
+	"field-sat-short-relative+1": "w przyszłą sobotę",
+	"field-year-narrow-relative+0": "w tym roku",
+	"field-year-narrow-relative+1": "w przyszłym roku",
+	"dateFormatItem-Gy": "y G",
+	"field-zone-narrow": "str. czas.",
+	"dayPeriods-standAlone-narrow-noon": "poł.",
+	"field-tue-relative+-1": "w zeszły wtorek",
+	"field-minute-short": "min",
+	"dateFormatItem-yw": "Y, 'tydz'. w",
+	"dateFormatItem-Hm": "HH:mm",
+	"field-week-relative+0": "w tym tygodniu",
+	"field-week-relative+1": "w przyszłym tygodniu",
+	"dateFormatItem-MMM": "LLL",
+	"field-sun-relative+0": "w tę niedzielę",
+	"field-sun-relative+1": "w przyszłą niedzielę",
+	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
+	"quarters-standAlone-abbr": [
 		"I kw.",
 		"II kw.",
 		"III kw.",
 		"IV kw."
 	],
-	"field-month-narrow": "mc",
-	"field-hour-narrow": "g.",
-	"field-fri-narrow-relative+-1": "w zeszły piątek",
-	"field-year-relative+0": "w tym roku",
-	"field-year-relative+1": "w przyszłym roku",
-	"field-fri-relative+-1": "w zeszły piątek",
-	"eraNarrow": [
-		"p.n.e.",
-		"n.e."
-	],
-	"dayPeriods-format-wide-noon": "w południe",
-	"field-tue-short-relative+-1": "w zeszły wtorek",
-	"field-minute-narrow": "min",
-	"dayPeriods-standAlone-wide-afternoon1": "popołudnie",
-	"dateFormatItem-yQQQ": "QQQ y",
-	"days-format-wide": [
-		"niedziela",
-		"poniedziałek",
-		"wtorek",
-		"środa",
-		"czwartek",
-		"piątek",
-		"sobota"
-	],
-	"dateFormatItem-yMMMMd": "d MMMM y",
-	"field-mon-narrow-relative+0": "w ten poniedziałek",
-	"dateFormatItem-EHm": "E, HH:mm",
-	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
-	"dayPeriods-standAlone-wide-midnight": "północ",
-	"dateFormatItem-yM": "MM.y",
-	"field-zone": "strefa czasowa",
-	"dateFormatItem-yMMMM": "LLLL y",
-	"dateFormatItem-MMMEd": "E, d MMM",
+	"dateFormatItem-MMMMW": "LLLL, 'tydz'. W",
+	"field-month-short-relative+-1": "w zeszłym mies.",
 	"dateFormatItem-EHms": "E, HH:mm:ss",
-	"dateFormatItem-yMEd": "E, d.MM.y",
-	"dayPeriods-standAlone-narrow-midnight": "półn.",
-	"field-quarter-narrow": "kw.",
-	"dayPeriods-standAlone-abbr-am": "AM",
-	"field-day-relative+-1": "wczoraj",
-	"field-sun-short-relative+-1": "w zeszłą niedzielę",
-	"field-day-relative+-2": "przedwczoraj",
-	"dayPeriods-format-narrow-night1": "w nocy",
-	"days-format-abbr": [
-		"niedz.",
-		"pon.",
-		"wt.",
-		"śr.",
-		"czw.",
-		"pt.",
-		"sob."
-	],
-	"field-sun-relative+0": "w tę niedzielę",
-	"field-sun-relative+1": "w przyszłą niedzielę",
-	"dateFormatItem-yMMMd": "d MMM y",
-	"dateFormatItem-Gy": "y G",
-	"field-era": "era",
-	"field-week-narrow": "tydz.",
-	"field-day-short": "dzień",
-	"dayPeriods-standAlone-abbr-evening1": "wieczór",
-	"field-fri-narrow-relative+0": "w ten piątek",
-	"dayPeriods-format-narrow-evening1": "wiecz.",
-	"field-fri-narrow-relative+1": "w przyszły piątek",
-	"dayPeriods-standAlone-wide-am": "AM"
+	"dateFormatItem-MMMMd": "d MMMM",
+	"field-week": "tydzień",
+	"field-day-narrow": "d."
 }
 //end v1.x content
 );
\ No newline at end of file
