@@ -8,21 +8,30 @@ define(
 	"field-wed-relative+0": "w tę środę",
 	"field-wed-relative+1": "w przyszłą środę",
 	"field-minute": "minuta",
+	"field-month-narrow-relative+-1": "w zeszłym mies.",
 	"field-tue-narrow-relative+0": "w ten wtorek",
 	"field-tue-narrow-relative+1": "w przyszły wtorek",
 	"field-thu-short-relative+0": "w ten czwartek",
 	"dateTimeFormat-short": "{1}, {0}",
 	"field-thu-short-relative+1": "w przyszły czwartek",
 	"field-day-relative+0": "dzisiaj",
+	"field-day-short-relative+-2": "przedwczoraj",
 	"field-day-relative+1": "jutro",
+	"field-week-narrow-relative+0": "w tym tyg.",
 	"field-day-relative+2": "pojutrze",
+	"field-week-narrow-relative+1": "w przyszłym tyg.",
 	"field-wed-narrow-relative+-1": "w zeszłą środę",
 	"field-year-narrow": "r.",
+	"field-era-short": "era",
+	"field-year-narrow-relative+0": "w tym roku",
 	"field-tue-relative+0": "w ten wtorek",
+	"field-year-narrow-relative+1": "w przyszłym roku",
 	"field-tue-relative+1": "w przyszły wtorek",
+	"field-weekdayOfMonth": "dzień miesiąca",
 	"field-second-short": "sek.",
 	"dayPeriods-format-narrow-am": "a",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "dz. mies.",
 	"field-week-relative+0": "w tym tygodniu",
 	"field-month-relative+0": "w tym miesiącu",
 	"field-week-relative+1": "w przyszłym tygodniu",
@@ -33,10 +42,12 @@ define(
 	"field-mon-short-relative+1": "w przyszły poniedziałek",
 	"field-second-relative+0": "teraz",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"field-weekOfMonth": "tydzień miesiąca",
 	"field-month-short": "mies.",
 	"dateFormatItem-GyMMMEd": "E, d MMM y G",
 	"dateFormatItem-yyyyMd": "d.MM.y G",
 	"field-day": "dzień",
+	"field-dayOfYear-short": "dz. roku",
 	"field-year-relative+-1": "w zeszłym roku",
 	"field-sat-short-relative+-1": "w zeszłą sobotę",
 	"field-hour-relative+0": "ta godzina",
@@ -58,6 +69,9 @@ define(
 	"dateFormatItem-GyMMMd": "d MMM y G",
 	"field-quarter": "kwartał",
 	"field-week-short": "tydz.",
+	"field-day-narrow-relative+0": "dziś",
+	"field-day-narrow-relative+1": "jutro",
+	"field-day-narrow-relative+2": "pojutrze",
 	"quarters-standAlone-wide": [
 		"I kwartał",
 		"II kwartał",
@@ -75,10 +89,11 @@ define(
 	],
 	"field-tue-short-relative+0": "w ten wtorek",
 	"field-tue-short-relative+1": "w przyszły wtorek",
+	"field-month-short-relative+-1": "w zeszłym mies.",
 	"field-mon-relative+-1": "w zeszły poniedziałek",
 	"dateFormatItem-GyMMM": "LLL y G",
 	"field-month": "miesiąc",
-	"field-day-narrow": "dzień",
+	"field-day-narrow": "d.",
 	"field-minute-short": "min",
 	"field-dayperiod": "rano / po południu / wieczorem",
 	"field-sat-short-relative+0": "w tę sobotę",
@@ -96,7 +111,9 @@ define(
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "w ten poniedziałek",
 	"field-mon-relative+1": "w przyszły poniedziałek",
+	"field-day-narrow-relative+-1": "wcz.",
 	"field-year-short": "r.",
+	"field-day-narrow-relative+-2": "przedwczoraj",
 	"months-format-narrow": [
 		"1",
 		"2",
@@ -113,7 +130,9 @@ define(
 	],
 	"field-quarter-relative+-1": "w zeszłym kwartale",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "rano / po poł. / wiecz.",
 	"dayPeriods-standAlone-narrow-am": "a",
+	"field-week-narrow-relative+-1": "w zeszłym tyg.",
 	"days-format-short": [
 		"nie",
 		"pon",
@@ -123,6 +142,7 @@ define(
 		"pią",
 		"sob"
 	],
+	"field-dayOfYear": "dzień roku",
 	"field-sat-relative+-1": "w zeszłą sobotę",
 	"dateTimeFormat-long": "{1}, {0}",
 	"dateFormatItem-Md": "d.MM",
@@ -148,6 +168,8 @@ define(
 	"field-fri-relative+0": "w ten piątek",
 	"field-sat-narrow-relative+1": "w przyszłą sobotę",
 	"field-fri-relative+1": "w przyszły piątek",
+	"field-month-narrow-relative+0": "w tym mies.",
+	"field-month-narrow-relative+1": "w przyszłym mies.",
 	"field-sun-short-relative+0": "w tę niedzielę",
 	"field-sun-short-relative+1": "w przyszłą niedzielę",
 	"field-week-relative+-1": "w zeszłym tygodniu",
@@ -172,6 +194,7 @@ define(
 	"field-wed-short-relative+-1": "w zeszłą środę",
 	"dateFormat-short": "dd.MM.y G",
 	"field-thu-short-relative+-1": "w zeszły czwartek",
+	"field-year-narrow-relative+-1": "w zeszłym roku",
 	"days-standAlone-wide": [
 		"niedziela",
 		"poniedziałek",
@@ -186,6 +209,7 @@ define(
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "w zeszły czwartek",
 	"field-tue-narrow-relative+-1": "w zeszły wtorek",
+	"field-weekOfMonth-short": "tydz. mies.",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "p",
 	"field-wed-short-relative+0": "w tę środę",
@@ -220,8 +244,11 @@ define(
 	"field-quarter-narrow-relative+0": "w tym kwartale",
 	"field-sat-relative+0": "w tę sobotę",
 	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
-	"dateFormatItem-h": "hh a",
 	"field-sat-relative+1": "w przyszłą sobotę",
+	"field-day-short-relative+2": "pojutrze",
+	"dateFormatItem-h": "hh a",
+	"field-week-short-relative+0": "w tym tyg.",
+	"field-week-short-relative+1": "w przyszłym tyg.",
 	"months-standAlone-abbr": [
 		"Muh.",
 		"Saf.",
@@ -236,7 +263,12 @@ define(
 		"Zu al-k.",
 		"Zu al-h."
 	],
+	"field-dayOfYear-narrow": "dz. r.",
+	"field-month-short-relative+0": "w tym mies.",
+	"field-month-short-relative+1": "w przyszłym mies.",
+	"field-weekdayOfMonth-short": "dzień mies.",
 	"dateFormatItem-MEd": "E, d.MM",
+	"field-zone-narrow": "str. czas.",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "w ten czwartek",
 	"field-thu-narrow-relative+1": "w przyszły czwartek",
@@ -244,8 +276,8 @@ define(
 	"field-mon-short-relative+-1": "w zeszły poniedziałek",
 	"field-thu-relative+0": "w ten czwartek",
 	"field-thu-relative+1": "w przyszły czwartek",
-	"dateFormatItem-hms": "hh:mm:ss a",
 	"field-fri-short-relative+-1": "w zeszły piątek",
+	"dateFormatItem-hms": "hh:mm:ss a",
 	"field-thu-relative+-1": "w zeszły czwartek",
 	"field-week": "tydzień",
 	"quarters-format-wide": [
@@ -258,7 +290,10 @@ define(
 	"field-wed-narrow-relative+0": "w tę środę",
 	"field-wed-narrow-relative+1": "w przyszłą środę",
 	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
+	"field-year-short-relative+0": "w tym roku",
+	"field-dayperiod-short": "rano / po południu / wieczorem",
 	"dateFormatItem-yyyyMMM": "LLL y G",
+	"field-year-short-relative+1": "w przyszłym roku",
 	"field-fri-short-relative+0": "w ten piątek",
 	"field-fri-short-relative+1": "w przyszły piątek",
 	"days-standAlone-short": [
@@ -270,8 +305,10 @@ define(
 		"pią",
 		"sob"
 	],
+	"field-week-short-relative+-1": "w zeszłym tyg.",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "godz.",
+	"field-zone-short": "str. czasowa",
 	"quarters-format-abbr": [
 		"I kw.",
 		"II kw.",
@@ -283,6 +320,7 @@ define(
 	"field-fri-narrow-relative+-1": "w zeszły piątek",
 	"field-year-relative+0": "w tym roku",
 	"field-year-relative+1": "w przyszłym roku",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "w zeszły piątek",
 	"field-tue-short-relative+-1": "w zeszły wtorek",
 	"field-minute-narrow": "min",
@@ -297,12 +335,16 @@ define(
 	],
 	"field-mon-narrow-relative+0": "w ten poniedziałek",
 	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
+	"field-year-short-relative+-1": "w zeszłym roku",
 	"field-zone": "strefa czasowa",
 	"dateFormatItem-MMMEd": "E, d MMM",
+	"field-weekOfMonth-narrow": "tydz. mies.",
+	"field-weekday-narrow": "dz. tyg.",
 	"field-quarter-narrow": "kw.",
 	"field-sun-short-relative+-1": "w zeszłą niedzielę",
 	"field-day-relative+-1": "wczoraj",
 	"field-day-relative+-2": "przedwczoraj",
+	"field-weekday-short": "dzień tyg.",
 	"days-format-abbr": [
 		"niedz.",
 		"pon.",
@@ -315,7 +357,7 @@ define(
 	"field-sun-relative+0": "w tę niedzielę",
 	"field-sun-relative+1": "w przyszłą niedzielę",
 	"dateFormatItem-Gy": "y G",
-	"field-day-short": "dzień",
+	"field-day-short": "dz.",
 	"field-week-narrow": "tydz.",
 	"field-era": "era",
 	"field-fri-narrow-relative+0": "w ten piątek",
