@@ -5,7 +5,8 @@ define(
 	"decimalFormat-long": "000 biliões",
 	"currencyFormat": "#,##0.00 ¤;(#,##0.00 ¤)",
 	"decimalFormat-short": "000 Bi",
-	"currencyFormat-short": "¤000 B"
+	"currencyFormat-short": "000 B ¤",
+	"approximatelySign": "~"
 }
 //end v1.x content
 );
\ No newline at end of file
