@@ -1,6 +1,87 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "este trimestre",
+	"field-quarter-short-relative+1": "próximo trimestre",
+	"field-tue-relative+-1": "terça-feira passada",
+	"field-year": "ano",
+	"field-wed-relative+0": "esta quarta-feira",
+	"field-wed-relative+1": "próxima quarta-feira",
+	"field-minute": "minuto",
+	"field-month-narrow-relative+-1": "mês passado",
+	"field-tue-narrow-relative+0": "esta ter.",
+	"field-tue-narrow-relative+1": "próxima ter.",
+	"field-thu-short-relative+0": "esta qui.",
+	"field-thu-short-relative+1": "próxima qui.",
+	"field-day-relative+0": "hoje",
+	"field-day-short-relative+-2": "anteontem",
+	"field-day-relative+1": "amanhã",
+	"field-week-narrow-relative+0": "esta semana",
+	"field-day-relative+2": "depois de amanhã",
+	"field-week-narrow-relative+1": "próxima semana",
+	"field-wed-narrow-relative+-1": "qua. passada",
+	"field-year-narrow": "ano",
+	"field-era-short": "era",
+	"field-year-narrow-relative+0": "este ano",
+	"field-tue-relative+0": "esta terça-feira",
+	"field-year-narrow-relative+1": "próximo ano",
+	"field-tue-relative+1": "próxima terça-feira",
+	"field-weekdayOfMonth": "dia da semana do mês",
+	"field-second-short": "seg.",
+	"field-weekdayOfMonth-narrow": "dia da sem. do mês",
+	"field-week-relative+0": "esta semana",
+	"field-month-relative+0": "este mês",
+	"field-week-relative+1": "próxima semana",
+	"field-month-relative+1": "próximo mês",
+	"field-sun-narrow-relative+0": "este dom.",
+	"field-mon-short-relative+0": "esta seg.",
+	"field-sun-narrow-relative+1": "próximo dom.",
+	"field-mon-short-relative+1": "próxima seg.",
+	"field-second-relative+0": "agora",
+	"months-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
+	"field-weekOfMonth": "semana do mês",
+	"field-month-short": "mês",
+	"field-day": "dia",
+	"field-dayOfYear-short": "dia do ano",
+	"field-year-relative+-1": "ano passado",
+	"field-sat-short-relative+-1": "sáb. passado",
+	"field-hour-relative+0": "esta hora",
+	"field-wed-relative+-1": "quarta-feira passada",
+	"field-sat-narrow-relative+-1": "sáb. passado",
+	"field-second": "segundo",
+	"dateFormat-long": "d 'de' MMMM 'de' U",
+	"field-quarter": "trimestre",
+	"field-week-short": "sem.",
+	"field-day-narrow-relative+2": "depois de amanhã",
+	"field-tue-short-relative+0": "esta ter.",
+	"field-tue-short-relative+1": "próxima ter.",
+	"field-month-short-relative+-1": "mês passado",
+	"field-mon-relative+-1": "segunda-feira passada",
+	"field-month": "mês",
+	"field-day-narrow": "dia",
+	"field-minute-short": "min.",
+	"field-dayperiod": "AM/PM",
+	"field-sat-short-relative+0": "este sáb.",
+	"field-sat-short-relative+1": "próximo sáb.",
+	"dateFormat-medium": "dd/MM U",
+	"field-second-narrow": "seg.",
+	"field-mon-relative+0": "esta segunda-feira",
+	"field-mon-relative+1": "próxima segunda-feira",
+	"field-year-short": "ano",
+	"field-day-narrow-relative+-2": "anteontem",
 	"months-format-narrow": [
 		"1",
 		"2",
@@ -15,23 +96,12 @@ define(
 		"11",
 		"12"
 	],
-	"field-second-relative+0": "agora",
 	"field-quarter-relative+-1": "último trimestre",
-	"field-weekday": "dia da semana",
-	"field-mon-narrow-relative+0": "esta seg.",
-	"field-mon-narrow-relative+1": "próxima seg.",
-	"field-wed-relative+0": "esta quarta-feira",
-	"field-wed-relative+1": "próxima quarta-feira",
-	"field-week-short": "sem.",
-	"field-tue-relative+-1": "terça-feira passada",
-	"field-year-short": "ano",
-	"field-thu-narrow-relative+-1": "qui. passada",
-	"field-hour-relative+0": "esta hora",
-	"dateFormat-long": "d 'de' MMMM 'de' U",
-	"field-quarter-narrow": "trim.",
-	"field-fri-relative+-1": "sexta-feira passada",
-	"field-hour-short": "h",
-	"field-wed-relative+-1": "quarta-feira passada",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "semana passada",
+	"field-dayOfYear": "dia do ano",
+	"field-sat-relative+-1": "sábado passado",
+	"field-hour": "hora",
 	"months-format-wide": [
 		"Mês 1",
 		"Mês 2",
@@ -47,27 +117,18 @@ define(
 		"Mês 12"
 	],
 	"dateFormat-full": "EEEE, d 'de' MMMM 'de' U",
-	"field-mon-short-relative+-1": "seg. passada",
-	"field-thu-relative+-1": "quinta-feira passada",
-	"field-era": "era",
-	"months-standAlone-wide": [
-		"Mês 1",
-		"Mês 2",
-		"Mês 3",
-		"Mês 4",
-		"Mês 5",
-		"Mês 6",
-		"Mês 7",
-		"Mês 8",
-		"Mês 9",
-		"Mês 10",
-		"Mês 11",
-		"Mês 12"
-	],
+	"field-month-relative+-1": "mês passado",
+	"field-quarter-short": "trim.",
 	"field-sat-narrow-relative+0": "este sáb.",
+	"field-fri-relative+0": "esta sexta-feira",
 	"field-sat-narrow-relative+1": "próximo sáb.",
-	"field-year": "ano",
-	"field-hour": "hora",
+	"field-fri-relative+1": "próxima sexta-feira",
+	"field-month-narrow-relative+0": "este mês",
+	"field-month-narrow-relative+1": "próximo mês",
+	"field-sun-short-relative+0": "este dom.",
+	"field-sun-short-relative+1": "próximo dom.",
+	"field-week-relative+-1": "semana passada",
+	"field-quarter-short-relative+-1": "último trimestre",
 	"months-format-abbr": [
 		"Mês 1",
 		"Mês 2",
@@ -82,17 +143,42 @@ define(
 		"Mês 11",
 		"Mês 12"
 	],
-	"field-sat-relative+0": "este sábado",
-	"field-sat-relative+1": "próximo sábado",
-	"field-sat-short-relative+-1": "sáb. passado",
-	"field-minute-narrow": "m",
-	"field-day-relative+0": "hoje",
-	"field-day-relative+1": "amanhã",
-	"field-thu-relative+0": "esta quinta-feira",
+	"field-quarter-relative+0": "este trimestre",
+	"field-minute-relative+0": "este minuto",
+	"field-quarter-relative+1": "próximo trimestre",
+	"field-wed-short-relative+-1": "qua. passada",
+	"dateFormat-short": "dd/MM/yy",
+	"field-thu-short-relative+-1": "qui. passada",
+	"field-year-narrow-relative+-1": "ano passado",
 	"field-mon-narrow-relative+-1": "seg. passada",
-	"field-day-relative+2": "depois de amanhã",
-	"field-wed-narrow-relative+0": "esta qua.",
-	"field-thu-relative+1": "próxima quinta-feira",
+	"field-thu-narrow-relative+-1": "qui. passada",
+	"field-tue-narrow-relative+-1": "ter. passada",
+	"field-weekOfMonth-short": "sem. do mês",
+	"field-wed-short-relative+0": "esta qua.",
+	"months-standAlone-wide": [
+		"Mês 1",
+		"Mês 2",
+		"Mês 3",
+		"Mês 4",
+		"Mês 5",
+		"Mês 6",
+		"Mês 7",
+		"Mês 8",
+		"Mês 9",
+		"Mês 10",
+		"Mês 11",
+		"Mês 12"
+	],
+	"field-wed-short-relative+1": "próxima qua.",
+	"field-sun-relative+-1": "domingo passado",
+	"field-weekday": "dia da semana",
+	"field-quarter-narrow-relative+0": "este trimestre",
+	"field-sat-relative+0": "este sábado",
+	"field-quarter-narrow-relative+1": "próximo trimestre",
+	"field-sat-relative+1": "próximo sábado",
+	"field-day-short-relative+2": "depois de amanhã",
+	"field-week-short-relative+0": "esta semana",
+	"field-week-short-relative+1": "próxima semana",
 	"months-standAlone-abbr": [
 		"Mês 1",
 		"Mês 2",
@@ -107,99 +193,58 @@ define(
 		"Mês 11",
 		"Mês 12"
 	],
+	"field-dayOfYear-narrow": "dia do ano",
+	"field-month-short-relative+0": "este mês",
+	"field-month-short-relative+1": "próximo mês",
+	"field-weekdayOfMonth-short": "dia da sem. do mês",
+	"field-zone-narrow": "fuso",
+	"field-thu-narrow-relative+0": "esta qui.",
+	"field-thu-narrow-relative+1": "próxima qui.",
+	"field-sun-narrow-relative+-1": "dom. passado",
+	"field-mon-short-relative+-1": "seg. passada",
+	"field-thu-relative+0": "esta quinta-feira",
+	"field-thu-relative+1": "próxima quinta-feira",
+	"field-fri-short-relative+-1": "sex. passada",
+	"field-thu-relative+-1": "quinta-feira passada",
+	"field-week": "semana",
+	"field-wed-narrow-relative+0": "esta qua.",
 	"field-wed-narrow-relative+1": "próxima qua.",
-	"field-mon-short-relative+0": "esta seg.",
-	"field-mon-short-relative+1": "próxima seg.",
-	"field-wed-short-relative+-1": "qua. passada",
-	"field-fri-narrow-relative+-1": "sex. passada",
+	"field-quarter-narrow-relative+-1": "último trimestre",
+	"field-year-short-relative+0": "este ano",
+	"field-dayperiod-short": "AM/PM",
+	"field-year-short-relative+1": "próximo ano",
+	"field-fri-short-relative+0": "esta sex.",
+	"field-fri-short-relative+1": "próxima sex.",
+	"field-week-short-relative+-1": "semana passada",
+	"field-hour-short": "h",
+	"field-zone-short": "fuso",
+	"field-month-narrow": "mês",
 	"field-hour-narrow": "h",
-	"field-tue-short-relative+0": "esta ter.",
-	"field-year-narrow": "ano",
-	"field-tue-short-relative+1": "próxima ter.",
-	"field-minute-short": "min.",
-	"field-day-narrow": "dia",
-	"field-wed-short-relative+0": "esta qua.",
-	"field-wed-short-relative+1": "próxima qua.",
-	"field-sun-relative+0": "este domingo",
-	"field-sun-relative+1": "próximo domingo",
-	"field-minute": "minuto",
-	"field-month-short": "mês",
-	"field-dayperiod": "AM/PM",
+	"field-fri-narrow-relative+-1": "sex. passada",
+	"field-year-relative+0": "este ano",
+	"field-year-relative+1": "próximo ano",
+	"field-era-narrow": "era",
+	"field-fri-relative+-1": "sexta-feira passada",
+	"field-tue-short-relative+-1": "ter. passada",
+	"field-minute-narrow": "min.",
+	"field-mon-narrow-relative+0": "esta seg.",
+	"field-mon-narrow-relative+1": "próxima seg.",
+	"field-year-short-relative+-1": "ano passado",
+	"field-zone": "fuso horário",
+	"field-weekOfMonth-narrow": "sem. do mês",
+	"field-weekday-narrow": "dia da sem.",
+	"field-quarter-narrow": "trim.",
+	"field-sun-short-relative+-1": "dom. passado",
 	"field-day-relative+-1": "ontem",
 	"field-day-relative+-2": "anteontem",
-	"field-minute-relative+0": "este minuto",
-	"field-week-narrow": "sem.",
-	"field-wed-narrow-relative+-1": "qua. passada",
+	"field-weekday-short": "dia da sem.",
+	"field-sun-relative+0": "este domingo",
+	"field-sun-relative+1": "próximo domingo",
 	"field-day-short": "dia",
-	"field-quarter-relative+0": "este trimestre",
-	"field-quarter-relative+1": "próximo trimestre",
-	"field-fri-relative+0": "esta sexta-feira",
-	"field-fri-relative+1": "próxima sexta-feira",
-	"field-day": "dia",
-	"field-second-narrow": "s",
-	"field-zone": "fuso horário",
-	"months-standAlone-narrow": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
-	],
-	"field-year-relative+-1": "ano passado",
-	"field-month-relative+-1": "mês passado",
-	"field-thu-short-relative+0": "esta qui.",
-	"field-thu-short-relative+1": "próx. qui",
-	"field-quarter": "trimestre",
-	"field-month": "mês",
-	"field-tue-relative+0": "esta terça-feira",
-	"field-tue-relative+1": "próxima terça-feira",
+	"field-week-narrow": "sem.",
+	"field-era": "era",
 	"field-fri-narrow-relative+0": "esta sex.",
-	"field-fri-narrow-relative+1": "próxima sex.",
-	"field-fri-short-relative+-1": "sex. passada",
-	"field-sun-narrow-relative+-1": "dom. passado",
-	"field-sun-narrow-relative+0": "este dom.",
-	"field-thu-narrow-relative+0": "esta qui.",
-	"field-sun-narrow-relative+1": "próximo dom.",
-	"field-thu-narrow-relative+1": "próx. qui",
-	"field-tue-narrow-relative+0": "esta ter.",
-	"field-mon-relative+0": "esta segunda-feira",
-	"field-tue-narrow-relative+1": "próxima ter.",
-	"field-mon-relative+1": "próxima segunda-feira",
-	"dateFormat-short": "dd/MM/yy",
-	"field-tue-narrow-relative+-1": "ter. passada",
-	"field-second-short": "seg.",
-	"field-second": "segundo",
-	"field-fri-short-relative+0": "esta sex.",
-	"field-sat-relative+-1": "sábado passado",
-	"field-fri-short-relative+1": "próxima sex.",
-	"field-sun-relative+-1": "domingo passado",
-	"field-month-relative+0": "este mês",
-	"field-month-relative+1": "próximo mês",
-	"field-week": "semana",
-	"field-sat-short-relative+0": "este sáb.",
-	"dateFormat-medium": "dd/MM U",
-	"field-sat-short-relative+1": "próximo sáb.",
-	"field-year-relative+0": "este ano",
-	"field-week-relative+-1": "semana passada",
-	"field-year-relative+1": "próximo ano",
-	"field-quarter-short": "trim.",
-	"field-sun-short-relative+-1": "dom. passado",
-	"field-thu-short-relative+-1": "qui. passada",
-	"field-tue-short-relative+-1": "ter. passada",
-	"field-mon-relative+-1": "segunda-feira passada",
-	"field-sat-narrow-relative+-1": "sáb. passado",
-	"field-month-narrow": "mês",
-	"field-week-relative+0": "esta semana",
-	"field-sun-short-relative+0": "este dom.",
-	"field-week-relative+1": "próxima semana",
-	"field-sun-short-relative+1": "próximo dom."
+	"field-fri-narrow-relative+1": "próxima sex."
 }
 //end v1.x content
 );
\ No newline at end of file
