@@ -10,13 +10,13 @@ define(
 	"decimalFormat-short": "000 tri",
 	"nan": "NaN",
 	"plusSign": "+",
-	"currencyFormat": "¤#,##0.00;(¤#,##0.00)",
+	"currencyFormat": "¤ #,##0.00",
 	"perMille": "‰",
 	"group": ".",
 	"percentFormat": "#,##0%",
 	"decimalFormat-long": "000 trilhões",
 	"decimalFormat": "#,##0.###",
-	"currencyFormat-short": "¤000 tri",
+	"currencyFormat-short": "¤ 000 tri",
 	"timeSeparator": ":",
 	"decimal": ",",
 	"exponential": "E"
