@@ -1,6 +1,77 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "trim. acesta",
+	"field-quarter-short-relative+1": "trim. viitor",
+	"field-tue-relative+-1": "marțea trecută",
+	"field-year": "an",
+	"field-wed-relative+0": "miercurea aceasta",
+	"field-wed-relative+1": "miercurea viitoare",
+	"field-minute": "minut",
+	"field-month-narrow-relative+-1": "luna trecută",
+	"field-tue-narrow-relative+0": "ma. aceasta",
+	"field-tue-narrow-relative+1": "ma. viitoare",
+	"field-thu-short-relative+0": "joia aceasta",
+	"field-day-short-relative+-1": "ieri",
+	"field-thu-short-relative+1": "joia viitoare",
+	"field-day-relative+0": "azi",
+	"field-day-short-relative+-2": "alaltăieri",
+	"field-day-relative+1": "mâine",
+	"field-week-narrow-relative+0": "săpt. aceasta",
+	"field-day-relative+2": "poimâine",
+	"field-week-narrow-relative+1": "săpt. viitoare",
+	"field-wed-narrow-relative+-1": "mi. trecută",
+	"field-year-narrow": "an",
+	"field-era-short": "eră",
+	"field-year-narrow-relative+0": "anul acesta",
+	"field-tue-relative+0": "marțea aceasta",
+	"field-year-narrow-relative+1": "anul viitor",
+	"field-tue-relative+1": "marțea viitoare",
+	"field-weekdayOfMonth": "ziua săptămânii din lună",
+	"field-second-short": "sec.",
+	"field-weekdayOfMonth-narrow": "ziua săpt. din lună",
+	"field-week-relative+0": "săptămâna aceasta",
+	"field-month-relative+0": "luna aceasta",
+	"field-week-relative+1": "săptămâna viitoare",
+	"field-month-relative+1": "luna viitoare",
+	"field-sun-narrow-relative+0": "du. aceasta",
+	"field-mon-short-relative+0": "lun. aceasta",
+	"field-sun-narrow-relative+1": "du. viitoare",
+	"field-mon-short-relative+1": "lun. viitoare",
+	"field-second-relative+0": "acum",
+	"field-weekOfMonth": "săptămâna din lună",
+	"field-month-short": "lună",
+	"field-day": "zi",
+	"field-dayOfYear-short": "ziua din an",
+	"field-year-relative+-1": "anul trecut",
+	"field-sat-short-relative+-1": "sâm. trecută",
+	"field-hour-relative+0": "ora aceasta",
+	"field-second-short-relative+0": "acum",
+	"field-wed-relative+-1": "miercurea trecută",
+	"field-sat-narrow-relative+-1": "sâ. trecută",
+	"field-second": "secundă",
+	"field-hour-short-relative+0": "ora aceasta",
+	"field-quarter": "trimestru",
+	"field-week-short": "săpt.",
+	"field-day-narrow-relative+0": "azi",
+	"field-day-narrow-relative+1": "mâine",
+	"field-day-narrow-relative+2": "poimâine",
+	"field-tue-short-relative+0": "mar. aceasta",
+	"field-tue-short-relative+1": "mar. viitoare",
+	"field-month-short-relative+-1": "luna trecută",
+	"field-mon-relative+-1": "lunea trecută",
+	"field-month": "lună",
+	"field-day-narrow": "zi",
+	"field-minute-short": "min.",
+	"field-dayperiod": "a.m/p.m.",
+	"field-sat-short-relative+0": "sâm. aceasta",
+	"field-sat-short-relative+1": "sâm. viitoare",
+	"field-second-narrow": "s",
+	"field-mon-relative+0": "lunea aceasta",
+	"field-mon-relative+1": "lunea viitoare",
+	"field-day-narrow-relative+-1": "ieri",
+	"field-year-short": "an",
+	"field-day-narrow-relative+-2": "alaltăieri",
 	"months-format-narrow": [
 		"1",
 		"2",
@@ -15,43 +86,26 @@ define(
 		"11",
 		"12"
 	],
-	"field-second-relative+0": "acum",
 	"field-quarter-relative+-1": "trimestrul trecut",
-	"field-weekday": "Zi a săptămânii",
-	"field-mon-narrow-relative+0": "lu. aceasta",
-	"field-mon-narrow-relative+1": "lu. viitoare",
-	"field-wed-relative+0": "miercurea aceasta",
-	"field-wed-relative+1": "miercurea viitoare",
-	"field-week-short": "săpt.",
-	"field-tue-relative+-1": "marțea trecută",
-	"field-year-short": "an",
-	"field-thu-narrow-relative+-1": "jo. trecută",
-	"field-hour-relative+0": "ora aceasta",
-	"field-quarter-narrow": "trim.",
-	"field-fri-relative+-1": "vinerea trecută",
-	"field-hour-short": "h",
-	"field-wed-relative+-1": "miercurea trecută",
-	"field-mon-short-relative+-1": "lun. trecută",
-	"field-thu-relative+-1": "joia trecută",
-	"field-era": "eră",
-	"months-standAlone-wide": [
-		"1",
-		"2",
-		"3",
-		"4",
-		"5",
-		"6",
-		"7",
-		"8",
-		"9",
-		"10",
-		"11",
-		"12"
-	],
-	"field-sat-narrow-relative+0": "sâ. aceasta",
-	"field-sat-narrow-relative+1": "sâ. viitoare",
-	"field-year": "an",
+	"field-dayperiod-narrow": "a.m/p.m.",
+	"field-week-narrow-relative+-1": "săpt. trecută",
+	"field-dayOfYear": "ziua din an",
+	"field-sat-relative+-1": "sâmbăta trecută",
 	"field-hour": "oră",
+	"field-minute-narrow-relative+0": "minutul acesta",
+	"field-month-relative+-1": "luna trecută",
+	"field-quarter-short": "trim.",
+	"field-sat-narrow-relative+0": "sâ. aceasta",
+	"field-fri-relative+0": "vinerea aceasta",
+	"field-sat-narrow-relative+1": "sâ. viitoare",
+	"field-fri-relative+1": "vinerea viitoare",
+	"field-month-narrow-relative+0": "luna aceasta",
+	"field-month-narrow-relative+1": "luna viitoare",
+	"field-sun-short-relative+0": "dum. aceasta",
+	"field-sun-short-relative+1": "dum. viitoare",
+	"field-week-relative+-1": "săptămâna trecută",
+	"field-quarter-short-relative+-1": "trim. trecut",
+	"field-minute-short-relative+0": "minutul acesta",
 	"months-format-abbr": [
 		"1",
 		"2",
@@ -66,17 +120,44 @@ define(
 		"11",
 		"12"
 	],
-	"field-sat-relative+0": "sâmbăta aceasta",
-	"field-sat-relative+1": "sâmbăta viitoare",
-	"field-sat-short-relative+-1": "sâm. trecută",
-	"field-minute-narrow": "m",
-	"field-day-relative+0": "azi",
-	"field-day-relative+1": "mâine",
-	"field-thu-relative+0": "joia aceasta",
+	"field-quarter-relative+0": "trimestrul acesta",
+	"field-minute-relative+0": "minutul acesta",
+	"field-quarter-relative+1": "trimestrul viitor",
+	"field-wed-short-relative+-1": "mie. trecută",
+	"field-thu-short-relative+-1": "joia trecută",
+	"field-year-narrow-relative+-1": "anul trecut",
 	"field-mon-narrow-relative+-1": "lu. trecută",
-	"field-day-relative+2": "poimâine",
-	"field-wed-narrow-relative+0": "mi. aceasta",
-	"field-thu-relative+1": "joia viitoare",
+	"field-thu-narrow-relative+-1": "jo. trecută",
+	"field-tue-narrow-relative+-1": "ma. trecută",
+	"field-weekOfMonth-short": "săpt. din lună",
+	"field-wed-short-relative+0": "mie. aceasta",
+	"months-standAlone-wide": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
+	"field-wed-short-relative+1": "mie. viitoare",
+	"field-sun-relative+-1": "duminica trecută",
+	"field-second-narrow-relative+0": "acum",
+	"field-weekday": "ziua din săptămână",
+	"field-day-short-relative+0": "azi",
+	"field-quarter-narrow-relative+0": "trim. acesta",
+	"field-sat-relative+0": "sâmbăta aceasta",
+	"field-day-short-relative+1": "mâine",
+	"field-quarter-narrow-relative+1": "trim. viitor",
+	"field-sat-relative+1": "sâmbăta viitoare",
+	"field-day-short-relative+2": "poimâine",
+	"field-week-short-relative+0": "săpt. aceasta",
+	"field-week-short-relative+1": "săpt. viitoare",
 	"months-standAlone-abbr": [
 		"1",
 		"2",
@@ -91,89 +172,59 @@ define(
 		"11",
 		"12"
 	],
+	"field-dayOfYear-narrow": "ziua din an",
+	"field-month-short-relative+0": "luna aceasta",
+	"field-month-short-relative+1": "luna viitoare",
+	"field-weekdayOfMonth-short": "ziua săpt. din lună",
+	"field-zone-narrow": "fus",
+	"field-thu-narrow-relative+0": "jo. aceasta",
+	"field-thu-narrow-relative+1": "jo. viitoare",
+	"field-sun-narrow-relative+-1": "du. trecută",
+	"field-mon-short-relative+-1": "lun. trecută",
+	"field-thu-relative+0": "joia aceasta",
+	"field-thu-relative+1": "joia viitoare",
+	"field-fri-short-relative+-1": "vin. trecută",
+	"field-thu-relative+-1": "joia trecută",
+	"field-week": "săptămână",
+	"field-wed-narrow-relative+0": "mi. aceasta",
 	"field-wed-narrow-relative+1": "mi. viitoare",
-	"field-mon-short-relative+0": "lun. aceasta",
-	"field-mon-short-relative+1": "lun. viitoare",
-	"field-wed-short-relative+-1": "mie. trecută",
-	"field-fri-narrow-relative+-1": "vi. trecută",
+	"field-quarter-narrow-relative+-1": "trim. trecut",
+	"field-year-short-relative+0": "anul acesta",
+	"field-dayperiod-short": "a.m/p.m.",
+	"field-year-short-relative+1": "anul viitor",
+	"field-fri-short-relative+0": "vin. aceasta",
+	"field-fri-short-relative+1": "vin. viitoare",
+	"field-week-short-relative+-1": "săpt. trecută",
+	"field-hour-narrow-relative+0": "ora aceasta",
+	"field-hour-short": "h",
+	"field-zone-short": "fus",
+	"field-month-narrow": "lună",
 	"field-hour-narrow": "h",
-	"field-tue-short-relative+0": "mar. aceasta",
-	"field-year-narrow": "an",
-	"field-tue-short-relative+1": "mar. viitoare",
-	"field-minute-short": "min.",
-	"field-day-narrow": "zi",
-	"field-wed-short-relative+0": "mie. aceasta",
-	"field-wed-short-relative+1": "mie. viitoare",
-	"field-sun-relative+0": "duminica aceasta",
-	"field-sun-relative+1": "duminica viitoare",
-	"field-minute": "minut",
-	"field-month-short": "lună",
-	"field-dayperiod": "a.m/p.m.",
+	"field-fri-narrow-relative+-1": "vi. trecută",
+	"field-year-relative+0": "anul acesta",
+	"field-year-relative+1": "anul viitor",
+	"field-era-narrow": "eră",
+	"field-fri-relative+-1": "vinerea trecută",
+	"field-tue-short-relative+-1": "mar. trecută",
+	"field-minute-narrow": "m",
+	"field-mon-narrow-relative+0": "lu. aceasta",
+	"field-mon-narrow-relative+1": "lu. viitoare",
+	"field-year-short-relative+-1": "anul trecut",
+	"field-zone": "fus orar",
+	"field-weekOfMonth-narrow": "săpt. din lună",
+	"field-weekday-narrow": "ziua din săpt.",
+	"field-quarter-narrow": "trim.",
+	"field-sun-short-relative+-1": "dum. trecută",
 	"field-day-relative+-1": "ieri",
 	"field-day-relative+-2": "alaltăieri",
-	"field-minute-relative+0": "minutul acesta",
-	"field-week-narrow": "săpt.",
-	"field-wed-narrow-relative+-1": "mi. trecută",
+	"field-weekday-short": "ziua din săpt.",
+	"field-sun-relative+0": "duminica aceasta",
+	"field-sun-relative+1": "duminica viitoare",
 	"field-day-short": "zi",
-	"field-quarter-relative+0": "trimestrul acesta",
-	"field-quarter-relative+1": "trimestrul viitor",
-	"field-fri-relative+0": "vinerea aceasta",
-	"field-fri-relative+1": "vinerea viitoare",
-	"field-day": "zi",
-	"field-second-narrow": "s",
-	"field-zone": "fus orar",
-	"field-year-relative+-1": "anul trecut",
-	"field-month-relative+-1": "luna trecută",
-	"field-thu-short-relative+0": "joi aceasta",
-	"field-thu-short-relative+1": "joia viitoare",
-	"field-quarter-narrow-relative+0": "trim. acesta",
-	"field-quarter-narrow-relative+1": "trim. viitor",
-	"field-quarter": "trimestru",
-	"field-month": "lună",
-	"field-tue-relative+0": "marțea aceasta",
-	"field-quarter-short-relative+0": "trim. acesta",
-	"field-tue-relative+1": "marțea viitoare",
-	"field-quarter-short-relative+1": "trim. viitor",
+	"field-week-narrow": "săpt.",
+	"field-era": "eră",
 	"field-fri-narrow-relative+0": "vi. aceasta",
-	"field-fri-narrow-relative+1": "vi. viitoare",
-	"field-fri-short-relative+-1": "vin. trecută",
-	"field-sun-narrow-relative+-1": "du. trecută",
-	"field-quarter-short-relative+-1": "trim. trecut",
-	"field-sun-narrow-relative+0": "du. aceasta",
-	"field-thu-narrow-relative+0": "jo. aceasta",
-	"field-sun-narrow-relative+1": "du. viitoare",
-	"field-thu-narrow-relative+1": "jo. viitoare",
-	"field-tue-narrow-relative+0": "ma. aceasta",
-	"field-mon-relative+0": "lunea aceasta",
-	"field-tue-narrow-relative+1": "ma. viitoare",
-	"field-mon-relative+1": "lunea viitoare",
-	"field-tue-narrow-relative+-1": "ma. trecută",
-	"field-second-short": "sec.",
-	"field-second": "secundă",
-	"field-fri-short-relative+0": "vin. aceasta",
-	"field-sat-relative+-1": "sâmbăta trecută",
-	"field-fri-short-relative+1": "vin. viitoare",
-	"field-sun-relative+-1": "duminica trecută",
-	"field-month-relative+0": "luna aceasta",
-	"field-quarter-narrow-relative+-1": "trim. trecut",
-	"field-month-relative+1": "luna viitoare",
-	"field-week": "săptămână",
-	"field-sat-short-relative+0": "sâm. aceasta",
-	"field-sat-short-relative+1": "sâm. viitoare",
-	"field-year-relative+0": "anul acesta",
-	"field-week-relative+-1": "săptămâna trecută",
-	"field-year-relative+1": "anul viitor",
-	"field-quarter-short": "trim.",
-	"field-sun-short-relative+-1": "dum. trecută",
-	"field-thu-short-relative+-1": "joi trecută",
-	"field-tue-short-relative+-1": "mar. trecută",
-	"field-mon-relative+-1": "lunea trecută",
-	"field-sat-narrow-relative+-1": "sâ. trecută",
-	"field-month-narrow": "lună",
-	"field-week-relative+0": "săptămâna aceasta",
-	"field-sun-short-relative+0": "dum. aceasta",
-	"field-week-relative+1": "săptămâna viitoare",
-	"field-sun-short-relative+1": "dum. viitoare"
+	"field-fri-narrow-relative+1": "vi. viitoare"
 }
 //end v1.x content
 );
\ No newline at end of file
