@@ -8,21 +8,31 @@ define(
 	"field-wed-relative+0": "miercurea aceasta",
 	"field-wed-relative+1": "miercurea viitoare",
 	"field-minute": "minut",
+	"field-month-narrow-relative+-1": "luna trecută",
 	"field-tue-narrow-relative+0": "ma. aceasta",
 	"field-tue-narrow-relative+1": "ma. viitoare",
-	"field-thu-short-relative+0": "joi aceasta",
+	"field-thu-short-relative+0": "joia aceasta",
+	"field-day-short-relative+-1": "ieri",
 	"dateTimeFormat-short": "{1}, {0}",
 	"field-thu-short-relative+1": "joia viitoare",
 	"field-day-relative+0": "azi",
+	"field-day-short-relative+-2": "alaltăieri",
 	"field-day-relative+1": "mâine",
+	"field-week-narrow-relative+0": "săpt. aceasta",
 	"field-day-relative+2": "poimâine",
+	"field-week-narrow-relative+1": "săpt. viitoare",
 	"field-wed-narrow-relative+-1": "mi. trecută",
 	"field-year-narrow": "an",
+	"field-era-short": "eră",
+	"field-year-narrow-relative+0": "anul acesta",
 	"field-tue-relative+0": "marțea aceasta",
+	"field-year-narrow-relative+1": "anul viitor",
 	"field-tue-relative+1": "marțea viitoare",
+	"field-weekdayOfMonth": "ziua săptămânii din lună",
 	"field-second-short": "sec.",
 	"dayPeriods-format-narrow-am": "a.m.",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "ziua săpt. din lună",
 	"dayPeriods-format-abbr-am": "a.m.",
 	"field-week-relative+0": "săptămâna aceasta",
 	"field-month-relative+0": "luna aceasta",
@@ -34,16 +44,36 @@ define(
 	"field-mon-short-relative+1": "lun. viitoare",
 	"field-second-relative+0": "acum",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"months-standAlone-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
+	"eraNames": [
+		"A.H."
+	],
+	"field-weekOfMonth": "săptămâna din lună",
 	"dayPeriods-standAlone-abbr-pm": "p.m.",
 	"field-month-short": "lună",
 	"dateFormatItem-GyMMMEd": "E, d MMM y G",
 	"dateFormatItem-yyyyMd": "dd.MM.y G",
 	"field-day": "zi",
+	"field-dayOfYear-short": "ziua din an",
 	"field-year-relative+-1": "anul trecut",
 	"dayPeriods-format-wide-am": "a.m.",
 	"field-sat-short-relative+-1": "sâm. trecută",
 	"field-hour-relative+0": "ora aceasta",
 	"dateFormatItem-yyyyMEd": "E, dd.MM.y G",
+	"field-second-short-relative+0": "acum",
 	"field-wed-relative+-1": "miercurea trecută",
 	"dateTimeFormat-medium": "{1}, {0}",
 	"field-sat-narrow-relative+-1": "sâ. trecută",
@@ -60,8 +90,12 @@ define(
 	"dayPeriods-standAlone-wide-pm": "p.m.",
 	"dateFormat-long": "d MMMM y G",
 	"dateFormatItem-GyMMMd": "d MMM y G",
+	"field-hour-short-relative+0": "ora aceasta",
 	"field-quarter": "trimestru",
 	"field-week-short": "săpt.",
+	"field-day-narrow-relative+0": "azi",
+	"field-day-narrow-relative+1": "mâine",
+	"field-day-narrow-relative+2": "poimâine",
 	"quarters-standAlone-wide": [
 		"trimestrul I",
 		"trimestrul al II-lea",
@@ -79,6 +113,7 @@ define(
 	],
 	"field-tue-short-relative+0": "mar. aceasta",
 	"field-tue-short-relative+1": "mar. viitoare",
+	"field-month-short-relative+-1": "luna trecută",
 	"field-mon-relative+-1": "lunea trecută",
 	"dateFormatItem-GyMMM": "MMM y G",
 	"field-month": "lună",
@@ -104,10 +139,28 @@ define(
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "lunea aceasta",
 	"field-mon-relative+1": "lunea viitoare",
+	"field-day-narrow-relative+-1": "ieri",
 	"field-year-short": "an",
+	"field-day-narrow-relative+-2": "alaltăieri",
+	"months-format-narrow": [
+		"1",
+		"2",
+		"3",
+		"4",
+		"5",
+		"6",
+		"7",
+		"8",
+		"9",
+		"10",
+		"11",
+		"12"
+	],
 	"field-quarter-relative+-1": "trimestrul trecut",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "a.m/p.m.",
 	"dayPeriods-standAlone-narrow-am": "a.m.",
+	"field-week-narrow-relative+-1": "săpt. trecută",
 	"days-format-short": [
 		"du.",
 		"lu.",
@@ -124,10 +177,26 @@ define(
 		"IV"
 	],
 	"dayPeriods-format-wide-pm": "p.m.",
+	"field-dayOfYear": "ziua din an",
 	"field-sat-relative+-1": "sâmbăta trecută",
 	"dateTimeFormat-long": "{1} 'la' {0}",
 	"dateFormatItem-Md": "dd.MM",
+	"field-minute-narrow-relative+0": "minutul acesta",
 	"field-hour": "oră",
+	"months-format-wide": [
+		"Muharram",
+		"Safar",
+		"Rabiʻ I",
+		"Rabiʻ II",
+		"Jumada I",
+		"Jumada II",
+		"Rajab",
+		"Shaʻban",
+		"Ramadan",
+		"Shawwal",
+		"Dhuʻl-Qiʻdah",
+		"Dhuʻl-Hijjah"
+	],
 	"dateFormat-full": "EEEE, d MMMM y G",
 	"field-month-relative+-1": "luna trecută",
 	"field-quarter-short": "trim.",
@@ -135,16 +204,34 @@ define(
 	"field-fri-relative+0": "vinerea aceasta",
 	"field-sat-narrow-relative+1": "sâ. viitoare",
 	"field-fri-relative+1": "vinerea viitoare",
+	"field-month-narrow-relative+0": "luna aceasta",
+	"field-month-narrow-relative+1": "luna viitoare",
 	"field-sun-short-relative+0": "dum. aceasta",
 	"field-sun-short-relative+1": "dum. viitoare",
 	"field-week-relative+-1": "săptămâna trecută",
 	"field-quarter-short-relative+-1": "trim. trecut",
+	"field-minute-short-relative+0": "minutul acesta",
+	"months-format-abbr": [
+		"Muh.",
+		"Saf.",
+		"Rab. I",
+		"Rab. II",
+		"Jum. I",
+		"Jum. II",
+		"Raj.",
+		"Sha.",
+		"Ram.",
+		"Shaw.",
+		"Dhuʻl-Q.",
+		"Dhuʻl-H."
+	],
 	"field-quarter-relative+0": "trimestrul acesta",
 	"field-minute-relative+0": "minutul acesta",
 	"field-quarter-relative+1": "trimestrul viitor",
 	"field-wed-short-relative+-1": "mie. trecută",
 	"dateFormat-short": "dd.MM.y GGGGG",
-	"field-thu-short-relative+-1": "joi trecută",
+	"field-thu-short-relative+-1": "joia trecută",
+	"field-year-narrow-relative+-1": "anul trecut",
 	"days-standAlone-wide": [
 		"duminică",
 		"luni",
@@ -159,9 +246,24 @@ define(
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "jo. trecută",
 	"field-tue-narrow-relative+-1": "ma. trecută",
-	"dateFormatItem-yyyy": "y G",
+	"field-weekOfMonth-short": "săpt. din lună",
 	"dayPeriods-standAlone-narrow-pm": "p.m.",
+	"dateFormatItem-yyyy": "y G",
 	"field-wed-short-relative+0": "mie. aceasta",
+	"months-standAlone-wide": [
+		"Muharram",
+		"Safar",
+		"Rabiʻ I",
+		"Rabiʻ II",
+		"Jumada I",
+		"Jumada II",
+		"Rajab",
+		"Shaʻban",
+		"Ramadan",
+		"Shawwal",
+		"Dhuʻl-Qiʻdah",
+		"Dhuʻl-Hijjah"
+	],
 	"field-wed-short-relative+1": "mie. viitoare",
 	"field-sun-relative+-1": "duminica trecută",
 	"days-standAlone-abbr": [
@@ -173,13 +275,38 @@ define(
 		"vin.",
 		"sâm."
 	],
+	"field-second-narrow-relative+0": "acum",
 	"dateTimeFormat-full": "{1} 'la' {0}",
-	"field-weekday": "Zi a săptămânii",
+	"field-weekday": "ziua din săptămână",
+	"field-day-short-relative+0": "azi",
 	"field-quarter-narrow-relative+0": "trim. acesta",
+	"field-day-short-relative+1": "mâine",
 	"field-sat-relative+0": "sâmbăta aceasta",
 	"field-quarter-narrow-relative+1": "trim. viitor",
+	"field-day-short-relative+2": "poimâine",
 	"field-sat-relative+1": "sâmbăta viitoare",
+	"field-week-short-relative+0": "săpt. aceasta",
+	"field-week-short-relative+1": "săpt. viitoare",
+	"months-standAlone-abbr": [
+		"Muh.",
+		"Saf.",
+		"Rab. I",
+		"Rab. II",
+		"Jum. I",
+		"Jum. II",
+		"Raj.",
+		"Sha.",
+		"Ram.",
+		"Shaw.",
+		"Dhuʻl-Q.",
+		"Dhuʻl-H."
+	],
+	"field-dayOfYear-narrow": "ziua din an",
+	"field-month-short-relative+0": "luna aceasta",
+	"field-month-short-relative+1": "luna viitoare",
+	"field-weekdayOfMonth-short": "ziua săpt. din lună",
 	"dateFormatItem-MEd": "E, dd.MM",
+	"field-zone-narrow": "fus",
 	"dateFormatItem-y": "y",
 	"field-thu-narrow-relative+0": "jo. aceasta",
 	"field-thu-narrow-relative+1": "jo. viitoare",
@@ -206,7 +333,10 @@ define(
 	"field-wed-narrow-relative+0": "mi. aceasta",
 	"field-wed-narrow-relative+1": "mi. viitoare",
 	"field-quarter-narrow-relative+-1": "trim. trecut",
+	"field-year-short-relative+0": "anul acesta",
+	"field-dayperiod-short": "a.m/p.m.",
 	"dateFormatItem-yyyyMMM": "MMM y G",
+	"field-year-short-relative+1": "anul viitor",
 	"field-fri-short-relative+0": "vin. aceasta",
 	"field-fri-short-relative+1": "vin. viitoare",
 	"days-standAlone-short": [
@@ -218,8 +348,11 @@ define(
 		"vi.",
 		"sâ."
 	],
+	"field-week-short-relative+-1": "săpt. trecută",
+	"field-hour-narrow-relative+0": "ora aceasta",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "h",
+	"field-zone-short": "fus",
 	"quarters-format-abbr": [
 		"trim. I",
 		"trim. II",
@@ -231,7 +364,9 @@ define(
 	"field-fri-narrow-relative+-1": "vi. trecută",
 	"field-year-relative+0": "anul acesta",
 	"field-year-relative+1": "anul viitor",
+	"field-era-narrow": "eră",
 	"field-fri-relative+-1": "vinerea trecută",
+	"eraNarrow": "AH",
 	"field-tue-short-relative+-1": "mar. trecută",
 	"field-minute-narrow": "m",
 	"days-format-wide": [
@@ -245,13 +380,17 @@ define(
 	],
 	"field-mon-narrow-relative+0": "lu. aceasta",
 	"field-mon-narrow-relative+1": "lu. viitoare",
+	"field-year-short-relative+-1": "anul trecut",
 	"field-zone": "fus orar",
 	"dateFormatItem-MMMEd": "E, d MMM",
+	"field-weekOfMonth-narrow": "săpt. din lună",
+	"field-weekday-narrow": "ziua din săpt.",
 	"field-quarter-narrow": "trim.",
 	"field-sun-short-relative+-1": "dum. trecută",
 	"field-day-relative+-1": "ieri",
 	"dayPeriods-standAlone-abbr-am": "a.m.",
 	"field-day-relative+-2": "alaltăieri",
+	"field-weekday-short": "ziua din săpt.",
 	"days-format-abbr": [
 		"dum.",
 		"lun.",
