@@ -10,19 +10,29 @@ define(
 	"field-wed-relative+1": "в следующую среду",
 	"dateFormatItem-ms": "mm:ss",
 	"field-minute": "минута",
+	"field-month-narrow-relative+-1": "в пр. мес.",
 	"field-tue-narrow-relative+0": "в этот вт.",
 	"field-tue-narrow-relative+1": "в след. вт.",
+	"field-day-short-relative+-1": "вчера",
 	"field-thu-short-relative+0": "в этот чт.",
-	"field-thu-short-relative+1": "в след. чт.",
 	"field-day-relative+0": "сегодня",
+	"field-day-short-relative+-2": "позавчера",
+	"field-thu-short-relative+1": "в след. чт.",
 	"field-day-relative+1": "завтра",
+	"field-week-narrow-relative+0": "на эт. нед.",
 	"field-day-relative+2": "послезавтра",
+	"field-week-narrow-relative+1": "на след. нед.",
 	"field-wed-narrow-relative+-1": "в прош. ср.",
 	"field-year-narrow": "г.",
+	"field-era-short": "эра",
+	"field-year-narrow-relative+0": "в эт. г.",
 	"field-tue-relative+0": "в этот вторник",
+	"field-year-narrow-relative+1": "в сл. г.",
 	"field-tue-relative+1": "в следующий вторник",
+	"field-weekdayOfMonth": "день недели в месяце",
 	"field-second-short": "сек.",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "дн. нед. в мес.",
 	"field-week-relative+0": "на этой неделе",
 	"field-month-relative+0": "в этом месяце",
 	"field-week-relative+1": "на следующей неделе",
@@ -33,30 +43,37 @@ define(
 	"field-mon-short-relative+1": "в след. пн.",
 	"field-second-relative+0": "сейчас",
 	"dateFormatItem-yyyyQQQ": "QQQ U",
+	"field-weekOfMonth": "неделя месяца",
 	"field-month-short": "мес.",
 	"dateFormatItem-GyMMMEd": "E, d MMM U",
 	"dateFormatItem-yyyyMd": "dd.MM.y",
 	"field-day": "день",
+	"field-dayOfYear-short": "дн. года",
 	"field-year-relative+-1": "в прошлом году",
 	"field-sat-short-relative+-1": "в прош. сб.",
-	"field-hour-relative+0": "в этом часе",
+	"field-hour-relative+0": "в этот час",
 	"dateFormatItem-yyyyMEd": "E, dd.MM.y",
 	"field-wed-relative+-1": "в прошлую среду",
 	"field-sat-narrow-relative+-1": "в прош. сб.",
 	"field-second": "секунда",
 	"dateFormat-long": "d MMMM U",
 	"dateFormatItem-GyMMMd": "d MMM U",
+	"field-hour-short-relative+0": "в этот час",
 	"field-quarter": "квартал",
 	"field-week-short": "нед.",
+	"field-day-narrow-relative+0": "сегодня",
+	"field-day-narrow-relative+1": "завтра",
+	"field-day-narrow-relative+2": "послезавтра",
 	"field-tue-short-relative+0": "в этот вт.",
 	"field-tue-short-relative+1": "в след. вт.",
+	"field-month-short-relative+-1": "в прошлом мес.",
 	"field-mon-relative+-1": "в прошлый понедельник",
 	"dateFormatItem-GyMMM": "LLL U",
 	"field-month": "месяц",
 	"field-day-narrow": "дн.",
 	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "мин.",
-	"field-dayperiod": "ДП/ПП",
+	"field-dayperiod": "AM/PM",
 	"field-sat-short-relative+0": "в эту сб.",
 	"field-sat-short-relative+1": "в след. сб.",
 	"dateFormat-medium": "dd.MM U",
@@ -65,7 +82,9 @@ define(
 	"field-second-narrow": "с",
 	"field-mon-relative+0": "в этот понедельник",
 	"field-mon-relative+1": "в следующий понедельник",
+	"field-day-narrow-relative+-1": "вчера",
 	"field-year-short": "г.",
+	"field-day-narrow-relative+-2": "позавчера",
 	"months-format-narrow": [
 		"1",
 		"2",
@@ -82,6 +101,9 @@ define(
 	],
 	"field-quarter-relative+-1": "в прошлом квартале",
 	"dateFormatItem-yyyyMMMd": "d MMM U",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "на пр. нед.",
+	"field-dayOfYear": "день года",
 	"field-sat-relative+-1": "в прошлую субботу",
 	"dateFormatItem-Md": "dd.MM",
 	"field-hour": "час",
@@ -93,6 +115,8 @@ define(
 	"field-fri-relative+0": "в эту пятницу",
 	"field-sat-narrow-relative+1": "в след. сб.",
 	"field-fri-relative+1": "в следующую пятницу",
+	"field-month-narrow-relative+0": "в эт. мес.",
+	"field-month-narrow-relative+1": "в след. мес.",
 	"field-sun-short-relative+0": "в это вс.",
 	"field-sun-short-relative+1": "в след. вс.",
 	"field-week-relative+-1": "на прошлой неделе",
@@ -116,15 +140,16 @@ define(
 	"field-quarter-relative+1": "в следующем квартале",
 	"field-wed-short-relative+-1": "в прош. ср.",
 	"dateFormat-short": "dd.MM.y",
+	"field-year-narrow-relative+-1": "в пр. г.",
 	"field-thu-short-relative+-1": "в прош. чт.",
 	"dateFormatItem-yyyyMMMEd": "E, d MMM U",
 	"field-mon-narrow-relative+-1": "в прош. пн.",
 	"field-thu-narrow-relative+-1": "в прош. чт.",
 	"dateFormatItem-E": "ccc",
-	"field-tue-narrow-relative+-1": "в прош. вт.",
 	"dateFormatItem-H": "H",
+	"field-weekOfMonth-short": "нед. месяца",
+	"field-tue-narrow-relative+-1": "в прош. вт.",
 	"dateFormatItem-yyyy": "U",
-	"field-wed-short-relative+0": "в эту ср.",
 	"dateFormatItem-M": "L",
 	"months-standAlone-wide": [
 		"1",
@@ -140,16 +165,22 @@ define(
 		"11",
 		"12"
 	],
+	"field-wed-short-relative+0": "в эту ср.",
 	"field-wed-short-relative+1": "в след. ср.",
 	"field-sun-relative+-1": "в прошлое воскресенье",
 	"dateFormatItem-hm": "h:mm a",
 	"dateFormatItem-d": "d",
 	"field-weekday": "день недели",
+	"field-day-short-relative+0": "сегодня",
 	"field-quarter-narrow-relative+0": "тек. кв.",
+	"field-day-short-relative+1": "завтра",
 	"field-sat-relative+0": "в эту субботу",
 	"field-quarter-narrow-relative+1": "след. кв.",
 	"dateFormatItem-h": "h a",
+	"field-day-short-relative+2": "послезавтра",
 	"field-sat-relative+1": "в следующую субботу",
+	"field-week-short-relative+0": "на этой нед.",
+	"field-week-short-relative+1": "на следующей нед.",
 	"months-standAlone-abbr": [
 		"1",
 		"2",
@@ -164,12 +195,17 @@ define(
 		"11",
 		"12"
 	],
+	"field-dayOfYear-narrow": "дн. года",
+	"field-month-short-relative+0": "в этом мес.",
+	"field-month-short-relative+1": "в следующем мес.",
+	"field-weekdayOfMonth-short": "дн. нед. в месяце",
 	"dateFormatItem-MEd": "E, dd.MM",
+	"field-zone-narrow": "час. пояс",
 	"dateFormatItem-y": "U",
 	"field-thu-narrow-relative+0": "в этот чт.",
-	"field-thu-narrow-relative+1": "в след. чт.",
 	"field-sun-narrow-relative+-1": "в прош. вс.",
 	"field-mon-short-relative+-1": "в прош. пн.",
+	"field-thu-narrow-relative+1": "в след. чт.",
 	"field-thu-relative+0": "в этот четверг",
 	"field-thu-relative+1": "в следующий четверг",
 	"dateFormatItem-hms": "h:mm:ss a",
@@ -180,27 +216,38 @@ define(
 	"field-wed-narrow-relative+0": "в эту ср.",
 	"field-wed-narrow-relative+1": "в след. ср.",
 	"field-quarter-narrow-relative+-1": "посл. кв.",
+	"field-year-short-relative+0": "в этом г.",
 	"dateFormatItem-yyyyMMM": "LLL U",
+	"field-dayperiod-short": "AM/PM",
+	"field-year-short-relative+1": "в след. г.",
 	"field-fri-short-relative+0": "в эту пт.",
 	"field-fri-short-relative+1": "в след. пт.",
+	"field-week-short-relative+-1": "на прошлой нед.",
+	"field-hour-narrow-relative+0": "в этот час",
 	"dateFormatItem-yyyyQQQQ": "QQQQ U",
-	"field-hour-short": "ч.",
+	"field-hour-short": "ч",
+	"field-zone-short": "час. пояс",
 	"field-month-narrow": "мес.",
 	"field-hour-narrow": "ч",
 	"field-fri-narrow-relative+-1": "в прош. пт.",
 	"field-year-relative+0": "в этом году",
 	"field-year-relative+1": "в следующем году",
+	"field-era-narrow": "эра",
 	"field-fri-relative+-1": "в прошлую пятницу",
 	"field-tue-short-relative+-1": "в прош. вт.",
 	"field-minute-narrow": "мин",
 	"field-mon-narrow-relative+0": "в этот пн.",
 	"field-mon-narrow-relative+1": "в след. пн.",
+	"field-year-short-relative+-1": "в прошлом г.",
 	"field-zone": "часовой пояс",
 	"dateFormatItem-MMMEd": "ccc, d MMM",
+	"field-weekOfMonth-narrow": "нед. мес.",
+	"field-weekday-narrow": "дн. нед.",
 	"field-quarter-narrow": "кв.",
 	"field-sun-short-relative+-1": "в прош. вс.",
 	"field-day-relative+-1": "вчера",
 	"field-day-relative+-2": "позавчера",
+	"field-weekday-short": "дн. недели",
 	"field-sun-relative+0": "в это воскресенье",
 	"field-sun-relative+1": "в следующее воскресенье",
 	"dateFormatItem-Gy": "U",
