@@ -5,25 +5,36 @@ define(
 	"field-quarter-short-relative+1": "следующий кв.",
 	"field-tue-relative+-1": "в прошлый вторник",
 	"field-year": "год",
-	"dateFormatItem-Hm": "H:mm",
+	"dateFormatItem-Hm": "HH:mm",
 	"field-wed-relative+0": "в эту среду",
 	"field-wed-relative+1": "в следующую среду",
 	"dateFormatItem-ms": "mm:ss",
 	"field-minute": "минута",
+	"field-month-narrow-relative+-1": "в пр. мес.",
 	"field-tue-narrow-relative+0": "в этот вт.",
 	"field-tue-narrow-relative+1": "в след. вт.",
+	"field-day-short-relative+-1": "вчера",
 	"field-thu-short-relative+0": "в этот чт.",
 	"dateTimeFormat-short": "{1}, {0}",
-	"field-thu-short-relative+1": "в след. чт.",
 	"field-day-relative+0": "сегодня",
+	"field-day-short-relative+-2": "позавчера",
+	"field-thu-short-relative+1": "в след. чт.",
 	"field-day-relative+1": "завтра",
+	"field-week-narrow-relative+0": "на эт. нед.",
 	"field-day-relative+2": "послезавтра",
+	"field-week-narrow-relative+1": "на след. нед.",
+	"dateFormatItem-EBhms": "ccc, h:mm:ss B",
 	"field-wed-narrow-relative+-1": "в прош. ср.",
 	"field-year-narrow": "г.",
+	"field-era-short": "эра",
+	"field-year-narrow-relative+0": "в эт. г.",
 	"field-tue-relative+0": "в этот вторник",
+	"field-year-narrow-relative+1": "в сл. г.",
 	"field-tue-relative+1": "в следующий вторник",
+	"field-weekdayOfMonth": "день недели в месяце",
 	"field-second-short": "сек.",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "дн. нед. в мес.",
 	"field-week-relative+0": "на этой неделе",
 	"field-month-relative+0": "в этом месяце",
 	"field-week-relative+1": "на следующей неделе",
@@ -33,92 +44,122 @@ define(
 	"field-sun-narrow-relative+1": "в след. вс.",
 	"field-mon-short-relative+1": "в след. пн.",
 	"field-second-relative+0": "сейчас",
-	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"dateFormatItem-yyyyQQQ": "QQQ y 'г'. G",
+	"field-weekOfMonth": "неделя месяца",
 	"field-month-short": "мес.",
 	"dateFormatItem-GyMMMEd": "E, d MMM y 'г'. G",
 	"dateFormatItem-yyyyMd": "dd.MM.y G",
 	"field-day": "день",
+	"field-dayOfYear-short": "дн. года",
 	"field-year-relative+-1": "в прошлом году",
 	"field-sat-short-relative+-1": "в прош. сб.",
-	"field-hour-relative+0": "в этом часе",
+	"field-hour-relative+0": "в этот час",
 	"dateFormatItem-yyyyMEd": "E, dd.MM.y G",
 	"field-wed-relative+-1": "в прошлую среду",
 	"dateTimeFormat-medium": "{1}, {0}",
 	"field-sat-narrow-relative+-1": "в прош. сб.",
 	"field-second": "секунда",
+	"dateFormatItem-Ehms": "ccc, h:mm:ss a",
 	"dateFormat-long": "d MMMM y 'г'. G",
 	"dateFormatItem-GyMMMd": "d MMM y 'г'. G",
+	"field-hour-short-relative+0": "в этот час",
 	"field-quarter": "квартал",
 	"field-week-short": "нед.",
+	"field-day-narrow-relative+0": "сегодня",
+	"field-day-narrow-relative+1": "завтра",
+	"field-day-narrow-relative+2": "послезавтра",
 	"field-tue-short-relative+0": "в этот вт.",
 	"field-tue-short-relative+1": "в след. вт.",
+	"field-month-short-relative+-1": "в прошлом мес.",
 	"field-mon-relative+-1": "в прошлый понедельник",
-	"dateFormatItem-GyMMM": "LLL y G",
+	"dateFormatItem-GyMMM": "LLL y 'г'. G",
 	"field-month": "месяц",
 	"field-day-narrow": "дн.",
 	"dateFormatItem-MMM": "LLL",
 	"field-minute-short": "мин.",
-	"field-dayperiod": "ДП/ПП",
+	"field-dayperiod": "AM/PM",
 	"field-sat-short-relative+0": "в эту сб.",
 	"field-sat-short-relative+1": "в след. сб.",
 	"dateFormat-medium": "d MMM y 'г'. G",
-	"dateFormatItem-yyyyMMMM": "LLLL y G",
+	"dateFormatItem-yyyyMMMM": "LLLL y 'г'. G",
 	"dateFormatItem-yyyyM": "MM.y G",
 	"field-second-narrow": "с",
 	"field-mon-relative+0": "в этот понедельник",
 	"field-mon-relative+1": "в следующий понедельник",
+	"field-day-narrow-relative+-1": "вчера",
 	"field-year-short": "г.",
+	"field-day-narrow-relative+-2": "позавчера",
 	"field-quarter-relative+-1": "в прошлом квартале",
 	"dateFormatItem-yyyyMMMd": "d MMM y 'г'. G",
+	"field-dayperiod-narrow": "AM/PM",
+	"field-week-narrow-relative+-1": "на пр. нед.",
+	"field-dayOfYear": "день года",
 	"field-sat-relative+-1": "в прошлую субботу",
 	"dateTimeFormat-long": "{1}, {0}",
 	"dateFormatItem-Md": "dd.MM",
 	"field-hour": "час",
 	"dateFormat-full": "EEEE, d MMMM y 'г'. G",
 	"field-month-relative+-1": "в прошлом месяце",
-	"dateFormatItem-Hms": "H:mm:ss",
+	"dateFormatItem-Hms": "HH:mm:ss",
 	"field-quarter-short": "кв.",
 	"field-sat-narrow-relative+0": "в эту сб.",
 	"field-fri-relative+0": "в эту пятницу",
 	"field-sat-narrow-relative+1": "в след. сб.",
 	"field-fri-relative+1": "в следующую пятницу",
+	"dateFormatItem-EBhm": "ccc, h:mm B",
+	"field-month-narrow-relative+0": "в эт. мес.",
+	"field-month-narrow-relative+1": "в след. мес.",
 	"field-sun-short-relative+0": "в это вс.",
 	"field-sun-short-relative+1": "в след. вс.",
 	"field-week-relative+-1": "на прошлой неделе",
 	"field-quarter-short-relative+-1": "последний кв.",
+	"dateFormatItem-Ehm": "ccc, h:mm a",
 	"field-quarter-relative+0": "в текущем квартале",
 	"field-minute-relative+0": "в эту минуту",
 	"field-quarter-relative+1": "в следующем квартале",
 	"field-wed-short-relative+-1": "в прош. ср.",
 	"dateFormat-short": "dd.MM.y G",
+	"dateFormatItem-Bh": "h B",
+	"field-year-narrow-relative+-1": "в пр. г.",
 	"field-thu-short-relative+-1": "в прош. чт.",
 	"dateFormatItem-yyyyMMMEd": "E, d MMM y 'г'. G",
 	"field-mon-narrow-relative+-1": "в прош. пн.",
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "в прош. чт.",
 	"dateFormatItem-E": "ccc",
+	"dateFormatItem-H": "HH",
+	"field-weekOfMonth-short": "нед. месяца",
 	"field-tue-narrow-relative+-1": "в прош. вт.",
-	"dateFormatItem-H": "H",
-	"dateFormatItem-yyyy": "y G",
-	"field-wed-short-relative+0": "в эту ср.",
+	"dateFormatItem-yyyy": "y 'г'. G",
 	"dateFormatItem-M": "L",
+	"field-wed-short-relative+0": "в эту ср.",
 	"field-wed-short-relative+1": "в след. ср.",
 	"field-sun-relative+-1": "в прошлое воскресенье",
 	"dateTimeFormat-full": "{1}, {0}",
 	"dateFormatItem-hm": "h:mm a",
 	"dateFormatItem-d": "d",
 	"field-weekday": "день недели",
+	"field-day-short-relative+0": "сегодня",
 	"field-quarter-narrow-relative+0": "тек. кв.",
+	"field-day-short-relative+1": "завтра",
 	"field-sat-relative+0": "в эту субботу",
 	"field-quarter-narrow-relative+1": "след. кв.",
 	"dateFormatItem-h": "h a",
+	"field-day-short-relative+2": "послезавтра",
 	"field-sat-relative+1": "в следующую субботу",
+	"field-week-short-relative+0": "на этой нед.",
+	"field-week-short-relative+1": "на следующей нед.",
+	"field-dayOfYear-narrow": "дн. года",
+	"field-month-short-relative+0": "в этом мес.",
+	"field-month-short-relative+1": "в следующем мес.",
+	"field-weekdayOfMonth-short": "дн. нед. в месяце",
 	"dateFormatItem-MEd": "E, dd.MM",
-	"dateFormatItem-y": "y G",
+	"field-zone-narrow": "час. пояс",
+	"dateFormatItem-y": "y 'г'. G",
 	"field-thu-narrow-relative+0": "в этот чт.",
-	"field-thu-narrow-relative+1": "в след. чт.",
 	"field-sun-narrow-relative+-1": "в прош. вс.",
 	"field-mon-short-relative+-1": "в прош. пн.",
+	"field-thu-narrow-relative+1": "в след. чт.",
 	"field-thu-relative+0": "в этот четверг",
 	"field-thu-relative+1": "в следующий четверг",
 	"dateFormatItem-hms": "h:mm:ss a",
@@ -129,30 +170,45 @@ define(
 	"field-wed-narrow-relative+0": "в эту ср.",
 	"field-wed-narrow-relative+1": "в след. ср.",
 	"field-quarter-narrow-relative+-1": "посл. кв.",
-	"dateFormatItem-yyyyMMM": "LLL y G",
+	"field-year-short-relative+0": "в этом г.",
+	"dateFormatItem-yyyyMMM": "LLL y 'г'. G",
+	"field-dayperiod-short": "AM/PM",
+	"field-year-short-relative+1": "в след. г.",
 	"field-fri-short-relative+0": "в эту пт.",
 	"field-fri-short-relative+1": "в след. пт.",
+	"field-week-short-relative+-1": "на прошлой нед.",
+	"field-hour-narrow-relative+0": "в этот час",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y 'г'. G",
-	"field-hour-short": "ч.",
+	"field-hour-short": "ч",
+	"field-zone-short": "час. пояс",
 	"field-month-narrow": "мес.",
 	"field-hour-narrow": "ч",
 	"field-fri-narrow-relative+-1": "в прош. пт.",
 	"field-year-relative+0": "в этом году",
 	"field-year-relative+1": "в следующем году",
+	"field-era-narrow": "эра",
 	"field-fri-relative+-1": "в прошлую пятницу",
+	"dateFormatItem-Bhms": "h:mm:ss B",
 	"field-tue-short-relative+-1": "в прош. вт.",
 	"field-minute-narrow": "мин",
 	"field-mon-narrow-relative+0": "в этот пн.",
+	"dateFormatItem-EHm": "ccc HH:mm",
 	"field-mon-narrow-relative+1": "в след. пн.",
+	"field-year-short-relative+-1": "в прошлом г.",
 	"field-zone": "часовой пояс",
 	"dateFormatItem-MMMEd": "ccc, d MMM",
+	"field-weekOfMonth-narrow": "нед. мес.",
+	"dateFormatItem-EHms": "ccc HH:mm:ss",
+	"field-weekday-narrow": "дн. нед.",
 	"field-quarter-narrow": "кв.",
 	"field-sun-short-relative+-1": "в прош. вс.",
 	"field-day-relative+-1": "вчера",
 	"field-day-relative+-2": "позавчера",
+	"field-weekday-short": "дн. недели",
+	"dateFormatItem-Bhm": "h:mm B",
 	"field-sun-relative+0": "в это воскресенье",
 	"field-sun-relative+1": "в следующее воскресенье",
-	"dateFormatItem-Gy": "y G",
+	"dateFormatItem-Gy": "y 'г'. G",
 	"field-day-short": "дн.",
 	"field-week-narrow": "нед.",
 	"field-era": "эра",
