@@ -11,14 +11,14 @@ define(
 	"CHF_displayName": "švicarski frank",
 	"CNY_symbol": "CN¥",
 	"EUR_displayName": "evro",
-	"GBP_symbol": "£",
+	"GBP_symbol": "GBP",
 	"CAD_displayName": "kanadski dolar",
 	"USD_symbol": "$",
 	"EUR_symbol": "€",
 	"AUD_displayName": "avstralski dolar",
 	"CHF_symbol": "CHF",
 	"HKD_symbol": "HK$",
-	"AUD_symbol": "A$"
+	"AUD_symbol": "AUD"
 }
 //end v1.x content
 );
\ No newline at end of file
