@@ -6,10 +6,9 @@ define(
 	"superscriptingExponent": "×",
 	"list": ";",
 	"percentSign": "%",
-	"minusSign": "–",
+	"minusSign": "−",
 	"decimalFormat-short": "000 bil'.'",
 	"nan": "NaN",
-	"plusSign": "+",
 	"currencyFormat": "#,##0.00 ¤;(#,##0.00 ¤)",
 	"perMille": "‰",
 	"group": ".",
