@@ -1,186 +1,11 @@
 define(
 //begin v1.x content
 {
-	"field-quarter-short-relative+0": "овог квартала",
-	"dayPeriods-standAlone-abbr-noon": "подне",
-	"field-quarter-short-relative+1": "следећег квартала",
-	"field-tue-relative+-1": "прошлог уторка",
-	"field-year": "година",
-	"dateFormatItem-yw": "w. 'седмица' 'у' y.",
-	"dayPeriods-format-abbr-afternoon1": "по подне",
-	"dateFormatItem-Hm": "HH:mm",
-	"field-wed-relative+0": "у среду",
-	"field-wed-relative+1": "следеће среде",
-	"dateFormatItem-ms": "mm:ss",
-	"timeFormat-short": "HH:mm",
-	"field-minute": "минут",
-	"field-tue-narrow-relative+0": "у уто",
-	"field-tue-narrow-relative+1": "следећег уто",
-	"field-thu-short-relative+0": "у чет",
-	"dateTimeFormat-short": "{1} {0}",
-	"field-day-relative+0": "данас",
-	"field-thu-short-relative+1": "следећег чет",
-	"field-day-relative+1": "сутра",
-	"field-day-relative+2": "прекосутра",
-	"field-wed-narrow-relative+-1": "прошле сре",
-	"field-year-narrow": "г.",
-	"field-tue-relative+0": "у уторак",
-	"field-tue-relative+1": "следећег уторка",
-	"dayPeriods-format-narrow-am": "a",
-	"field-second-short": "сек.",
-	"dayPeriods-standAlone-abbr-morning1": "јутро",
-	"dateFormatItem-MMMd": "d. MMM",
-	"dayPeriods-format-narrow-morning1": "ујутру",
-	"dayPeriods-format-abbr-am": "пре подне",
-	"field-month-relative+0": "овог месеца",
-	"field-week-relative+0": "ове недеље",
-	"timeFormat-medium": "HH:mm:ss",
-	"field-month-relative+1": "следећег месеца",
-	"field-week-relative+1": "следеће недеље",
+	"dateFormatItem-yMMMM": "MMMM y.",
+	"field-thu-narrow-relative+0": "у чет",
+	"field-thu-narrow-relative+1": "следећег чет",
 	"field-sun-narrow-relative+0": "у нед",
-	"field-mon-short-relative+0": "у пон",
-	"field-sun-narrow-relative+1": "следеће нед",
-	"field-mon-short-relative+1": "следећег пон",
-	"field-second-relative+0": "сада",
-	"months-standAlone-narrow": [
-		"ј",
-		"ф",
-		"м",
-		"а",
-		"м",
-		"ј",
-		"ј",
-		"а",
-		"с",
-		"о",
-		"н",
-		"д"
-	],
-	"dayPeriods-standAlone-wide-noon": "подне",
-	"eraNames": [
-		"пре нове ере",
-		"нове ере"
-	],
-	"dayPeriods-standAlone-abbr-pm": "по подне",
-	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
-	"field-month-short": "мес.",
-	"field-day": "дан",
-	"dayPeriods-standAlone-wide-night1": "ноћ",
-	"field-year-relative+-1": "прошле године",
-	"dayPeriods-format-wide-am": "пре подне",
-	"field-sat-short-relative+-1": "прошле суб",
-	"dayPeriods-format-narrow-afternoon1": "по подне",
-	"dayPeriods-format-wide-afternoon1": "по подне",
-	"field-hour-relative+0": "овог сата",
-	"field-wed-relative+-1": "прошле среде",
-	"dateTimeFormat-medium": "{1} {0}",
-	"days-standAlone-narrow": [
-		"н",
-		"п",
-		"у",
-		"с",
-		"ч",
-		"п",
-		"с"
-	],
-	"dayPeriods-standAlone-narrow-noon": "подне",
-	"field-sat-narrow-relative+-1": "прошле суб",
-	"field-second": "секунд",
-	"dayPeriods-standAlone-wide-pm": "по подне",
-	"dateFormatItem-Ehms": "E h:mm:ss a",
-	"dateFormat-long": "dd. MMMM y.",
-	"dateFormatItem-GyMMMd": "d. MMM y. G",
-	"dayPeriods-standAlone-abbr-midnight": "поноћ",
-	"field-quarter": "квартал",
-	"field-week-short": "нед.",
-	"dayPeriods-format-narrow-midnight": "у поноћ",
-	"dateFormatItem-yMMMEd": "E, d. MMM y.",
-	"quarters-standAlone-wide": [
-		"први квартал",
-		"други квартал",
-		"трећи квартал",
-		"четврти квартал"
-	],
-	"days-format-narrow": [
-		"н",
-		"п",
-		"у",
-		"с",
-		"ч",
-		"п",
-		"с"
-	],
-	"dayPeriods-format-wide-evening1": "увече",
-	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
-	"field-tue-short-relative+0": "у уто",
-	"field-tue-short-relative+1": "следећег уто",
-	"field-mon-relative+-1": "прошлог понедељка",
-	"dateFormatItem-GyMMM": "MMM y. G",
-	"field-month": "месец",
-	"dayPeriods-standAlone-abbr-night1": "ноћ",
-	"field-day-narrow": "д.",
-	"dayPeriods-standAlone-narrow-afternoon1": "по подне",
-	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "мин.",
-	"field-dayperiod": "пре подне/по подне",
-	"field-sat-short-relative+0": "у суб",
-	"field-sat-short-relative+1": "следеће суб",
-	"dayPeriods-format-narrow-pm": "p",
-	"dateFormat-medium": "dd.MM.y.",
-	"eraAbbr": [
-		"п. н. е.",
-		"н. е."
-	],
-	"quarters-standAlone-abbr": [
-		"К1",
-		"К2",
-		"К3",
-		"К4"
-	],
-	"dayPeriods-format-abbr-pm": "по подне",
-	"field-second-narrow": "с.",
-	"dayPeriods-standAlone-narrow-night1": "ноћу",
-	"field-mon-relative+0": "у понедељак",
-	"field-year-short": "год.",
-	"field-mon-relative+1": "следећег понедељка",
-	"months-format-narrow": [
-		"ј",
-		"ф",
-		"м",
-		"а",
-		"м",
-		"ј",
-		"ј",
-		"а",
-		"с",
-		"о",
-		"н",
-		"д"
-	],
-	"dayPeriods-format-wide-morning1": "ујутро",
-	"field-quarter-relative+-1": "прошлог квартала",
-	"dayPeriods-standAlone-narrow-am": "пре подне",
-	"days-format-short": [
-		"не",
-		"по",
-		"ут",
-		"ср",
-		"че",
-		"пе",
-		"су"
-	],
-	"quarters-format-narrow": [
-		"1.",
-		"2.",
-		"3.",
-		"4."
-	],
-	"dayPeriods-format-wide-pm": "по подне",
-	"field-sat-relative+-1": "прошле суботе",
-	"dateTimeFormat-long": "{1} {0}",
-	"dateFormatItem-Md": "d.M.",
-	"field-hour": "сат",
-	"dateFormatItem-yQQQQ": "QQQQ y.",
+	"field-sun-narrow-relative+1": "сл. нед.",
 	"months-format-wide": [
 		"јануар",
 		"фебруар",
@@ -195,48 +20,28 @@ define(
 		"новембар",
 		"децембар"
 	],
-	"dayPeriods-format-wide-night1": "ноћу",
-	"dateFormat-full": "EEEE, dd. MMMM y.",
-	"dateFormatItem-MMMdd": "dd.MMM",
-	"field-month-relative+-1": "прошлог месеца",
+	"dayPeriods-standAlone-abbr-pm": "по подне",
 	"dateFormatItem-Hms": "HH:mm:ss",
-	"field-quarter-short": "кв.",
-	"field-sat-narrow-relative+0": "у суб",
-	"dateFormatItem-Hmv": "HH:mm v",
-	"field-fri-relative+0": "у петак",
-	"field-sat-narrow-relative+1": "следеће суб",
-	"field-fri-relative+1": "следећег петка",
-	"dayPeriods-format-narrow-noon": "у подне",
-	"field-sun-short-relative+0": "у нед",
-	"field-sun-short-relative+1": "следеће нед",
-	"field-week-relative+-1": "прошле недеље",
-	"field-quarter-short-relative+-1": "прошлог квартала",
-	"dateFormatItem-Ehm": "E h:mm a",
-	"months-format-abbr": [
-		"јан",
-		"феб",
-		"мар",
-		"апр",
-		"мај",
-		"јун",
-		"јул",
-		"авг",
-		"сеп",
-		"окт",
-		"нов",
-		"дец"
+	"field-fri-narrow-relative+0": "у пет",
+	"field-fri-narrow-relative+1": "следећег пет",
+	"eraNarrow": [
+		"п.н.е.",
+		"н.е."
 	],
-	"dayPeriods-format-wide-midnight": "поноћ",
-	"field-quarter-relative+0": "овог квартала",
-	"timeFormat-long": "HH:mm:ss z",
-	"field-minute-relative+0": "овог минута",
-	"field-quarter-relative+1": "следећег квартала",
-	"field-wed-short-relative+-1": "прошле сре",
-	"dateFormatItem-yMMM": "MMM y.",
-	"dateFormat-short": "d.M.yy.",
+	"dateFormatItem-Hmv": "HH:mm v",
+	"dateFormatItem-hmsv": "h:mm:ss a v",
+	"dateFormatItem-yMMMd": "d. MMM y.",
 	"dayPeriods-format-abbr-night1": "ноћу",
-	"dateFormatItem-MMMMW": "W. 'седмица' 'у' MMM.",
-	"field-thu-short-relative+-1": "прошлог чет",
+	"dayPeriods-format-narrow-evening1": "увече",
+	"days-standAlone-narrow": [
+		"н",
+		"п",
+		"у",
+		"с",
+		"ч",
+		"п",
+		"с"
+	],
 	"days-standAlone-wide": [
 		"недеља",
 		"понедељак",
@@ -246,15 +51,68 @@ define(
 		"петак",
 		"субота"
 	],
-	"field-mon-narrow-relative+-1": "прошлог пон",
-	"dateFormatItem-MMMMd": "d. MMMM",
+	"dayPeriods-format-abbr-afternoon1": "по подне",
+	"dayPeriods-format-wide-evening1": "увече",
+	"dateFormatItem-Ehm": "E h:mm a",
+	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
+	"field-wed-narrow-relative+-1": "прошле сре",
+	"dayPeriods-standAlone-wide-evening1": "вече",
+	"days-format-wide": [
+		"недеља",
+		"понедељак",
+		"уторак",
+		"среда",
+		"четвртак",
+		"петак",
+		"субота"
+	],
+	"dateFormatItem-yMM": "MM.y.",
+	"field-month-short-relative+0": "овог мес.",
+	"field-month-short-relative+1": "следећег мес.",
+	"dateFormatItem-Ehms": "E h:mm:ss a",
+	"dayPeriods-standAlone-narrow-evening1": "вече",
+	"dayPeriods-standAlone-abbr-afternoon1": "поподне",
+	"field-thu-relative+0": "у четвртак",
+	"dayPeriods-standAlone-abbr-night1": "ноћ",
+	"field-thu-relative+1": "следећег четвртка",
+	"dayPeriods-format-wide-am": "пре подне",
+	"field-fri-relative+0": "у петак",
+	"field-fri-relative+1": "следећег петка",
+	"dateFormatItem-yMd": "d.M.y.",
 	"field-thu-narrow-relative+-1": "прошлог чет",
-	"dateFormatItem-E": "E",
-	"dateFormatItem-H": "HH",
-	"field-tue-narrow-relative+-1": "прошлог уто",
-	"dayPeriods-format-abbr-evening1": "увече",
-	"dayPeriods-standAlone-narrow-pm": "по подне",
-	"dateFormatItem-M": "L",
+	"field-quarter-relative+0": "овог квартала",
+	"field-quarter-relative+1": "следећег квартала",
+	"field-sun-short-relative+0": "у нед",
+	"timeFormat-short": "HH:mm",
+	"field-sun-short-relative+1": "сл. нед.",
+	"dateFormatItem-hms": "h:mm:ss a",
+	"dayPeriods-format-narrow-afternoon1": "по подне",
+	"dateFormatItem-Md": "d.M.",
+	"dateFormatItem-Hmsv": "HH:mm:ss v",
+	"dateFormatItem-hmv": "h:mm a v",
+	"field-week-narrow": "н.",
+	"field-hour-relative+0": "овог сата",
+	"field-day-relative+-1": "јуче",
+	"field-day-relative+-2": "прекјуче",
+	"field-mon-narrow-relative+-1": "прошлог пон",
+	"field-minute-narrow": "мин.",
+	"dateFormatItem-MMMMEd": "E, d. MMMM",
+	"field-thu-short-relative+0": "у чет",
+	"field-mon-relative+0": "у понедељак",
+	"field-thu-short-relative+1": "следећег чет",
+	"field-mon-relative+1": "следећег понедељка",
+	"field-day-narrow-relative+0": "данас",
+	"field-era-short": "ера",
+	"field-day-narrow-relative+1": "сутра",
+	"field-sat-narrow-relative+0": "у суб",
+	"field-day-narrow-relative+2": "прекосутра",
+	"timeFormat-long": "HH:mm:ss z",
+	"field-sat-narrow-relative+1": "следеће суб",
+	"field-week-narrow-relative+0": "ове н.",
+	"field-week-narrow-relative+1": "следеће н.",
+	"field-wed-narrow-relative+0": "у сре",
+	"field-wed-narrow-relative+1": "следеће сре",
+	"field-month": "месец",
 	"months-standAlone-wide": [
 		"јануар",
 		"фебруар",
@@ -269,11 +127,198 @@ define(
 		"новембар",
 		"децембар"
 	],
+	"field-weekday-narrow": "дан у недељи",
+	"dayPeriods-standAlone-narrow-afternoon1": "поподне",
+	"field-year-relative+0": "ове године",
+	"field-year-relative+1": "следеће године",
+	"dayPeriods-format-abbr-evening1": "увече",
+	"dayPeriods-format-abbr-noon": "подне",
+	"dayPeriods-format-narrow-midnight": "поноћ",
+	"dayPeriods-format-wide-midnight": "поноћ",
+	"field-tue-relative+0": "у уторак",
+	"field-tue-relative+1": "следећег уторка",
+	"dayPeriods-standAlone-abbr-evening1": "вече",
+	"dateFormatItem-hm": "h:mm a",
+	"dayPeriods-standAlone-wide-midnight": "поноћ",
+	"field-year-narrow": "г.",
+	"dayPeriods-standAlone-abbr-noon": "подне",
+	"field-tue-short-relative+0": "у уто",
+	"dayPeriods-standAlone-narrow-midnight": "поноћ",
+	"field-tue-short-relative+1": "следећег уто",
+	"field-tue-narrow-relative+0": "у уто",
+	"field-tue-narrow-relative+1": "следећег уто",
+	"dateTimeFormat-full": "{1} {0}",
+	"dateFormatItem-E": "E",
+	"dateFormatItem-EBhm": "E hh:mm B",
+	"dateFormatItem-H": "HH",
+	"field-wed-relative+0": "у среду",
+	"field-wed-relative+1": "следеће среде",
+	"dateFormatItem-M": "L",
 	"field-wed-short-relative+0": "у сре",
+	"field-fri-short-relative+0": "у пет",
 	"field-wed-short-relative+1": "следеће сре",
-	"dateFormatItem-Hmsv": "HH:mm:ss v",
-	"field-sun-relative+-1": "прошле недеље",
-	"dateFormatItem-MMMMEd": "E, d. MMMM",
+	"field-fri-short-relative+1": "следећег пет",
+	"field-weekOfMonth-short": "нед. у мес.",
+	"field-quarter-short-relative+-1": "прошлог квартала",
+	"field-year-short-relative+-1": "прошле год.",
+	"dateFormatItem-Bhm": "hh:mm B",
+	"dayPeriods-format-wide-night1": "ноћу",
+	"dateTimeFormat-medium": "{1} {0}",
+	"field-quarter-narrow-relative+-1": "прошлог квартала",
+	"dateFormatItem-d": "d",
+	"dayPeriods-format-abbr-pm": "по подне",
+	"dateFormatItem-h": "h a",
+	"quarters-standAlone-wide": [
+		"први квартал",
+		"други квартал",
+		"трећи квартал",
+		"четврти квартал"
+	],
+	"field-weekOfMonth-narrow": "нед. у мес.",
+	"dateFormatItem-y": "y.",
+	"field-minute-relative+0": "овог минута",
+	"field-year-short-relative+0": "ове год.",
+	"dateFormatItem-EBhms": "E hh:mm:ss B",
+	"field-year-short-relative+1": "следеће год.",
+	"field-weekday": "дан у недељи",
+	"dayPeriods-format-narrow-pm": "p",
+	"field-tue-narrow-relative+-1": "прошлог уто",
+	"dateFormatItem-yMEd": "E, d.M.y.",
+	"dayPeriods-standAlone-wide-night1": "ноћ",
+	"field-year-narrow-relative+-1": "прошле г.",
+	"field-sat-relative+-1": "прошле суботе",
+	"dayPeriods-format-abbr-midnight": "поноћ",
+	"dayPeriods-format-narrow-morning1": "ујутру",
+	"dayPeriods-format-wide-morning1": "ујутро",
+	"dayPeriods-standAlone-abbr-midnight": "поноћ",
+	"dayPeriods-standAlone-narrow-pm": "по подне",
+	"dayPeriods-standAlone-wide-morning1": "јутро",
+	"field-mon-narrow-relative+0": "у пон",
+	"field-mon-narrow-relative+1": "следећег пон",
+	"field-second": "секунд",
+	"dateFormatItem-yMMMEd": "E, d. MMM y.",
+	"field-year-relative+-1": "прошле године",
+	"field-weekdayOfMonth-short": "дан у месецу",
+	"dateFormat-short": "d.M.yy.",
+	"eraNames": [
+		"пре нове ере",
+		"нове ере"
+	],
+	"field-second-short": "сек.",
+	"field-thu-short-relative+-1": "прошлог чет",
+	"field-zone": "временска зона",
+	"field-dayperiod-narrow": "пре подне/по подне",
+	"field-sun-short-relative+-1": "пр. нед.",
+	"dayPeriods-standAlone-narrow-morning1": "јутро",
+	"eraAbbr": [
+		"п. н. е.",
+		"н. е."
+	],
+	"field-week-short": "нед.",
+	"dayPeriods-standAlone-abbr-am": "пре подне",
+	"dayPeriods-standAlone-wide-pm": "по подне",
+	"dateFormatItem-ms": "mm:ss",
+	"field-day-relative+0": "данас",
+	"field-day-relative+1": "сутра",
+	"field-day-relative+2": "прекосутра",
+	"field-day-short-relative+0": "данас",
+	"field-dayOfYear-short": "дан у год.",
+	"field-day-short-relative+1": "сутра",
+	"dateFormat-long": "dd. MMMM y.",
+	"field-day-short-relative+2": "прекосутра",
+	"field-sun-narrow-relative+-1": "пр. нед.",
+	"dayPeriods-format-wide-noon": "подне",
+	"field-second-relative+0": "сада",
+	"field-quarter-relative+-1": "прошлог квартала",
+	"dayPeriods-format-narrow-night1": "ноћу",
+	"quarters-format-abbr": [
+		"К1",
+		"К2",
+		"К3",
+		"К4"
+	],
+	"dayPeriods-standAlone-wide-noon": "подне",
+	"dayPeriods-standAlone-narrow-night1": "ноћ",
+	"field-week-relative+-1": "прошле недеље",
+	"dayPeriods-format-abbr-morning1": "ујутро",
+	"field-month-relative+-1": "прошлог месеца",
+	"months-format-narrow": [
+		"ј",
+		"ф",
+		"м",
+		"а",
+		"м",
+		"ј",
+		"ј",
+		"а",
+		"с",
+		"о",
+		"н",
+		"д"
+	],
+	"field-year": "година",
+	"field-era": "ера",
+	"dayPeriods-standAlone-abbr-morning1": "јутро",
+	"days-standAlone-short": [
+		"не",
+		"по",
+		"ут",
+		"ср",
+		"че",
+		"пе",
+		"су"
+	],
+	"quarters-format-narrow": [
+		"1.",
+		"2.",
+		"3.",
+		"4."
+	],
+	"dateFormatItem-yQQQQ": "QQQQ y.",
+	"field-day-short-relative+-1": "јуче",
+	"field-day-short-relative+-2": "прекјуче",
+	"dateFormatItem-GyMMM": "MMM y. G",
+	"timeFormat-full": "HH:mm:ss zzzz",
+	"dateFormatItem-Bhms": "hh:mm:ss B",
+	"field-hour": "сат",
+	"field-dayOfYear-narrow": "дан у год.",
+	"field-quarter": "квартал",
+	"field-month-narrow-relative+0": "овог м.",
+	"field-month-narrow-relative+1": "следећег м.",
+	"dateFormatItem-MMdd": "dd.MM.",
+	"field-day": "дан",
+	"field-mon-relative+-1": "прошлог понедељка",
+	"field-dayOfYear": "дан у години",
+	"dateFormat-medium": "dd.MM.y.",
+	"dateTimeFormat-short": "{1} {0}",
+	"dateFormatItem-yMMM": "MMM y.",
+	"dateFormatItem-GyMMMd": "d. MMM y. G",
+	"dateFormatItem-MEd": "E, d.M.",
+	"field-tue-short-relative+-1": "прошлог уто",
+	"field-year-short": "год.",
+	"field-month-short": "мес.",
+	"dateFormatItem-MMMEd": "E d. MMM",
+	"dayPeriods-format-wide-afternoon1": "по подне",
+	"dateFormatItem-MMMd": "d. MMM",
+	"dateFormatItem-Bh": "h B",
+	"months-format-abbr": [
+		"јан",
+		"феб",
+		"мар",
+		"апр",
+		"мај",
+		"јун",
+		"јул",
+		"авг",
+		"сеп",
+		"окт",
+		"нов",
+		"дец"
+	],
+	"dayPeriods-format-abbr-am": "пре подне",
+	"field-sat-relative+0": "у суботу",
+	"field-sat-relative+1": "следеће суботе",
+	"dayPeriods-format-wide-pm": "по подне",
 	"days-standAlone-abbr": [
 		"нед",
 		"пон",
@@ -283,16 +328,95 @@ define(
 		"пет",
 		"суб"
 	],
-	"dateTimeFormat-full": "{1} {0}",
-	"dateFormatItem-hm": "h:mm a",
-	"dateFormatItem-d": "d",
-	"field-weekday": "дан у недељи",
-	"dayPeriods-standAlone-wide-evening1": "вече",
-	"field-quarter-narrow-relative+0": "овог квартала",
-	"field-sat-relative+0": "у суботу",
-	"dateFormatItem-h": "h a",
-	"field-quarter-narrow-relative+1": "следећег квартала",
-	"field-sat-relative+1": "следеће суботе",
+	"field-zone-short": "временска зона",
+	"field-week-short-relative+0": "ове нед.",
+	"field-week-short-relative+1": "следеће нед.",
+	"dayPeriods-standAlone-wide-afternoon1": "поподне",
+	"field-fri-short-relative+-1": "прошлог пет",
+	"field-month-narrow": "м.",
+	"dayPeriods-format-narrow-am": "a",
+	"field-month-narrow-relative+-1": "прошлог м.",
+	"days-format-abbr": [
+		"нед",
+		"пон",
+		"уто",
+		"сре",
+		"чет",
+		"пет",
+		"суб"
+	],
+	"field-weekday-short": "дан у недељи",
+	"field-day-narrow-relative+-1": "јуче",
+	"field-day-narrow-relative+-2": "прекјуче",
+	"field-quarter-short": "кв.",
+	"days-format-short": [
+		"не",
+		"по",
+		"ут",
+		"ср",
+		"че",
+		"пе",
+		"су"
+	],
+	"months-standAlone-narrow": [
+		"ј",
+		"ф",
+		"м",
+		"а",
+		"м",
+		"ј",
+		"ј",
+		"а",
+		"с",
+		"о",
+		"н",
+		"д"
+	],
+	"days-format-narrow": [
+		"н",
+		"п",
+		"у",
+		"с",
+		"ч",
+		"п",
+		"с"
+	],
+	"dateFormatItem-EHm": "E HH:mm",
+	"field-quarter-narrow": "кв.",
+	"field-mon-short-relative+0": "у пон",
+	"field-mon-short-relative+1": "следећег пон",
+	"field-dayperiod-short": "пре подне/по подне",
+	"dayPeriods-standAlone-narrow-am": "пре подне",
+	"field-week-narrow-relative+-1": "прошле н.",
+	"field-thu-relative+-1": "прошлог четвртка",
+	"field-fri-narrow-relative+-1": "прошлог пет",
+	"field-mon-short-relative+-1": "прошлог пон",
+	"timeFormat-medium": "HH:mm:ss",
+	"field-quarter-short-relative+0": "овог квартала",
+	"field-quarter-short-relative+1": "следећег квартала",
+	"dateFormatItem-Ed": "E d.",
+	"field-wed-relative+-1": "прошле среде",
+	"field-weekOfMonth": "недеља у месецу",
+	"field-weekdayOfMonth-narrow": "дан у месецу",
+	"dayPeriods-standAlone-wide-am": "пре подне",
+	"dateFormatItem-yQQQ": "QQQ y.",
+	"field-fri-relative+-1": "прошлог петка",
+	"field-minute": "минут",
+	"quarters-standAlone-narrow": [
+		"1.",
+		"2.",
+		"3.",
+		"4."
+	],
+	"quarters-format-wide": [
+		"први квартал",
+		"други квартал",
+		"трећи квартал",
+		"четврти квартал"
+	],
+	"field-day-short": "д.",
+	"field-dayperiod": "пре подне/по подне",
+	"field-hour-short": "ч.",
 	"months-standAlone-abbr": [
 		"јан",
 		"феб",
@@ -307,128 +431,54 @@ define(
 		"нов",
 		"дец"
 	],
-	"dateFormatItem-hmsv": "h:mm:ss a v",
-	"dayPeriods-format-abbr-morning1": "ујутро",
-	"dayPeriods-standAlone-narrow-evening1": "увече",
-	"dateFormatItem-yMM": "MM.y.",
-	"timeFormat-full": "HH:mm:ss zzzz",
-	"dateFormatItem-MEd": "E, d.M.",
-	"dateFormatItem-y": "y.",
-	"field-thu-narrow-relative+0": "у чет",
-	"field-sun-narrow-relative+-1": "прошле нед",
-	"field-mon-short-relative+-1": "прошлог пон",
-	"field-thu-narrow-relative+1": "следећег чет",
-	"field-thu-relative+0": "у четвртак",
-	"dayPeriods-standAlone-abbr-afternoon1": "поподне",
-	"field-thu-relative+1": "следећег четвртка",
-	"dateFormatItem-hms": "h:mm:ss a",
-	"field-fri-short-relative+-1": "прошлог пет",
-	"dateFormatItem-hmv": "h:mm a v",
-	"dayPeriods-format-abbr-noon": "подне",
-	"field-thu-relative+-1": "прошлог четвртка",
-	"dateFormatItem-yMd": "d.M.y.",
-	"quarters-standAlone-narrow": [
-		"1.",
-		"2.",
-		"3.",
-		"4."
-	],
-	"field-week": "недеља",
-	"quarters-format-wide": [
-		"први квартал",
-		"други квартал",
-		"трећи квартал",
-		"четврти квартал"
-	],
-	"dateFormatItem-Ed": "E d.",
-	"field-wed-narrow-relative+0": "у сре",
-	"field-wed-narrow-relative+1": "следеће сре",
-	"dayPeriods-standAlone-wide-morning1": "јутро",
-	"field-quarter-narrow-relative+-1": "прошлог квартала",
-	"field-fri-short-relative+0": "у пет",
-	"field-fri-short-relative+1": "следећег пет",
-	"days-standAlone-short": [
-		"не",
-		"по",
-		"ут",
-		"ср",
-		"че",
-		"пе",
-		"су"
-	],
-	"dayPeriods-standAlone-narrow-morning1": "ујутро",
-	"dayPeriods-format-abbr-midnight": "поноћ",
-	"field-hour-short": "ч.",
+	"field-month-relative+0": "овог месеца",
+	"field-second-narrow": "с.",
+	"field-month-relative+1": "следећег месеца",
+	"dateFormat-full": "EEEE, dd. MMMM y.",
+	"field-era-narrow": "ера",
+	"field-sat-short-relative+-1": "прошле суб",
+	"dayPeriods-format-narrow-noon": "подне",
+	"field-week-short-relative+-1": "прошле нед.",
+	"dateTimeFormat-long": "{1} {0}",
+	"dateFormatItem-yM": "M.y.",
+	"field-sun-relative+-1": "прошле недеље",
+	"field-wed-short-relative+-1": "прошле сре",
+	"field-weekdayOfMonth": "дан у месецу",
+	"field-quarter-narrow-relative+0": "овог квартала",
+	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
+	"field-quarter-narrow-relative+1": "следећег квартала",
+	"field-sat-short-relative+0": "у суб",
+	"field-hour-narrow": "ч.",
+	"field-sat-short-relative+1": "следеће суб",
+	"field-year-narrow-relative+0": "ове г.",
+	"field-year-narrow-relative+1": "следеће г.",
+	"dateFormatItem-Gy": "y. G",
+	"field-zone-narrow": "временска зона",
+	"dayPeriods-standAlone-narrow-noon": "подне",
+	"field-tue-relative+-1": "прошлог уторка",
+	"field-minute-short": "мин.",
+	"dateFormatItem-yw": "w. 'седмица' 'у' Y.",
+	"dateFormatItem-MMMdd": "dd.MMM",
+	"dateFormatItem-Hm": "HH:mm",
+	"field-week-relative+0": "ове недеље",
+	"field-week-relative+1": "следеће недеље",
+	"dateFormatItem-MMM": "LLL",
+	"field-sun-relative+0": "у недељу",
+	"field-sun-relative+1": "следеће недеље",
 	"dateFormatItem-yMMdd": "dd.MM.y.",
-	"quarters-format-abbr": [
+	"field-sat-narrow-relative+-1": "прошле суб",
+	"quarters-standAlone-abbr": [
 		"К1",
 		"К2",
 		"К3",
 		"К4"
 	],
-	"field-month-narrow": "м.",
-	"field-hour-narrow": "ч.",
-	"field-fri-narrow-relative+-1": "прошлог пет",
-	"field-year-relative+0": "ове године",
-	"field-year-relative+1": "следеће године",
-	"field-fri-relative+-1": "прошлог петка",
-	"eraNarrow": [
-		"п.н.е.",
-		"н.е."
-	],
-	"dayPeriods-format-wide-noon": "подне",
-	"field-tue-short-relative+-1": "прошлог уто",
-	"field-minute-narrow": "мин.",
-	"dayPeriods-standAlone-wide-afternoon1": "поподне",
-	"dateFormatItem-yQQQ": "QQQ y.",
-	"days-format-wide": [
-		"недеља",
-		"понедељак",
-		"уторак",
-		"среда",
-		"четвртак",
-		"петак",
-		"субота"
-	],
-	"field-mon-narrow-relative+0": "у пон",
-	"dateFormatItem-EHm": "E HH:mm",
-	"field-mon-narrow-relative+1": "следећег пон",
-	"dayPeriods-standAlone-wide-midnight": "поноћ",
-	"dateFormatItem-yM": "M.y.",
-	"field-zone": "временска зона",
-	"dateFormatItem-yMMMM": "MMMM y.",
-	"dateFormatItem-MMMEd": "E d. MMM",
+	"dateFormatItem-MMMMW": "W. 'седмица' 'у' MMMM.",
+	"field-month-short-relative+-1": "прошлог мес.",
 	"dateFormatItem-EHms": "E HH:mm:ss",
-	"dateFormatItem-yMEd": "E, d.M.y.",
-	"dayPeriods-standAlone-narrow-midnight": "поноћ",
-	"field-quarter-narrow": "кв.",
-	"dayPeriods-standAlone-abbr-am": "пре подне",
-	"field-day-relative+-1": "јуче",
-	"field-sun-short-relative+-1": "прошле нед",
-	"field-day-relative+-2": "прекјуче",
-	"dayPeriods-format-narrow-night1": "ноћу",
-	"days-format-abbr": [
-		"нед",
-		"пон",
-		"уто",
-		"сре",
-		"чет",
-		"пет",
-		"суб"
-	],
-	"dateFormatItem-MMdd": "dd.MM.",
-	"field-sun-relative+0": "у недељу",
-	"field-sun-relative+1": "следеће недеље",
-	"dateFormatItem-yMMMd": "d. MMM y.",
-	"dateFormatItem-Gy": "y. G",
-	"field-era": "ера",
-	"field-week-narrow": "н.",
-	"field-day-short": "д.",
-	"dayPeriods-standAlone-abbr-evening1": "вече",
-	"field-fri-narrow-relative+0": "у пет",
-	"dayPeriods-format-narrow-evening1": "увече",
-	"field-fri-narrow-relative+1": "следећег пет",
-	"dayPeriods-standAlone-wide-am": "пре подне"
+	"dateFormatItem-MMMMd": "d. MMMM",
+	"field-week": "недеља",
+	"field-day-narrow": "д."
 }
 //end v1.x content
 );
\ No newline at end of file
