@@ -5,25 +5,34 @@ define(
 	"field-quarter-short-relative+1": "следећег квартала",
 	"field-tue-relative+-1": "прошлог уторка",
 	"field-year": "година",
-	"dateFormatItem-Hm": "HH.mm",
 	"field-wed-relative+0": "у среду",
 	"field-wed-relative+1": "следеће среде",
-	"dateFormatItem-ms": "mm.ss",
 	"field-minute": "минут",
+	"field-month-narrow-relative+-1": "прошлог м.",
 	"field-tue-narrow-relative+0": "у уто",
 	"field-tue-narrow-relative+1": "следећег уто",
 	"field-thu-short-relative+0": "у чет",
+	"field-day-short-relative+-1": "јуче",
 	"field-thu-short-relative+1": "следећег чет",
 	"field-day-relative+0": "данас",
+	"field-day-short-relative+-2": "прекјуче",
 	"field-day-relative+1": "сутра",
+	"field-week-narrow-relative+0": "ове н.",
 	"field-day-relative+2": "прекосутра",
+	"field-week-narrow-relative+1": "следеће н.",
 	"field-wed-narrow-relative+-1": "прошле сре",
+	"dateFormatItem-EBhms": "E hh:mm:ss B",
 	"field-year-narrow": "г.",
+	"field-era-short": "ера",
+	"field-year-narrow-relative+0": "ове г.",
 	"field-tue-relative+0": "у уторак",
+	"field-year-narrow-relative+1": "следеће г.",
 	"field-tue-relative+1": "следећег уторка",
+	"field-weekdayOfMonth": "дан у месецу",
 	"field-second-short": "сек.",
 	"dayPeriods-format-narrow-am": "a",
 	"dateFormatItem-MMMd": "d. MMM",
+	"field-weekdayOfMonth-narrow": "дан у месецу",
 	"dayPeriods-format-abbr-am": "пре подне",
 	"field-week-relative+0": "ове недеље",
 	"field-month-relative+0": "овог месеца",
@@ -31,18 +40,20 @@ define(
 	"field-month-relative+1": "следећег месеца",
 	"field-sun-narrow-relative+0": "у нед",
 	"field-mon-short-relative+0": "у пон",
-	"field-sun-narrow-relative+1": "следеће нед",
+	"field-sun-narrow-relative+1": "сл. нед.",
 	"field-mon-short-relative+1": "следећег пон",
 	"field-second-relative+0": "сада",
 	"dateFormatItem-yyyyQQQ": "QQQ, y. G",
 	"eraNames": [
 		"АХ"
 	],
+	"field-weekOfMonth": "недеља у месецу",
 	"dayPeriods-standAlone-abbr-pm": "по подне",
 	"field-month-short": "мес.",
 	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
 	"dateFormatItem-yyyyMd": "d.M.y. GGGGG",
 	"field-day": "дан",
+	"field-dayOfYear-short": "дан у год.",
 	"field-year-relative+-1": "прошле године",
 	"dayPeriods-format-wide-am": "пре подне",
 	"field-sat-short-relative+-1": "прошле суб",
@@ -61,10 +72,14 @@ define(
 		"с"
 	],
 	"dayPeriods-standAlone-wide-pm": "по подне",
+	"dateFormatItem-Ehms": "E hh:mm:ss a",
 	"dateFormat-long": "d. MMMM y. G",
 	"dateFormatItem-GyMMMd": "d. MMM y. G",
 	"field-quarter": "квартал",
 	"field-week-short": "нед.",
+	"field-day-narrow-relative+0": "данас",
+	"field-day-narrow-relative+1": "сутра",
+	"field-day-narrow-relative+2": "прекосутра",
 	"quarters-standAlone-wide": [
 		"први квартал",
 		"други квартал",
@@ -82,6 +97,7 @@ define(
 	],
 	"field-tue-short-relative+0": "у уто",
 	"field-tue-short-relative+1": "следећег уто",
+	"field-month-short-relative+-1": "прошлог мес.",
 	"field-mon-relative+-1": "прошлог понедељка",
 	"dateFormatItem-GyMMM": "MMM y. G",
 	"field-month": "месец",
@@ -107,10 +123,14 @@ define(
 	"field-second-narrow": "с.",
 	"field-mon-relative+0": "у понедељак",
 	"field-mon-relative+1": "следећег понедељка",
+	"field-day-narrow-relative+-1": "јуче",
 	"field-year-short": "год.",
+	"field-day-narrow-relative+-2": "прекјуче",
 	"field-quarter-relative+-1": "прошлог квартала",
 	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
+	"field-dayperiod-narrow": "пре подне/по подне",
 	"dayPeriods-standAlone-narrow-am": "пре подне",
+	"field-week-narrow-relative+-1": "прошле н.",
 	"days-format-short": [
 		"не",
 		"по",
@@ -127,6 +147,7 @@ define(
 		"4."
 	],
 	"dayPeriods-format-wide-pm": "по подне",
+	"field-dayOfYear": "дан у години",
 	"field-sat-relative+-1": "прошле суботе",
 	"dateFormatItem-Md": "d.M.",
 	"field-hour": "сат",
@@ -146,16 +167,19 @@ define(
 	],
 	"dateFormat-full": "EEEE, d. MMMM y. G",
 	"field-month-relative+-1": "прошлог месеца",
-	"dateFormatItem-Hms": "HH.mm.ss",
 	"field-quarter-short": "кв.",
 	"field-sat-narrow-relative+0": "у суб",
 	"field-fri-relative+0": "у петак",
 	"field-sat-narrow-relative+1": "следеће суб",
 	"field-fri-relative+1": "следећег петка",
+	"dateFormatItem-EBhm": "E hh:mm B",
+	"field-month-narrow-relative+0": "овог м.",
+	"field-month-narrow-relative+1": "следећег м.",
 	"field-sun-short-relative+0": "у нед",
-	"field-sun-short-relative+1": "следеће нед",
+	"field-sun-short-relative+1": "сл. нед.",
 	"field-week-relative+-1": "прошле недеље",
 	"field-quarter-short-relative+-1": "прошлог квартала",
+	"dateFormatItem-Ehm": "E hh:mm a",
 	"months-format-abbr": [
 		"Мурахам",
 		"Сафар",
@@ -176,6 +200,7 @@ define(
 	"field-wed-short-relative+-1": "прошле сре",
 	"dateFormat-short": "d.M.y. GGGGG",
 	"field-thu-short-relative+-1": "прошлог чет",
+	"field-year-narrow-relative+-1": "прошле г.",
 	"days-standAlone-wide": [
 		"недеља",
 		"понедељак",
@@ -190,6 +215,7 @@ define(
 	"dateFormatItem-MMMMd": "d. MMMM",
 	"field-thu-narrow-relative+-1": "прошлог чет",
 	"field-tue-narrow-relative+-1": "прошлог уто",
+	"field-weekOfMonth-short": "нед. у мес.",
 	"dateFormatItem-yyyy": "y. G",
 	"dayPeriods-standAlone-narrow-pm": "по подне",
 	"field-wed-short-relative+0": "у сре",
@@ -218,13 +244,17 @@ define(
 		"пет",
 		"суб"
 	],
-	"dateFormatItem-hm": "hh.mm a",
+	"dateFormatItem-hm": "hh:mm a",
 	"field-weekday": "дан у недељи",
+	"field-day-short-relative+0": "данас",
 	"field-quarter-narrow-relative+0": "овог квартала",
 	"field-sat-relative+0": "у суботу",
+	"field-day-short-relative+1": "сутра",
 	"field-quarter-narrow-relative+1": "следећег квартала",
-	"dateFormatItem-h": "hh a",
 	"field-sat-relative+1": "следеће суботе",
+	"field-day-short-relative+2": "прекосутра",
+	"field-week-short-relative+0": "ове нед.",
+	"field-week-short-relative+1": "следеће нед.",
 	"months-standAlone-abbr": [
 		"Мурахам",
 		"Сафар",
@@ -239,16 +269,21 @@ define(
 		"Дуʻл-Киʻда",
 		"Дуʻл-хиђа"
 	],
+	"field-dayOfYear-narrow": "дан у год.",
+	"field-month-short-relative+0": "овог мес.",
+	"field-month-short-relative+1": "следећег мес.",
+	"field-weekdayOfMonth-short": "дан у месецу",
 	"dateFormatItem-MEd": "E, d.M.",
+	"field-zone-narrow": "временска зона",
 	"dateFormatItem-y": "y. G",
 	"field-thu-narrow-relative+0": "у чет",
 	"field-thu-narrow-relative+1": "следећег чет",
-	"field-sun-narrow-relative+-1": "прошле нед",
+	"field-sun-narrow-relative+-1": "пр. нед.",
 	"field-mon-short-relative+-1": "прошлог пон",
 	"field-thu-relative+0": "у четвртак",
 	"field-thu-relative+1": "следећег четвртка",
-	"dateFormatItem-hms": "hh.mm.ss a",
 	"field-fri-short-relative+-1": "прошлог пет",
+	"dateFormatItem-hms": "hh:mm:ss a",
 	"field-thu-relative+-1": "прошлог четвртка",
 	"field-week": "недеља",
 	"quarters-standAlone-narrow": [
@@ -267,7 +302,10 @@ define(
 	"field-wed-narrow-relative+0": "у сре",
 	"field-wed-narrow-relative+1": "следеће сре",
 	"field-quarter-narrow-relative+-1": "прошлог квартала",
+	"field-year-short-relative+0": "ове год.",
+	"field-dayperiod-short": "пре подне/по подне",
 	"dateFormatItem-yyyyMMM": "MMM y. G",
+	"field-year-short-relative+1": "следеће год.",
 	"field-fri-short-relative+0": "у пет",
 	"field-fri-short-relative+1": "следећег пет",
 	"days-standAlone-short": [
@@ -279,8 +317,10 @@ define(
 		"пе",
 		"су"
 	],
+	"field-week-short-relative+-1": "прошле нед.",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
 	"field-hour-short": "ч.",
+	"field-zone-short": "временска зона",
 	"quarters-format-abbr": [
 		"К1",
 		"К2",
@@ -292,10 +332,12 @@ define(
 	"field-fri-narrow-relative+-1": "прошлог пет",
 	"field-year-relative+0": "ове године",
 	"field-year-relative+1": "следеће године",
+	"field-era-narrow": "ера",
 	"field-fri-relative+-1": "прошлог петка",
 	"eraNarrow": [
 		"АХ"
 	],
+	"dateFormatItem-Bhms": "hh:mm:ss B",
 	"field-tue-short-relative+-1": "прошлог уто",
 	"field-minute-narrow": "мин.",
 	"days-format-wide": [
@@ -309,13 +351,17 @@ define(
 	],
 	"field-mon-narrow-relative+0": "у пон",
 	"field-mon-narrow-relative+1": "следећег пон",
+	"field-year-short-relative+-1": "прошле год.",
 	"field-zone": "временска зона",
 	"dateFormatItem-MMMEd": "E, d. MMM",
+	"field-weekOfMonth-narrow": "нед. у мес.",
+	"field-weekday-narrow": "дан у недељи",
 	"field-quarter-narrow": "кв.",
-	"field-sun-short-relative+-1": "прошле нед",
+	"field-sun-short-relative+-1": "пр. нед.",
 	"field-day-relative+-1": "јуче",
 	"dayPeriods-standAlone-abbr-am": "пре подне",
 	"field-day-relative+-2": "прекјуче",
+	"field-weekday-short": "дан у недељи",
 	"days-format-abbr": [
 		"нед",
 		"пон",
@@ -325,6 +371,7 @@ define(
 		"пет",
 		"суб"
 	],
+	"dateFormatItem-Bhm": "hh:mm B",
 	"field-sun-relative+0": "у недељу",
 	"field-sun-relative+1": "следеће недеље",
 	"dateFormatItem-Gy": "y. G",
