@@ -23,13 +23,16 @@ define(
 	"field-week-narrow-relative+1": "nästa v.",
 	"field-wed-narrow-relative+-1": "förra ons.",
 	"field-year-narrow": "år",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "i år",
 	"field-tue-relative+0": "tisdag denna vecka",
 	"field-year-narrow-relative+1": "nästa år",
 	"field-tue-relative+1": "tisdag nästa vecka",
+	"field-weekdayOfMonth": "veckodag i månad",
 	"field-second-short": "sek",
 	"dayPeriods-format-narrow-am": "fm",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "veckodag i mån.",
 	"dayPeriods-format-abbr-am": "fm",
 	"field-week-relative+0": "denna vecka",
 	"field-month-relative+0": "denna månad",
@@ -42,11 +45,16 @@ define(
 	"field-mon-short-relative+1": "mån. nästa vecka",
 	"field-second-relative+0": "nu",
 	"dateFormatItem-yyyyQQQ": "QQQ y G",
+	"eraNames": [
+		"efter Hirja"
+	],
+	"field-weekOfMonth": "vecka i månaden",
 	"dayPeriods-standAlone-abbr-pm": "e.m.",
 	"field-month-short": "m",
 	"dateFormatItem-GyMMMEd": "E d MMM y G",
 	"dateFormatItem-yyyyMd": "y-MM-dd G",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag under året",
 	"field-year-relative+-1": "i fjol",
 	"dayPeriods-format-wide-am": "fm",
 	"field-sat-short-relative+-1": "lör. förra veckan",
@@ -71,8 +79,8 @@ define(
 	"field-hour-short-relative+0": "denna timme",
 	"field-quarter": "kvartal",
 	"field-week-short": "v",
-	"field-day-narrow-relative+0": "i dag",
-	"field-day-narrow-relative+1": "i morgon",
+	"field-day-narrow-relative+0": "idag",
+	"field-day-narrow-relative+1": "imorgon",
 	"field-day-narrow-relative+2": "i övermorgon",
 	"quarters-standAlone-wide": [
 		"1:a kvartalet",
@@ -117,11 +125,12 @@ define(
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "måndag denna vecka",
 	"field-mon-relative+1": "måndag nästa vecka",
-	"field-day-narrow-relative+-1": "i går",
+	"field-day-narrow-relative+-1": "igår",
 	"field-year-short": "år",
 	"field-day-narrow-relative+-2": "i förrgår",
 	"field-quarter-relative+-1": "förra kvartalet",
 	"dateFormatItem-yyyyMMMd": "d MMM y G",
+	"field-dayperiod-narrow": "fm/em",
 	"dayPeriods-standAlone-narrow-am": "fm",
 	"field-week-narrow-relative+-1": "förra v.",
 	"days-format-short": [
@@ -134,6 +143,7 @@ define(
 		"lö"
 	],
 	"dayPeriods-format-wide-pm": "em",
+	"field-dayOfYear": "dag under året",
 	"field-sat-relative+-1": "lördag förra veckan",
 	"dateFormatItem-Md": "d/M",
 	"field-minute-narrow-relative+0": "denna minut",
@@ -198,10 +208,10 @@ define(
 		"lördag"
 	],
 	"dateFormatItem-yyyyMMMEd": "E d MMM y G",
-	"field-mon-narrow-relative+-1": "förra mån.",
 	"dateFormatItem-MMMMd": "d MMMM",
 	"field-thu-narrow-relative+-1": "förra tors.",
 	"field-tue-narrow-relative+-1": "förra tis.",
+	"field-weekOfMonth-short": "vk. i mån.",
 	"dateFormatItem-yyyy": "y G",
 	"dayPeriods-standAlone-narrow-pm": "em",
 	"field-wed-short-relative+0": "ons. denna vecka",
@@ -255,10 +265,13 @@ define(
 		"dhu-l-ga’da",
 		"dhu-l-hijja"
 	],
+	"field-dayOfYear-narrow": "dag under året",
 	"field-month-short-relative+0": "denna mån.",
 	"field-month-short-relative+1": "nästa mån.",
+	"field-weekdayOfMonth-short": "veckodag i mån.",
 	"timeFormat-full": "'kl'. HH.mm.ss zzzz",
 	"dateFormatItem-MEd": "E d/M",
+	"field-zone-narrow": "tidszon",
 	"dateFormatItem-y": "y G",
 	"field-thu-narrow-relative+0": "denna tors.",
 	"field-thu-narrow-relative+1": "nästa tors.",
@@ -280,6 +293,7 @@ define(
 	"field-wed-narrow-relative+1": "nästa ons.",
 	"field-quarter-narrow-relative+-1": "förra kv.",
 	"field-year-short-relative+0": "i år",
+	"field-dayperiod-short": "fm/em",
 	"dateFormatItem-yyyyMMM": "MMM y G",
 	"field-year-short-relative+1": "nästa år",
 	"field-fri-short-relative+0": "fre. denna vecka",
@@ -297,6 +311,7 @@ define(
 	"field-hour-narrow-relative+0": "denna timme",
 	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
 	"field-hour-short": "tim",
+	"field-zone-short": "tidszon",
 	"quarters-format-abbr": [
 		"K1",
 		"K2",
@@ -308,7 +323,9 @@ define(
 	"field-fri-narrow-relative+-1": "förra fre.",
 	"field-year-relative+0": "i år",
 	"field-year-relative+1": "nästa år",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "fredag förra veckan",
+	"eraNarrow": "AH",
 	"field-tue-short-relative+-1": "tis. förra veckan",
 	"field-minute-narrow": "m",
 	"days-format-wide": [
@@ -320,16 +337,17 @@ define(
 		"fredag",
 		"lördag"
 	],
-	"field-mon-narrow-relative+0": "denna mån.",
-	"field-mon-narrow-relative+1": "nästa mån.",
 	"field-year-short-relative+-1": "i fjol",
 	"field-zone": "tidszon",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "vk.i mån.",
+	"field-weekday-narrow": "veckodag",
 	"field-quarter-narrow": "kv.",
 	"field-sun-short-relative+-1": "sön. förra veckan",
 	"field-day-relative+-1": "i går",
 	"dayPeriods-standAlone-abbr-am": "f.m.",
 	"field-day-relative+-2": "i förrgår",
+	"field-weekday-short": "veckodag",
 	"days-format-abbr": [
 		"sön",
 		"mån",
