@@ -22,11 +22,14 @@ define(
 	"field-week-narrow-relative+1": "nästa v.",
 	"field-wed-narrow-relative+-1": "förra ons.",
 	"field-year-narrow": "år",
+	"field-era-short": "era",
 	"field-year-narrow-relative+0": "i år",
 	"field-tue-relative+0": "tisdag denna vecka",
 	"field-year-narrow-relative+1": "nästa år",
 	"field-tue-relative+1": "tisdag nästa vecka",
+	"field-weekdayOfMonth": "veckodag i månad",
 	"field-second-short": "sek",
+	"field-weekdayOfMonth-narrow": "veckodag i mån.",
 	"field-week-relative+0": "denna vecka",
 	"field-month-relative+0": "denna månad",
 	"field-week-relative+1": "nästa vecka",
@@ -36,8 +39,14 @@ define(
 	"field-sun-narrow-relative+1": "nästa sön.",
 	"field-mon-short-relative+1": "mån. nästa vecka",
 	"field-second-relative+0": "nu",
+	"eraNames": [
+		"före Republiken Kina",
+		"Minguo"
+	],
+	"field-weekOfMonth": "vecka i månaden",
 	"field-month-short": "m",
 	"field-day": "dag",
+	"field-dayOfYear-short": "dag under året",
 	"field-year-relative+-1": "i fjol",
 	"field-sat-short-relative+-1": "lör. förra veckan",
 	"field-hour-relative+0": "denna timme",
@@ -48,8 +57,8 @@ define(
 	"field-hour-short-relative+0": "denna timme",
 	"field-quarter": "kvartal",
 	"field-week-short": "v",
-	"field-day-narrow-relative+0": "i dag",
-	"field-day-narrow-relative+1": "i morgon",
+	"field-day-narrow-relative+0": "idag",
+	"field-day-narrow-relative+1": "imorgon",
 	"field-day-narrow-relative+2": "i övermorgon",
 	"field-tue-short-relative+0": "tis. denna vecka",
 	"field-tue-short-relative+1": "tis. nästa vecka",
@@ -68,11 +77,13 @@ define(
 	"field-second-narrow": "s",
 	"field-mon-relative+0": "måndag denna vecka",
 	"field-mon-relative+1": "måndag nästa vecka",
-	"field-day-narrow-relative+-1": "i går",
+	"field-day-narrow-relative+-1": "igår",
 	"field-year-short": "år",
 	"field-day-narrow-relative+-2": "i förrgår",
 	"field-quarter-relative+-1": "förra kvartalet",
+	"field-dayperiod-narrow": "fm/em",
 	"field-week-narrow-relative+-1": "förra v.",
+	"field-dayOfYear": "dag under året",
 	"field-sat-relative+-1": "lördag förra veckan",
 	"field-hour": "timme",
 	"field-minute-narrow-relative+0": "denna minut",
@@ -95,9 +106,9 @@ define(
 	"field-wed-short-relative+-1": "ons. förra veckan",
 	"field-thu-short-relative+-1": "tors. förra veckan",
 	"field-year-narrow-relative+-1": "i fjol",
-	"field-mon-narrow-relative+-1": "förra mån.",
 	"field-thu-narrow-relative+-1": "förra tors.",
 	"field-tue-narrow-relative+-1": "förra tis.",
+	"field-weekOfMonth-short": "vk. i mån.",
 	"field-wed-short-relative+0": "ons. denna vecka",
 	"field-wed-short-relative+1": "ons. nästa vecka",
 	"field-sun-relative+-1": "söndag förra veckan",
@@ -112,8 +123,11 @@ define(
 	"field-day-short-relative+2": "i övermorgon",
 	"field-week-short-relative+0": "denna v.",
 	"field-week-short-relative+1": "nästa v.",
+	"field-dayOfYear-narrow": "dag under året",
 	"field-month-short-relative+0": "denna mån.",
 	"field-month-short-relative+1": "nästa mån.",
+	"field-weekdayOfMonth-short": "veckodag i mån.",
+	"field-zone-narrow": "tidszon",
 	"field-thu-narrow-relative+0": "denna tors.",
 	"field-thu-narrow-relative+1": "nästa tors.",
 	"field-sun-narrow-relative+-1": "förra sön.",
@@ -127,28 +141,36 @@ define(
 	"field-wed-narrow-relative+1": "nästa ons.",
 	"field-quarter-narrow-relative+-1": "förra kv.",
 	"field-year-short-relative+0": "i år",
+	"field-dayperiod-short": "fm/em",
 	"field-year-short-relative+1": "nästa år",
 	"field-fri-short-relative+0": "fre. denna vecka",
 	"field-fri-short-relative+1": "fre. nästa vecka",
 	"field-week-short-relative+-1": "förra v.",
 	"field-hour-narrow-relative+0": "denna timme",
 	"field-hour-short": "tim",
+	"field-zone-short": "tidszon",
 	"field-month-narrow": "mån",
 	"field-hour-narrow": "h",
 	"field-fri-narrow-relative+-1": "förra fre.",
 	"field-year-relative+0": "i år",
 	"field-year-relative+1": "nästa år",
+	"field-era-narrow": "era",
 	"field-fri-relative+-1": "fredag förra veckan",
+	"eraNarrow": [
+		"f.R.K.",
+		"R.K."
+	],
 	"field-tue-short-relative+-1": "tis. förra veckan",
 	"field-minute-narrow": "m",
-	"field-mon-narrow-relative+0": "denna mån.",
-	"field-mon-narrow-relative+1": "nästa mån.",
 	"field-year-short-relative+-1": "i fjol",
 	"field-zone": "tidszon",
+	"field-weekOfMonth-narrow": "vk.i mån.",
+	"field-weekday-narrow": "veckodag",
 	"field-quarter-narrow": "kv.",
 	"field-sun-short-relative+-1": "sön. förra veckan",
 	"field-day-relative+-1": "i går",
 	"field-day-relative+-2": "i förrgår",
+	"field-weekday-short": "veckodag",
 	"field-sun-relative+0": "söndag denna vecka",
 	"field-sun-relative+1": "söndag nästa vecka",
 	"field-day-short": "dag",
