@@ -1,6 +1,8 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "ไตรมาสนี้",
+	"field-quarter-short-relative+1": "ไตรมาสหน้า",
 	"field-tue-relative+-1": "อังคารที่แล้ว",
 	"field-year": "ปี",
 	"field-wed-relative+0": "พุธนี้",
@@ -18,15 +20,18 @@ define(
 	"field-week-narrow-relative+0": "สัปดาห์นี้",
 	"field-day-relative+2": "มะรืนนี้",
 	"field-week-narrow-relative+1": "สัปดาห์หน้า",
-	"field-wed-narrow-relative+-1": "พุธที่ผ่านมา",
+	"field-wed-narrow-relative+-1": "พุธที่แล้ว",
 	"field-year-narrow": "ปี",
+	"field-era-short": "สมัย",
 	"field-year-narrow-relative+0": "ปีนี้",
 	"field-tue-relative+0": "อังคารนี้",
 	"field-year-narrow-relative+1": "ปีหน้า",
 	"field-tue-relative+1": "อังคารหน้า",
+	"field-weekdayOfMonth": "วันของเดือน",
 	"field-second-short": "วิ",
 	"dayPeriods-format-narrow-am": "a",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "วันของเดือน",
 	"dayPeriods-format-abbr-am": "ก่อนเที่ยง",
 	"field-week-relative+0": "สัปดาห์นี้",
 	"field-month-relative+0": "เดือนนี้",
@@ -55,18 +60,20 @@ define(
 	"eraNames": [
 		"ฮิจเราะห์ศักราช"
 	],
+	"field-weekOfMonth": "สัปดาห์ของเดือน",
 	"dayPeriods-standAlone-abbr-pm": "หลังเที่ยง",
 	"field-month-short": "เดือน",
 	"dateFormatItem-GyMMMEd": "E d MMM G y",
 	"dateFormatItem-yyyyMd": "d/M/y GGGGG",
 	"field-day": "วัน",
+	"field-dayOfYear-short": "วันของปี",
 	"field-year-relative+-1": "ปีที่แล้ว",
 	"dayPeriods-format-wide-am": "ก่อนเที่ยง",
 	"field-sat-short-relative+-1": "เสาร์ที่แล้ว",
 	"field-hour-relative+0": "ชั่วโมงนี้",
 	"dateFormatItem-yyyyMEd": "E d/M/y GGGGG",
 	"field-wed-relative+-1": "พุธที่แล้ว",
-	"field-sat-narrow-relative+-1": "เสาร์ที่ผ่านมา",
+	"field-sat-narrow-relative+-1": "เสาร์ที่แล้ว",
 	"field-second": "วินาที",
 	"days-standAlone-narrow": [
 		"อา",
@@ -108,7 +115,6 @@ define(
 	"field-month": "เดือน",
 	"field-day-narrow": "วัน",
 	"dateFormatItem-MMM": "LLL",
-	"field-minute-short": "น.",
 	"field-dayperiod": "ช่วงวัน",
 	"field-sat-short-relative+0": "เสาร์นี้",
 	"field-sat-short-relative+1": "เสาร์หน้า",
@@ -148,6 +154,7 @@ define(
 	],
 	"field-quarter-relative+-1": "ไตรมาสที่แล้ว",
 	"dateFormatItem-yyyyMMMd": "d MMM G y",
+	"field-dayperiod-narrow": "ช่วงวัน",
 	"dayPeriods-standAlone-narrow-am": "ก่อนเที่ยง",
 	"field-week-narrow-relative+-1": "สัปดาห์ที่แล้ว",
 	"days-format-short": [
@@ -160,6 +167,7 @@ define(
 		"ส."
 	],
 	"dayPeriods-format-wide-pm": "หลังเที่ยง",
+	"field-dayOfYear": "วันของปี",
 	"field-sat-relative+-1": "เสาร์ที่แล้ว",
 	"dateFormatItem-Md": "d/M",
 	"field-hour": "ชั่วโมง",
@@ -189,6 +197,7 @@ define(
 	"field-sun-short-relative+0": "วันอาทิตย์นี้",
 	"field-sun-short-relative+1": "วันอาทิตย์หน้า",
 	"field-week-relative+-1": "สัปดาห์ที่แล้ว",
+	"field-quarter-short-relative+-1": "ไตรมาสที่แล้ว",
 	"months-format-abbr": [
 		"มุฮัร.",
 		"เศาะ.",
@@ -221,10 +230,11 @@ define(
 		"วันเสาร์"
 	],
 	"dateFormatItem-yyyyMMMEd": "E d MMM G y",
-	"field-mon-narrow-relative+-1": "จันทร์ที่ผ่านมา",
+	"field-mon-narrow-relative+-1": "จันทร์ที่แล้ว",
 	"dateFormatItem-MMMMd": "d MMMM",
-	"field-thu-narrow-relative+-1": "พฤหัสที่ผ่านมา",
-	"field-tue-narrow-relative+-1": "อังคารที่ผ่านมา",
+	"field-thu-narrow-relative+-1": "พฤหัสที่แล้ว",
+	"field-tue-narrow-relative+-1": "อังคารที่แล้ว",
+	"field-weekOfMonth-short": "สัปดาห์ของเดือน",
 	"dateFormatItem-yyyy": "G y",
 	"dayPeriods-standAlone-narrow-pm": "หลังเที่ยง",
 	"field-wed-short-relative+0": "พุธนี้",
@@ -255,12 +265,14 @@ define(
 		"ส."
 	],
 	"dateFormatItem-d": "d",
-	"field-weekday": "วันในสัปดาห์",
+	"field-weekday": "วันของสัปดาห์",
 	"field-day-short-relative+0": "วันนี้",
-	"field-sat-relative+0": "เสาร์นี้",
+	"field-quarter-narrow-relative+0": "ไตรมาสนี้",
 	"field-day-short-relative+1": "พรุ่งนี้",
-	"field-sat-relative+1": "เสาร์หน้า",
+	"field-sat-relative+0": "เสาร์นี้",
+	"field-quarter-narrow-relative+1": "ไตรมาสหน้า",
 	"field-day-short-relative+2": "มะรืนนี้",
+	"field-sat-relative+1": "เสาร์หน้า",
 	"field-week-short-relative+0": "สัปดาห์นี้",
 	"field-week-short-relative+1": "สัปดาห์หน้า",
 	"months-standAlone-abbr": [
@@ -277,15 +289,18 @@ define(
 		"ซุลกิอฺ.",
 		"ซุลหิจ."
 	],
+	"field-dayOfYear-narrow": "วันของปี",
 	"field-month-short-relative+0": "เดือนนี้",
 	"field-month-short-relative+1": "เดือนหน้า",
+	"field-weekdayOfMonth-short": "วันของเดือน",
 	"timeFormat-full": "H นาฬิกา mm นาที ss วินาที zzzz",
 	"dateFormatItem-MEd": "E, d/M",
+	"field-zone-narrow": "เขตเวลา",
 	"dateFormatItem-y": "G y",
 	"field-thu-narrow-relative+0": "พฤหัสนี้",
-	"field-thu-narrow-relative+1": "พฤหัสหน้า",
 	"field-sun-narrow-relative+-1": "วันอาทิตย์ที่แล้ว",
 	"field-mon-short-relative+-1": "จันทร์ที่แล้ว",
+	"field-thu-narrow-relative+1": "พฤหัสหน้า",
 	"field-thu-relative+0": "พฤหัสนี้",
 	"field-thu-relative+1": "พฤหัสหน้า",
 	"field-fri-short-relative+-1": "ศุกร์ที่แล้ว",
@@ -300,8 +315,10 @@ define(
 	"dateFormatItem-Ed": "E d",
 	"field-wed-narrow-relative+0": "พุธนี้",
 	"field-wed-narrow-relative+1": "พุธหน้า",
+	"field-quarter-narrow-relative+-1": "ไตรมาสที่แล้ว",
 	"field-year-short-relative+0": "ปีนี้",
 	"dateFormatItem-yyyyMMM": "MMM G y",
+	"field-dayperiod-short": "ช่วงวัน",
 	"field-year-short-relative+1": "ปีหน้า",
 	"field-fri-short-relative+0": "ศุกร์นี้",
 	"field-fri-short-relative+1": "ศุกร์หน้า",
@@ -317,6 +334,7 @@ define(
 	"field-week-short-relative+-1": "สัปดาห์ที่แล้ว",
 	"dateFormatItem-yyyyQQQQ": "QQQQ G y",
 	"field-hour-short": "ชม.",
+	"field-zone-short": "โซน",
 	"quarters-format-abbr": [
 		"ไตรมาส 1",
 		"ไตรมาส 2",
@@ -325,15 +343,16 @@ define(
 	],
 	"field-month-narrow": "เดือน",
 	"field-hour-narrow": "ชม.",
-	"field-fri-narrow-relative+-1": "ศุกร์ที่ผ่านมา",
+	"field-fri-narrow-relative+-1": "ศุกร์ที่แล้ว",
 	"field-year-relative+0": "ปีนี้",
 	"field-year-relative+1": "ปีหน้า",
+	"field-era-narrow": "สมัย",
 	"field-fri-relative+-1": "ศุกร์ที่แล้ว",
 	"eraNarrow": [
 		"ฮ.ศ."
 	],
 	"field-tue-short-relative+-1": "อังคารที่แล้ว",
-	"field-minute-narrow": "น.",
+	"field-minute-narrow": "นาที",
 	"days-format-wide": [
 		"วันอาทิตย์",
 		"วันจันทร์",
@@ -348,11 +367,14 @@ define(
 	"field-year-short-relative+-1": "ปีที่แล้ว",
 	"field-zone": "เขตเวลา",
 	"dateFormatItem-MMMEd": "E d MMM",
+	"field-weekOfMonth-narrow": "สัปดาห์ของเดือน",
+	"field-weekday-narrow": "วันของสัปดาห์",
 	"field-quarter-narrow": "ไตรมาส",
 	"field-sun-short-relative+-1": "วันอาทิตย์ที่แล้ว",
 	"field-day-relative+-1": "เมื่อวาน",
 	"dayPeriods-standAlone-abbr-am": "ก่อนเที่ยง",
 	"field-day-relative+-2": "เมื่อวานซืน",
+	"field-weekday-short": "วันของสัปดาห์",
 	"days-format-abbr": [
 		"อา.",
 		"จ.",
