@@ -1,28 +1,89 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "şimdi",
-	"field-quarter-relative+-1": "geçen çeyrek",
-	"field-weekday": "haftanın günü",
-	"field-mon-narrow-relative+0": "bu pzt.",
-	"field-mon-narrow-relative+1": "gelecek pzt.",
-	"field-day-narrow-relative+0": "bugün",
-	"field-day-narrow-relative+1": "yarın",
-	"field-day-short-relative+0": "bugün",
-	"field-day-narrow-relative+2": "öbür gün",
-	"field-day-short-relative+1": "yarın",
-	"field-day-short-relative+2": "öbür gün",
+	"field-quarter-short-relative+0": "bu çyr.",
+	"field-quarter-short-relative+1": "gelecek çyr.",
+	"field-tue-relative+-1": "geçen salı",
+	"field-year": "yıl",
 	"field-wed-relative+0": "bu çarşamba",
 	"field-wed-relative+1": "gelecek çarşamba",
-	"field-week-short": "hf.",
-	"field-year-short": "yıl",
-	"field-tue-relative+-1": "geçen salı",
-	"field-thu-narrow-relative+-1": "geçen per.",
+	"field-minute": "dakika",
+	"field-month-narrow-relative+-1": "geçen ay",
+	"field-tue-narrow-relative+0": "bu salı",
+	"field-tue-narrow-relative+1": "gelecek salı",
+	"field-thu-short-relative+0": "bu per.",
+	"field-day-short-relative+-1": "dün",
+	"field-thu-short-relative+1": "gelecek per.",
+	"field-day-relative+0": "bugün",
+	"field-day-short-relative+-2": "evvelsi gün",
+	"field-day-relative+1": "yarın",
+	"field-week-narrow-relative+0": "bu hf.",
+	"field-day-relative+2": "öbür gün",
+	"field-week-narrow-relative+1": "gelecek hf.",
+	"field-wed-narrow-relative+-1": "geçen çar.",
+	"field-year-narrow": "yıl",
+	"field-era-short": "çağ",
+	"field-year-narrow-relative+0": "bu yıl",
+	"field-tue-relative+0": "bu salı",
+	"field-year-narrow-relative+1": "gelecek yıl",
+	"field-tue-relative+1": "gelecek salı",
+	"field-weekdayOfMonth": "ayın günü",
+	"field-second-short": "sn.",
+	"field-weekdayOfMonth-narrow": "ayın günü",
+	"field-week-relative+0": "bu hafta",
+	"field-month-relative+0": "bu ay",
+	"field-week-relative+1": "gelecek hafta",
+	"field-month-relative+1": "gelecek ay",
+	"field-sun-narrow-relative+0": "bu paz.",
+	"field-mon-short-relative+0": "bu pzt.",
+	"field-sun-narrow-relative+1": "gelecek paz.",
+	"field-mon-short-relative+1": "gelecek pzt.",
+	"field-second-relative+0": "şimdi",
+	"eraNames": [
+		"ERA0",
+		"ERA1"
+	],
+	"field-weekOfMonth": "ayın haftası",
+	"field-month-short": "ay",
+	"field-day": "gün",
+	"field-dayOfYear-short": "yılın günü",
+	"field-year-relative+-1": "geçen yıl",
+	"field-sat-short-relative+-1": "geçen cmt.",
 	"field-hour-relative+0": "bu saat",
-	"field-quarter-narrow": "çyr.",
-	"field-fri-relative+-1": "geçen cuma",
-	"field-hour-short": "sa.",
 	"field-wed-relative+-1": "geçen çarşamba",
+	"field-sat-narrow-relative+-1": "geçen cmt.",
+	"field-second": "saniye",
+	"field-quarter": "çeyrek",
+	"field-week-short": "hf.",
+	"field-day-narrow-relative+0": "bugün",
+	"field-day-narrow-relative+1": "yarın",
+	"field-day-narrow-relative+2": "öbür gün",
+	"field-tue-short-relative+0": "bu salı",
+	"field-tue-short-relative+1": "gelecek salı",
+	"field-month-short-relative+-1": "geçen ay",
+	"field-mon-relative+-1": "geçen pazartesi",
+	"field-month": "ay",
+	"field-day-narrow": "gün",
+	"field-minute-short": "dk.",
+	"field-dayperiod": "ÖÖ/ÖS",
+	"field-sat-short-relative+0": "bu cmt.",
+	"field-sat-short-relative+1": "gelecek cmt.",
+	"eraAbbr": [
+		"ERA0",
+		"ERA1"
+	],
+	"field-second-narrow": "sn.",
+	"field-mon-relative+0": "bu pazartesi",
+	"field-mon-relative+1": "gelecek pazartesi",
+	"field-day-narrow-relative+-1": "dün",
+	"field-year-short": "yıl",
+	"field-day-narrow-relative+-2": "evvelsi gün",
+	"field-quarter-relative+-1": "geçen çeyrek",
+	"field-dayperiod-narrow": "ÖÖ/ÖS",
+	"field-week-narrow-relative+-1": "geçen hf.",
+	"field-dayOfYear": "yılın günü",
+	"field-sat-relative+-1": "geçen cumartesi",
+	"field-hour": "saat",
 	"months-format-wide": [
 		"Meskerem",
 		"Tikimt",
@@ -38,117 +99,112 @@ define(
 		"Nehasa",
 		"Pagumiene"
 	],
-	"field-mon-short-relative+-1": "geçen pzt.",
-	"field-day-short-relative+-1": "dün",
-	"field-thu-relative+-1": "geçen perşembe",
-	"field-day-short-relative+-2": "evvelsi gün",
-	"field-era": "Miladi Dönem",
+	"field-month-relative+-1": "geçen ay",
+	"field-quarter-short": "çyr.",
 	"field-sat-narrow-relative+0": "bu cmt.",
+	"field-fri-relative+0": "bu cuma",
 	"field-sat-narrow-relative+1": "gelecek cmt.",
-	"field-year": "yıl",
-	"field-hour": "saat",
-	"field-day-narrow-relative+-1": "dün",
-	"field-sat-relative+0": "bu cumartesi",
-	"field-day-narrow-relative+-2": "evvelsi gün",
-	"field-sat-relative+1": "gelecek cumartesi",
-	"field-sat-short-relative+-1": "geçen cmt.",
-	"field-minute-narrow": "dk.",
-	"field-day-relative+0": "bugün",
-	"field-day-relative+1": "yarın",
-	"field-thu-relative+0": "bu perşembe",
-	"field-day-relative+2": "öbür gün",
-	"field-mon-narrow-relative+-1": "geçen pzt.",
-	"field-wed-narrow-relative+0": "bu çar.",
-	"field-thu-relative+1": "gelecek perşembe",
-	"field-wed-narrow-relative+1": "gelecek çar.",
-	"field-mon-short-relative+0": "bu pzt.",
-	"field-mon-short-relative+1": "gelecek pzt.",
+	"field-fri-relative+1": "gelecek cuma",
+	"field-month-narrow-relative+0": "bu ay",
+	"field-month-narrow-relative+1": "gelecek ay",
+	"field-sun-short-relative+0": "bu paz.",
+	"field-sun-short-relative+1": "gelecek paz.",
+	"field-week-relative+-1": "geçen hafta",
+	"field-quarter-short-relative+-1": "geçen çyr.",
+	"field-quarter-relative+0": "bu çeyrek",
+	"field-minute-relative+0": "bu dakika",
+	"field-quarter-relative+1": "gelecek çeyrek",
 	"field-wed-short-relative+-1": "geçen çar.",
-	"field-fri-narrow-relative+-1": "geçen cuma",
-	"field-hour-narrow": "sa.",
-	"field-year-narrow": "yıl",
-	"field-tue-short-relative+0": "bu salı",
-	"field-tue-short-relative+1": "gelecek salı",
-	"field-minute-short": "dk.",
-	"field-day-narrow": "gün",
+	"field-thu-short-relative+-1": "geçen per.",
 	"field-year-narrow-relative+-1": "geçen yıl",
+	"field-mon-narrow-relative+-1": "geçen pzt.",
+	"field-thu-narrow-relative+-1": "geçen per.",
+	"field-tue-narrow-relative+-1": "geçen salı",
+	"field-weekOfMonth-short": "ayın haftası",
 	"field-wed-short-relative+0": "bu çar.",
+	"months-standAlone-wide": [
+		"Meskerem",
+		"Tikimt",
+		"Hidar",
+		"Tahsas",
+		"Tir",
+		"Yakatit",
+		"Magabit",
+		"Miyazya",
+		"Ginbot",
+		"Sene",
+		"Hamle",
+		"Nehasa",
+		"Pagumiene"
+	],
 	"field-wed-short-relative+1": "gelecek çar.",
-	"field-sun-relative+0": "bu pazar",
-	"field-sun-relative+1": "gelecek pazar",
+	"field-sun-relative+-1": "geçen pazar",
+	"field-weekday": "haftanın günü",
+	"field-day-short-relative+0": "bugün",
+	"field-quarter-narrow-relative+0": "bu çyr.",
+	"field-sat-relative+0": "bu cumartesi",
+	"field-day-short-relative+1": "yarın",
+	"field-quarter-narrow-relative+1": "gelecek çyr.",
+	"field-sat-relative+1": "gelecek cumartesi",
+	"field-day-short-relative+2": "öbür gün",
+	"field-week-short-relative+0": "bu hf.",
+	"field-week-short-relative+1": "gelecek hf.",
+	"field-dayOfYear-narrow": "yılın günü",
+	"field-month-short-relative+0": "bu ay",
+	"field-month-short-relative+1": "gelecek ay",
+	"field-weekdayOfMonth-short": "ayın günü",
+	"field-zone-narrow": "dilim",
+	"field-thu-narrow-relative+0": "bu per.",
+	"field-thu-narrow-relative+1": "gelecek per.",
+	"field-sun-narrow-relative+-1": "geçen paz.",
+	"field-mon-short-relative+-1": "geçen pzt.",
+	"field-thu-relative+0": "bu perşembe",
+	"field-thu-relative+1": "gelecek perşembe",
+	"field-fri-short-relative+-1": "geçen cuma",
+	"field-thu-relative+-1": "geçen perşembe",
+	"field-week": "hafta",
+	"field-wed-narrow-relative+0": "bu çar.",
+	"field-wed-narrow-relative+1": "gelecek çar.",
+	"field-quarter-narrow-relative+-1": "geçen çyr.",
 	"field-year-short-relative+0": "bu yıl",
-	"field-minute": "dakika",
-	"field-month-short": "ay",
+	"field-dayperiod-short": "ÖÖ/ÖS",
 	"field-year-short-relative+1": "gelecek yıl",
-	"field-dayperiod": "ÖÖ/ÖS",
+	"field-fri-short-relative+0": "bu cuma",
+	"field-fri-short-relative+1": "gelecek cuma",
+	"field-week-short-relative+-1": "geçen hf.",
+	"field-hour-short": "sa.",
+	"field-zone-short": "dilim",
+	"field-month-narrow": "ay",
+	"field-hour-narrow": "sa.",
+	"field-fri-narrow-relative+-1": "geçen cuma",
+	"field-year-relative+0": "bu yıl",
+	"field-year-relative+1": "gelecek yıl",
+	"field-era-narrow": "çağ",
+	"field-fri-relative+-1": "geçen cuma",
+	"eraNarrow": [
+		"ERA0",
+		"ERA1"
+	],
+	"field-tue-short-relative+-1": "geçen salı",
+	"field-minute-narrow": "dk.",
+	"field-mon-narrow-relative+0": "bu pzt.",
+	"field-mon-narrow-relative+1": "gelecek pzt.",
+	"field-year-short-relative+-1": "geçen yıl",
+	"field-zone": "saat dilimi",
+	"field-weekOfMonth-narrow": "ayın haftası",
+	"field-weekday-narrow": "haftanın günü",
+	"field-quarter-narrow": "çyr.",
+	"field-sun-short-relative+-1": "geçen paz.",
 	"field-day-relative+-1": "dün",
 	"field-day-relative+-2": "evvelsi gün",
-	"field-minute-relative+0": "bu dakika",
-	"field-week-narrow": "hf.",
-	"field-wed-narrow-relative+-1": "geçen çar.",
+	"field-weekday-short": "haftanın günü",
+	"field-sun-relative+0": "bu pazar",
+	"field-sun-relative+1": "gelecek pazar",
 	"field-day-short": "gün",
-	"field-quarter-relative+0": "bu çeyrek",
-	"field-quarter-relative+1": "gelecek çeyrek",
-	"field-fri-relative+0": "bu cuma",
-	"field-fri-relative+1": "gelecek cuma",
-	"field-day": "gün",
-	"field-second-narrow": "sn.",
-	"field-zone": "saat dilimi",
-	"field-year-relative+-1": "geçen yıl",
-	"field-month-relative+-1": "geçen ay",
-	"field-thu-short-relative+0": "bu per.",
-	"field-thu-short-relative+1": "gelecek per.",
-	"field-quarter": "çeyrek",
-	"field-month": "ay",
-	"field-tue-relative+0": "bu salı",
-	"field-tue-relative+1": "gelecek salı",
+	"field-week-narrow": "hf.",
+	"field-era": "çağ",
 	"field-fri-narrow-relative+0": "bu cuma",
-	"field-fri-narrow-relative+1": "gelecek cuma",
-	"field-fri-short-relative+-1": "geçen cuma",
-	"field-year-narrow-relative+0": "bu yıl",
-	"field-sun-narrow-relative+-1": "geçen paz.",
-	"field-year-narrow-relative+1": "gelecek yıl",
-	"field-sun-narrow-relative+0": "bu paz.",
-	"field-thu-narrow-relative+0": "bu per.",
-	"field-sun-narrow-relative+1": "gelecek paz.",
-	"field-thu-narrow-relative+1": "gelecek per.",
-	"field-tue-narrow-relative+0": "bu salı",
-	"field-mon-relative+0": "bu pazartesi",
-	"field-tue-narrow-relative+1": "gelecek salı",
-	"field-mon-relative+1": "gelecek pazartesi",
-	"field-tue-narrow-relative+-1": "geçen salı",
-	"field-month-narrow-relative+0": "bu ay",
-	"field-second-short": "sn.",
-	"field-month-narrow-relative+1": "gelecek ay",
-	"field-second": "saniye",
-	"field-fri-short-relative+0": "bu cuma",
-	"field-sat-relative+-1": "geçen cumartesi",
-	"field-fri-short-relative+1": "gelecek cuma",
-	"field-sun-relative+-1": "geçen pazar",
-	"field-month-short-relative+0": "bu ay",
-	"field-month-relative+0": "bu ay",
-	"field-month-short-relative+1": "gelecek ay",
-	"field-month-relative+1": "gelecek ay",
-	"field-week": "hafta",
-	"field-sat-short-relative+0": "bu cmt.",
-	"field-sat-short-relative+1": "gelecek cmt.",
-	"field-year-relative+0": "bu yıl",
-	"field-week-relative+-1": "geçen hafta",
-	"field-year-relative+1": "gelecek yıl",
-	"field-year-short-relative+-1": "geçen yıl",
-	"field-quarter-short": "çyr.",
-	"field-sun-short-relative+-1": "geçen paz.",
-	"field-thu-short-relative+-1": "geçen per.",
-	"field-tue-short-relative+-1": "geçen salı",
-	"field-mon-relative+-1": "geçen pazartesi",
-	"field-sat-narrow-relative+-1": "geçen cmt.",
-	"field-month-narrow": "ay",
-	"field-month-narrow-relative+-1": "geçen ay",
-	"field-month-short-relative+-1": "geçen ay",
-	"field-week-relative+0": "bu hafta",
-	"field-sun-short-relative+0": "bu paz.",
-	"field-week-relative+1": "gelecek hafta",
-	"field-sun-short-relative+1": "gelecek paz."
+	"field-fri-narrow-relative+1": "gelecek cuma"
 }
 //end v1.x content
 );
\ No newline at end of file
