@@ -1,6 +1,8 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "bu çyr.",
+	"field-quarter-short-relative+1": "gelecek çyr.",
 	"field-tue-relative+-1": "geçen salı",
 	"field-year": "yıl",
 	"field-wed-relative+0": "bu çarşamba",
@@ -15,16 +17,22 @@ define(
 	"field-day-relative+0": "bugün",
 	"field-day-short-relative+-2": "evvelsi gün",
 	"field-day-relative+1": "yarın",
+	"field-week-narrow-relative+0": "bu hf.",
 	"field-day-relative+2": "öbür gün",
+	"field-week-narrow-relative+1": "gelecek hf.",
 	"field-wed-narrow-relative+-1": "geçen çar.",
+	"dateFormatItem-EBhms": "E B h:mm:ss",
 	"field-year-narrow": "yıl",
+	"field-era-short": "çağ",
 	"field-year-narrow-relative+0": "bu yıl",
 	"field-tue-relative+0": "bu salı",
 	"field-year-narrow-relative+1": "gelecek yıl",
 	"field-tue-relative+1": "gelecek salı",
+	"field-weekdayOfMonth": "ayın günü",
 	"field-second-short": "sn.",
 	"dayPeriods-format-narrow-am": "öö",
 	"dateFormatItem-MMMd": "d MMM",
+	"field-weekdayOfMonth-narrow": "ayın günü",
 	"dayPeriods-format-abbr-am": "ÖÖ",
 	"field-week-relative+0": "bu hafta",
 	"field-month-relative+0": "bu ay",
@@ -50,11 +58,16 @@ define(
 		"K",
 		"A"
 	],
+	"eraNames": [
+		"AP"
+	],
+	"field-weekOfMonth": "ayın haftası",
 	"dayPeriods-standAlone-abbr-pm": "ÖS",
 	"field-month-short": "ay",
 	"dateFormatItem-GyMMMEd": "G d MMM y E",
 	"dateFormatItem-yyyyMd": "GGGGG dd.MM.y",
 	"field-day": "gün",
+	"field-dayOfYear-short": "yılın günü",
 	"field-year-relative+-1": "geçen yıl",
 	"dayPeriods-format-wide-am": "ÖÖ",
 	"field-sat-short-relative+-1": "geçen cmt.",
@@ -109,6 +122,9 @@ define(
 	"dayPeriods-format-narrow-pm": "ös",
 	"dateFormat-medium": "G d MMM y",
 	"dateFormatItem-yyyyMMMM": "G MMMM y",
+	"eraAbbr": [
+		"AP"
+	],
 	"quarters-standAlone-abbr": [
 		"Ç1",
 		"Ç2",
@@ -139,7 +155,9 @@ define(
 	],
 	"field-quarter-relative+-1": "geçen çeyrek",
 	"dateFormatItem-yyyyMMMd": "G dd MMM y",
+	"field-dayperiod-narrow": "ÖÖ/ÖS",
 	"dayPeriods-standAlone-narrow-am": "ÖÖ",
+	"field-week-narrow-relative+-1": "geçen hf.",
 	"days-format-short": [
 		"Pa",
 		"Pt",
@@ -156,6 +174,7 @@ define(
 		"4."
 	],
 	"dayPeriods-format-wide-pm": "ÖS",
+	"field-dayOfYear": "yılın günü",
 	"field-sat-relative+-1": "geçen cumartesi",
 	"dateFormatItem-Md": "dd/MM",
 	"field-hour": "saat",
@@ -180,11 +199,13 @@ define(
 	"field-fri-relative+0": "bu cuma",
 	"field-sat-narrow-relative+1": "gelecek cmt.",
 	"field-fri-relative+1": "gelecek cuma",
+	"dateFormatItem-EBhm": "E B h:mm",
 	"field-month-narrow-relative+0": "bu ay",
 	"field-month-narrow-relative+1": "gelecek ay",
 	"field-sun-short-relative+0": "bu paz.",
 	"field-sun-short-relative+1": "gelecek paz.",
 	"field-week-relative+-1": "geçen hafta",
+	"field-quarter-short-relative+-1": "geçen çyr.",
 	"months-format-abbr": [
 		"Ferverdin",
 		"Ordibeheşt",
@@ -204,6 +225,7 @@ define(
 	"field-quarter-relative+1": "gelecek çeyrek",
 	"field-wed-short-relative+-1": "geçen çar.",
 	"dateFormat-short": "GGGGG d.MM.y",
+	"dateFormatItem-Bh": "B h",
 	"field-thu-short-relative+-1": "geçen per.",
 	"field-year-narrow-relative+-1": "geçen yıl",
 	"days-standAlone-wide": [
@@ -220,6 +242,7 @@ define(
 	"dateFormatItem-MMMMd": "dd MMMM",
 	"field-thu-narrow-relative+-1": "geçen per.",
 	"field-tue-narrow-relative+-1": "geçen salı",
+	"field-weekOfMonth-short": "ayın haftası",
 	"dayPeriods-standAlone-narrow-pm": "ÖS",
 	"field-wed-short-relative+0": "bu çar.",
 	"months-standAlone-wide": [
@@ -249,10 +272,14 @@ define(
 	],
 	"field-weekday": "haftanın günü",
 	"field-day-short-relative+0": "bugün",
+	"field-quarter-narrow-relative+0": "bu çyr.",
 	"field-sat-relative+0": "bu cumartesi",
 	"field-day-short-relative+1": "yarın",
+	"field-quarter-narrow-relative+1": "gelecek çyr.",
 	"field-sat-relative+1": "gelecek cumartesi",
 	"field-day-short-relative+2": "öbür gün",
+	"field-week-short-relative+0": "bu hf.",
+	"field-week-short-relative+1": "gelecek hf.",
 	"months-standAlone-abbr": [
 		"Ferverdin",
 		"Ordibeheşt",
@@ -267,9 +294,12 @@ define(
 		"Behmen",
 		"Esfend"
 	],
+	"field-dayOfYear-narrow": "yılın günü",
 	"field-month-short-relative+0": "bu ay",
 	"field-month-short-relative+1": "gelecek ay",
+	"field-weekdayOfMonth-short": "ayın günü",
 	"dateFormatItem-MEd": "dd/MM E",
+	"field-zone-narrow": "dilim",
 	"field-thu-narrow-relative+0": "bu per.",
 	"field-thu-narrow-relative+1": "gelecek per.",
 	"field-sun-narrow-relative+-1": "geçen paz.",
@@ -294,7 +324,9 @@ define(
 	"dateFormatItem-Ed": "d E",
 	"field-wed-narrow-relative+0": "bu çar.",
 	"field-wed-narrow-relative+1": "gelecek çar.",
+	"field-quarter-narrow-relative+-1": "geçen çyr.",
 	"field-year-short-relative+0": "bu yıl",
+	"field-dayperiod-short": "ÖÖ/ÖS",
 	"dateFormatItem-yyyyMMM": "G MMM y",
 	"field-year-short-relative+1": "gelecek yıl",
 	"field-fri-short-relative+0": "bu cuma",
@@ -308,8 +340,10 @@ define(
 		"Cu",
 		"Ct"
 	],
+	"field-week-short-relative+-1": "geçen hf.",
 	"dateFormatItem-yyyyQQQQ": "G y/QQQQ",
 	"field-hour-short": "sa.",
+	"field-zone-short": "dilim",
 	"quarters-format-abbr": [
 		"Ç1",
 		"Ç2",
@@ -321,7 +355,10 @@ define(
 	"field-fri-narrow-relative+-1": "geçen cuma",
 	"field-year-relative+0": "bu yıl",
 	"field-year-relative+1": "gelecek yıl",
+	"field-era-narrow": "çağ",
 	"field-fri-relative+-1": "geçen cuma",
+	"eraNarrow": "AP",
+	"dateFormatItem-Bhms": "B h:mm:ss",
 	"field-tue-short-relative+-1": "geçen salı",
 	"field-minute-narrow": "dk.",
 	"days-format-wide": [
@@ -338,11 +375,14 @@ define(
 	"field-year-short-relative+-1": "geçen yıl",
 	"field-zone": "saat dilimi",
 	"dateFormatItem-MMMEd": "d MMM E",
+	"field-weekOfMonth-narrow": "ayın haftası",
+	"field-weekday-narrow": "haftanın günü",
 	"field-quarter-narrow": "çyr.",
 	"field-sun-short-relative+-1": "geçen paz.",
 	"field-day-relative+-1": "dün",
 	"dayPeriods-standAlone-abbr-am": "ÖÖ",
 	"field-day-relative+-2": "evvelsi gün",
+	"field-weekday-short": "haftanın günü",
 	"days-format-abbr": [
 		"Paz",
 		"Pzt",
@@ -352,11 +392,12 @@ define(
 		"Cum",
 		"Cmt"
 	],
+	"dateFormatItem-Bhm": "B h:mm",
 	"field-sun-relative+0": "bu pazar",
 	"field-sun-relative+1": "gelecek pazar",
 	"field-day-short": "gün",
 	"field-week-narrow": "hf.",
-	"field-era": "Miladi Dönem",
+	"field-era": "çağ",
 	"field-fri-narrow-relative+0": "bu cuma",
 	"field-fri-narrow-relative+1": "gelecek cuma",
 	"dayPeriods-standAlone-wide-am": "ÖÖ"
