@@ -22,6 +22,7 @@ define(
 	"field-hour-relative+0": "這一小時",
 	"field-fri-relative+-1": "上週五",
 	"field-wed-relative+-1": "上週三",
+	"field-dayOfYear": "年天",
 	"months-format-wide": [
 		"1月",
 		"2月",
@@ -36,6 +37,7 @@ define(
 		"11月",
 		"12月"
 	],
+	"dateTimeFormat-medium": "{1} {0}",
 	"dateFormat-full": "y年M月d日 EEEE",
 	"field-thu-relative+-1": "上週四",
 	"field-era": "年代",
@@ -65,8 +67,9 @@ define(
 	"field-hour": "小時",
 	"field-sat-relative+0": "本週六",
 	"field-sat-relative+1": "下週六",
+	"dateFormatItem-EBhms": "E Bh:mm:ss",
 	"timeFormat-full": "ah:mm:ss [zzzz]",
-	"dateFormatItem-MMMMW": "MMM的第W週",
+	"dateFormatItem-MMMMW": "MMMM的第W週",
 	"field-thu-relative+0": "本週四",
 	"field-thu-relative+1": "下週四",
 	"field-day-relative+2": "後天",
@@ -84,6 +87,7 @@ define(
 		"第4季"
 	],
 	"field-sun-relative+0": "本週日",
+	"dateFormatItem-Bh": "Bh時",
 	"field-sun-relative+1": "下週日",
 	"quarters-standAlone-abbr": [
 		"第1季",
@@ -91,7 +95,7 @@ define(
 		"第3季",
 		"第4季"
 	],
-	"dateFormatItem-yw": "y年的第w週",
+	"dateFormatItem-yw": "Y年的第w週",
 	"eraAbbr": [
 		"西元前",
 		"西元"
@@ -102,6 +106,7 @@ define(
 	"field-quarter-relative+0": "這一季",
 	"field-quarter-relative+1": "下一季",
 	"dateFormatItem-MEd": "M/d（E）",
+	"dateTimeFormat-full": "{1} {0}",
 	"field-fri-relative+0": "本週五",
 	"field-fri-relative+1": "下週五",
 	"field-zone": "時區",
@@ -111,8 +116,10 @@ define(
 		"西元"
 	],
 	"field-quarter": "季",
+	"field-weekOfMonth": "週",
 	"field-tue-relative+0": "本週二",
 	"field-tue-relative+1": "下週二",
+	"dateFormatItem-EBhm": "E Bh:mm",
 	"dateFormatItem-EHm": "E HH:mm",
 	"field-mon-relative+0": "本週一",
 	"field-mon-relative+1": "下週一",
@@ -121,6 +128,7 @@ define(
 	"field-sat-relative+-1": "上週六",
 	"dateFormatItem-yMMMEd": "y年M月d日 E",
 	"field-sun-relative+-1": "上週日",
+	"field-weekdayOfMonth": "每月平日",
 	"field-month-relative+1": "下個月",
 	"dateFormatItem-Ed": "d E",
 	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
@@ -130,6 +138,7 @@ define(
 	"dateFormatItem-Hmv": "HH:mm [v]",
 	"dateFormatItem-hmv": "ah:mm [v]",
 	"field-mon-relative+-1": "上週一",
+	"dayPeriods-format-abbr-morning1": "清晨",
 	"field-week-relative+0": "本週",
 	"field-week-relative+1": "下週"
 }
