@@ -1,26 +1,39 @@
 define(
 //begin v1.x content
 {
+	"field-quarter-short-relative+0": "本季度",
+	"field-quarter-short-relative+1": "下季度",
 	"field-tue-relative+-1": "上周二",
 	"field-year": "年",
 	"field-wed-relative+0": "本周三",
 	"field-wed-relative+1": "下周三",
 	"timeFormat-short": "ah:mm",
 	"field-minute": "分钟",
+	"field-month-narrow-relative+-1": "上个月",
 	"field-tue-narrow-relative+0": "本周二",
 	"field-tue-narrow-relative+1": "下周二",
 	"field-thu-short-relative+0": "本周四",
+	"field-day-short-relative+-1": "昨天",
 	"field-thu-short-relative+1": "下周四",
 	"field-day-relative+0": "今天",
+	"field-day-short-relative+-2": "前天",
 	"field-day-relative+1": "明天",
+	"field-week-narrow-relative+0": "本周",
 	"field-day-relative+2": "后天",
+	"field-week-narrow-relative+1": "下周",
 	"field-wed-narrow-relative+-1": "上周三",
+	"dateFormatItem-EBhms": "EB h:mm:ss",
 	"field-year-narrow": "年",
+	"field-era-short": "纪元",
+	"field-year-narrow-relative+0": "今年",
 	"field-tue-relative+0": "本周二",
+	"field-year-narrow-relative+1": "明年",
 	"field-tue-relative+1": "下周二",
+	"field-weekdayOfMonth": "月中日",
 	"field-second-short": "秒",
 	"dayPeriods-format-narrow-am": "上午",
 	"dateFormatItem-MMMd": "M月d日",
+	"field-weekdayOfMonth-narrow": "月中日",
 	"dayPeriods-format-abbr-am": "上午",
 	"field-week-relative+0": "本周",
 	"field-month-relative+0": "本月",
@@ -51,16 +64,19 @@ define(
 	"eraNames": [
 		"希伯来历"
 	],
+	"field-weekOfMonth": "月中周",
 	"dayPeriods-standAlone-abbr-pm": "下午",
 	"field-month-short": "月",
 	"dateFormatItem-GyMMMEd": "Gy年MM月d日E",
 	"dateFormatItem-yyyyMd": "G y/M/d",
 	"field-day": "日",
+	"field-dayOfYear-short": "年中日",
 	"field-year-relative+-1": "去年",
 	"dayPeriods-format-wide-am": "上午",
 	"field-sat-short-relative+-1": "上周六",
 	"field-hour-relative+0": "这一时间 / 此时",
 	"dateFormatItem-yyyyMEd": "G y/M/dE",
+	"field-second-short-relative+0": "现在",
 	"field-wed-relative+-1": "上周三",
 	"field-sat-narrow-relative+-1": "上周六",
 	"field-second": "秒",
@@ -74,10 +90,15 @@ define(
 		"六"
 	],
 	"dayPeriods-standAlone-wide-pm": "下午",
+	"dateFormatItem-Ehms": "Ea h:mm:ss",
 	"dateFormat-long": "Gy年M月d日",
 	"dateFormatItem-GyMMMd": "Gy年MM月d日",
+	"field-hour-short-relative+0": "这一时间 / 此时",
 	"field-quarter": "季度",
 	"field-week-short": "周",
+	"field-day-narrow-relative+0": "今天",
+	"field-day-narrow-relative+1": "明天",
+	"field-day-narrow-relative+2": "后天",
 	"quarters-standAlone-wide": [
 		"第一季度",
 		"第二季度",
@@ -95,6 +116,7 @@ define(
 	],
 	"field-tue-short-relative+0": "本周二",
 	"field-tue-short-relative+1": "下周二",
+	"field-month-short-relative+-1": "上个月",
 	"field-mon-relative+-1": "上周一",
 	"dateFormatItem-GyMMM": "Gy年MM月",
 	"field-month": "月",
@@ -121,10 +143,14 @@ define(
 	"field-second-narrow": "秒",
 	"field-mon-relative+0": "本周一",
 	"field-mon-relative+1": "下周一",
+	"field-day-narrow-relative+-1": "昨天",
 	"field-year-short": "年",
+	"field-day-narrow-relative+-2": "前天",
 	"field-quarter-relative+-1": "上季度",
 	"dateFormatItem-yyyyMMMd": "Gy年MM月d日",
+	"field-dayperiod-narrow": "上午/下午",
 	"dayPeriods-standAlone-narrow-am": "上午",
+	"field-week-narrow-relative+-1": "上周",
 	"days-format-short": [
 		"周日",
 		"周一",
@@ -135,8 +161,10 @@ define(
 		"周六"
 	],
 	"dayPeriods-format-wide-pm": "下午",
+	"field-dayOfYear": "年中日",
 	"field-sat-relative+-1": "上周六",
 	"dateFormatItem-Md": "M/d",
+	"field-minute-narrow-relative+0": "此刻",
 	"field-hour": "小时",
 	"months-format-wide": [
 		"一月",
@@ -160,9 +188,15 @@ define(
 	"field-fri-relative+0": "本周五",
 	"field-sat-narrow-relative+1": "下周六",
 	"field-fri-relative+1": "下周五",
+	"dateFormatItem-EBhm": "EB h:mm",
+	"field-month-narrow-relative+0": "本月",
+	"field-month-narrow-relative+1": "下个月",
 	"field-sun-short-relative+0": "本周日",
 	"field-sun-short-relative+1": "下周日",
 	"field-week-relative+-1": "上周",
+	"field-quarter-short-relative+-1": "上季度",
+	"field-minute-short-relative+0": "此刻",
+	"dateFormatItem-Ehm": "Ea h:mm",
 	"months-format-abbr": [
 		"1月",
 		"2月",
@@ -184,7 +218,9 @@ define(
 	"field-quarter-relative+1": "下季度",
 	"field-wed-short-relative+-1": "上周三",
 	"dateFormat-short": "Gy-M-d",
+	"dateFormatItem-Bh": "Bh时",
 	"field-thu-short-relative+-1": "上周四",
+	"field-year-narrow-relative+-1": "去年",
 	"days-standAlone-wide": [
 		"星期日",
 		"星期一",
@@ -198,11 +234,11 @@ define(
 	"field-mon-narrow-relative+-1": "上周一",
 	"dateFormatItem-MMMMd": "M月d日",
 	"field-thu-narrow-relative+-1": "上周四",
+	"field-weekOfMonth-short": "月中周",
 	"field-tue-narrow-relative+-1": "上周二",
 	"dateFormatItem-H": "H时",
 	"dateFormatItem-yyyy": "Gy年",
 	"dayPeriods-standAlone-narrow-pm": "下午",
-	"field-wed-short-relative+0": "本周三",
 	"months-standAlone-wide": [
 		"一月",
 		"二月",
@@ -218,6 +254,7 @@ define(
 		"十二月",
 		"十三月"
 	],
+	"field-wed-short-relative+0": "本周三",
 	"field-wed-short-relative+1": "下周三",
 	"field-sun-relative+-1": "上周日",
 	"days-standAlone-abbr": [
@@ -229,14 +266,22 @@ define(
 		"周五",
 		"周六"
 	],
+	"field-second-narrow-relative+0": "现在",
 	"dateFormatItem-hm": "ah:mm",
 	"months-format-abbr-leap": "闰7月",
 	"dateFormatItem-d": "d日",
 	"field-weekday": "工作日",
 	"months-standAlone-narrow-leap": "7",
+	"field-day-short-relative+0": "今天",
+	"field-quarter-narrow-relative+0": "本季度",
+	"field-day-short-relative+1": "明天",
 	"field-sat-relative+0": "本周六",
-	"dateFormatItem-h": "ah时",
+	"field-quarter-narrow-relative+1": "下季度",
+	"field-day-short-relative+2": "后天",
 	"field-sat-relative+1": "下周六",
+	"dateFormatItem-h": "ah时",
+	"field-week-short-relative+0": "本周",
+	"field-week-short-relative+1": "下周",
 	"months-standAlone-abbr": [
 		"1月",
 		"2月",
@@ -253,17 +298,22 @@ define(
 		"13月"
 	],
 	"months-format-wide-leap": "闰七月",
+	"field-dayOfYear-narrow": "年中日",
+	"field-month-short-relative+0": "本月",
+	"field-month-short-relative+1": "下个月",
+	"field-weekdayOfMonth-short": "月中日",
 	"timeFormat-full": "zzzz ah:mm:ss",
 	"dateFormatItem-MEd": "M/dE",
+	"field-zone-narrow": "时区",
 	"dateFormatItem-y": "Gy年",
 	"field-thu-narrow-relative+0": "本周四",
-	"field-thu-narrow-relative+1": "下周四",
 	"field-sun-narrow-relative+-1": "上周日",
 	"field-mon-short-relative+-1": "上周一",
+	"field-thu-narrow-relative+1": "下周四",
 	"field-thu-relative+0": "本周四",
 	"field-thu-relative+1": "下周四",
-	"dateFormatItem-hms": "ah:mm:ss",
 	"field-fri-short-relative+-1": "上周五",
+	"dateFormatItem-hms": "ah:mm:ss",
 	"field-thu-relative+-1": "上周四",
 	"field-week": "周",
 	"quarters-format-wide": [
@@ -275,7 +325,11 @@ define(
 	"dateFormatItem-Ed": "d日E",
 	"field-wed-narrow-relative+0": "本周三",
 	"field-wed-narrow-relative+1": "下周三",
+	"field-quarter-narrow-relative+-1": "上季度",
+	"field-year-short-relative+0": "今年",
 	"dateFormatItem-yyyyMMM": "Gy年MM月",
+	"field-dayperiod-short": "上午/下午",
+	"field-year-short-relative+1": "明年",
 	"field-fri-short-relative+0": "本周五",
 	"field-fri-short-relative+1": "下周五",
 	"days-standAlone-short": [
@@ -287,9 +341,12 @@ define(
 		"周五",
 		"周六"
 	],
+	"field-week-short-relative+-1": "上周",
 	"months-standAlone-abbr-leap": "闰7月",
+	"field-hour-narrow-relative+0": "这一时间 / 此时",
 	"dateFormatItem-yyyyQQQQ": "Gy年第Q季度",
 	"field-hour-short": "小时",
+	"field-zone-short": "时区",
 	"quarters-format-abbr": [
 		"1季度",
 		"2季度",
@@ -301,10 +358,10 @@ define(
 	"field-fri-narrow-relative+-1": "上周五",
 	"field-year-relative+0": "今年",
 	"field-year-relative+1": "明年",
+	"field-era-narrow": "纪元",
 	"field-fri-relative+-1": "上周五",
-	"eraNarrow": [
-		"希伯来历"
-	],
+	"eraNarrow": "希伯来历",
+	"dateFormatItem-Bhms": "Bh:mm:ss",
 	"field-tue-short-relative+-1": "上周二",
 	"field-minute-narrow": "分",
 	"days-format-wide": [
@@ -318,14 +375,18 @@ define(
 	],
 	"field-mon-narrow-relative+0": "本周一",
 	"field-mon-narrow-relative+1": "下周一",
+	"field-year-short-relative+-1": "去年",
 	"field-zone": "时区",
 	"dateFormatItem-MMMEd": "M月d日E",
+	"field-weekOfMonth-narrow": "月中周",
+	"field-weekday-narrow": "工作日",
 	"months-standAlone-wide-leap": "闰七月",
 	"field-quarter-narrow": "季",
 	"field-sun-short-relative+-1": "上周日",
 	"field-day-relative+-1": "昨天",
 	"dayPeriods-standAlone-abbr-am": "上午",
 	"field-day-relative+-2": "前天",
+	"field-weekday-short": "工作日",
 	"days-format-abbr": [
 		"周日",
 		"周一",
@@ -335,6 +396,7 @@ define(
 		"周五",
 		"周六"
 	],
+	"dateFormatItem-Bhm": "Bh:mm",
 	"field-sun-relative+0": "本周日",
 	"field-sun-relative+1": "下周日",
 	"dateFormatItem-Gy": "Gy年",
