@@ -1,150 +1,215 @@
 define(
 //begin v1.x content
 {
-	"field-second-relative+0": "现在",
-	"field-quarter-relative+-1": "上季度",
-	"field-weekday": "工作日",
-	"field-mon-narrow-relative+0": "本周一",
-	"field-mon-narrow-relative+1": "下周一",
-	"field-wed-relative+0": "本周三",
-	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
-	"dateFormatItem-MMMEd": "M月d日E",
-	"field-wed-relative+1": "下周三",
-	"field-week-short": "周",
-	"field-year-short": "年",
+	"field-quarter-short-relative+0": "本季度",
+	"field-quarter-short-relative+1": "下季度",
 	"field-tue-relative+-1": "上周二",
-	"field-thu-narrow-relative+-1": "上周四",
-	"field-hour-relative+0": "这一时间 / 此时",
-	"dateFormat-long": "Gy年M月d日",
-	"field-quarter-narrow": "季",
-	"field-fri-relative+-1": "上周五",
-	"field-hour-short": "小时",
-	"field-wed-relative+-1": "上周三",
-	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
-	"dateFormat-full": "Gy年M月d日EEEE",
-	"dateFormatItem-yyyyMEd": "Gy/M/dE",
-	"field-mon-short-relative+-1": "上周一",
-	"field-thu-relative+-1": "上周四",
-	"dateFormatItem-Md": "M/d",
-	"field-era": "纪元",
-	"field-sat-narrow-relative+0": "本周六",
-	"field-sat-narrow-relative+1": "下周六",
 	"field-year": "年",
-	"dateFormatItem-yyyyMMMM": "Gy年M月",
-	"field-hour": "小时",
-	"field-sat-relative+0": "本周六",
-	"field-sat-relative+1": "下周六",
-	"field-sat-short-relative+-1": "上周六",
-	"field-minute-narrow": "分",
-	"dateFormatItem-E": "ccc",
+	"field-wed-relative+0": "本周三",
+	"field-wed-relative+1": "下周三",
+	"field-minute": "分钟",
+	"field-month-narrow-relative+-1": "上个月",
+	"field-tue-narrow-relative+0": "本周二",
+	"field-tue-narrow-relative+1": "下周二",
+	"field-day-short-relative+-1": "昨天",
+	"field-thu-short-relative+0": "本周四",
 	"field-day-relative+0": "今天",
+	"field-day-short-relative+-2": "前天",
+	"field-thu-short-relative+1": "下周四",
 	"field-day-relative+1": "明天",
-	"field-thu-relative+0": "本周四",
-	"dateFormatItem-GyMMMd": "Gy年M月d日",
+	"field-week-narrow-relative+0": "本周",
 	"field-day-relative+2": "后天",
-	"field-mon-narrow-relative+-1": "上周一",
-	"field-wed-narrow-relative+0": "本周三",
-	"field-thu-relative+1": "下周四",
-	"field-wed-narrow-relative+1": "下周三",
-	"dateFormatItem-Gy": "Gy年",
-	"field-mon-short-relative+0": "本周一",
-	"field-mon-short-relative+1": "下周一",
-	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
-	"dateFormatItem-M": "M月",
-	"field-wed-short-relative+-1": "上周三",
-	"field-fri-narrow-relative+-1": "上周五",
-	"dateFormatItem-yyyyMMM": "Gy年M月",
-	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
-	"dateFormatItem-MMMMd": "M月d日",
-	"field-hour-narrow": "小时",
+	"field-week-narrow-relative+1": "下周",
+	"field-wed-narrow-relative+-1": "上周三",
 	"field-year-narrow": "年",
+	"field-era-short": "纪元",
+	"field-year-narrow-relative+0": "今年",
+	"field-tue-relative+0": "本周二",
+	"field-year-narrow-relative+1": "明年",
+	"field-tue-relative+1": "下周二",
+	"field-weekdayOfMonth": "月中日",
+	"field-second-short": "秒",
+	"dateFormatItem-MMMd": "M月d日",
+	"field-weekdayOfMonth-narrow": "月中日",
+	"field-week-relative+0": "本周",
+	"field-month-relative+0": "本月",
+	"field-week-relative+1": "下周",
+	"field-month-relative+1": "下个月",
+	"field-sun-narrow-relative+0": "本周日",
+	"field-mon-short-relative+0": "本周一",
+	"field-sun-narrow-relative+1": "下周日",
+	"field-mon-short-relative+1": "下周一",
+	"field-second-relative+0": "现在",
+	"dateFormatItem-yyyyQQQ": "Gy年第Q季度",
+	"eraNames": [
+		"民国前",
+		"民国"
+	],
+	"field-weekOfMonth": "月中周",
+	"field-month-short": "月",
+	"dateFormatItem-GyMMMEd": "Gy年M月d日E",
+	"dateFormatItem-yyyyMd": "Gy/M/d",
+	"field-day": "日",
+	"field-dayOfYear-short": "年中日",
+	"field-year-relative+-1": "去年",
+	"field-sat-short-relative+-1": "上周六",
+	"field-hour-relative+0": "这一时间 / 此时",
+	"dateFormatItem-yyyyMEd": "Gy/M/dE",
+	"field-second-short-relative+0": "现在",
+	"field-wed-relative+-1": "上周三",
+	"field-sat-narrow-relative+-1": "上周六",
+	"field-second": "秒",
+	"dateFormat-long": "Gy年M月d日",
+	"dateFormatItem-GyMMMd": "Gy年M月d日",
+	"field-hour-short-relative+0": "这一时间 / 此时",
+	"field-quarter": "季度",
+	"field-week-short": "周",
+	"field-day-narrow-relative+0": "今天",
+	"field-day-narrow-relative+1": "明天",
+	"field-day-narrow-relative+2": "后天",
 	"field-tue-short-relative+0": "本周二",
 	"field-tue-short-relative+1": "下周二",
-	"field-minute-short": "分",
+	"field-month-short-relative+-1": "上个月",
+	"field-mon-relative+-1": "上周一",
+	"dateFormatItem-GyMMM": "Gy年M月",
+	"field-month": "月",
 	"field-day-narrow": "日",
-	"field-wed-short-relative+0": "本周三",
-	"field-wed-short-relative+1": "下周三",
-	"field-sun-relative+0": "本周日",
-	"field-sun-relative+1": "下周日",
+	"dateFormatItem-MMM": "LLL",
+	"field-minute-short": "分",
+	"field-dayperiod": "上午/下午",
+	"field-sat-short-relative+0": "本周六",
+	"field-sat-short-relative+1": "下周六",
+	"dateFormat-medium": "Gy年M月d日",
+	"dateFormatItem-yyyyMMMM": "Gy年M月",
 	"eraAbbr": [
 		"民国前",
 		"民国"
 	],
-	"field-minute": "分钟",
-	"field-month-short": "月",
-	"field-dayperiod": "上午/下午",
+	"dateFormatItem-yyyyM": "Gy年M月",
+	"field-second-narrow": "秒",
+	"field-mon-relative+0": "本周一",
+	"field-mon-relative+1": "下周一",
+	"field-day-narrow-relative+-1": "昨天",
+	"field-year-short": "年",
+	"field-day-narrow-relative+-2": "前天",
+	"field-quarter-relative+-1": "上季度",
+	"dateFormatItem-yyyyMMMd": "Gy年M月d日",
+	"field-dayperiod-narrow": "上午/下午",
+	"field-week-narrow-relative+-1": "上周",
+	"field-dayOfYear": "年中日",
+	"field-sat-relative+-1": "上周六",
+	"dateFormatItem-Md": "M/d",
+	"field-hour": "小时",
+	"field-minute-narrow-relative+0": "此刻",
+	"dateFormat-full": "Gy年M月d日EEEE",
+	"field-month-relative+-1": "上个月",
+	"field-quarter-short": "季",
+	"field-sat-narrow-relative+0": "本周六",
+	"field-fri-relative+0": "本周五",
+	"field-sat-narrow-relative+1": "下周六",
+	"field-fri-relative+1": "下周五",
+	"field-month-narrow-relative+0": "本月",
+	"field-month-narrow-relative+1": "下个月",
+	"field-sun-short-relative+0": "本周日",
+	"field-sun-short-relative+1": "下周日",
+	"field-week-relative+-1": "上周",
+	"field-quarter-short-relative+-1": "上季度",
+	"field-minute-short-relative+0": "此刻",
+	"field-quarter-relative+0": "本季度",
+	"field-minute-relative+0": "此刻",
+	"field-quarter-relative+1": "下季度",
+	"field-wed-short-relative+-1": "上周三",
+	"dateFormat-short": "Gy/M/d",
+	"field-year-narrow-relative+-1": "去年",
+	"field-thu-short-relative+-1": "上周四",
+	"dateFormatItem-yyyyMMMEd": "Gy年M月d日E",
+	"field-mon-narrow-relative+-1": "上周一",
+	"dateFormatItem-MMMMd": "M月d日",
+	"field-thu-narrow-relative+-1": "上周四",
+	"dateFormatItem-E": "ccc",
+	"field-tue-narrow-relative+-1": "上周二",
+	"field-weekOfMonth-short": "月中周",
+	"dateFormatItem-yyyy": "Gy年",
+	"dateFormatItem-M": "M月",
+	"field-wed-short-relative+0": "本周三",
+	"field-wed-short-relative+1": "下周三",
+	"field-sun-relative+-1": "上周日",
+	"field-second-narrow-relative+0": "现在",
 	"dateFormatItem-d": "d日",
+	"field-weekday": "工作日",
+	"field-day-short-relative+0": "今天",
+	"field-quarter-narrow-relative+0": "本季度",
+	"field-day-short-relative+1": "明天",
+	"field-sat-relative+0": "本周六",
+	"field-quarter-narrow-relative+1": "下季度",
+	"field-day-short-relative+2": "后天",
+	"field-sat-relative+1": "下周六",
+	"field-week-short-relative+0": "本周",
+	"field-week-short-relative+1": "下周",
+	"field-dayOfYear-narrow": "年中日",
+	"field-month-short-relative+0": "本月",
+	"field-month-short-relative+1": "下个月",
+	"field-weekdayOfMonth-short": "月中日",
+	"dateFormatItem-MEd": "M/dE",
+	"field-zone-narrow": "时区",
+	"dateFormatItem-y": "Gy年",
+	"field-thu-narrow-relative+0": "本周四",
+	"field-sun-narrow-relative+-1": "上周日",
+	"field-mon-short-relative+-1": "上周一",
+	"field-thu-narrow-relative+1": "下周四",
+	"field-thu-relative+0": "本周四",
+	"field-thu-relative+1": "下周四",
+	"field-fri-short-relative+-1": "上周五",
+	"field-thu-relative+-1": "上周四",
+	"field-week": "周",
+	"dateFormatItem-Ed": "d日E",
+	"field-wed-narrow-relative+0": "本周三",
+	"field-wed-narrow-relative+1": "下周三",
+	"field-quarter-narrow-relative+-1": "上季度",
+	"field-year-short-relative+0": "今年",
+	"dateFormatItem-yyyyMMM": "Gy年M月",
+	"field-dayperiod-short": "上午/下午",
+	"field-year-short-relative+1": "明年",
+	"field-fri-short-relative+0": "本周五",
+	"field-fri-short-relative+1": "下周五",
+	"field-week-short-relative+-1": "上周",
+	"field-hour-narrow-relative+0": "这一时间 / 此时",
+	"dateFormatItem-yyyyQQQQ": "Gy年第Q季度",
+	"field-hour-short": "小时",
+	"field-zone-short": "时区",
+	"field-month-narrow": "月",
+	"field-hour-narrow": "小时",
+	"field-fri-narrow-relative+-1": "上周五",
+	"field-year-relative+0": "今年",
+	"field-year-relative+1": "明年",
+	"field-era-narrow": "纪元",
+	"field-fri-relative+-1": "上周五",
+	"eraNarrow": [
+		"民国前",
+		"民国"
+	],
+	"field-tue-short-relative+-1": "上周二",
+	"field-minute-narrow": "分",
+	"field-mon-narrow-relative+0": "本周一",
+	"field-mon-narrow-relative+1": "下周一",
+	"field-year-short-relative+-1": "去年",
+	"field-zone": "时区",
+	"dateFormatItem-MMMEd": "M月d日E",
+	"field-weekOfMonth-narrow": "月中周",
+	"field-weekday-narrow": "工作日",
+	"field-quarter-narrow": "季",
+	"field-sun-short-relative+-1": "上周日",
 	"field-day-relative+-1": "昨天",
 	"field-day-relative+-2": "前天",
-	"field-minute-relative+0": "此刻",
-	"field-week-narrow": "周",
-	"field-wed-narrow-relative+-1": "上周三",
-	"dateFormatItem-MMMd": "M月d日",
+	"field-weekday-short": "工作日",
+	"field-sun-relative+0": "本周日",
+	"field-sun-relative+1": "下周日",
+	"dateFormatItem-Gy": "Gy年",
 	"field-day-short": "日",
-	"field-quarter-relative+0": "本季度",
-	"field-quarter-relative+1": "下季度",
-	"dateFormatItem-MEd": "M/dE",
-	"field-fri-relative+0": "本周五",
-	"field-fri-relative+1": "下周五",
-	"field-day": "日",
-	"field-second-narrow": "秒",
-	"field-zone": "时区",
-	"dateFormatItem-y": "Gy年",
-	"field-year-relative+-1": "去年",
-	"field-month-relative+-1": "上个月",
-	"field-thu-short-relative+0": "本周四",
-	"field-thu-short-relative+1": "下周四",
-	"field-quarter": "季度",
-	"dateFormatItem-yyyyMd": "Gy/M/d",
-	"field-month": "月",
-	"dateFormatItem-MMM": "LLL",
-	"field-tue-relative+0": "本周二",
-	"field-tue-relative+1": "下周二",
+	"field-week-narrow": "周",
+	"field-era": "纪元",
 	"field-fri-narrow-relative+0": "本周五",
-	"field-fri-narrow-relative+1": "下周五",
-	"field-fri-short-relative+-1": "上周五",
-	"field-sun-narrow-relative+-1": "上周日",
-	"field-sun-narrow-relative+0": "本周日",
-	"field-thu-narrow-relative+0": "本周四",
-	"field-sun-narrow-relative+1": "下周日",
-	"field-thu-narrow-relative+1": "下周四",
-	"field-tue-narrow-relative+0": "本周二",
-	"field-mon-relative+0": "本周一",
-	"field-tue-narrow-relative+1": "下周二",
-	"field-mon-relative+1": "下周一",
-	"dateFormat-short": "Gyy/M/d",
-	"field-tue-narrow-relative+-1": "上周二",
-	"field-second-short": "秒",
-	"field-second": "秒",
-	"field-fri-short-relative+0": "本周五",
-	"field-sat-relative+-1": "上周六",
-	"field-fri-short-relative+1": "下周五",
-	"field-sun-relative+-1": "上周日",
-	"field-month-relative+0": "本月",
-	"field-month-relative+1": "下个月",
-	"dateFormatItem-Ed": "d日E",
-	"field-week": "周",
-	"field-sat-short-relative+0": "本周六",
-	"dateFormat-medium": "Gy年M月d日",
-	"field-sat-short-relative+1": "下周六",
-	"field-year-relative+0": "今年",
-	"field-week-relative+-1": "上周",
-	"dateFormatItem-yyyyM": "Gy年M月",
-	"field-year-relative+1": "明年",
-	"dateFormatItem-yyyyQQQQ": "Gy年第Q季度",
-	"field-quarter-short": "季",
-	"field-sun-short-relative+-1": "上周日",
-	"field-thu-short-relative+-1": "上周四",
-	"field-tue-short-relative+-1": "上周二",
-	"dateFormatItem-GyMMM": "Gy年M月",
-	"field-mon-relative+-1": "上周一",
-	"field-sat-narrow-relative+-1": "上周六",
-	"field-month-narrow": "月",
-	"dateFormatItem-yyyy": "Gy年",
-	"field-week-relative+0": "本周",
-	"field-sun-short-relative+0": "本周日",
-	"field-week-relative+1": "下周",
-	"field-sun-short-relative+1": "下周日"
+	"field-fri-narrow-relative+1": "下周五"
 }
 //end v1.x content
 );
\ No newline at end of file
